(* MayCottBach.m *)
(*

Date last modified:  24 June 2004

24 June 2004 Adding SwapCY.
17 June 2004 Adding Bianchi rules for CY.
16 June 2004 Adding CYDDCYDDToBBCYDDCYDD

I checked and tested this file carefully on 7 June 2004.

7 June 2004 Adding CYCYToBBCYCY and CYCYToCYDDCY.
7 June 2004 Adding CYSkew rule.
6 June 2004 Changing so as to make consistent with conventions stated
            in Rod's message of 5-6 June 2004.
4 June 2004 Copying over from Cotton.m

This file contains definitions relating to the Cotton-York tensor and
the Bach tensor.

I checked this file over and tested it on 5 June 2004.

*)
(**************************************)
(* Start with the Cotton-York tensor. *)
(**************************************)
(*
See Rod's message of 7 July 2002.
Rod's message of 5-6 June 2004 supersedes the message from 7 July 2002.
*)

DefineTensor[CY,3];

DefineRule[CYToP,CY[L[i],L[j],L[k]],
  P[L[i],L[k]][L[j]]-P[L[i],L[j]][L[k]],
  NewRule->True];
DefineRule[CYSkew,CY[L[i],L[j],L[k]],
                 -CY[L[i],L[k],L[j]],NewRule->True];

(******************************************************)

DefineRule[KillCYTrace,CY[L[i],U[i],L[j]],0,NewRule->True];
DefineRule[KillCYTrace,CY[L[i],L[j],U[i]],0];
DefineRule[KillCYTrace,CY[L[i],L[j],U[j]],0];

DefineRule[CYToDivWeyl,
           CY[L[j],L[k],L[l]],
           (1/(n-3))Weyl[L[i],L[j],L[k],L[l]][U[i]],
           NewRule->True];

DefineRule[DivWeylToCY,
           Weyl[L[i],L[j],L[k],L[l]][U[i]],
           (n-3)CY[L[j],L[k],L[l]],
           NewRule->True];

DefineRule[DivWeylToCY,
           Weyl[L[j],L[i],L[k],L[l]][U[i]],
           -(n-3)CY[L[j],L[k],L[l]]];

DefineRule[DivWeylToCY,
           Weyl[L[k],L[l],L[i],L[j]][U[i]],
           (n-3)CY[L[j],L[k],L[l]]];

DefineRule[DivWeylToCY,
           Weyl[L[k],L[l],L[j],L[i]][U[i]],
           -(n-3)CY[L[j],L[k],L[l]]];

(*******************************************************)

DefineRule[PToCYOne,
  P[L[i],L[j]][L[k]],
  CY[L[j],L[k],L[i]]+P[L[k],L[j]][L[i]],NewRule->True];


DefineRule[PToCYTwo,
  P[L[i],L[l]][L[j]],
  CY[L[i],L[j],L[l]]+P[L[i],L[j]][L[l]],NewRule->True];

(*******************************************************)

DefineTensor[BBCY,3];
DefineTensor[DDCY,3];

DefineRule[CYCYToBBCYCY,
    CY[L[i],L[j],L[k]]CY[L[l],L[m],L[p]],
  BBCY[L[i],L[j],L[k]]CY[L[l],L[m],L[p]],NewRule->True];

DefineRule[CYCYToCYDDCY,
  CY[L[i],L[j],L[k]]  CY[L[l],L[m],L[p]],
  CY[L[i],L[j],L[k]]DDCY[L[l],L[m],L[p]],NewRule->True];

DefineRule[BBCYToCY,BBCY,CY,NewRule->True];
DefineRule[DDCYToCY,DDCY,CY,NewRule->True];

(****************************************************************)
(* I checked and tested the following material on 17 May 2004.  *)
(****************************************************************)

DefineTensor[BBCYDD,3];
DefineTensor[EECYDD,3];

DefineRule[CYDDCYDDToBBCYDDCYDD,
      CY[L[i1],L[i2],L[i3]][L[i4]]CY[L[j1],L[j2],L[j3]][L[j4]],
  BBCYDD[L[i1],L[i2],L[i3]][L[i4]]CY[L[j1],L[j2],L[j3]][L[j4]],
    NewRule->True];

DefineRule[CYDDCYDDToCYDDEECYDD,
  CY[L[i1],L[i2],L[i3]][L[i4]]    CY[L[j1],L[j2],L[j3]][L[j4]],
  CY[L[i1],L[i2],L[i3]][L[i4]]EECYDD[L[j1],L[j2],L[j3]][L[j4]],
    NewRule->True];

DefineRule[BBCYDDToCY,BBCYDD,CY,NewRule->True];
DefineRule[EECYDDToCY,EECYDD,CY,NewRule->True];

(*******************************************************)
(*  I checked the following material on 17 June 2004.  *)
(*******************************************************)

DefineRule[CYFirstBianchiRule,
  CY[L[i],L[j],L[k]],
  -CY[L[j],L[k],L[i]]-CY[L[k],L[i],L[j]],NewRule->True];

DefineRule[CYSecondBianchiRule,
  CY[L[i],L[j],L[k]][L[l]],
  -CY[L[i],L[l],L[j]][L[k]]-CY[L[i],L[k],L[l]][L[j]]+
  P[L[l],L[m]]Weyl[L[i],U[m],L[j],L[k]]
  -P[L[k],L[m]]Weyl[L[i],U[m],L[j],L[l]]
  +P[L[j],L[m]]Weyl[L[i],U[m],L[k],L[l]],
    NewRule->True];

(***************************************************************)
(*                          SwapCY                             *)
(***************************************************************)
(* SwapCY:  Swap (interchange) copies of CY_{ijk}.

24 June 2004 originating
             I checked this over and ran some tests on 24 June 2004.

Input:

Operand:  A tensor expression (which may include tractors)

TermList:  Parameter is optional.  TermList is a positive integer or a
  list of such integers indicating the terms to which the user wishes to
  apply the function.  If omitted, or if the user codes "Omitted", then
  SwapCY acts on all of Operand.

Urgency:  Parameter is optional.  Default value is 2, which means that
  SwapCY will apply the SuperSimplify command to its intermediate
  result.  The other option available to the caller is to specify
  Urgency=1.  In this case SwapCY will not call SuperSimplify.  This
  speeds up the computation but reduces the likelihood that SwapCY
  will successfully interchange the copies of the tensor.  See remarks
  below.

Output:

A tensor expression equivalent to Operand.

Ricci has certain procedures for deciding upon the order in which it
arranges factors of tensor expressions.  These rules may prevent this
function from successfully arranging the factors in the order
requested by the caller.  In any case, this function always returns a
tensor expression which is equivalent to Operand.

*)

DefineTensor[AASwapCY,3];
DefineRule[CYCYToCYAASwapCY,
  CY[L[i1],L[i2],L[i3]]      CY[L[j1],L[j2],L[j3]],
  CY[L[i1],L[i2],L[i3]]AASwapCY[L[j1],L[j2],L[j3]],
  NewRule->True];
DefineRule[AASwapCYToCY,AASwapCY,CY,NewRule->True];

Options[SwapCY] := {TermList->"Omitted",Urgency->2};

SwapCY[Operand_,opts___] :=

Module[{
  ValResult,
  Temp,
  OldTensor,
  NewTensor,
  ResultTensor,
  LocalUrgency,
  LocalTermList
},
(
  LocalUrgency=(Urgency/.{opts}/.Options[SwapCY]);
  LocalTermList=(TermList/.{opts}/.Options[SwapCY]);
  
  If[(ToString[Head[LocalUrgency]] != "Integer")||
     (LocalUrgency<1)||
     (LocalUrgency>2),
    (
    Message[TrCalc::FFFF];
    Return[Operand]
    ),
    Null
  ];

  ValResult=TracCalcValSelect[Operand,TermList->LocalTermList];

  If[ValResult[[1]]!=0,
    Return[Operand],
    (
    OldTensor=ValResult[[2]];
    Temp=OldTensor;
    Temp=(Temp/.CYCYToCYAASwapCY);
    Temp=TensorSimplify[Temp];
    If[LocalUrgency==2,
      Temp=SuperSimplify[Temp],
      Null];
    Temp=(Temp/.AASwapCYToCY);
    Temp=NewDummy[Temp];
    NewTensor=Temp;
    ResultTensor=(Operand+NewTensor-OldTensor//TensorExpand);
    Return[ResultTensor]
    )
  ]   (* End If *)
)     (* End body of Module *)
];    (* End Module *)

(**********************************)
(* Now work with the Bach tensor. *)
(**********************************)

DefineTensor[BachTensor,2,Symmetries->Symmetric];

DefineRule[ExpandBachTensor,BachTensor[L[j],L[l]],
  P[L[j],L[l]][L[i],U[i]]-P[L[j],L[i]][L[l],U[i]]+
  P[U[k],U[i]]Weyl[L[i],L[j],L[k],L[l]],NewRule->True];

DefineRule[KillBachTrace,BachTensor[L[i],U[i]],0,NewRule->True];

DefineRule[PijkkToBach,P[L[i],L[j]][L[k],U[k]],
  BachTensor[L[i],L[j]]+P[L[i],L[k]][L[j],U[k]]
  -P[U[k],U[l]]Weyl[L[k],L[i],L[l],L[j]],NewRule->True];

(******************** End of file **********************)
