(*
  Warning1.m

  Date last modified:  16 May 2013

  16 May 2013:  Adding HmcDOne, HmcDTwo.  I checked this over.

  File contains definitions relating to intrinsic derivatives.

  I am labeling this file as "Warning1.m."  The idea is to warn the user
  to use this file only when he or she is working with intrinsic derivatives.

  Derivatives in this file are originally intrinsic derivatives.  Some of the
  macro definitions in this file have the effect of expressing these derivatives
  in terms of ambient covariant derivatives.  After we use these
  macros, explicit covariant derivatives will then be ambient covariant
  derivatives.  See the notebook IntrinD.nb for further information.
*)

DefineTensor[HmcDOne,1];
DefineTensor[HmcDTwo,2];

DefineRule[HmcDOneToFake,Hmc[L[a]],HmcDOne[L[a]],NewRule->True];
DefineRule[HmcDTwoToFake,Hmc[L[a],L[b]],HmcDTwo[L[a],L[b]],NewRule->True];

DefineRule[ExpandHmcDOne,HmcDOne[L[a]],
  Hmc[L[a]]-Hmc[L[b]]Nvec[L[a]]Nvec[U[b]],NewRule->True];

DefineRule[ExpandHmcDTwo,HmcDTwo[L[a],L[b]],
   Hmc[][L[a],L[b]] - Hmc[][L[c],L[b]]*Nvec[L[a]]*Nvec[U[c]] - 
   Hmc[][L[c]]*Nvec[L[a]][L[b]]*Nvec[U[c]] - 
   Hmc[][L[a],L[c]]*Nvec[L[b]]*Nvec[U[c]] + 
   Hmc[][L[c],L[d]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[U[c]]*Nvec[U[d]] + 
   Hmc[][L[c]]*Nvec[L[a]][L[d]]*Nvec[L[b]]*Nvec[U[c]]*Nvec[U[d]],
   NewRule->True];

(*******************************************************************************)

DefineTensor[TfSFFDThree,5];
DefineTensor[TfSFFDTwo,4];
DefineTensor[TfSFFDOne,3];

DefineRule[TfSFFDThreeToFake,
        TfSFF[L[a],L[b]][L[c],L[d],L[e]],
  TfSFFDThree[L[a],L[b],L[c],L[d],L[e]],NewRule->True];

DefineRule[TfSFFDTwoToFake,
      TfSFF[L[a],L[b]][L[c],L[d]],
  TfSFFDTwo[L[a],L[b],L[c],L[d]],NewRule->True];

DefineRule[TfSFFDOneToFake,
      TfSFF[L[a],L[b]][L[c]],
  TfSFFDOne[L[a],L[b],L[c]],NewRule->True];

DefineTensor[LapLapf,0];
DefineTensor[Lapf,0];
DefineTensor[fDFour,4];
DefineTensor[fDThree,3];
DefineTensor[fDTwo,2];
DefineTensor[fDOne,1];

DefineRule[LapLapfToFake,
  f[L[i],U[i],L[j],U[j]],
  LapLapf,
  NewRule->True];

DefineRule[LapfToFake,
  f[L[i],U[i]],
  Lapf,
  NewRule->True];

DefineRule[fDFourToFake,
       f[L[a],L[b],L[c],L[d]],
  fDFour[L[a],L[b],L[c],L[d]],
  NewRule->True];

DefineRule[fDThreeToFake,
        f[L[a],L[b],L[c]],
  fDThree[L[a],L[b],L[c]],
  NewRule->True];

DefineRule[fDTwoToFake,
      f[L[a],L[b]],
  fDTwo[L[a],L[b]],
  NewRule->True];

DefineRule[fDOneToFake,
      f[L[a]],
  fDOne[L[a]],
  NewRule->True];

DefineTensor[RhoSigmaDTwo,4];
DefineTensor[RhoSigmaDOne,3];

DefineRule[RhoSigmaDTwoToFake,
      RhoSigma[L[i],L[j]][L[k],L[l]],
  RhoSigmaDTwo[L[i],L[j],L[k],L[l]],
  NewRule->True];

DefineRule[RhoSigmaDOneToFake,
      RhoSigma[L[i],L[j]][L[k]],
  RhoSigmaDOne[L[i],L[j],L[k]],
  NewRule->True];

DefineTensor[LapTrPSigma,0];

DefineRule[LapTrPSigmaToFake,
  TrPSigma[L[i],U[i]],
  LapTrPSigma,
  NewRule->True];

DefineTensor[TrPSigmaDOne,1];

DefineRule[TrPSigmaDOneToFake,
      TrPSigma[L[i]],
  TrPSigmaDOne[L[i]],
  NewRule->True];

DefineTensor[TrPSigmaDTwo,2];

DefineRule[TrPSigmaDTwoToFake,
      TrPSigma[L[i],L[j]],
  TrPSigmaDTwo[L[i],L[j]],
  NewRule->True];

DefineRule[KillgSgmDer,
  gSgm[L[i],L[j]][L[k]],
  0,
  NewRule->True];

DefineRule[amnTon,amn,n,NewRule->True];

DefineRule[ExpandRhoSigmaDTwo,
  RhoSigmaDTwo[L[a],L[b],L[c],L[d]],
  -(Nvec[L[c]][L[d]]*Nvec[U[e]]*RhoSigma[L[a],L[b]][L[e]])+
Nvec[L[c]][L[e]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*RhoSigma[L[a],L[b]][L[i]]+
RhoSigma[L[a],L[b]][L[c],L[d]]-Nvec[L[d]]*Nvec[U[e]]*
RhoSigma[L[a],L[b]][L[c],L[e]]-Nvec[L[c]]*Nvec[U[e]]*
RhoSigma[L[a],L[b]][L[e],L[d]]+Nvec[L[c]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*
RhoSigma[L[a],L[b]][L[e],L[i]]-
Nvec[L[b]][L[d]]*Nvec[U[e]]*RhoSigma[L[a],L[e]][L[c]]+Nvec[L[b]][L[d]]*
Nvec[L[c]]*Nvec[U[e]]*Nvec[U[i]]*RhoSigma[L[a],L[e]][L[i]]+Nvec[L[b]]*
Nvec[L[c]][L[d]]*Nvec[U[e]]*Nvec[U[i]]*RhoSigma[L[a],L[e]][L[i]]-
Nvec[L[b]]*Nvec[U[e]]*RhoSigma[L[a],L[e]][L[c],L[d]]+Nvec[L[b]]*Nvec[L[d]]*
Nvec[U[e]]*Nvec[U[i]]*RhoSigma[L[a],L[e]][L[c],L[i]]+Nvec[L[b]]*Nvec[L[c]]*
Nvec[U[e]]*Nvec[U[i]]*RhoSigma[L[a],L[e]][L[i],L[d]]-Nvec[L[b]]*
Nvec[L[c]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*
RhoSigma[L[a],L[e]][L[i],L[j]]+Nvec[L[b]][L[e]]*Nvec[L[d]]*
Nvec[U[e]]*Nvec[U[i]]*RhoSigma[L[a],L[i]][L[c]]-Nvec[L[b]][L[e]]*Nvec[L[c]]*
Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*RhoSigma[L[a],L[i]][L[j]]-
Nvec[L[b]]*Nvec[L[c]][L[e]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*
RhoSigma[L[a],L[i]][L[j]]-Nvec[L[a]][L[d]]*Nvec[U[e]]*
RhoSigma[L[e],L[b]][L[c]]+Nvec[L[a]][L[d]]*Nvec[L[c]]*Nvec[U[e]]*Nvec[U[i]]*
RhoSigma[L[e],L[b]][L[i]]+Nvec[L[a]]*Nvec[L[c]][L[d]]*Nvec[U[e]]*
Nvec[U[i]]*RhoSigma[L[e],L[b]][L[i]]-Nvec[L[a]]*Nvec[U[e]]*
RhoSigma[L[e],L[b]][L[c],L[d]]+Nvec[L[a]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*
RhoSigma[L[e],L[b]][L[c],L[i]]+Nvec[L[a]]*Nvec[L[c]]*Nvec[U[e]]*Nvec[U[i]]*
RhoSigma[L[e],L[b]][L[i],L[d]]-Nvec[L[a]]*Nvec[L[c]]*Nvec[L[d]]*Nvec[U[e]]*
Nvec[U[i]]*Nvec[U[j]]*RhoSigma[L[e],L[b]][L[i],L[j]]+Nvec[L[a]][L[d]]*
Nvec[L[b]]*Nvec[U[e]]*Nvec[U[i]]*RhoSigma[L[e],L[i]][L[c]]+Nvec[L[a]]*
Nvec[L[b]][L[d]]*Nvec[U[e]]*Nvec[U[i]]*RhoSigma[L[e],L[i]][L[c]]-
Nvec[L[a]][L[d]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*
RhoSigma[L[e],L[i]][L[j]]-Nvec[L[a]]*Nvec[L[b]][L[d]]*Nvec[L[c]]*Nvec[U[e]]*
Nvec[U[i]]*Nvec[U[j]]*RhoSigma[L[e],L[i]][L[j]]-Nvec[L[a]]*Nvec[L[b]]*
Nvec[L[c]][L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*RhoSigma[L[e],L[i]][L[j]]+
Nvec[L[a]]*Nvec[L[b]]*Nvec[U[e]]*Nvec[U[i]]*RhoSigma[L[e],L[i]][L[c],L[d]]-
Nvec[L[a]]*Nvec[L[b]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*
RhoSigma[L[e],L[i]][L[c],L[j]]-Nvec[L[a]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[U[e]]*
Nvec[U[i]]*Nvec[U[j]]*RhoSigma[L[e],L[i]][L[j],L[d]]+
Nvec[L[a]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*
Nvec[U[j]]*Nvec[U[k]]*RhoSigma[L[e],L[i]][L[j],L[k]]+Nvec[L[a]][L[e]]*
Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*RhoSigma[L[i],L[b]][L[c]]-Nvec[L[a]][L[e]]*
Nvec[L[c]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*
RhoSigma[L[i],L[b]][L[j]]-Nvec[L[a]]*Nvec[L[c]][L[e]]*Nvec[L[d]]*Nvec[U[e]]*
Nvec[U[i]]*Nvec[U[j]]*RhoSigma[L[i],L[b]][L[j]]-Nvec[L[a]][L[e]]*Nvec[L[b]]*
Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*RhoSigma[L[i],L[j]][L[c]]-
Nvec[L[a]]*Nvec[L[b]][L[e]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*
RhoSigma[L[i],L[j]][L[c]]+Nvec[L[a]][L[e]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[L[d]]*
Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*Nvec[U[k]]*RhoSigma[L[i],L[j]][L[k]]+
Nvec[L[a]]*Nvec[L[b]][L[e]]*Nvec[L[c]]*Nvec[L[d]]*Nvec[U[e]]*
Nvec[U[i]]*Nvec[U[j]]*Nvec[U[k]]*RhoSigma[L[i],L[j]][L[k]]+Nvec[L[a]]*
Nvec[L[b]]*Nvec[L[c]][L[e]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*
Nvec[U[k]]*RhoSigma[L[i],L[j]][L[k]],
NewRule->True];

DefineRule[ExpandRhoSigmaDOne,
  RhoSigmaDOne[L[i],L[j],L[k]],
-(Nvec[L[i]]*Nvec[L[j]]*Nvec[L[k]]*Nvec[U[a]]*Nvec[U[b]]*Nvec[U[c]]*
RhoSigma[L[a],L[b]][L[c]])+Nvec[L[i]]*Nvec[L[j]]*Nvec[U[a]]*Nvec[U[b]]*
RhoSigma[L[a],L[b]][L[k]]+Nvec[L[i]]*Nvec[L[k]]*Nvec[U[a]]*Nvec[U[b]]*
RhoSigma[L[a],L[j]][L[b]]-Nvec[L[i]]*Nvec[U[a]]*RhoSigma[L[a],L[j]][L[k]]+
Nvec[L[j]]*Nvec[L[k]]*Nvec[U[a]]*Nvec[U[b]]*RhoSigma[L[i],L[a]][L[b]]-
Nvec[L[j]]*Nvec[U[a]]*RhoSigma[L[i],L[a]][L[k]]-Nvec[L[k]]*Nvec[U[a]]*
RhoSigma[L[i],L[j]][L[a]]+RhoSigma[L[i],L[j]][L[k]],
  NewRule->True];

DefineRule[ExpandLapTrPSigma,
  LapTrPSigma,
  -(Nvec[U[a]][L[a]]*Nvec[U[b]]*TrPSigma[L[b]])-
  Nvec[U[a]]*Nvec[U[b]]*TrPSigma[L[a],L[b]]+
  TrPSigma[L[a],U[a]],NewRule->True];

DefineRule[ExpandTrPSigmaDTwo,
  TrPSigmaDTwo[L[a],L[b]],
  -(Nvec[L[a]][L[b]]*Nvec[U[c]]*TrPSigma[L[c]])+Nvec[L[a]][L[c]]*Nvec[L[b]]*
  Nvec[U[c]]*Nvec[U[d]]*TrPSigma[L[d]]+TrPSigma[L[a],L[b]]-
  Nvec[L[b]]*Nvec[U[c]]*TrPSigma[L[a],L[c]]-Nvec[L[a]]*Nvec[U[c]]*
  TrPSigma[L[c],L[b]]+Nvec[L[a]]*Nvec[L[b]]*Nvec[U[c]]*Nvec[U[d]]*
  TrPSigma[L[c],L[d]],
  NewRule->True];

DefineRule[ExpandTrPSigmaDOne,
  TrPSigmaDOne[L[i]],
  PiPro[L[i],U[a]]*TrPSigma[L[a]],
  NewRule->True];

DefineRule[ExpandLapLapf,
  LapLapf,
f[L[a],U[a],L[b],U[b]]-f[L[a],L[b],L[c],U[c]]*Nvec[U[a]]*Nvec[U[b]]-
f[L[b],L[c],U[c]]*Nvec[U[a]][L[a]]*Nvec[U[b]]-2*f[L[a],L[b],L[c]]*
Nvec[U[a]][U[c]]*Nvec[U[b]]-f[L[a],L[b]]*Nvec[U[a]][L[c],U[c]]*Nvec[U[b]]-
2*f[L[a],L[b],L[c]]*Nvec[U[a]]*Nvec[U[b]][U[c]]-2*f[L[a],L[b]]*
Nvec[U[a]][L[c]]*Nvec[U[b]][U[c]]-f[L[a],L[b]]*Nvec[U[a]]*
Nvec[U[b]][L[c],U[c]]-f[L[b]]*Nvec[U[a]][L[a]]*Nvec[U[b]][L[c],U[c]]-
f[L[a],U[a],L[b],L[c]]*Nvec[U[b]]*Nvec[U[c]]-f[L[a],U[a],L[c]]*Nvec[U[b]][L[b]]*
Nvec[U[c]]-2*f[L[a],L[b]]*Nvec[U[a]][U[b]]*Nvec[U[c]][L[c]]-
2*f[L[a],L[b]]*Nvec[U[a]]*Nvec[U[c]][L[c],U[b]]-2*f[L[a]]*
Nvec[U[a]][L[b]]*Nvec[U[c]][L[c],U[b]]-f[L[b]]*Nvec[U[b]]*
Nvec[U[c]][L[c],L[a],U[a]]+f[L[a],L[b],L[c],L[d]]*Nvec[U[a]]*Nvec[U[b]]*
Nvec[U[c]]*Nvec[U[d]]+f[L[b],L[c],L[d]]*Nvec[U[a]][L[a]]*Nvec[U[b]]*
Nvec[U[c]]*Nvec[U[d]]+2*f[L[a],L[b],L[c]]*Nvec[U[a]][L[d]]*Nvec[U[b]]*
Nvec[U[c]]*Nvec[U[d]]+f[L[a],L[b]]*Nvec[U[a]][L[c],L[d]]*Nvec[U[b]]*
Nvec[U[c]]*Nvec[U[d]]+2*f[L[a],L[b],L[c]]*Nvec[U[a]]*Nvec[U[b]][L[d]]*
Nvec[U[c]]*Nvec[U[d]]+2*f[L[a],L[b]]*Nvec[U[a]][L[c]]*Nvec[U[b]][L[d]]*
Nvec[U[c]]*Nvec[U[d]]+f[L[a],L[b]]*Nvec[U[a]]*Nvec[U[b]][L[c],L[d]]*Nvec[U[c]]*
Nvec[U[d]]+f[L[b]]*Nvec[U[a]][L[a]]*Nvec[U[b]][L[c],L[d]]*Nvec[U[c]]*Nvec[U[d]]+
f[L[a],L[b],L[d]]*Nvec[U[a]]*Nvec[U[b]]*Nvec[U[c]][L[c]]*Nvec[U[d]]+
f[L[b],L[d]]*Nvec[U[a]][L[a]]*Nvec[U[b]]*Nvec[U[c]][L[c]]*Nvec[U[d]]+
3*f[L[a],L[b]]*Nvec[U[a]][L[c]]*Nvec[U[b]]*Nvec[U[c]]*Nvec[U[d]][L[d]]+
f[L[a],L[b]]*Nvec[U[a]]*Nvec[U[b]][L[c]]*Nvec[U[c]]*Nvec[U[d]][L[d]]+
f[L[a]]*Nvec[U[a]][L[b]]*Nvec[U[b]]*Nvec[U[c]][L[c]]*Nvec[U[d]][L[d]]+
f[L[a]]*Nvec[U[a]]*Nvec[U[b]]*Nvec[U[c]][L[c]]*Nvec[U[d]][L[d],L[b]]+
2*f[L[a],L[b]]*Nvec[U[a]]*Nvec[U[b]]*Nvec[U[c]]*Nvec[U[d]][L[d],L[c]]+
2*f[L[b]]*Nvec[U[a]]*Nvec[U[b]][L[a]]*Nvec[U[c]]*Nvec[U[d]][L[d],L[c]]+
f[L[a]]*Nvec[U[a]]*Nvec[U[b]]*Nvec[U[c]]*Nvec[U[d]][L[d],L[b],L[c]],
NewRule->True];

DefineRule[ExpandLapf,
  Lapf,
  f[L[a],U[a]]-f[L[a],L[b]]*Nvec[U[a]]*Nvec[U[b]]-
  f[L[b]]*Nvec[U[a]][L[a]]*Nvec[U[b]],
  NewRule->True];

DefineRule[ExpandTfSFFDTwo,
  TfSFFDTwo[L[a],L[b],L[c],L[d]],
-(Nvec[L[c]][L[d]]*Nvec[U[e]]*TfSFF[L[a],L[b]][L[e]])+
Nvec[L[c]][L[e]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*TfSFF[L[a],L[b]][L[i]]+
TfSFF[L[a],L[b]][L[c],L[d]]-Nvec[L[d]]*Nvec[U[e]]*TfSFF[L[a],L[b]][L[c],L[e]]-
Nvec[L[c]]*Nvec[U[e]]*TfSFF[L[a],L[b]][L[e],L[d]]+Nvec[L[c]]*Nvec[L[d]]*
Nvec[U[e]]*Nvec[U[i]]*TfSFF[L[a],L[b]][L[e],L[i]]-Nvec[L[b]][L[d]]*
Nvec[U[e]]*TfSFF[L[a],L[e]][L[c]]+Nvec[L[b]][L[d]]*Nvec[L[c]]*Nvec[U[e]]*
Nvec[U[i]]*TfSFF[L[a],L[e]][L[i]]+Nvec[L[b]]*
Nvec[L[c]][L[d]]*Nvec[U[e]]*Nvec[U[i]]*TfSFF[L[a],L[e]][L[i]]-
Nvec[L[b]]*Nvec[U[e]]*TfSFF[L[a],L[e]][L[c],L[d]]+Nvec[L[b]]*Nvec[L[d]]*
Nvec[U[e]]*Nvec[U[i]]*TfSFF[L[a],L[e]][L[c],L[i]]+Nvec[L[b]]*Nvec[L[c]]*
Nvec[U[e]]*Nvec[U[i]]*TfSFF[L[a],L[e]][L[i],L[d]]-Nvec[L[b]]*Nvec[L[c]]*
Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*TfSFF[L[a],L[e]][L[i],L[j]]+
Nvec[L[b]][L[e]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*TfSFF[L[a],L[i]][L[c]]-
Nvec[L[b]][L[e]]*Nvec[L[c]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*
TfSFF[L[a],L[i]][L[j]]-Nvec[L[b]]*Nvec[L[c]][L[e]]*Nvec[L[d]]*Nvec[U[e]]*
Nvec[U[i]]*Nvec[U[j]]*TfSFF[L[a],L[i]][L[j]]-Nvec[L[a]][L[d]]*Nvec[U[e]]*
TfSFF[L[b],L[e]][L[c]]+Nvec[L[a]][L[d]]*Nvec[L[c]]*Nvec[U[e]]*Nvec[U[i]]*
TfSFF[L[b],L[e]][L[i]]+Nvec[L[a]]*Nvec[L[c]][L[d]]*Nvec[U[e]]*Nvec[U[i]]*
TfSFF[L[b],L[e]][L[i]]-Nvec[L[a]]*Nvec[U[e]]*TfSFF[L[b],L[e]][L[c],L[d]]+
Nvec[L[a]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*TfSFF[L[b],L[e]][L[c],L[i]]+
Nvec[L[a]]*Nvec[L[c]]*Nvec[U[e]]*Nvec[U[i]]*TfSFF[L[b],L[e]][L[i],L[d]]-
Nvec[L[a]]*Nvec[L[c]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*
TfSFF[L[b],L[e]][L[i],L[j]]+Nvec[L[a]][L[e]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*
TfSFF[L[b],L[i]][L[c]]-Nvec[L[a]][L[e]]*Nvec[L[c]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*
Nvec[U[j]]*TfSFF[L[b],L[i]][L[j]]-Nvec[L[a]]*Nvec[L[c]][L[e]]*Nvec[L[d]]*Nvec[U[e]]*
Nvec[U[i]]*Nvec[U[j]]*TfSFF[L[b],L[i]][L[j]]+Nvec[L[a]][L[d]]*Nvec[L[b]]*
Nvec[U[e]]*Nvec[U[i]]*TfSFF[L[e],L[i]][L[c]]+Nvec[L[a]]*Nvec[L[b]][L[d]]*Nvec[U[e]]*
Nvec[U[i]]*TfSFF[L[e],L[i]][L[c]]-Nvec[L[a]][L[d]]*Nvec[L[b]]*Nvec[L[c]]*
Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*TfSFF[L[e],L[i]][L[j]]-Nvec[L[a]]*
Nvec[L[b]][L[d]]*Nvec[L[c]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*
TfSFF[L[e],L[i]][L[j]]-Nvec[L[a]]*Nvec[L[b]]*Nvec[L[c]][L[d]]*Nvec[U[e]]*
Nvec[U[i]]*Nvec[U[j]]*TfSFF[L[e],L[i]][L[j]]+Nvec[L[a]]*Nvec[L[b]]*
Nvec[U[e]]*Nvec[U[i]]*TfSFF[L[e],L[i]][L[c],L[d]]-Nvec[L[a]]*Nvec[L[b]]*
Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*TfSFF[L[e],L[i]][L[c],L[j]]-
Nvec[L[a]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*
TfSFF[L[e],L[i]][L[j],L[d]]+Nvec[L[a]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[L[d]]*
Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*Nvec[U[k]]*TfSFF[L[e],L[i]][L[j],L[k]]-
Nvec[L[a]][L[e]]*Nvec[L[b]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*
TfSFF[L[i],L[j]][L[c]]-Nvec[L[a]]*Nvec[L[b]][L[e]]*Nvec[L[d]]*Nvec[U[e]]*
Nvec[U[i]]*Nvec[U[j]]*TfSFF[L[i],L[j]][L[c]]+Nvec[L[a]][L[e]]*Nvec[L[b]]*Nvec[L[c]]*
Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*Nvec[U[k]]*TfSFF[L[i],L[j]][L[k]]+
Nvec[L[a]]*Nvec[L[b]][L[e]]*Nvec[L[c]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*
Nvec[U[j]]*Nvec[U[k]]*TfSFF[L[i],L[j]][L[k]]+Nvec[L[a]]*Nvec[L[b]]*
Nvec[L[c]][L[e]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*Nvec[U[k]]*
TfSFF[L[i],L[j]][L[k]],
NewRule->True];

DefineRule[ExpandTfSFFDOne,
  TfSFFDOne[L[a],L[b],L[c]],
  TfSFF[L[a],L[b]][L[c]]-Nvec[L[c]]*Nvec[U[d]]*TfSFF[L[a],L[b]][L[d]]-
  Nvec[L[b]]*Nvec[U[d]]*TfSFF[L[a],L[d]][L[c]]+Nvec[L[b]]*Nvec[L[c]]*Nvec[U[d]]*
  Nvec[U[e]]*TfSFF[L[a],L[d]][L[e]]-Nvec[L[a]]*Nvec[U[d]]*TfSFF[L[b],L[d]][L[c]]+
  Nvec[L[a]]*Nvec[L[c]]*Nvec[U[d]]*Nvec[U[e]]*TfSFF[L[b],L[d]][L[e]]+Nvec[L[a]]*
  Nvec[L[b]]*Nvec[U[d]]*Nvec[U[e]]*TfSFF[L[d],L[e]][L[c]]-Nvec[L[a]]*Nvec[L[b]]*
  Nvec[L[c]]*Nvec[U[d]]*Nvec[U[e]]*Nvec[U[i]]*TfSFF[L[d],L[e]][L[i]],
  NewRule->True];

DefineRule[ExpandfDFour,
 fDFour[L[a],L[b],L[c],L[d]],
f[L[a],L[b],L[c],L[d]]-
f[L[e],L[b],L[c],L[d]]*Nvec[L[a]]*Nvec[U[e]]-
f[L[e],L[c],L[d]]*Nvec[L[a]][L[b]]*Nvec[U[e]]-
f[L[e],L[b],L[d]]*Nvec[L[a]][L[c]]*Nvec[U[e]]-
f[L[e],L[b],L[c]]*Nvec[L[a]][L[d]]*Nvec[U[e]]-
f[L[e],L[d]]*Nvec[L[a]][L[b],L[c]]*Nvec[U[e]]-
f[L[e],L[c]]*Nvec[L[a]][L[b],L[d]]*Nvec[U[e]]-
f[L[e],L[b]]*Nvec[L[a]][L[c],L[d]]*Nvec[U[e]]-
f[L[e]]*Nvec[L[a]][L[b],L[c],L[d]]*Nvec[U[e]]-
f[L[a],L[e],L[c],L[d]]*Nvec[L[b]]*Nvec[U[e]]-
f[L[a],L[e],L[d]]*Nvec[L[b]][L[c]]*Nvec[U[e]]-
f[L[a],L[e],L[c]]*Nvec[L[b]][L[d]]*Nvec[U[e]]-
f[L[a],L[e]]*Nvec[L[b]][L[c],L[d]]*Nvec[U[e]]-
f[L[a],L[b],L[e],L[d]]*Nvec[L[c]]*Nvec[U[e]]-
f[L[a],L[b],L[e]]*Nvec[L[c]][L[d]]*Nvec[U[e]]-
f[L[a],L[b],L[c],L[e]]*Nvec[L[d]]*Nvec[U[e]]-
f[L[e],L[d]]*Nvec[L[a]][L[b]]*Nvec[U[e]][L[c]]-
f[L[e]]*Nvec[L[a]][L[b],L[d]]*Nvec[U[e]][L[c]]-
f[L[e],L[c]]*Nvec[L[a]][L[b]]*Nvec[U[e]][L[d]]-
f[L[e],L[b]]*Nvec[L[a]][L[c]]*Nvec[U[e]][L[d]]-
f[L[e]]*Nvec[L[a]][L[b],L[c]]*Nvec[U[e]][L[d]]-
f[L[a],L[e]]*Nvec[L[b]][L[c]]*Nvec[U[e]][L[d]]-
f[L[e]]*Nvec[L[a]][L[b]]*Nvec[U[e]][L[c],L[d]]+
f[L[e],L[i],L[c],L[d]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[U[e]]*Nvec[U[i]]+
f[L[e],L[i],L[d]]*Nvec[L[a]][L[c]]*Nvec[L[b]]*Nvec[U[e]]*
Nvec[U[i]]+f[L[e],L[i],L[c]]*Nvec[L[a]][L[d]]*Nvec[L[b]]*
Nvec[U[e]]*Nvec[U[i]]+f[L[e],L[c],L[d]]*Nvec[L[a]][L[i]]*
Nvec[L[b]]*Nvec[U[e]]*Nvec[U[i]]+
f[L[e],L[i]]*Nvec[L[a]][L[c],L[d]]*Nvec[L[b]]*Nvec[U[e]]*
Nvec[U[i]]+f[L[e],L[d]]*Nvec[L[a]][L[i],L[c]]*Nvec[L[b]]*
Nvec[U[e]]*Nvec[U[i]]+f[L[e],L[c]]*Nvec[L[a]][L[i],L[d]]*
Nvec[L[b]]*Nvec[U[e]]*Nvec[U[i]]+
f[L[e]]*Nvec[L[a]][L[i],L[c],L[d]]*Nvec[L[b]]*Nvec[U[e]]*
Nvec[U[i]]+f[L[e],L[i],L[d]]*Nvec[L[a]]*Nvec[L[b]][L[c]]*
Nvec[U[e]]*Nvec[U[i]]+f[L[e],L[i]]*Nvec[L[a]][L[d]]*
Nvec[L[b]][L[c]]*Nvec[U[e]]*Nvec[U[i]]+
f[L[e],L[d]]*Nvec[L[a]][L[i]]*Nvec[L[b]][L[c]]*Nvec[U[e]]*
Nvec[U[i]]+f[L[e]]*Nvec[L[a]][L[i],L[d]]*Nvec[L[b]][L[c]]*
Nvec[U[e]]*Nvec[U[i]]+f[L[e],L[i],L[c]]*Nvec[L[a]]*
Nvec[L[b]][L[d]]*Nvec[U[e]]*Nvec[U[i]]+
f[L[e],L[i]]*Nvec[L[a]][L[c]]*Nvec[L[b]][L[d]]*Nvec[U[e]]*
Nvec[U[i]]+f[L[e],L[c]]*Nvec[L[a]][L[i]]*Nvec[L[b]][L[d]]*
Nvec[U[e]]*Nvec[U[i]]+f[L[e]]*Nvec[L[a]][L[i],L[c]]*
Nvec[L[b]][L[d]]*Nvec[U[e]]*Nvec[U[i]]+
f[L[e],L[i]]*Nvec[L[a]]*Nvec[L[b]][L[c],L[d]]*Nvec[U[e]]*
Nvec[U[i]]+f[L[e]]*Nvec[L[a]][L[i]]*Nvec[L[b]][L[c],L[d]]*
Nvec[U[e]]*Nvec[U[i]]+f[L[e],L[b],L[i],L[d]]*Nvec[L[a]]*
Nvec[L[c]]*Nvec[U[e]]*Nvec[U[i]]+
f[L[e],L[i],L[d]]*Nvec[L[a]][L[b]]*Nvec[L[c]]*Nvec[U[e]]*
Nvec[U[i]]+f[L[e],L[b],L[i]]*Nvec[L[a]][L[d]]*Nvec[L[c]]*
Nvec[U[e]]*Nvec[U[i]]+f[L[e],L[b],L[d]]*Nvec[L[a]][L[i]]*
Nvec[L[c]]*Nvec[U[e]]*Nvec[U[i]]+
f[L[e],L[i]]*Nvec[L[a]][L[b],L[d]]*Nvec[L[c]]*Nvec[U[e]]*
Nvec[U[i]]+f[L[e],L[d]]*Nvec[L[a]][L[b],L[i]]*Nvec[L[c]]*
Nvec[U[e]]*Nvec[U[i]]+f[L[e],L[b]]*Nvec[L[a]][L[i],L[d]]*
Nvec[L[c]]*Nvec[U[e]]*Nvec[U[i]]+
f[L[e]]*Nvec[L[a]][L[b],L[i],L[d]]*Nvec[L[c]]*Nvec[U[e]]*
Nvec[U[i]]+f[L[a],L[e],L[i],L[d]]*Nvec[L[b]]*Nvec[L[c]]*
Nvec[U[e]]*Nvec[U[i]]+f[L[a],L[e],L[i]]*Nvec[L[b]][L[d]]*
Nvec[L[c]]*Nvec[U[e]]*Nvec[U[i]]+
f[L[a],L[e],L[d]]*Nvec[L[b]][L[i]]*Nvec[L[c]]*Nvec[U[e]]*
Nvec[U[i]]+f[L[a],L[e]]*Nvec[L[b]][L[i],L[d]]*Nvec[L[c]]*
Nvec[U[e]]*Nvec[U[i]]+f[L[e],L[b],L[i]]*Nvec[L[a]]*
Nvec[L[c]][L[d]]*Nvec[U[e]]*Nvec[U[i]]+
f[L[e],L[i]]*Nvec[L[a]][L[b]]*Nvec[L[c]][L[d]]*Nvec[U[e]]*
Nvec[U[i]]+f[L[e],L[b]]*Nvec[L[a]][L[i]]*Nvec[L[c]][L[d]]*
Nvec[U[e]]*Nvec[U[i]]+f[L[e]]*Nvec[L[a]][L[b],L[i]]*
Nvec[L[c]][L[d]]*Nvec[U[e]]*Nvec[U[i]]+
f[L[a],L[e],L[i]]*Nvec[L[b]]*Nvec[L[c]][L[d]]*Nvec[U[e]]*
Nvec[U[i]]+f[L[a],L[e]]*Nvec[L[b]][L[i]]*Nvec[L[c]][L[d]]*
Nvec[U[e]]*Nvec[U[i]]+f[L[e],L[b],L[c],L[i]]*Nvec[L[a]]*
Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]+
f[L[e],L[c],L[i]]*Nvec[L[a]][L[b]]*Nvec[L[d]]*Nvec[U[e]]*
Nvec[U[i]]+f[L[e],L[b],L[i]]*Nvec[L[a]][L[c]]*Nvec[L[d]]*
Nvec[U[e]]*Nvec[U[i]]+f[L[e],L[b],L[c]]*Nvec[L[a]][L[i]]*
Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]+
f[L[e],L[i]]*Nvec[L[a]][L[b],L[c]]*Nvec[L[d]]*Nvec[U[e]]*
Nvec[U[i]]+f[L[e],L[c]]*Nvec[L[a]][L[b],L[i]]*Nvec[L[d]]*
Nvec[U[e]]*Nvec[U[i]]+f[L[e],L[b]]*Nvec[L[a]][L[c],L[i]]*
Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]+
f[L[e]]*Nvec[L[a]][L[b],L[c],L[i]]*Nvec[L[d]]*Nvec[U[e]]*
Nvec[U[i]]+f[L[a],L[e],L[c],L[i]]*Nvec[L[b]]*Nvec[L[d]]*
Nvec[U[e]]*Nvec[U[i]]+f[L[a],L[e],L[i]]*Nvec[L[b]][L[c]]*
Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]+
f[L[a],L[e],L[c]]*Nvec[L[b]][L[i]]*Nvec[L[d]]*Nvec[U[e]]*
Nvec[U[i]]+f[L[a],L[e]]*Nvec[L[b]][L[c],L[i]]*Nvec[L[d]]*
Nvec[U[e]]*Nvec[U[i]]+f[L[a],L[b],L[e],L[i]]*Nvec[L[c]]*
Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]+
f[L[a],L[b],L[e]]*Nvec[L[c]][L[i]]*Nvec[L[d]]*Nvec[U[e]]*
Nvec[U[i]]+f[L[e],L[d]]*Nvec[L[a]][L[i]]*Nvec[L[b]]*
Nvec[U[e]][L[c]]*Nvec[U[i]]+
f[L[e]]*Nvec[L[a]][L[i]]*Nvec[L[b]][L[d]]*Nvec[U[e]][L[c]]*
Nvec[U[i]]+f[L[e],L[i]]*Nvec[L[a]][L[b]]*Nvec[L[d]]*
Nvec[U[e]][L[c]]*Nvec[U[i]]+
f[L[e],L[i]]*Nvec[L[a]][L[c]]*Nvec[L[b]]*Nvec[U[e]][L[d]]*
Nvec[U[i]]+f[L[e],L[c]]*Nvec[L[a]][L[i]]*Nvec[L[b]]*
Nvec[U[e]][L[d]]*Nvec[U[i]]+
f[L[e]]*Nvec[L[a]][L[i]]*Nvec[L[b]][L[c]]*Nvec[U[e]][L[d]]*
Nvec[U[i]]+f[L[e],L[i]]*Nvec[L[a]][L[b]]*Nvec[L[c]]*
Nvec[U[e]][L[d]]*Nvec[U[i]]+
f[L[e],L[b]]*Nvec[L[a]][L[i]]*Nvec[L[c]]*Nvec[U[e]][L[d]]*
Nvec[U[i]]+f[L[a],L[e]]*Nvec[L[b]][L[i]]*Nvec[L[c]]*
Nvec[U[e]][L[d]]*Nvec[U[i]]+
f[L[e],L[d]]*Nvec[L[a]][L[b]]*Nvec[L[c]]*Nvec[U[e]][L[i]]*
Nvec[U[i]]+f[L[e]]*Nvec[L[a]][L[b],L[d]]*Nvec[L[c]]*
Nvec[U[e]][L[i]]*Nvec[U[i]]+
f[L[e]]*Nvec[L[a]][L[b]]*Nvec[L[c]][L[d]]*Nvec[U[e]][L[i]]*
Nvec[U[i]]+f[L[e],L[c]]*Nvec[L[a]][L[b]]*Nvec[L[d]]*
Nvec[U[e]][L[i]]*Nvec[U[i]]+
f[L[e],L[b]]*Nvec[L[a]][L[c]]*Nvec[L[d]]*Nvec[U[e]][L[i]]*
Nvec[U[i]]+f[L[e]]*Nvec[L[a]][L[b],L[c]]*Nvec[L[d]]*
Nvec[U[e]][L[i]]*Nvec[U[i]]+
f[L[a],L[e]]*Nvec[L[b]][L[c]]*Nvec[L[d]]*Nvec[U[e]][L[i]]*
Nvec[U[i]]+f[L[e]]*Nvec[L[a]][L[b]]*Nvec[L[d]]*
Nvec[U[e]][L[c],L[i]]*Nvec[U[i]]+
f[L[e]]*Nvec[L[a]][L[b]]*Nvec[L[c]]*Nvec[U[e]][L[i],L[d]]*
Nvec[U[i]]+f[L[i]]*Nvec[L[a]][L[e],L[d]]*Nvec[L[b]]*Nvec[U[e]]*
Nvec[U[i]][L[c]]+f[L[i]]*Nvec[L[a]][L[b],L[e]]*Nvec[L[d]]*
Nvec[U[e]]*Nvec[U[i]][L[c]]-
f[L[e],L[d]]*Nvec[L[a]]*Nvec[L[i]][L[b]]*Nvec[U[e]]*
Nvec[U[i]][L[c]]-f[L[e]]*Nvec[L[a]][L[d]]*Nvec[L[i]][L[b]]*
Nvec[U[e]]*Nvec[U[i]][L[c]]-
f[L[e]]*Nvec[L[a]]*Nvec[L[i]][L[b]]*Nvec[U[e]][L[d]]*
Nvec[U[i]][L[c]]+f[L[i]]*Nvec[L[a]][L[e],L[c]]*Nvec[L[b]]*
Nvec[U[e]]*Nvec[U[i]][L[d]]+
f[L[e],L[i]]*Nvec[L[a]]*Nvec[L[b]][L[c]]*Nvec[U[e]]*
Nvec[U[i]][L[d]]+f[L[e]]*Nvec[L[a]][L[i]]*Nvec[L[b]][L[c]]*
Nvec[U[e]]*Nvec[U[i]][L[d]]+
f[L[i]]*Nvec[L[a]][L[b],L[e]]*Nvec[L[c]]*Nvec[U[e]]*
Nvec[U[i]][L[d]]-f[L[e],L[c]]*Nvec[L[a]]*Nvec[L[i]][L[b]]*
Nvec[U[e]]*Nvec[U[i]][L[d]]-
f[L[e],L[b]]*Nvec[L[a]]*Nvec[L[i]][L[c]]*Nvec[U[e]]*
Nvec[U[i]][L[d]]-f[L[a],L[e]]*Nvec[L[b]]*Nvec[L[i]][L[c]]*
Nvec[U[e]]*Nvec[U[i]][L[d]]-
f[L[e]]*Nvec[L[a]]*Nvec[L[i]][L[b]]*Nvec[U[e]][L[c]]*
Nvec[U[i]][L[d]]-f[L[e]]*Nvec[L[a]]*Nvec[L[i]][L[d]]*Nvec[U[e]]*
Nvec[U[i]][L[b],L[c]]-f[L[e]]*Nvec[L[a]]*Nvec[L[i]][L[c]]*
Nvec[U[e]]*Nvec[U[i]][L[b],L[d]]+
f[L[i]]*Nvec[L[a]][L[e]]*Nvec[L[b]]*Nvec[U[e]]*
Nvec[U[i]][L[c],L[d]]-f[L[e]]*Nvec[L[a]]*Nvec[L[i]][L[b]]*
Nvec[U[e]]*Nvec[U[i]][L[c],L[d]]-
f[L[e],L[i],L[j],L[d]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[U[e]]*
Nvec[U[i]]*Nvec[U[j]]-f[L[e],L[i],L[j]]*Nvec[L[a]][L[d]]*
Nvec[L[b]]*Nvec[L[c]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]-
2*f[L[e],L[i],L[d]]*Nvec[L[a]][L[j]]*Nvec[L[b]]*Nvec[L[c]]*
Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e],L[d]]*Nvec[L[a]][L[i],L[j]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[U[e]]*
Nvec[U[i]]*Nvec[U[j]]-2*f[L[e],L[i]]*Nvec[L[a]][L[j],L[d]]*
Nvec[L[b]]*Nvec[L[c]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e]]*Nvec[L[a]][L[i],L[j],L[d]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[U[e]]*
Nvec[U[i]]*Nvec[U[j]]-f[L[e],L[i],L[j]]*Nvec[L[a]]*
Nvec[L[b]][L[d]]*Nvec[L[c]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]-
2*f[L[e],L[i]]*Nvec[L[a]][L[j]]*Nvec[L[b]][L[d]]*Nvec[L[c]]*
Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e]]*Nvec[L[a]][L[i],L[j]]*Nvec[L[b]][L[d]]*Nvec[L[c]]*
Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e],L[i],L[d]]*Nvec[L[a]]*Nvec[L[b]][L[j]]*Nvec[L[c]]*Nvec[U[e]]*
Nvec[U[i]]*Nvec[U[j]]-f[L[e],L[i]]*Nvec[L[a]][L[d]]*
Nvec[L[b]][L[j]]*Nvec[L[c]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e],L[d]]*Nvec[L[a]][L[i]]*Nvec[L[b]][L[j]]*Nvec[L[c]]*
Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e]]*Nvec[L[a]][L[i],L[d]]*Nvec[L[b]][L[j]]*Nvec[L[c]]*
Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e],L[i]]*Nvec[L[a]]*Nvec[L[b]][L[j],L[d]]*Nvec[L[c]]*Nvec[U[e]]*
Nvec[U[i]]*Nvec[U[j]]-f[L[e]]*Nvec[L[a]][L[i]]*
Nvec[L[b]][L[j],L[d]]*Nvec[L[c]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e],L[i],L[j]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[L[c]][L[d]]*Nvec[U[e]]*
Nvec[U[i]]*Nvec[U[j]]-2*f[L[e],L[i]]*Nvec[L[a]][L[j]]*Nvec[L[b]]*
Nvec[L[c]][L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e]]*Nvec[L[a]][L[i],L[j]]*Nvec[L[b]]*Nvec[L[c]][L[d]]*
Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e],L[i]]*Nvec[L[a]]*Nvec[L[b]][L[j]]*Nvec[L[c]][L[d]]*
Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e]]*Nvec[L[a]][L[i]]*Nvec[L[b]][L[j]]*Nvec[L[c]][L[d]]*
Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e],L[i],L[c],L[j]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[L[d]]*Nvec[U[e]]*
Nvec[U[i]]*Nvec[U[j]]-f[L[e],L[i],L[j]]*Nvec[L[a]][L[c]]*
Nvec[L[b]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e],L[c],L[i]]*Nvec[L[a]][L[j]]*Nvec[L[b]]*Nvec[L[d]]*Nvec[U[e]]*
Nvec[U[i]]*Nvec[U[j]]-f[L[e],L[i],L[c]]*Nvec[L[a]][L[j]]*
Nvec[L[b]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e],L[i]]*Nvec[L[a]][L[c],L[j]]*Nvec[L[b]]*Nvec[L[d]]*Nvec[U[e]]*
Nvec[U[i]]*Nvec[U[j]]-f[L[e],L[c]]*Nvec[L[a]][L[i],L[j]]*
Nvec[L[b]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e],L[i]]*Nvec[L[a]][L[j],L[c]]*Nvec[L[b]]*Nvec[L[d]]*Nvec[U[e]]*
Nvec[U[i]]*Nvec[U[j]]-f[L[e]]*Nvec[L[a]][L[i],L[c],L[j]]*
Nvec[L[b]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e],L[i],L[j]]*Nvec[L[a]]*Nvec[L[b]][L[c]]*Nvec[L[d]]*Nvec[U[e]]*
Nvec[U[i]]*Nvec[U[j]]-2*f[L[e],L[i]]*Nvec[L[a]][L[j]]*
Nvec[L[b]][L[c]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e]]*Nvec[L[a]][L[i],L[j]]*Nvec[L[b]][L[c]]*Nvec[L[d]]*
Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e],L[i],L[c]]*Nvec[L[a]]*Nvec[L[b]][L[j]]*Nvec[L[d]]*Nvec[U[e]]*
Nvec[U[i]]*Nvec[U[j]]-f[L[e],L[i]]*Nvec[L[a]][L[c]]*
Nvec[L[b]][L[j]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e],L[c]]*Nvec[L[a]][L[i]]*Nvec[L[b]][L[j]]*Nvec[L[d]]*
Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e]]*Nvec[L[a]][L[i],L[c]]*Nvec[L[b]][L[j]]*Nvec[L[d]]*
Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e],L[i]]*Nvec[L[a]]*Nvec[L[b]][L[c],L[j]]*Nvec[L[d]]*Nvec[U[e]]*
Nvec[U[i]]*Nvec[U[j]]-f[L[e]]*Nvec[L[a]][L[i]]*
Nvec[L[b]][L[c],L[j]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e],L[b],L[i],L[j]]*Nvec[L[a]]*Nvec[L[c]]*Nvec[L[d]]*Nvec[U[e]]*
Nvec[U[i]]*Nvec[U[j]]-f[L[e],L[i],L[j]]*Nvec[L[a]][L[b]]*
Nvec[L[c]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]-
2*f[L[e],L[b],L[i]]*Nvec[L[a]][L[j]]*Nvec[L[c]]*Nvec[L[d]]*
Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]-
2*f[L[e],L[i]]*Nvec[L[a]][L[b],L[j]]*Nvec[L[c]]*Nvec[L[d]]*
Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e],L[b]]*Nvec[L[a]][L[i],L[j]]*Nvec[L[c]]*Nvec[L[d]]*Nvec[U[e]]*
Nvec[U[i]]*Nvec[U[j]]-f[L[e]]*Nvec[L[a]][L[b],L[i],L[j]]*
Nvec[L[c]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[a],L[e],L[i],L[j]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[L[d]]*Nvec[U[e]]*
Nvec[U[i]]*Nvec[U[j]]-2*f[L[a],L[e],L[i]]*Nvec[L[b]][L[j]]*
Nvec[L[c]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[a],L[e]]*Nvec[L[b]][L[i],L[j]]*Nvec[L[c]]*Nvec[L[d]]*Nvec[U[e]]*
Nvec[U[i]]*Nvec[U[j]]-f[L[e],L[b],L[i]]*Nvec[L[a]]*
Nvec[L[c]][L[j]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e],L[i]]*Nvec[L[a]][L[b]]*Nvec[L[c]][L[j]]*Nvec[L[d]]*
Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e],L[b]]*Nvec[L[a]][L[i]]*Nvec[L[c]][L[j]]*Nvec[L[d]]*
Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e]]*Nvec[L[a]][L[b],L[i]]*Nvec[L[c]][L[j]]*Nvec[L[d]]*
Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[a],L[e],L[i]]*Nvec[L[b]]*Nvec[L[c]][L[j]]*Nvec[L[d]]*Nvec[U[e]]*
Nvec[U[i]]*Nvec[U[j]]-f[L[a],L[e]]*Nvec[L[b]][L[i]]*
Nvec[L[c]][L[j]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e],L[i]]*Nvec[L[a]][L[j]]*Nvec[L[b]]*Nvec[L[d]]*
Nvec[U[e]][L[c]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e]]*Nvec[L[a]][L[i]]*Nvec[L[b]][L[j]]*Nvec[L[d]]*
Nvec[U[e]][L[c]]*Nvec[U[i]]*Nvec[U[j]]-
2*f[L[e],L[i]]*Nvec[L[a]][L[j]]*Nvec[L[b]]*Nvec[L[c]]*
Nvec[U[e]][L[d]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e]]*Nvec[L[a]][L[i]]*Nvec[L[b]][L[j]]*Nvec[L[c]]*
Nvec[U[e]][L[d]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e],L[d]]*Nvec[L[a]][L[i]]*Nvec[L[b]]*Nvec[L[c]]*
Nvec[U[e]][L[j]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e]]*Nvec[L[a]][L[i]]*Nvec[L[b]][L[d]]*Nvec[L[c]]*
Nvec[U[e]][L[j]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e]]*Nvec[L[a]][L[i]]*Nvec[L[b]]*Nvec[L[c]][L[d]]*
Nvec[U[e]][L[j]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e],L[i]]*Nvec[L[a]][L[c]]*Nvec[L[b]]*Nvec[L[d]]*
Nvec[U[e]][L[j]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e],L[c]]*Nvec[L[a]][L[i]]*Nvec[L[b]]*Nvec[L[d]]*
Nvec[U[e]][L[j]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e]]*Nvec[L[a]][L[i]]*Nvec[L[b]][L[c]]*Nvec[L[d]]*
Nvec[U[e]][L[j]]*Nvec[U[i]]*Nvec[U[j]]-
2*f[L[e],L[i]]*Nvec[L[a]][L[b]]*Nvec[L[c]]*Nvec[L[d]]*
Nvec[U[e]][L[j]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e],L[b]]*Nvec[L[a]][L[i]]*Nvec[L[c]]*Nvec[L[d]]*
Nvec[U[e]][L[j]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e]]*Nvec[L[a]][L[b],L[i]]*Nvec[L[c]]*Nvec[L[d]]*
Nvec[U[e]][L[j]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[a],L[e]]*Nvec[L[b]][L[i]]*Nvec[L[c]]*Nvec[L[d]]*
Nvec[U[e]][L[j]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e]]*Nvec[L[a]][L[b]]*Nvec[L[c]][L[i]]*Nvec[L[d]]*
Nvec[U[e]][L[j]]*Nvec[U[i]]*Nvec[U[j]]-
f[L[e]]*Nvec[L[a]][L[b]]*Nvec[L[c]]*Nvec[L[d]]*
Nvec[U[e]][L[i],L[j]]*Nvec[U[i]]*Nvec[U[j]]+
f[L[e]]*Nvec[L[a]]*Nvec[L[d]]*Nvec[L[i]][L[b]]*Nvec[U[e]][L[j]]*
Nvec[U[i]][L[c]]*Nvec[U[j]]-
f[L[e],L[i]]*Nvec[L[a]]*Nvec[L[b]][L[j]]*Nvec[L[c]]*Nvec[U[e]]*
Nvec[U[i]][L[d]]*Nvec[U[j]]-
f[L[e]]*Nvec[L[a]][L[i]]*Nvec[L[b]][L[j]]*Nvec[L[c]]*Nvec[U[e]]*
Nvec[U[i]][L[d]]*Nvec[U[j]]+
f[L[e]]*Nvec[L[a]]*Nvec[L[c]]*Nvec[L[i]][L[b]]*Nvec[U[e]][L[j]]*
Nvec[U[i]][L[d]]*Nvec[U[j]]-
f[L[i]]*Nvec[L[a]][L[e],L[d]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[U[e]]*
Nvec[U[i]][L[j]]*Nvec[U[j]]-
f[L[i]]*Nvec[L[a]][L[e],L[c]]*Nvec[L[b]]*Nvec[L[d]]*Nvec[U[e]]*
Nvec[U[i]][L[j]]*Nvec[U[j]]-
f[L[e],L[i]]*Nvec[L[a]]*Nvec[L[b]][L[c]]*Nvec[L[d]]*Nvec[U[e]]*
Nvec[U[i]][L[j]]*Nvec[U[j]]-
f[L[e]]*Nvec[L[a]][L[i]]*Nvec[L[b]][L[c]]*Nvec[L[d]]*Nvec[U[e]]*
Nvec[U[i]][L[j]]*Nvec[U[j]]-
f[L[i]]*Nvec[L[a]][L[b],L[e]]*Nvec[L[c]]*Nvec[L[d]]*Nvec[U[e]]*
Nvec[U[i]][L[j]]*Nvec[U[j]]+
f[L[e],L[d]]*Nvec[L[a]]*Nvec[L[c]]*Nvec[L[i]][L[b]]*Nvec[U[e]]*
Nvec[U[i]][L[j]]*Nvec[U[j]]+
f[L[e]]*Nvec[L[a]][L[d]]*Nvec[L[c]]*Nvec[L[i]][L[b]]*Nvec[U[e]]*
Nvec[U[i]][L[j]]*Nvec[U[j]]+
f[L[e]]*Nvec[L[a]]*Nvec[L[c]][L[d]]*Nvec[L[i]][L[b]]*Nvec[U[e]]*
Nvec[U[i]][L[j]]*Nvec[U[j]]+
f[L[e],L[c]]*Nvec[L[a]]*Nvec[L[d]]*Nvec[L[i]][L[b]]*Nvec[U[e]]*
Nvec[U[i]][L[j]]*Nvec[U[j]]+
f[L[e],L[d]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[L[i]][L[c]]*Nvec[U[e]]*
Nvec[U[i]][L[j]]*Nvec[U[j]]+
f[L[e]]*Nvec[L[a]][L[d]]*Nvec[L[b]]*Nvec[L[i]][L[c]]*Nvec[U[e]]*
Nvec[U[i]][L[j]]*Nvec[U[j]]+
f[L[e]]*Nvec[L[a]]*Nvec[L[b]][L[d]]*Nvec[L[i]][L[c]]*Nvec[U[e]]*
Nvec[U[i]][L[j]]*Nvec[U[j]]+
f[L[e],L[b]]*Nvec[L[a]]*Nvec[L[d]]*Nvec[L[i]][L[c]]*Nvec[U[e]]*
Nvec[U[i]][L[j]]*Nvec[U[j]]+
f[L[a],L[e]]*Nvec[L[b]]*Nvec[L[d]]*Nvec[L[i]][L[c]]*Nvec[U[e]]*
Nvec[U[i]][L[j]]*Nvec[U[j]]+
f[L[e],L[c]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[L[i]][L[d]]*Nvec[U[e]]*
Nvec[U[i]][L[j]]*Nvec[U[j]]+
f[L[e]]*Nvec[L[a]]*Nvec[L[b]][L[c]]*Nvec[L[i]][L[d]]*Nvec[U[e]]*
Nvec[U[i]][L[j]]*Nvec[U[j]]+
f[L[e],L[b]]*Nvec[L[a]]*Nvec[L[c]]*Nvec[L[i]][L[d]]*Nvec[U[e]]*
Nvec[U[i]][L[j]]*Nvec[U[j]]+
f[L[a],L[e]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[L[i]][L[d]]*Nvec[U[e]]*
Nvec[U[i]][L[j]]*Nvec[U[j]]+
f[L[e]]*Nvec[L[a]]*Nvec[L[d]]*Nvec[L[i]][L[b]]*Nvec[U[e]][L[c]]*
Nvec[U[i]][L[j]]*Nvec[U[j]]+
f[L[e]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[L[i]][L[d]]*Nvec[U[e]][L[c]]*
Nvec[U[i]][L[j]]*Nvec[U[j]]+
f[L[e]]*Nvec[L[a]]*Nvec[L[c]]*Nvec[L[i]][L[b]]*Nvec[U[e]][L[d]]*
Nvec[U[i]][L[j]]*Nvec[U[j]]+
f[L[e]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[L[i]][L[c]]*Nvec[U[e]][L[d]]*
Nvec[U[i]][L[j]]*Nvec[U[j]]+
f[L[e]]*Nvec[L[a]]*Nvec[L[d]]*Nvec[L[i]][L[j]]*Nvec[U[e]]*
Nvec[U[i]][L[b],L[c]]*Nvec[U[j]]+
f[L[e]]*Nvec[L[a]]*Nvec[L[c]]*Nvec[L[i]][L[j]]*Nvec[U[e]]*
Nvec[U[i]][L[b],L[d]]*Nvec[U[j]]+
f[L[e]]*Nvec[L[a]]*Nvec[L[d]]*Nvec[L[i]][L[c]]*Nvec[U[e]]*
Nvec[U[i]][L[b],L[j]]*Nvec[U[j]]+
f[L[e]]*Nvec[L[a]]*Nvec[L[c]]*Nvec[L[i]][L[d]]*Nvec[U[e]]*
Nvec[U[i]][L[b],L[j]]*Nvec[U[j]]+
f[L[e]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[L[i]][L[j]]*Nvec[U[e]]*
Nvec[U[i]][L[c],L[d]]*Nvec[U[j]]-
f[L[i]]*Nvec[L[a]][L[e]]*Nvec[L[b]]*Nvec[L[d]]*Nvec[U[e]]*
Nvec[U[i]][L[c],L[j]]*Nvec[U[j]]+
f[L[e]]*Nvec[L[a]]*Nvec[L[d]]*Nvec[L[i]][L[b]]*Nvec[U[e]]*
Nvec[U[i]][L[c],L[j]]*Nvec[U[j]]+
f[L[e]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[L[i]][L[d]]*Nvec[U[e]]*
Nvec[U[i]][L[j],L[c]]*Nvec[U[j]]-
f[L[i]]*Nvec[L[a]][L[e]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[U[e]]*
Nvec[U[i]][L[j],L[d]]*Nvec[U[j]]+
f[L[e]]*Nvec[L[a]]*Nvec[L[c]]*Nvec[L[i]][L[b]]*Nvec[U[e]]*
Nvec[U[i]][L[j],L[d]]*Nvec[U[j]]+
f[L[e]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[L[i]][L[c]]*Nvec[U[e]]*
Nvec[U[i]][L[j],L[d]]*Nvec[U[j]]-
f[L[j]]*Nvec[L[a]][L[e],L[i]]*Nvec[L[b]]*Nvec[L[d]]*Nvec[U[e]]*
Nvec[U[i]]*Nvec[U[j]][L[c]]+
f[L[e],L[i]]*Nvec[L[a]]*Nvec[L[d]]*Nvec[L[j]][L[b]]*Nvec[U[e]]*
Nvec[U[i]]*Nvec[U[j]][L[c]]+
f[L[e]]*Nvec[L[a]][L[i]]*Nvec[L[d]]*Nvec[L[j]][L[b]]*Nvec[U[e]]*
Nvec[U[i]]*Nvec[U[j]][L[c]]-
f[L[j]]*Nvec[L[a]][L[e],L[i]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[U[e]]*
Nvec[U[i]]*Nvec[U[j]][L[d]]+
f[L[e],L[i]]*Nvec[L[a]]*Nvec[L[c]]*Nvec[L[j]][L[b]]*Nvec[U[e]]*
Nvec[U[i]]*Nvec[U[j]][L[d]]+
2*f[L[e],L[i]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[L[j]][L[c]]*Nvec[U[e]]*
Nvec[U[i]]*Nvec[U[j]][L[d]]+
f[L[e]]*Nvec[L[a]][L[i]]*Nvec[L[b]]*Nvec[L[j]][L[c]]*Nvec[U[e]]*
Nvec[U[i]]*Nvec[U[j]][L[d]]+
f[L[e],L[i],L[j],L[k]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[L[d]]*
Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*Nvec[U[k]]+
3*f[L[e],L[i],L[j]]*Nvec[L[a]][L[k]]*Nvec[L[b]]*Nvec[L[c]]*
Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*Nvec[U[k]]+
3*f[L[e],L[i]]*Nvec[L[a]][L[j],L[k]]*Nvec[L[b]]*Nvec[L[c]]*
Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*Nvec[U[k]]+
f[L[e]]*Nvec[L[a]][L[i],L[j],L[k]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[L[d]]*
Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*Nvec[U[k]]+
2*f[L[e],L[i],L[j]]*Nvec[L[a]]*Nvec[L[b]][L[k]]*Nvec[L[c]]*
Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*Nvec[U[k]]+
4*f[L[e],L[i]]*Nvec[L[a]][L[j]]*Nvec[L[b]][L[k]]*Nvec[L[c]]*
Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*Nvec[U[k]]+
2*f[L[e]]*Nvec[L[a]][L[i],L[j]]*Nvec[L[b]][L[k]]*Nvec[L[c]]*
Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*Nvec[U[k]]+
f[L[e],L[i]]*Nvec[L[a]]*Nvec[L[b]][L[j],L[k]]*Nvec[L[c]]*Nvec[L[d]]*
Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*Nvec[U[k]]+
f[L[e]]*Nvec[L[a]][L[i]]*Nvec[L[b]][L[j],L[k]]*Nvec[L[c]]*
Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*Nvec[U[k]]+
f[L[e],L[i],L[j]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[L[c]][L[k]]*Nvec[L[d]]*
Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*Nvec[U[k]]+
2*f[L[e],L[i]]*Nvec[L[a]][L[j]]*Nvec[L[b]]*Nvec[L[c]][L[k]]*
Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*Nvec[U[k]]+
f[L[e]]*Nvec[L[a]][L[i],L[j]]*Nvec[L[b]]*Nvec[L[c]][L[k]]*
Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*Nvec[U[k]]+
f[L[e],L[i]]*Nvec[L[a]]*Nvec[L[b]][L[j]]*Nvec[L[c]][L[k]]*
Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*Nvec[U[k]]+
f[L[e]]*Nvec[L[a]][L[i]]*Nvec[L[b]][L[j]]*Nvec[L[c]][L[k]]*
Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*Nvec[U[k]]+
3*f[L[e],L[i]]*Nvec[L[a]][L[j]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[L[d]]*
Nvec[U[e]][L[k]]*Nvec[U[i]]*Nvec[U[j]]*Nvec[U[k]]+
2*f[L[e]]*Nvec[L[a]][L[i]]*Nvec[L[b]][L[j]]*Nvec[L[c]]*Nvec[L[d]]*
Nvec[U[e]][L[k]]*Nvec[U[i]]*Nvec[U[j]]*Nvec[U[k]]+
f[L[e]]*Nvec[L[a]][L[i]]*Nvec[L[b]]*Nvec[L[c]][L[j]]*Nvec[L[d]]*
Nvec[U[e]][L[k]]*Nvec[U[i]]*Nvec[U[j]]*Nvec[U[k]]+
f[L[i]]*Nvec[L[a]][L[e],L[j]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[L[d]]*
Nvec[U[e]]*Nvec[U[i]][L[k]]*Nvec[U[j]]*Nvec[U[k]]+
f[L[e],L[i]]*Nvec[L[a]]*Nvec[L[b]][L[j]]*Nvec[L[c]]*Nvec[L[d]]*
Nvec[U[e]]*Nvec[U[i]][L[k]]*Nvec[U[j]]*Nvec[U[k]]+
f[L[e]]*Nvec[L[a]][L[i]]*Nvec[L[b]][L[j]]*Nvec[L[c]]*Nvec[L[d]]*
Nvec[U[e]]*Nvec[U[i]][L[k]]*Nvec[U[j]]*Nvec[U[k]]-
f[L[e],L[d]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[L[i]][L[j]]*
Nvec[U[e]]*Nvec[U[i]][L[k]]*Nvec[U[j]]*Nvec[U[k]]-
f[L[e]]*Nvec[L[a]][L[d]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[L[i]][L[j]]*
Nvec[U[e]]*Nvec[U[i]][L[k]]*Nvec[U[j]]*Nvec[U[k]]-
f[L[e]]*Nvec[L[a]]*Nvec[L[b]][L[d]]*Nvec[L[c]]*Nvec[L[i]][L[j]]*
Nvec[U[e]]*Nvec[U[i]][L[k]]*Nvec[U[j]]*Nvec[U[k]]-
f[L[e]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[L[c]][L[d]]*Nvec[L[i]][L[j]]*
Nvec[U[e]]*Nvec[U[i]][L[k]]*Nvec[U[j]]*Nvec[U[k]]-
f[L[e],L[c]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[L[d]]*Nvec[L[i]][L[j]]*
Nvec[U[e]]*Nvec[U[i]][L[k]]*Nvec[U[j]]*Nvec[U[k]]-
f[L[e]]*Nvec[L[a]]*Nvec[L[b]][L[c]]*Nvec[L[d]]*Nvec[L[i]][L[j]]*
Nvec[U[e]]*Nvec[U[i]][L[k]]*Nvec[U[j]]*Nvec[U[k]]-
f[L[e],L[b]]*Nvec[L[a]]*Nvec[L[c]]*Nvec[L[d]]*Nvec[L[i]][L[j]]*
Nvec[U[e]]*Nvec[U[i]][L[k]]*Nvec[U[j]]*Nvec[U[k]]-
f[L[a],L[e]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[L[d]]*Nvec[L[i]][L[j]]*
Nvec[U[e]]*Nvec[U[i]][L[k]]*Nvec[U[j]]*Nvec[U[k]]-
f[L[e]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[L[d]]*Nvec[L[i]][L[j]]*
Nvec[U[e]][L[c]]*Nvec[U[i]][L[k]]*Nvec[U[j]]*Nvec[U[k]]-
f[L[e]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[L[i]][L[j]]*
Nvec[U[e]][L[d]]*Nvec[U[i]][L[k]]*Nvec[U[j]]*Nvec[U[k]]-
2*f[L[e]]*Nvec[L[a]]*Nvec[L[c]]*Nvec[L[d]]*Nvec[L[i]][L[b]]*
Nvec[U[e]][L[j]]*Nvec[U[i]][L[k]]*Nvec[U[j]]*Nvec[U[k]]-
f[L[e]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[L[d]]*Nvec[L[i]][L[c]]*
Nvec[U[e]][L[j]]*Nvec[U[i]][L[k]]*Nvec[U[j]]*Nvec[U[k]]-
f[L[e]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[L[i]][L[d]]*
Nvec[U[e]][L[j]]*Nvec[U[i]][L[k]]*Nvec[U[j]]*Nvec[U[k]]-
2*f[L[e]]*Nvec[L[a]]*Nvec[L[c]]*Nvec[L[d]]*Nvec[L[i]][L[j]]*
Nvec[U[e]]*Nvec[U[i]][L[b],L[k]]*Nvec[U[j]]*Nvec[U[k]]-
f[L[e]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[L[d]]*Nvec[L[i]][L[j]]*Nvec[U[e]]*
Nvec[U[i]][L[c],L[k]]*Nvec[U[j]]*Nvec[U[k]]+
f[L[i]]*Nvec[L[a]][L[e]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[L[d]]*Nvec[U[e]]*
Nvec[U[i]][L[j],L[k]]*Nvec[U[j]]*Nvec[U[k]]-
f[L[e]]*Nvec[L[a]]*Nvec[L[c]]*Nvec[L[d]]*Nvec[L[i]][L[b]]*Nvec[U[e]]*
Nvec[U[i]][L[j],L[k]]*Nvec[U[j]]*Nvec[U[k]]-
f[L[e]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[L[d]]*Nvec[L[i]][L[c]]*Nvec[U[e]]*
Nvec[U[i]][L[j],L[k]]*Nvec[U[j]]*Nvec[U[k]]-
f[L[e]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[L[i]][L[d]]*Nvec[U[e]]*
Nvec[U[i]][L[j],L[k]]*Nvec[U[j]]*Nvec[U[k]]-
f[L[e]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[L[d]]*Nvec[L[i]][L[j]]*Nvec[U[e]]*
Nvec[U[i]][L[k],L[c]]*Nvec[U[j]]*Nvec[U[k]]-
2*f[L[e]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[L[i]][L[j]]*
Nvec[U[e]]*Nvec[U[i]][L[k],L[d]]*Nvec[U[j]]*Nvec[U[k]]+
f[L[j]]*Nvec[L[a]][L[e],L[i]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[L[d]]*
Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]][L[k]]*Nvec[U[k]]-
2*f[L[e],L[i]]*Nvec[L[a]]*Nvec[L[c]]*Nvec[L[d]]*Nvec[L[j]][L[b]]*
Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]][L[k]]*Nvec[U[k]]-
f[L[e]]*Nvec[L[a]][L[i]]*Nvec[L[c]]*Nvec[L[d]]*Nvec[L[j]][L[b]]*
Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]][L[k]]*Nvec[U[k]]-
f[L[e]]*Nvec[L[a]]*Nvec[L[c]][L[i]]*Nvec[L[d]]*Nvec[L[j]][L[b]]*
Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]][L[k]]*Nvec[U[k]]-
3*f[L[e],L[i]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[L[d]]*Nvec[L[j]][L[c]]*
Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]][L[k]]*Nvec[U[k]]-
2*f[L[e]]*Nvec[L[a]][L[i]]*Nvec[L[b]]*Nvec[L[d]]*Nvec[L[j]][L[c]]*
Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]][L[k]]*Nvec[U[k]]-
f[L[e]]*Nvec[L[a]]*Nvec[L[b]][L[i]]*Nvec[L[d]]*Nvec[L[j]][L[c]]*
Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]][L[k]]*Nvec[U[k]]-
3*f[L[e],L[i]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[L[j]][L[d]]*
Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]][L[k]]*Nvec[U[k]]-
f[L[e]]*Nvec[L[a]][L[i]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[L[j]][L[d]]*
Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]][L[k]]*Nvec[U[k]]-
f[L[e]]*Nvec[L[a]]*Nvec[L[b]][L[i]]*Nvec[L[c]]*Nvec[L[j]][L[d]]*
Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]][L[k]]*Nvec[U[k]]+
2*f[L[e]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[L[d]]*
Nvec[L[i]][L[j]]*Nvec[U[e]][L[k]]*Nvec[U[i]][L[l]]*Nvec[U[j]]*
Nvec[U[k]]*Nvec[U[l]]+3*f[L[e]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[L[c]]*
Nvec[L[d]]*Nvec[L[i]][L[j]]*Nvec[U[e]]*Nvec[U[i]][L[k],L[l]]*
Nvec[U[j]]*Nvec[U[k]]*Nvec[U[l]]+
4*f[L[e],L[i]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[L[d]]*
Nvec[L[j]][L[k]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]][L[l]]*Nvec[U[k]]*
Nvec[U[l]]+2*f[L[e]]*Nvec[L[a]][L[i]]*Nvec[L[b]]*Nvec[L[c]]*
Nvec[L[d]]*Nvec[L[j]][L[k]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]][L[l]]*
Nvec[U[k]]*Nvec[U[l]]+2*f[L[e]]*Nvec[L[a]]*Nvec[L[b]][L[i]]*
Nvec[L[c]]*Nvec[L[d]]*Nvec[L[j]][L[k]]*Nvec[U[e]]*Nvec[U[i]]*
Nvec[U[j]][L[l]]*Nvec[U[k]]*Nvec[U[l]]+
f[L[e]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[L[c]][L[i]]*Nvec[L[d]]*
Nvec[L[j]][L[k]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]][L[l]]*Nvec[U[k]]*
Nvec[U[l]],
NewRule->True];

DefineRule[ExpandfDThree,
  fDThree[L[a],L[b],L[c]],
f[L[a],L[b],L[c]]-
f[L[d],L[b],L[c]]*Nvec[L[a]]*Nvec[U[d]]-
f[L[d],L[c]]*Nvec[L[a]][L[b]]*Nvec[U[d]]-
f[L[d],L[b]]*Nvec[L[a]][L[c]]*Nvec[U[d]]-
f[L[d]]*Nvec[L[a]][L[b],L[c]]*Nvec[U[d]]-
f[L[a],L[d],L[c]]*Nvec[L[b]]*Nvec[U[d]]-
f[L[a],L[d]]*Nvec[L[b]][L[c]]*Nvec[U[d]]-
f[L[a],L[b],L[d]]*Nvec[L[c]]*Nvec[U[d]]-
f[L[d]]*Nvec[L[a]][L[b]]*Nvec[U[d]][L[c]]+
f[L[d],L[e],L[c]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[U[d]]*Nvec[U[e]]+
f[L[d],L[e]]*Nvec[L[a]][L[c]]*Nvec[L[b]]*Nvec[U[d]]*Nvec[U[e]]+
f[L[d],L[c]]*Nvec[L[a]][L[e]]*Nvec[L[b]]*Nvec[U[d]]*Nvec[U[e]]+
f[L[d]]*Nvec[L[a]][L[e],L[c]]*Nvec[L[b]]*Nvec[U[d]]*Nvec[U[e]]+
f[L[d],L[e]]*Nvec[L[a]]*Nvec[L[b]][L[c]]*Nvec[U[d]]*Nvec[U[e]]+
f[L[d]]*Nvec[L[a]][L[e]]*Nvec[L[b]][L[c]]*Nvec[U[d]]*Nvec[U[e]]+
f[L[d],L[b],L[e]]*Nvec[L[a]]*Nvec[L[c]]*Nvec[U[d]]*Nvec[U[e]]+
f[L[d],L[e]]*Nvec[L[a]][L[b]]*Nvec[L[c]]*Nvec[U[d]]*Nvec[U[e]]+
f[L[d],L[b]]*Nvec[L[a]][L[e]]*Nvec[L[c]]*Nvec[U[d]]*Nvec[U[e]]+
f[L[d]]*Nvec[L[a]][L[b],L[e]]*Nvec[L[c]]*Nvec[U[d]]*Nvec[U[e]]+
f[L[a],L[d],L[e]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[U[d]]*Nvec[U[e]]+
f[L[a],L[d]]*Nvec[L[b]][L[e]]*Nvec[L[c]]*Nvec[U[d]]*Nvec[U[e]]+
f[L[d]]*Nvec[L[a]][L[e]]*Nvec[L[b]]*Nvec[U[d]][L[c]]*Nvec[U[e]]+
f[L[d]]*Nvec[L[a]][L[b]]*Nvec[L[c]]*Nvec[U[d]][L[e]]*Nvec[U[e]]-
f[L[d]]*Nvec[L[a]]*Nvec[L[e]][L[b]]*Nvec[U[d]]*Nvec[U[e]][L[c]]-
f[L[d],L[e],L[i]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[U[d]]*
Nvec[U[e]]*Nvec[U[i]]-2*f[L[d],L[e]]*Nvec[L[a]][L[i]]*Nvec[L[b]]*
Nvec[L[c]]*Nvec[U[d]]*Nvec[U[e]]*Nvec[U[i]]-
f[L[d]]*Nvec[L[a]][L[e],L[i]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[U[d]]*
Nvec[U[e]]*Nvec[U[i]]-f[L[d],L[e]]*Nvec[L[a]]*Nvec[L[b]][L[i]]*
Nvec[L[c]]*Nvec[U[d]]*Nvec[U[e]]*Nvec[U[i]]-
f[L[d]]*Nvec[L[a]][L[e]]*Nvec[L[b]][L[i]]*Nvec[L[c]]*Nvec[U[d]]*
Nvec[U[e]]*Nvec[U[i]]-f[L[d]]*Nvec[L[a]][L[e]]*Nvec[L[b]]*
Nvec[L[c]]*Nvec[U[d]][L[i]]*Nvec[U[e]]*Nvec[U[i]]+
f[L[d]]*Nvec[L[a]]*Nvec[L[c]]*Nvec[L[e]][L[b]]*Nvec[U[d]]*
Nvec[U[e]][L[i]]*Nvec[U[i]]+
f[L[d]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[L[e]][L[c]]*Nvec[U[d]]*
Nvec[U[e]][L[i]]*Nvec[U[i]]-
f[L[d]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[L[e]][L[i]]*Nvec[U[d]]*
Nvec[U[e]][L[j]]*Nvec[U[i]]*Nvec[U[j]],
NewRule->True];

DefineRule[ExpandfDTwo,
  fDTwo[L[i],L[j]],
  f[L[i],L[j]]-f[L[a],L[j]]*Nvec[L[i]]*Nvec[U[a]]-f[L[a]]*Nvec[L[i]][L[j]]*
  Nvec[U[a]]-f[L[i],L[a]]*Nvec[L[j]]*Nvec[U[a]]+f[L[a],L[b]]*Nvec[L[i]]*Nvec[L[j]]*
  Nvec[U[a]]*Nvec[U[b]]+f[L[a]]*Nvec[L[i]][L[b]]*Nvec[L[j]]*Nvec[U[a]]*Nvec[U[b]],
  NewRule->True];

DefineRule[ExpandfDOne,
  fDOne[L[i]],f[L[a]]*PiPro[L[i],U[a]],
NewRule->True];

(*** End of file ***)
