(*
  ~/ljp/rsd/sub/gen/dtm3/June8.m

  Date last modified:  26 August 2017

  File created in June, 2008.

  Contains definitions related to problems involving hypersurfaces.

  26 August 2017:  Adding NvecThreeToFake
  4 August 2011:  Adding NvecClean
  1 July 2010:  Adding NbNbSigHatEta
  29 June 2010:  Adding NvecZS
  29 June 2010:  Adding YToYS, ZToZS, XToXS
  20 June 2010:  Chaning pres to pres1
  5 June 2010:  PartsSFFbb, PartsTfSFFbb
  2 April 2010:  incorporating amn into DOpSig.
  18 March 2010:  Adding PartsNvecThree
  13 March 2010:  Adding TotallyIntrinsicTractorSFF, amn.
  1 March 2010:  Adding NvecOneNvecOneToFakeNvecOne, etc.
  28 February 2010:  Adding PseudoOne, PseudoTwo, NvecOneToFake
  7 February 2010:  Adding PartsSFF and PartsTfSFF
  6 February 2010:  Adding NvecTwoToFake
  3 February 2010:  Adding function ToNbNvec
  1 February 2010:  Adding rule KillTraceTfSFF, function ToTfSFF
  1 August 2009:  Adding NbNbNbHatZeroW
  9 July 2009:  NbHatOneW, NbNbHatOneW, NbNbNbHatOneW
  7 July 2009:  Adding YSHat, ZSHat, XSHat
  5 July 2009:  Adding DABOp
  3 July 2009:  Adding covariant derivatives for conformal metric.
  27 June 2009:  Adding rule NvecPermute
  26 June 2009:  Adding tractor second fundamental form (TracSFF).
  25 June 2009:  Adding rule DivNvecToHmc
  20 June 2009:  Adding macros to combine Y, Z, and X tractors.
  18 June 2009:  Copying over tractor curvature definitions
  11 June 2009:  Adding the Robin operator
  25 April 2009:  Adding function SFFShuffle
  16 April 2009:  Adding LapSigHatDen
  14 January 2009:  Introducing RhoSigmaHat
  3 January 2009:  Changing the definitions of NSigTwo, NSigThree,
                   NSigFour.  Adding derivatives of intrinsic splitting
                   tractors.
  2 January 2009:  Fixing dimension in TrPSigma and RhoSigma
  5 September 2008:  Adding YYPPSg, ZZPPSg, XXPPSg
  1 September 2008:  Adding PiProTra and Ntra
  13 August 2008:  Adding Weingarten rules
  12 August 2008:  Adding R-Sigma
  5 August 2008:  Adding another Nvec rule.
  4 August 2008:  Adding NSgmf function definition.
  3 August 2008:  Removing definition of mean curvature HHH.
  25 July 2008:  Second order covariant derivative under conformal
                 metric
  8 July 2008:   Tools for embedding tangent bundle of submanifold.
  30 June 2008:  adding definitions associated with conformal
                 change of metric.
*)

SubMfd::AAAA="Index at wrong elevation."
SubMfd::BBBB="Index names must match."

(******************************************************************)
(*
  The normal vector.  This vector has weight -1 and is conformally
  invariant.  This is used in NvecRule and in the Weingarten rules.
*)

DefineTensor[Nvec,1,Variance->Contravariant];
DefineTensor[ZZZZNvec,1,Variance->Contravariant]; (* Same as Nvec *)
DefineTensor[ZZNvecOne,2];
DefineTensor[ZZNvecTwo,3];
DefineTensor[ZZNvecThree,4];

(* The normal tractor.  This has weight zero. *)

DefineTensor[Ntra,1,Bundle->tractor1,Variance->Contravariant];

(*
  The mean curvature H.  This scalar function has weight -1.
*)

DefineTensor[Hmc,0];
DefineTensor[HmcH,0];   (* Mean curvature under the conformal metric. *)

DefineRule[ExpandNtra,
  Ntra[U[AA]],
  Nvec[U[i]]Z[U[AA],L[i]]-Hmc*X[U[AA]],
  NewRule->True];

(******************************************************************)
(*
R-Sigma

The Riemannian curvature tensor for Sigma as embedded into
the ambient manifold.  This definition makes no assumptions about
dimension except for the fact that the dimension of Sigma is one less
than the ambient dimension.  We assume that there is a well-defined
normal vector.
*)

DefineTensor[RSigma,4,Variance->Covariant];

DefineRule[ExpandRSigma,
RSigma[L[i],L[j],L[k],L[l]],
   -(Nvec[L[i]][L[l]]*Nvec[L[j]][L[k]])+ 
   Nvec[L[i]][L[k]]*Nvec[L[j]][L[l]]- 
   Nvec[L[i]][L[m]]*Nvec[L[j]][L[l]]*Nvec[L[k]]*Nvec[U[m]]+ 
   Nvec[L[i]][L[l]]*Nvec[L[j]][L[m]]*Nvec[L[k]]*Nvec[U[m]]+ 
   Nvec[L[i]][L[m]]*Nvec[L[j]][L[k]]*Nvec[L[l]]*Nvec[U[m]]- 
   Nvec[L[i]][L[k]]*Nvec[L[j]][L[m]]*Nvec[L[l]]*Nvec[U[m]]+ 
   Rm[L[i],L[j],L[k],L[l]]- 
   Nvec[L[l]]*Nvec[U[m]]*Rm[L[i],L[j],L[k],L[m]]+ 
   Nvec[L[k]]*Nvec[U[m]]*Rm[L[i],L[j],L[l],L[m]]- 
   Nvec[L[j]]*Nvec[U[m]]*Rm[L[i],L[m],L[k],L[l]]+ 
   Nvec[L[j]]*Nvec[L[l]]*Nvec[U[m]]*Nvec[U[p]]*Rm[L[i],L[m],L[k],L[p]]- 
   Nvec[L[j]]*Nvec[L[k]]*Nvec[U[m]]*Nvec[U[p]]*Rm[L[i],L[m],L[l],L[p]]+ 
   Nvec[L[i]]*Nvec[U[m]]*Rm[L[j],L[m],L[k],L[l]]- 
   Nvec[L[i]]*Nvec[L[l]]*Nvec[U[m]]*Nvec[U[p]]*Rm[L[j],L[m],L[k],L[p]]+ 
   Nvec[L[i]]*Nvec[L[k]]*Nvec[U[m]]*Nvec[U[p]]*Rm[L[j],L[m],L[l],L[p]],
NewRule->True];

(******************************************************************)
(* Rc-Sigma

The Ricci tensor of the submanifold as embedded into the ambient
manifold.
*)

DefineTensor[RicciSigma,2,Variance->Covariant];

DefineRule[ExpandRicciSigma,
RicciSigma[L[i],L[j]],
   -(Nvec[L[i]][L[k]]*Nvec[U[k]][L[j]]) + 
   Nvec[L[i]][L[j]]*Nvec[U[k]][L[k]]+ 
   Nvec[L[i]][L[k]]*Nvec[L[j]]*Nvec[U[k]][L[l]]*Nvec[U[l]]- 
   Nvec[L[i]][L[k]]*Nvec[L[j]]*Nvec[U[k]]*Nvec[U[l]][L[l]]+ 
   Rc[L[i],L[j]]- Nvec[L[j]]*Nvec[U[k]]*Rc[L[i],L[k]]- 
   Nvec[L[i]]*Nvec[U[k]]*Rc[L[j],L[k]]+ 
   Nvec[L[i]]*Nvec[L[j]]*Nvec[U[k]]*Nvec[U[l]]*Rc[L[k],L[l]]- 
   Nvec[U[k]]*Nvec[U[l]]*Rm[L[i],L[k],L[j],L[l]],
NewRule->True];

(******************************************************************)
(* Scalar-Sigma

The scalar curvature of the submanifold as expressed in terms of
ambient objects.
*)

DefineTensor[ScalarSigma,0];

DefineRule[ExpandScalarSigma,
ScalarSigma,
  -(Nvec[U[i]][L[j]]*Nvec[U[j]][L[i]])+ 
  Nvec[U[i]][L[i]]*Nvec[U[j]][L[j]]- 
  2*Nvec[U[i]]*Nvec[U[j]]*Rc[L[i],L[j]]+Sc,
NewRule->True];

(******************************************************************)
(* J-tensor associated with Sigma*)

DefineTensor[TrPSigma,0];

DefineRule[ExpandTrPSigma,
                 TrPSigma,
-(Nvec[U[i]][L[j]]*Nvec[U[j]][L[i]])/(2*(-2+n))+
(Nvec[U[i]][L[i]]*Nvec[U[j]][L[j]])/(2*(-2+n))-
Nvec[U[i]]*Nvec[U[j]]*P[L[i],L[j]]+P[L[i],U[i]],
NewRule->True];

(******************************************************************)
(* The rho-tensor associated with Sigma as embedded into the ambient
   tensor space*)

DefineTensor[RhoSigma,2,Variance->Covariant];

DefineRule[ExpandRhoSigma,
                 RhoSigma[L[i1],L[j1]],
(Nvec[L[i1]][L[j1]]*Nvec[U[i]][L[i]])/(-3+n)-
(Nvec[L[i1]][L[i]]*Nvec[U[i]][L[j1]])/(-3+n)+
(Nvec[L[i1]][L[i]]*Nvec[L[j1]]*Nvec[U[i]][L[j]]*Nvec[U[j]])/(-3+n)+
(g[L[i1],L[j1]]*Nvec[U[i]][L[j]]*Nvec[U[j]][L[i]])/
(2*(-3+n)*(-2+n))-(Nvec[L[i1]]*Nvec[L[j1]]*Nvec[U[i]][L[j]]*
Nvec[U[j]][L[i]])/(2*(-3+n)*(-2+n))-
(Nvec[L[i1]][L[i]]*Nvec[L[j1]]*Nvec[U[i]]*Nvec[U[j]][L[j]])/(-3+n)-
(g[L[i1],L[j1]]*Nvec[U[i]][L[i]]*Nvec[U[j]][L[j]])/
(2*(-3+n)*(-2+n))+(Nvec[L[i1]]*Nvec[L[j1]]*Nvec[U[i]][L[i]]*
Nvec[U[j]][L[j]])/(2*(-3+n)*(-2+n))+
Nvec[L[i1]]*Nvec[L[j1]]*Nvec[U[i]]*Nvec[U[j]]*P[L[i],L[j]]-
Nvec[L[j1]]*Nvec[U[i]]*P[L[i],L[i1]]-
Nvec[L[i1]]*Nvec[U[i]]*P[L[i],L[j1]]+P[L[i1],L[j1]]-
(Nvec[U[i]]*Nvec[U[j]]*Weyl[L[i],L[i1],L[j],L[j1]])/(-3+n),
NewRule->True];

(******************************************************************)

DefineTensor[ups,0];              (* The upsilon function *)
DefineTensor[psi,0];

(******************************************************************)
(* The rho-tensor associated with Sigma and the conformal metric,
   as embedded into the ambient tensor space*)

DefineTensor[RhoSigmaHat,2,Symmetries->Symmetric];

DefineRule[ExpandRhoSigmaHat,
RhoSigmaHat[L[i],L[j]],
  -((Nvec[L[i]][L[k]]*Nvec[U[k]][L[j]])/(-3+n))+
  (Nvec[L[i]][L[j]]*Nvec[U[k]][L[k]])/(-3+n)+
  (Nvec[L[i]][L[k]]*Nvec[L[j]]*Nvec[U[k]][L[l]]*Nvec[U[l]])/(-3+n)+
  (g[L[i],L[j]]*Nvec[U[k]][L[l]]*Nvec[U[l]][L[k]])/
  (2*(-3+n)*(-2+n))-(Nvec[L[i]]*Nvec[L[j]]*Nvec[U[k]][L[l]]*
  Nvec[U[l]][L[k]])/(2*(-3+n)*(-2+n))-
  (Nvec[L[i]][L[k]]*Nvec[L[j]]*Nvec[U[k]]*Nvec[U[l]][L[l]])/(-3+n)-
  (g[L[i],L[j]]*Nvec[U[k]][L[k]]*Nvec[U[l]][L[l]])/
  (2*(-3+n)*(-2+n))+(Nvec[L[i]]*Nvec[L[j]]*Nvec[U[k]][L[k]]*
  Nvec[U[l]][L[l]])/(2*(-3+n)*(-2+n))+P[L[i],L[j]]-
  Nvec[L[j]]*Nvec[U[k]]*P[L[i],L[k]]-
  Nvec[L[i]]*Nvec[U[k]]*P[L[j],L[k]]+
  Nvec[L[i]]*Nvec[L[j]]*Nvec[U[k]]*Nvec[U[l]]*P[L[k],L[l]]+
  ups[][L[i]]*ups[][L[j]]+Nvec[L[j]][L[i]]*Nvec[U[k]]*ups[][L[k]]-
  Nvec[L[j]]*Nvec[U[k]]*ups[][L[i]]*ups[][L[k]]-
  Nvec[L[i]]*Nvec[U[k]]*ups[][L[j]]*ups[][L[k]]-
  Nvec[L[i]]*Nvec[L[j]][L[k]]*Nvec[U[k]]*Nvec[U[l]]*ups[][L[l]]+
  (g[L[i],L[j]]*Nvec[U[k]]*Nvec[U[l]]*ups[][L[k]]*ups[][L[l]])/2+
  (Nvec[L[i]]*Nvec[L[j]]*Nvec[U[k]]*Nvec[U[l]]*ups[][L[k]]*ups[][L[l]])/
  2-(g[L[i],L[j]]*ups[][L[k]]*ups[][U[k]])/2+
  (Nvec[L[i]]*Nvec[L[j]]*ups[][L[k]]*ups[][U[k]])/2-ups[][L[j],L[i]]+
  Nvec[L[i]]*Nvec[U[k]]*ups[][L[j],L[k]]+
  Nvec[L[j]]*Nvec[U[k]]*ups[][L[k],L[i]]-
  Nvec[L[i]]*Nvec[L[j]]*Nvec[U[k]]*Nvec[U[l]]*ups[][L[k],L[l]]-
  (Nvec[U[k]]*Nvec[U[l]]*Weyl[L[i],L[k],L[j],L[l]])/(-3+n),
NewRule->True];

(******************************************************************)
(* The J-tensor associated with Sigma and the conformal metric,
   as embedded into the ambient tensor space*)

DefineTensor[TrPSigmaHat,0];

DefineRule[ExpandTrPSigmaHat,
  TrPSigmaHat,
    -(Nvec[U[i]][L[j]]*Nvec[U[j]][L[i]])/(2*(-2+n))+
    (Nvec[U[i]][L[i]]*Nvec[U[j]][L[j]])/(2*(-2+n))-
    Nvec[U[i]]*Nvec[U[j]]*P[L[i],L[j]]+P[L[i],U[i]]+
    Nvec[U[i]][L[i]]*Nvec[U[j]]*ups[][L[j]]+
    ((-3+n)*Nvec[U[i]]*Nvec[U[j]]*ups[][L[i]]*ups[][L[j]])/2+
    ((3-n)*ups[][L[i]]*ups[][U[i]])/2+
    Nvec[U[i]]*Nvec[U[j]]*ups[][L[i],L[j]]-ups[][L[i],U[i]],
  NewRule->True];

(******************************************************************)
(* Projector things. *)
(******************************************************************)

DefineTensor[YH,1,Bundle->tractor1,Variance->Con];
DefineTensor[ZH,{1,1},Bundle->{tractor1,tangent},Variance->{Con,Con}];
DefineTensor[XH,1,Bundle->tractor1,Variance->Con];

DefineRule[ExpandYH,
  YH[U[AA]],
  Y[U[AA]]-ups[U[i]]Z[U[AA],L[i]]-(1/2)ups[L[i]]ups[U[i]]X[U[AA]],
  NewRule->True];

DefineRule[ExpandZH,
  ZH[U[AA],L[i]],
  Z[U[AA],L[i]]+ups[L[i]]X[U[AA]],
  NewRule->True];

DefineRule[ExpandXH,XH,X,NewRule->True];

(******************************************************************)

(* Riemann tensor for conformal metric.

   The following tensor and its expansion assume that all four
   indices are down and that all terms are weight-two objects.
   RmH has an implied [(\hat{g},1)]_2 attached, and all terms of the
   expansion have an implied [(g,1)]_2 attached.  You may raise indices,
   but pay attention to weights and metrics.
 *)

DefineTensor[RmH,4,Variance->Covariant];

DefineRule[ExpandRmH,
  RmH[L[i],L[j],L[k],L[l]],
   Rm[L[i],L[j],L[k],L[l]]
  -g[L[k],L[i]]ups[L[l],L[j]]
  +g[L[k],L[j]]ups[L[l],L[i]]
  +g[L[k],L[i]]ups[L[l]]ups[L[j]]
  -g[L[k],L[j]]ups[L[l]]ups[L[i]]
  -g[L[l],L[j]]ups[L[k],L[i]]
  +g[L[l],L[i]]ups[L[k],L[j]]
  +g[L[l],L[j]]ups[L[k]]ups[L[i]]
  -g[L[l],L[i]]ups[L[k]]ups[L[j]]
  -g[L[k],L[i]]g[L[j],L[l]]ups[L[p]]ups[U[p]]
  +g[L[k],L[j]]g[L[i],L[l]]ups[L[p]]ups[U[p]],
  NewRule->True];

(*
  Rho-tensor for conformal metric.

  This tensor has weight zero, so you may assume that densities
  are not involved.
*)

DefineTensor[PH,2,Variance->Covariant];

DefineRule[ExpandPH,
  PH[L[i],L[j]],
  P[L[i],L[j]]-ups[L[j],L[i]]+ups[L[i]]ups[L[j]]
  -(1/2)g[L[i],L[j]]ups[L[k]]ups[U[k]],
  NewRule->True];

(*
  J-tensor for conformal metric.

  This tensor has weight -2.  You should assume that TrPH has
  an implied [(\hat{g},1)]_{-2} attached.  You should assume that each
  term on the right-hand side has an implied [(g,1)]_{-2} attached.
*)

DefineTensor[TrPH,0];

DefineRule[ExpandTrPH,
  TrPH,
  TrP-ups[L[i],U[i]]+((2-n)/2)ups[L[i]]ups[U[i]],
  NewRule->True];

(*
  The following definitions show how the three parts of a tractor
  change under conformal change of the metric used in splitting the
  tractor bundle.
*)

DefineTensor[sgm,0];
DefineTensor[sgmH,0];
DefineTensor[mu,1,Variance->Contravariant];
DefineTensor[muH,1,Variance->Contravariant];
DefineTensor[rho,0];
DefineTensor[rhoH,0];

DefineRule[ExpandsgmH,sgmH,sgm,NewRule->True];

DefineRule[ExpandmuH,
  muH[U[i]],
  mu[U[i]]+ups[U[i]]sgm,
  NewRule->True];

DefineRule[ExpandrhoH,
  rhoH,
  rho-ups[L[i]]mu[U[i]]-(1/2)ups[U[i]]ups[L[i]]sgm,
  NewRule->True];

(*
  muSgm:  mu-Sigma, a contravariant tensor of rank one and weight
  minus one defined on the submanifold Sigma.
*)

DefineTensor[muSgm,1,Variance->Contravariant];

(*
  The following vector fields are assumed to be tangent to Sigma
  along Sigma.  These are used in NvecRule and in the Weingarten
  rules.
*)

DefineTensor[VVSgm,1,Variance->Contravariant];
DefineTensor[WWSgm,1,Variance->Contravariant];
DefineTensor[XXSgm,1,Variance->Contravariant];
DefineTensor[YYSgm,1,Variance->Contravariant];
DefineTensor[ZZSgm,1,Variance->Contravariant];


(******************************************************************)
(* Weingarten rules.

   See Theorem 8, Chapter 1, in Volume III of the five-volume work by
   Spivak.  The following rules are valid along Sigma.
*)

(*****)

DefineRule[WeingartenVVWW,
  Nvec[L[i]][L[j]]VVSgm[U[i]]WWSgm[U[j]],
  Nvec[L[i]][L[j]]VVSgm[U[j]]WWSgm[U[i]],
NewRule->True];

DefineRule[WeingartenVVXX,
  Nvec[L[i]][L[j]]VVSgm[U[i]]XXSgm[U[j]],
  Nvec[L[i]][L[j]]VVSgm[U[j]]XXSgm[U[i]],
NewRule->True];

DefineRule[WeingartenVVYY,
  Nvec[L[i]][L[j]]VVSgm[U[i]]YYSgm[U[j]],
  Nvec[L[i]][L[j]]VVSgm[U[j]]YYSgm[U[i]],
NewRule->True];

DefineRule[WeingartenVVZZ,
  Nvec[L[i]][L[j]]VVSgm[U[i]]ZZSgm[U[j]],
  Nvec[L[i]][L[j]]VVSgm[U[j]]ZZSgm[U[i]],
NewRule->True];

(*****)

DefineRule[WeingartenWWVV,
  Nvec[L[i]][L[j]]WWSgm[U[i]]VVSgm[U[j]],
  Nvec[L[i]][L[j]]WWSgm[U[j]]VVSgm[U[i]],
NewRule->True];

DefineRule[WeingartenWWXX,
  Nvec[L[i]][L[j]]WWSgm[U[i]]XXSgm[U[j]],
  Nvec[L[i]][L[j]]WWSgm[U[j]]XXSgm[U[i]],
NewRule->True];

DefineRule[WeingartenWWYY,
  Nvec[L[i]][L[j]]WWSgm[U[i]]YYSgm[U[j]],
  Nvec[L[i]][L[j]]WWSgm[U[j]]YYSgm[U[i]],
NewRule->True];

DefineRule[WeingartenWWZZ,
  Nvec[L[i]][L[j]]WWSgm[U[i]]ZZSgm[U[j]],
  Nvec[L[i]][L[j]]WWSgm[U[j]]ZZSgm[U[i]],
NewRule->True];

(*****)

DefineRule[WeingartenXXVV,
  Nvec[L[i]][L[j]]XXSgm[U[i]]VVSgm[U[j]],
  Nvec[L[i]][L[j]]XXSgm[U[j]]VVSgm[U[i]],
NewRule->True];

DefineRule[WeingartenXXWW,
  Nvec[L[i]][L[j]]XXSgm[U[i]]WWSgm[U[j]],
  Nvec[L[i]][L[j]]XXSgm[U[j]]WWSgm[U[i]],
NewRule->True];

DefineRule[WeingartenXXYY,
  Nvec[L[i]][L[j]]XXSgm[U[i]]YYSgm[U[j]],
  Nvec[L[i]][L[j]]XXSgm[U[j]]YYSgm[U[i]],
NewRule->True];

DefineRule[WeingartenXXZZ,
  Nvec[L[i]][L[j]]XXSgm[U[i]]ZZSgm[U[j]],
  Nvec[L[i]][L[j]]XXSgm[U[j]]ZZSgm[U[i]],
NewRule->True];

(*****)

DefineRule[WeingartenYYVV,
  Nvec[L[i]][L[j]]YYSgm[U[i]]VVSgm[U[j]],
  Nvec[L[i]][L[j]]YYSgm[U[j]]VVSgm[U[i]],
NewRule->True];

DefineRule[WeingartenYYWW,
  Nvec[L[i]][L[j]]YYSgm[U[i]]WWSgm[U[j]],
  Nvec[L[i]][L[j]]YYSgm[U[j]]WWSgm[U[i]],
NewRule->True];

DefineRule[WeingartenYYXX,
  Nvec[L[i]][L[j]]YYSgm[U[i]]XXSgm[U[j]],
  Nvec[L[i]][L[j]]YYSgm[U[j]]XXSgm[U[i]],
NewRule->True];

DefineRule[WeingartenYYZZ,
  Nvec[L[i]][L[j]]YYSgm[U[i]]ZZSgm[U[j]],
  Nvec[L[i]][L[j]]YYSgm[U[j]]ZZSgm[U[i]],
NewRule->True];

(*****)

DefineRule[WeingartenZZVV,
  Nvec[L[i]][L[j]]ZZSgm[U[i]]VVSgm[U[j]],
  Nvec[L[i]][L[j]]ZZSgm[U[j]]VVSgm[U[i]],
NewRule->True];

DefineRule[WeingartenZZWW,
  Nvec[L[i]][L[j]]ZZSgm[U[i]]WWSgm[U[j]],
  Nvec[L[i]][L[j]]ZZSgm[U[j]]WWSgm[U[i]],
NewRule->True];

DefineRule[WeingartenZZXX,
  Nvec[L[i]][L[j]]ZZSgm[U[i]]XXSgm[U[j]],
  Nvec[L[i]][L[j]]ZZSgm[U[j]]XXSgm[U[i]],
NewRule->True];

DefineRule[WeingartenZZYY,
  Nvec[L[i]][L[j]]ZZSgm[U[i]]YYSgm[U[j]],
  Nvec[L[i]][L[j]]ZZSgm[U[j]]YYSgm[U[i]],
NewRule->True];

(**************************************************************)

DefineRule[NvecRule,Nvec[L[i]]Nvec[U[i]],1,NewRule->True];
DefineRule[NvecRule,Nvec[L[i]]Nvec[U[i]][L[j]],0];
DefineRule[NvecRule,Nvec[L[i]][L[j]]Nvec[U[i]],0];
DefineRule[NvecRule,muSgm[L[i]]Nvec[U[i]],0];

DefineRule[NvecRule,Nvec[L[j]]VVSgm[U[j]],0];
DefineRule[NvecRule,Nvec[L[j]]WWSgm[U[j]],0];
DefineRule[NvecRule,Nvec[L[j]]XXSgm[U[j]],0];
DefineRule[NvecRule,Nvec[L[j]]YYSgm[U[j]],0];
DefineRule[NvecRule,Nvec[L[j]]ZZSgm[U[j]],0];

DefineRule[NvecToZZZZNvec,Nvec,ZZZZNvec,NewRule->True];
DefineRule[ZZZZNvecToNvec,ZZZZNvec,Nvec,NewRule->True];

DefineRule[PseudoOne,
      Nvec[L[i]][L[j]]Nvec[L[k]][L[l]],
  ZZZZNvec[L[i]][L[j]]Nvec[L[k]][L[l]],
	   NewRule->True];

DefineRule[PseudoTwo,
  Nvec[L[i]][L[j]]    Nvec[L[k]][L[l]],
  Nvec[L[i]][L[j]]ZZZZNvec[L[k]][L[l]],
  NewRule->True];

DefineRule[NvecOneToFake,
       Nvec[L[i]][L[j]],
  ZZNvecOne[L[i],L[j]],
  NewRule->True];

DefineRule[FakeToNvecOne,
  ZZNvecOne[L[i],L[j]],
       Nvec[L[i]][L[j]],
  NewRule->True];

DefineRule[NvecOneNvecOneToFakeNvecOne,
        Nvec[L[i]][L[j]]Nvec[L[k]][L[l]],
    ZZNvecOne[L[i],L[j]]Nvec[L[k]][L[l]],
    NewRule->True];

DefineRule[NvecOneNvecOneToNvecOneFake,
    Nvec[L[i]][L[j]]     Nvec[L[k]][L[l]],
    Nvec[L[i]][L[j]]ZZNvecOne[L[k],L[l]],
    NewRule->True];

DefineRule[NvecTwoToFake,
           Nvec[L[i]][L[j],L[k]],
      ZZNvecTwo[L[i],L[j],L[k]],NewRule->True];

DefineRule[FakeToNvecTwo,
      ZZNvecTwo[L[i],L[j],L[k]],
           Nvec[L[i]][L[j],L[k]],NewRule->True];

DefineRule[NvecThreeToFake,
	   Nvec[L[i]][L[j],L[k],L[l]],
    ZZNvecThree[L[i],L[j],L[k],L[l]],NewRule->True];

DefineRule[FakeToNvecThree,
    ZZNvecThree[L[i],L[j],L[k],L[l]],
	   Nvec[L[i]][L[j],L[k],L[l]],NewRule->True];

DefineRule[PartsNvec,
   Nvec[L[i]]Nvec[U[i]][L[j],L[k]],
  -Nvec[L[i]][L[j]]Nvec[U[i]][L[k]],
  NewRule->True];

DefineRule[PartsNvecThree,
   Nvec[L[a]]Nvec[U[a]][L[b],L[c],L[d]],
     -Nvec[L[a]][L[c],L[d]]Nvec[U[a]][L[b]]
     -Nvec[L[a]][L[c]]Nvec[U[a]][L[b],L[d]]
     -Nvec[L[a]][L[d]]Nvec[U[a]][L[b],L[c]],
   NewRule->True];

DefineRule[PartsNvecBB,
  Nvec[L[a]]Nvec[L[b]][L[c]]Nvec[U[c]],
  Nvec[L[b]][L[a]]-Nvec[L[a]][L[b]]+Nvec[L[a]][L[c]]Nvec[L[b]]Nvec[U[c]],
  NewRule->True];

DefineRule[NvecPermute,
  Nvec[L[i]][L[j]],
  Nvec[L[j]][L[i]]+Nvec[L[j]]Nvec[L[i]][L[a]]Nvec[U[a]]-
  Nvec[L[i]]Nvec[L[j]][L[a]]Nvec[U[a]],
  NewRule->True];

(**************************************************************)
(*
  PiPro:  The Pi projector.  This tensor is conformally invariant and
  unweighted.
*)

DefineTensor[PiPro,2,Variance->{Covariant,Contravariant}];
DefineTensor[PiProTra,2,Bundle->tractor1,
                         Variance->{Covariant,Contravariant}];

DefineRule[ExpandPiPro,
  PiPro[L[i],U[j]],
  Kronecker[L[i],U[j]]-Nvec[L[i]]Nvec[U[j]],
  NewRule->True];

DefineRule[ExpandPiProTra,
  PiProTra[L[AA],U[BB]],
  Kronecker[L[AA],U[BB]]-Ntra[L[AA]]Ntra[U[BB]],
  NewRule->True];

(**************************************************************)
(*
  gSgm:  g-Sigma, i.e. the metric on the submanifold.  If both indices
  are down, then this should be a weight-2 object.  We will assume
  that it is trivialized by means of the background metric.
*)

DefineTensor[gSgm,2,Symmetries->Symmetric];

DefineRule[ExpandgSgm,
  gSgm[L[i],L[j]],
     g[L[i],L[j]]-Nvec[L[i]]Nvec[L[j]],
  NewRule->True];

(****************************************************************)

DefineRule[TraceRhoSigma,
  gSgm[L[i],L[j]]RhoSigma[U[i],U[j]],
  TrPSigma,
  NewRule->True];

(****************************************************************)

(* Y^\Sigma, Z^\Sigma, and X^\Sigma.  See Section 5.2 of David Grant's
   master's thesis. *)

DefineTensor[YS,1,Bundle->tractor1,Variance->Contravariant];
DefineTensor[ZS,{1,1},Bundle->{tractor1,tangent},Variance->{Con,Co}];
DefineTensor[XS,1,Bundle->tractor1,Variance->Contravariant];

DefineRule[ExpandYS,
  YS[U[AA]],
  Y[U[AA]]+Z[U[AA],L[i]]Nvec[U[i]]Hmc-(1/2)Hmc*Hmc*X[U[AA]],
  NewRule->True];

DefineRule[ExpandZS,
  ZS[U[AA],U[i]],
  PiPro[L[j],U[i]]Z[U[AA],U[j]],
  NewRule->True];

DefineRule[ExpandXS,XS,X,NewRule->True];

DefineRule[YToYS,
   Y[U[AA]],
  YS[U[AA]]-Z[U[AA],U[a]]Nvec[L[a]]Hmc+(1/2)(Hmc^2)X[U[AA]],
  NewRule->True];

DefineRule[ZToZS,
   Z[U[AA],U[a]],
  ZS[U[AA],U[a]]+Nvec[L[b]]Nvec[U[a]]Z[U[AA],U[b]],
  NewRule->True];

DefineRule[XToXS,
   X[U[AA]],
  XS[U[AA]],
  NewRule->True];

(******************************************************************)
(* Derivatives of YS, ZS, and XS *)
(******************************************************************)
(*
IMPORTANT POINT:

The covariant derivatives in GradXYZSigma are intrinsic covariant
derivatives associated with the nabla that one gets on \Sigma from its
usual metric, i.e. from the metric that it inherits from the ambient
metric.
*)

DefineRule[GradXYZSigma,
  YS[U[AA]][L[i]],
  RhoSigma[L[i],L[j]]ZS[U[AA],U[j]],
  NewRule->True];

DefineRule[GradXYZSigma,
  ZS[U[AA],L[j]][L[i]],
  -RhoSigma[L[i],L[j]]XS[U[AA]]-gSgm[L[i],L[j]]YS[U[AA]]];

DefineRule[GradXYZSigma,
  XS[U[AA]][L[i]],
  ZS[U[AA], L[i]]];

(******************************************************************)
(* Intrinsic tractor inner product                                *)
(******************************************************************)

DefineRule[IProdSig,YS[L[AA]]YS[U[AA]],0];
DefineRule[IProdSig,YS[L[AA]]ZS[U[AA],L[i]],0];

DefineRule[IProdSig,ZS[L[AA],L[i]]ZS[U[AA],L[j]],gSgm[L[i],L[j]]];

DefineRule[IProdSig,XS[L[AA]]YS[U[AA]],1];
DefineRule[IProdSig,XS[L[AA]]ZS[U[AA],L[i]],0];
DefineRule[IProdSig,XS[L[AA]]XS[U[AA]],0];

DefineRule[NvecZS,Nvec[U[i]]ZS[L[AA],L[i]],0,NewRule->True];

(****************************************************************)

DefineConstant[amn];                   (* The ambient dimension *)

(****************************************************************)

(*
  In TotallyIntrinsicTractorSFF, the explicit covariant derivatives
  are assumed to be intrinsic covariant derivatives.  This is a very
  important point!

  See LIBoxLf.nb.
*)

DefineTensor[TotallyIntrinsicTractorSFF,2,Bundle->tractor1,
                                          Variance->Contravariant];

DefineRule[ExpandTotallyIntrinsicTractorSFF,
                 TotallyIntrinsicTractorSFF[L[AA],L[BB]],
  (TfSFF[L[a],L[b]][U[b],U[a]]*XS[L[AA]]*XS[L[BB]])/(-2+amn)+
  RhoSigma[L[a],L[b]]*TfSFF[U[a],U[b]]*XS[L[AA]]*XS[L[BB]]-
  ((-3+amn)*TfSFF[L[a],L[b]][U[b]]*XS[L[BB]]*ZS[L[AA],U[a]])/
  (-2+amn)-((-3+amn)*TfSFF[L[a],L[b]][U[a]]*XS[L[AA]]*
  ZS[L[BB],U[b]])/(-2+amn)+
  (-3+amn)*TfSFF[L[a],L[b]]*ZS[L[AA],U[a]]*ZS[L[BB],U[b]],
NewRule->True];

(****************************************************************)

(* Y^\Sigma, Z^\Sigma, and X^\Sigma, as constructed with the conformal
   metric.
*)

DefineTensor[YSHat,1,Bundle->tractor1,Variance->Contravariant];
DefineTensor[ZSHat,{1,1},Bundle->{tractor1,tangent},Variance->{Con,Co}];
DefineTensor[XSHat,1,Bundle->tractor1,Variance->Contravariant];
DefineRule[ExpandYSHat,
  YSHat[U[AA]],
  YS[U[AA]]-gSgm[U[a],U[b]]ups[L[b]]ZS[U[AA],L[a]]-
  (1/2)g[U[a],U[b]]PiPro[L[a],U[i]]ups[L[i]]PiPro[L[b],U[j]]ups[L[j]]XS[U[AA]],
  NewRule->True];
DefineRule[ExpandZSHat,
  ZSHat[U[AA],L[a]],
  ZS[U[AA],L[a]]+PiPro[L[a],U[i]]ups[L[i]]XS[U[AA]],
  NewRule->True];
DefineRule[ExpandXSHat,XSHat,XS,NewRule->True];

(*****************************************************************)

(*
  The second fundamental form and the trace-free second fundamental
  form

  Note:  The second fundamental form is symmetric.  To prove this, use
  Theorem 8 in Chapter 1 of the third volume of the five-volume work
  by Spivak.
*)

DefineTensor[SFF,2,Variance->Covariant,Symmetries->Symmetric];
DefineTensor[TfSFF,2,Variance->Covariant,Symmetries->Symmetric];

DefineRule[ExpandSFF,
  SFF[L[i],L[j]],
  PiPro[L[i],U[k]]Nvec[L[j]][L[k]],
  NewRule->True];

DefineRule[ExpandTfSFF,
  TfSFF[L[i],L[j]],
    SFF[L[i],L[j]]-gSgm[L[i],L[j]]Hmc,
  NewRule->True];

DefineRule[KillTraceTfSFF,TfSFF[L[i],U[i]],0,NewRule->True];

DefineRule[NbNvecToSFF,
  Nvec[L[j]][L[i]],
   SFF[L[i],L[j]]+Nvec[L[j]][L[k]]Nvec[L[i]]Nvec[U[k]],
  NewRule->True];

DefineRule[DivNvecToHmc,Nvec[U[i]][L[i]],(n-1)Hmc,NewRule->True];

DefineRule[SFFToTfSFF,
      SFF[L[i],L[j]],
    TfSFF[L[i],L[j]]+gSgm[L[i],L[j]]Hmc,
  NewRule->True];

DefineRule[NvecSFF,Nvec[U[a]]  SFF[L[a],L[b]],0,NewRule->True];
DefineRule[NvecSFF,Nvec[U[b]]  SFF[L[a],L[b]],0];
DefineRule[NvecSFF,Nvec[U[a]]TfSFF[L[a],L[b]],0];
DefineRule[NvecSFF,Nvec[U[b]]TfSFF[L[a],L[b]],0];

DefineRule[PartsSFF,
   Nvec[U[i]]      SFF[L[i],L[j]][L[k]],
  -Nvec[U[i]][L[k]]SFF[L[i],L[j]],       NewRule->True];

DefineRule[PartsSFF,
   Nvec[U[j]]      SFF[L[i],L[j]][L[k]],
  -Nvec[U[j]][L[k]]SFF[L[i],L[j]]];

DefineRule[PartsTfSFF,
   Nvec[U[i]]      TfSFF[L[i],L[j]][L[k]],
  -Nvec[U[i]][L[k]]TfSFF[L[i],L[j]],       NewRule->True];

DefineRule[PartsTfSFF,
   Nvec[U[j]]      TfSFF[L[i],L[j]][L[k]],
  -Nvec[U[j]][L[k]]TfSFF[L[i],L[j]]];

DefineRule[PartsSFFbb,
         SFF[L[a],L[b]][L[i],L[j]]Nvec[U[a]],
  -SFF[L[a],L[b]][L[i]]Nvec[U[a]][L[j]]
  -SFF[L[a],L[b]][L[j]]Nvec[U[a]][L[i]]
  -SFF[L[a],L[b]]      Nvec[U[a]][L[i],L[j]],NewRule->True];

DefineRule[PartsSFFbb,
         SFF[L[a],L[b]][L[i],L[j]]Nvec[U[b]],
  -SFF[L[a],L[b]][L[i]]Nvec[U[b]][L[j]]
  -SFF[L[a],L[b]][L[j]]Nvec[U[b]][L[i]]
  -SFF[L[a],L[b]]      Nvec[U[b]][L[i],L[j]]
];

DefineRule[PartsTfSFFbb,
         TfSFF[L[a],L[b]][L[i],L[j]]Nvec[U[a]],
  -TfSFF[L[a],L[b]][L[i]]Nvec[U[a]][L[j]]
  -TfSFF[L[a],L[b]][L[j]]Nvec[U[a]][L[i]]
  -TfSFF[L[a],L[b]]      Nvec[U[a]][L[i],L[j]],NewRule->True];

DefineRule[PartsTfSFFbb,
         TfSFF[L[a],L[b]][L[i],L[j]]Nvec[U[b]],
  -TfSFF[L[a],L[b]][L[i]]Nvec[U[b]][L[j]]
  -TfSFF[L[a],L[b]][L[j]]Nvec[U[b]][L[i]]
  -TfSFF[L[a],L[b]]      Nvec[U[b]][L[i],L[j]]
];

(* Rules for expanding the mean curvature *)

DefineRule[ExpandHmc,Hmc,(1/(n-1))Nvec[L[i]][U[i]],NewRule->True];
DefineRule[ExpandHmcH,HmcH,Hmc+ups[L[i]]Nvec[U[i]],NewRule->True];

(******************************************************************)
(*
  Rules for the covariant derivative on Sigma
*)

(*
  Nabla^{\Sigma} as applied to a function (a rank-zero tensor)
*)

NSgmf[operand_,newindex_]:=
  Module[{answer,LocalOp,Temp},
    (
      LocalOp=NewDummy[operand];
      Temp=NewDummy[ PiPro[newindex,U[pres1]]LocalOp[L[pres1]] ];
      answer=Temp;
      answer
    )
  ];

(* The following tensors are assumed to be tensors on Sigma.*)

DefineTensor[SigZero,0];
DefineTensor[SigOne,1];
DefineTensor[SigTwo,2];
DefineTensor[SigThree,3];
DefineTensor[SigFour,4];

(* The following tensors are the Sigma-covariant derivatives of
   the above tensors.  The last index slot is the index associated
   with covariant differentiation.
*)

DefineTensor[NSigZero,1];
DefineTensor[NSigOne,2];
DefineTensor[NSigTwo,3];
DefineTensor[NSigThree,4];
DefineTensor[NSigFour,5];

DefineRule[ExpandNSigZero,
  NSigZero[L[i]],
  PiPro[L[i],U[l]]SigZero[L[l]],
NewRule->True];

DefineRule[ExpandNSigOne,
  NSigOne[L[i],L[j]],
  PiPro[L[j],U[k]]PiPro[L[i],U[l]]SigOne[L[l]][L[k]],
NewRule->True];

DefineRule[ExpandNSigTwo,
  NSigTwo[L[i1],L[i2],L[i]],
  PiPro[L[i],U[p]]PiPro[L[i1],U[p1]]PiPro[L[i2],U[p2]]*
  SigTwo[L[p1],L[p2]][L[p]],
NewRule->True];

DefineRule[ExpandNSigThree,
  NSigThree[L[i1],L[i2],L[i3],L[i]],
  PiPro[L[i],U[p]]PiPro[L[i1],U[p1]]PiPro[L[i2],U[p2]]PiPro[L[i3],U[p3]]*
  SigThree[L[p1],L[p2],L[p3]][L[p]],
NewRule->True];

DefineRule[ExpandNSigFour,
  NSigFour[L[i1],L[i2],L[i3],L[i4],L[i]],
  PiPro[L[i],U[p]]*
  PiPro[L[i1],U[p1]]PiPro[L[i2],U[p2]]PiPro[L[i3],U[p3]]PiPro[L[i4],U[p4]]*
  SigFour[L[p1],L[p2],L[p3],L[p4]][L[p]],
NewRule->True];

(* The following tensors are second-order Sigma-covariant derivatives.
   The last two index slots are the indices associated with covariant
   differentiation.  The last slot is the outermost covariant
   derivative. *)

DefineTensor[NbNbSigZero,2];
DefineTensor[NbNbSigOne,3];
DefineTensor[NbNbSigTwo,4];

DefineRule[ExpandNbNbSigZero,
  NbNbSigZero[L[i2],L[i1]],
    PiPro[L[m1],U[m2]][L[m3]]*PiPro[L[i1],U[m3]]*PiPro[L[i2],U[m1]]*
    SigZero[][L[m2]]+PiPro[L[m1],U[m2]]*PiPro[L[i1],U[m3]]*
    PiPro[L[i2],U[m1]]*SigZero[][L[m2],L[m3]],
NewRule->True];

DefineRule[ExpandNbNbSigOne,
  NbNbSigOne[L[i3],L[i2],L[i1]],
    PiPro[L[m1],U[m2]]*PiPro[L[m3],U[m4]][L[m5]]*PiPro[L[i1],U[m5]]*
    PiPro[L[i2],U[m3]]*PiPro[L[i3],U[m1]]*SigOne[L[m2]][L[m4]]+
    PiPro[L[m1],U[m2]]*PiPro[L[m3],U[m4]][L[m5]]*PiPro[L[i1],U[m5]]*
    PiPro[L[i2],U[m1]]*PiPro[L[i3],U[m3]]*SigOne[L[m4]][L[m2]]+
    PiPro[L[m1],U[m2]]*PiPro[L[m3],U[m4]]*PiPro[L[i1],U[m5]]*PiPro[L[i2],U[m1]]*
    PiPro[L[i3],U[m3]]*SigOne[L[m4]][L[m2],L[m5]],
NewRule->True];

DefineRule[ExpandNbNbSigTwo,
  NbNbSigTwo[L[i3],L[i4],L[i2],L[i1]],
    PiPro[L[m1],U[m2]]*PiPro[L[m3],U[m4]]*PiPro[L[i1],U[m5]]*
    PiPro[L[i2],U[j]]*PiPro[L[i3],U[m1]]*PiPro[L[i4],U[m3]]*
    PiPro[L[j],U[i]][L[m5]]*SigTwo[L[m2],L[m4]][L[i]]+
    PiPro[L[m1],U[m2]]*PiPro[L[m3],U[m4]]*PiPro[L[i1],U[i]]*PiPro[L[i2],U[m1]]*
    PiPro[L[i3],U[m3]]*PiPro[L[i4],U[j]]*PiPro[L[j],U[m5]][L[i]]*
    SigTwo[L[m4],L[m5]][L[m2]]+
    PiPro[L[m1],U[m2]]*PiPro[L[m3],U[m4]]*PiPro[L[m5],U[i]]*PiPro[L[i1],U[j]]*
    PiPro[L[i2],U[m1]]*PiPro[L[i3],U[m3]]*PiPro[L[i4],U[m5]]*
    SigTwo[L[m4],L[i]][L[m2],L[j]]+
    PiPro[L[m1],U[m2]]*PiPro[L[m3],U[m4]]*PiPro[L[i1],U[m5]]*PiPro[L[i2],U[m1]]*
    PiPro[L[i3],U[j]]*PiPro[L[i4],U[m3]]*PiPro[L[j],U[i]][L[m5]]*
    SigTwo[L[i],L[m4]][L[m2]],
NewRule->True];

(******************************************************************)

(*
  I am not sure that I trust the ability of Ricci to accurately compute
  covariant derivatives with respect to the conformal metric.  For
  this reason, I am making a macro to do this here.  These macros do
  not involve any weights.
*)

(* Second-order covariant derivative of a smooth function *)

DefineTensor[NhNhTemTen,2,Variance->Covariant,Symmetries->Symmetric];

(* Temporary tensor, i.e. a smooth function.*)

DefineTensor[TemTen,0];

(* Second order covariant derivative with respect to the conformal
   metric.
*)

DefineRule[ExpandNhNhTemTen,
  NhNhTemTen[L[i],L[j]],
  TemTen[L[i],L[j]]-ups[L[i]]TemTen[L[j]]-ups[L[j]]TemTen[L[i]]
  +g[L[i],L[j]]ups[U[k]]TemTen[L[k]],
  NewRule->True];

(*****************************************************************)
(*****************************************************************)
(* Covariant derivatives under the conformal metric.  *)
(*****************************************************************)
(*****************************************************************)

(* Covariant derivative of a density under the conformal metric.  *)

NbHatDen[operand_,weight_,newindex_]:=

  Module[
  {w,LocalOp,answer},
  (
   If[ToString[newindex[[0]]]=="U",Message[SubMfd::AAAA],Null];
   w=weight;
   LocalOp=operand;
   answer=(LocalOp[newindex]+w*ups[newindex]LocalOp);
   answer
  )];

(*****************************************************************)

(* Second-order covariant derivative of a density under the conformal metric.

   Uses the conformal metric to compute the covariant derivative.
   User supplies the density, the weight of the density, and the two
   indices associated with the covariant differentiation.  The second
   index is the index of the last covariant derivative applied.  *)

NbNbHatDen[operand_,weight_,indbb_,indaa_]:=
  Module[
  {w,Den,answer},
  (
   w=weight;
   Den=operand;
   If[ToString[indbb[[0]]]=="U",Message[SubMfd::AAAA],Null];
   If[ToString[indaa[[0]]]=="U",Message[SubMfd::AAAA],Null];
   answer=
   (
     Den[indbb,indaa]+
     (w-1)ups[indaa]Den[indbb]+
     (w-1)ups[indbb]Den[indaa]+
     g[indaa,indbb]NewDummy[ups[U[i]]Den[L[i]]]+
     w*Den*ups[indbb,indaa]+
     w*(w-2)Den*ups[indaa]ups[indbb]+
     g[indaa,indbb]NewDummy[ups[U[i]]ups[L[i]]]w*Den
   );
   answer
  )];

(*****************************************************************)

(* Covariant derivative of a weighted vector field under the conformal
   metric.

   User supplies a vector field, its weight, and two indices.  The
   second index is the index associated with covariant
   differentiation.
*)

NbHatVV[operand_,weight_,upbb_,lowaa_]:=

Module[
  {w,VV,answer},
  (
   If[ToString[upbb[[0]]]=="L",Message[SubMfd::AAAA],Null];
   If[ToString[lowaa[[0]]]=="U",Message[SubMfd::AAAA],Null];
   VV=operand;
   w=weight;
   answer=
   (
    VV[upbb][lowaa]+
    (w+1)ups[lowaa]VV[upbb]-
    ups[upbb]VV[lowaa]+
    Kronecker[lowaa,upbb]NewDummy[ups[L[i]]VV[U[i]]]
   );
   answer
  )];

(*****************************************************************)

(* Covariant derivative of a weighted one-form under the conformal
   metric.

   User supplies a one-form, its weight, and two indices.  The second
   index is the index associated with the covariant differentiation.
*)

NbHatEta[operand_,weight_,lowbb_,lowaa_]:=

Module[
  {w,Eta,answer},
  (
   If[ToString[lowbb[[0]]]=="U",Message[SubMfd::AAAA],Null];
   If[ToString[lowaa[[0]]]=="U",Message[SubMfd::AAAA],Null];
   Eta=operand;
   w=weight;
   answer=
   (
    Eta[lowbb][lowaa]+
    (w-1)ups[lowaa]Eta[lowbb]-
    ups[lowbb]Eta[lowaa]+
    g[lowaa,lowbb]NewDummy[ups[U[i]]Eta[L[i]]]
   );
   answer
  )];

(*****************************************************************)
(* Intrinsic covariant derivative acting on a density, computed
   relative to the conformal metric.

   User supplies an intrinsic density, a weight, and a lower index.
*)

NbSigHatDen[operand_,weight_,lowaa_]:=

  Module[
    {w,LocalOp,answer},
    (
     If[ToString[lowaa[[0]]]=="U",Message[SubMfd::AAAA],Null];
     w=weight;
     LocalOp=operand;
     answer=NewDummy[PiPro[lowaa,U[pres1]](LocalOp[L[pres1]]+w*ups[L[pres1]]LocalOp)];
     answer
    )];

(*****************************************************************)

(* Intrinsic second-order covariant derivative acting on a density.
   This second-order derivative is computed relative to the conformal
   metric.

   User supplies a density, the weight of this density, and two
   indices.  The second of these two indices is associated with the
   last covariant derivative to be applied.
*)

NbNbSigHatDen[operand_,weight_,lowbb_,lowaa_]:=

Module[
  {w,f,answer},
  (
   If[ToString[lowbb[[0]]]=="U",Message[SubMfd::AAAA],Null];
   If[ToString[lowaa[[0]]]=="U",Message[SubMfd::AAAA],Null];
   f=operand;
   w=weight;
   answer=
   (
    NewDummy[
    f[lowbb,lowaa]-f[lowbb,L[pres1]]*Nvec[lowaa]*Nvec[U[pres1]]-
    f[L[pres1],lowaa]*Nvec[lowbb]*Nvec[U[pres1]]-
    f[L[pres1]]*Nvec[lowbb][lowaa]*Nvec[U[pres1]]+
    f[L[pres1],L[pres2]]*Nvec[lowaa]*Nvec[lowbb]*Nvec[U[pres1]]*Nvec[U[pres2]]+
    f[L[pres1]]*Nvec[lowaa]*Nvec[lowbb][L[pres2]]*Nvec[U[pres1]]*Nvec[U[pres2]]+
    (-1+w)*f[lowbb]*ups[lowaa]+
    (1-w)*f[L[pres1]]*Nvec[lowbb]*Nvec[U[pres1]]*ups[lowaa]+
    (-1+w)*f[lowaa]*ups[lowbb]+
    (1-w)*f[L[pres1]]*Nvec[lowaa]*Nvec[U[pres1]]*ups[lowbb]+
    (-2+w)*w*f*ups[lowaa]*ups[lowbb]+
    (1-w)*f[lowbb]*Nvec[lowaa]*Nvec[U[pres1]]*ups[L[pres1]]+
    (1-w)*f[lowaa]*Nvec[lowbb]*Nvec[U[pres1]]*ups[L[pres1]]-
    w*f*Nvec[lowbb][lowaa]*Nvec[U[pres1]]*ups[L[pres1]]-
    (-2+w)*w*f*Nvec[lowbb]*Nvec[U[pres1]]*ups[lowaa]*ups[L[pres1]]-
    (-2+w)*w*f*Nvec[lowaa]*Nvec[U[pres1]]*ups[lowbb]*ups[L[pres1]]-
    f[L[pres1]]*g[lowaa,lowbb]*Nvec[U[pres1]]*Nvec[U[pres2]]*ups[L[pres2]]+
    (-1+2*w)*f[L[pres1]]*Nvec[lowaa]*Nvec[lowbb]*Nvec[U[pres1]]*Nvec[U[pres2]]*
    ups[L[pres2]]+w*f*Nvec[lowaa]*Nvec[lowbb][L[pres1]]*Nvec[U[pres1]]*Nvec[U[pres2]]*
    ups[L[pres2]]-w*f*g[lowaa,lowbb]*Nvec[U[pres1]]*Nvec[U[pres2]]*ups[L[pres1]]*
    ups[L[pres2]]+(-1+w)*w*f*Nvec[lowaa]*Nvec[lowbb]*Nvec[U[pres1]]*Nvec[U[pres2]]*
    ups[L[pres1]]*ups[L[pres2]]+f[L[pres1]]*g[lowaa,lowbb]*ups[U[pres1]]-
    f[L[pres1]]*Nvec[lowaa]*Nvec[lowbb]*ups[U[pres1]]+
    w*f*g[lowaa,lowbb]*ups[L[pres1]]*ups[U[pres1]]-
    w*f*Nvec[lowaa]*Nvec[lowbb]*ups[L[pres1]]*ups[U[pres1]]+
    w*f*ups[lowbb,lowaa]-w*f*Nvec[lowaa]*Nvec[U[pres1]]*ups[lowbb,L[pres1]]-
    w*f*Nvec[lowbb]*Nvec[U[pres1]]*ups[L[pres1],lowaa]+
    w*f*Nvec[lowaa]*Nvec[lowbb]*Nvec[U[pres1]]*Nvec[U[pres2]]*ups[L[pres1],L[pres2]]]
   );
   answer
  )];

(*****************************************************************)
(* Intrinsic covariant derivative applied to an intrinsic rank-1
   covariant tensor, computed relative to the conformal metric.

   The user supplies a rank-1 covariant tensor without inserted
   indices.  This must be a tensor previously defined to Ricci, and
   not a sum of terms.  The last index that the user supplies is the
   index associated with covariant differentiation.
*)

NbSigHatEta[operand_,weight_,lowbb_,lowaa_]:=

Module[
  {w,om,answer,Temp},
  (
   If[ToString[lowaa[[0]]]=="U",Message[SubMfd::AAAA],Null];
   If[ToString[lowbb[[0]]]=="U",Message[SubMfd::AAAA],Null];
   w=weight;
   om=operand;
   Temp=
(
om[lowbb][lowaa]-Nvec[lowaa]*Nvec[U[pres1]]*om[lowbb][L[pres1]]-
Nvec[lowbb]*Nvec[U[pres1]]*om[L[pres1]][lowaa]+
Nvec[lowaa]*Nvec[lowbb]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[L[pres1]][L[pres2]]+
(-1+w)*om[lowbb]*ups[lowaa]+
(1-w)*Nvec[lowbb]*Nvec[U[pres1]]*om[L[pres1]]*ups[lowaa]-
om[lowaa]*ups[lowbb]+Nvec[lowaa]*Nvec[U[pres1]]*om[L[pres1]]*ups[lowbb]+
Nvec[lowbb]*Nvec[U[pres1]]*om[lowaa]*ups[L[pres1]]+
(1-w)*Nvec[lowaa]*Nvec[U[pres1]]*om[lowbb]*ups[L[pres1]]+
(-2+w)*Nvec[lowaa]*Nvec[lowbb]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[L[pres1]]*
ups[L[pres2]]+g[lowaa,lowbb]*om[L[pres1]]*ups[U[pres1]]-
2*Nvec[lowaa]*Nvec[lowbb]*om[L[pres1]]*ups[U[pres1]]+
Nvec[lowaa]*Nvec[lowbb]*Nvec[L[pres1]]*Nvec[U[pres1]]*om[L[pres2]]*ups[U[pres2]]
);
    Temp=NewDummy[Temp];
    answer=Temp;
    answer
)];


(*****************************************************************)
(* Second-order intrinsic covariant derivative applied to an
   intrinsic rank-1 covariant tensor, computed relative to the
   conformal metric.

   The user supplies an intrinsic rank-1 covariant tensor without
   inserted indices.  This must be a tensor previously defined to Ricci,
   and not a sum of terms.

   The first index supplied by the user is the index associated with
   the original rank-1 tensor.  The user supplies the other two indices
   in the order in which covariant derivatives are applied.
*)

NbNbSigHatEta[operand_,weight_,lowaa_,lowbb_,lowcc_]:=

Module[
  {w,om,answer,Temp},
  (
   If[ToString[lowaa[[0]]]=="U",Message[SubMfd::AAAA],Null];
   If[ToString[lowbb[[0]]]=="U",Message[SubMfd::AAAA],Null];
   If[ToString[lowcc[[0]]]=="U",Message[SubMfd::AAAA],Null];
   w=weight;
   om=operand;
   Temp=
(
  -(Nvec[lowbb][lowcc]*Nvec[U[pres1]]*om[lowaa][L[pres1]])+
  Nvec[lowbb][L[pres1]]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[lowaa][L[pres2]]+
  om[lowaa][lowbb,lowcc]-Nvec[lowcc]*Nvec[U[pres1]]*om[lowaa][lowbb,L[pres1]]-
  Nvec[lowbb]*Nvec[U[pres1]]*om[lowaa][L[pres1],lowcc]+
  Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[lowaa][L[pres1],L[pres2]]-
  Nvec[lowaa][lowcc]*Nvec[U[pres1]]*om[L[pres1]][lowbb]+
  Nvec[lowaa][lowcc]*Nvec[lowbb]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[L[pres1]][L[pres2]]+
  Nvec[lowaa]*Nvec[lowbb][lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[L[pres1]][L[pres2]]-
  Nvec[lowaa]*Nvec[U[pres1]]*om[L[pres1]][lowbb,lowcc]+
  Nvec[lowaa]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[L[pres1]][lowbb,L[pres2]]+
  Nvec[lowaa]*Nvec[lowbb]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[L[pres1]][L[pres2],lowcc]-
  Nvec[lowaa]*Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*Nvec[U[pres3]]*
  om[L[pres1]][L[pres2],L[pres3]]+Nvec[lowaa][L[pres1]]*Nvec[lowcc]*Nvec[U[pres1]]*
  Nvec[U[pres2]]*om[L[pres2]][lowbb]-
  Nvec[lowaa][L[pres1]]*Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*Nvec[U[pres3]]*
  om[L[pres2]][L[pres3]]-Nvec[lowaa]*Nvec[lowbb][L[pres1]]*Nvec[lowcc]*Nvec[U[pres1]]*
  Nvec[U[pres2]]*Nvec[U[pres3]]*om[L[pres2]][L[pres3]]-om[lowbb][lowcc]*ups[lowaa]+
  Nvec[lowcc]*Nvec[U[pres1]]*om[lowbb][L[pres1]]*ups[lowaa]-
  om[lowcc][lowbb]*ups[lowaa]+
  Nvec[lowbb]*Nvec[U[pres1]]*om[lowcc][L[pres1]]*ups[lowaa]+
  Nvec[lowbb][lowcc]*Nvec[U[pres1]]*om[L[pres1]]*ups[lowaa]+
  Nvec[lowcc]*Nvec[U[pres1]]*om[L[pres1]][lowbb]*ups[lowaa]+
  Nvec[lowbb]*Nvec[U[pres1]]*om[L[pres1]][lowcc]*ups[lowaa]-
  2*Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[L[pres1]][L[pres2]]*
  ups[lowaa]-Nvec[lowbb][L[pres1]]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*
  om[L[pres2]]*ups[lowaa]+(-2+w)*om[lowaa][lowcc]*ups[lowbb]+
  (2-w)*Nvec[lowcc]*Nvec[U[pres1]]*om[lowaa][L[pres1]]*ups[lowbb]+
  (1-w)*Nvec[lowaa][lowcc]*Nvec[U[pres1]]*om[L[pres1]]*ups[lowbb]+
  (2-w)*Nvec[lowaa]*Nvec[U[pres1]]*om[L[pres1]][lowcc]*ups[lowbb]+
  (-2+w)*Nvec[lowaa]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[L[pres1]][L[pres2]]*
  ups[lowbb]+(-1+w)*Nvec[lowaa][L[pres1]]*Nvec[lowcc]*Nvec[U[pres1]]*
  Nvec[U[pres2]]*om[L[pres2]]*ups[lowbb]+
  (2-w)*om[lowcc]*ups[lowaa]*ups[lowbb]+
  (-2+w)*Nvec[lowcc]*Nvec[U[pres1]]*om[L[pres1]]*ups[lowaa]*ups[lowbb]+
  (-2+w)*om[lowaa][lowbb]*ups[lowcc]+
  (2-w)*Nvec[lowbb]*Nvec[U[pres1]]*om[lowaa][L[pres1]]*ups[lowcc]+
  (2-w)*Nvec[lowaa]*Nvec[U[pres1]]*om[L[pres1]][lowbb]*ups[lowcc]+
  (-2+w)*Nvec[lowaa]*Nvec[lowbb]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[L[pres1]][L[pres2]]*
  ups[lowcc]+(3-w)*om[lowbb]*ups[lowaa]*ups[lowcc]+
  (-3+w)*Nvec[lowbb]*Nvec[U[pres1]]*om[L[pres1]]*ups[lowaa]*ups[lowcc]+
  (-3+w)*(-1+w)*om[lowaa]*ups[lowbb]*ups[lowcc]-
  (-3+w)*(-1+w)*Nvec[lowaa]*Nvec[U[pres1]]*om[L[pres1]]*ups[lowbb]*
  ups[lowcc]+(1-w)*Nvec[lowbb][lowcc]*Nvec[U[pres1]]*om[lowaa]*
  ups[L[pres1]]+(2-w)*Nvec[lowcc]*Nvec[U[pres1]]*om[lowaa][lowbb]*
  ups[L[pres1]]+(2-w)*Nvec[lowbb]*Nvec[U[pres1]]*om[lowaa][lowcc]*
  ups[L[pres1]]+Nvec[lowaa][lowcc]*Nvec[U[pres1]]*om[lowbb]*ups[L[pres1]]+
  Nvec[lowaa]*Nvec[U[pres1]]*om[lowbb][lowcc]*ups[L[pres1]]+
  Nvec[lowaa]*Nvec[U[pres1]]*om[lowcc][lowbb]*ups[L[pres1]]+
  (-3+w)*Nvec[lowcc]*Nvec[U[pres1]]*om[lowbb]*ups[lowaa]*ups[L[pres1]]+
  (-2+w)*Nvec[lowbb]*Nvec[U[pres1]]*om[lowcc]*ups[lowaa]*ups[L[pres1]]-
  (-3+w)*(-1+w)*Nvec[lowcc]*Nvec[U[pres1]]*om[lowaa]*ups[lowbb]*
  ups[L[pres1]]+(-2+w)*Nvec[lowaa]*Nvec[U[pres1]]*om[lowcc]*ups[lowbb]*
  ups[L[pres1]]-(-3+w)*(-1+w)*Nvec[lowbb]*Nvec[U[pres1]]*om[lowaa]*
  ups[lowcc]*ups[L[pres1]]+
  (-3+w)*Nvec[lowaa]*Nvec[U[pres1]]*om[lowbb]*ups[lowcc]*ups[L[pres1]]+
  (-1+w)*Nvec[lowbb][L[pres1]]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[lowaa]*
  ups[L[pres2]]-g[lowbb,lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[lowaa][L[pres1]]*
  ups[L[pres2]]+(-3+2*w)*Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*
  om[lowaa][L[pres1]]*ups[L[pres2]]-
  Nvec[lowaa][L[pres1]]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[lowbb]*ups[L[pres2]]-
  Nvec[lowaa]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[lowbb][L[pres1]]*ups[L[pres2]]-
  Nvec[lowaa]*Nvec[lowbb]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[lowcc][L[pres1]]*ups[L[pres2]]+
  (-2+w)*Nvec[lowaa][lowcc]*Nvec[lowbb]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[L[pres1]]*
  ups[L[pres2]]+(-2+w)*Nvec[lowaa]*Nvec[lowbb][lowcc]*Nvec[U[pres1]]*
  Nvec[U[pres2]]*om[L[pres1]]*ups[L[pres2]]-
  g[lowaa,lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[L[pres1]][lowbb]*ups[L[pres2]]+
  (-2+w)*Nvec[lowaa]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[L[pres1]][lowbb]*
  ups[L[pres2]]+(-3+w)*Nvec[lowaa]*Nvec[lowbb]*Nvec[U[pres1]]*Nvec[U[pres2]]*
  om[L[pres1]][lowcc]*ups[L[pres2]]+
  g[lowbb,lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[L[pres1]]*ups[lowaa]*ups[L[pres2]]-
  2*(-2+w)*Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[L[pres1]]*
  ups[lowaa]*ups[L[pres2]]+
  (1-w)*g[lowaa,lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[L[pres1]]*ups[lowbb]*
  ups[L[pres2]]+(-2+w)^2*Nvec[lowaa]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*
  om[L[pres1]]*ups[lowbb]*ups[L[pres2]]+
  (-3+w)*(-2+w)*Nvec[lowaa]*Nvec[lowbb]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[L[pres1]]*
  ups[lowcc]*ups[L[pres2]]+
  (1-w)*g[lowbb,lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[lowaa]*ups[L[pres1]]*
  ups[L[pres2]]+(-2+w)*(-1+w)*Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres1]]*
  Nvec[U[pres2]]*om[lowaa]*ups[L[pres1]]*ups[L[pres2]]+
  g[lowaa,lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[lowbb]*ups[L[pres1]]*ups[L[pres2]]+
  (2-w)*Nvec[lowaa]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[lowbb]*ups[L[pres1]]*
  ups[L[pres2]]+(2-w)*Nvec[lowaa]*Nvec[lowbb]*Nvec[U[pres1]]*Nvec[U[pres2]]*
  om[lowcc]*ups[L[pres1]]*ups[L[pres2]]+
  g[lowbb,lowcc]*Nvec[lowaa]*Nvec[U[pres1]]*Nvec[U[pres2]]*Nvec[U[pres3]]*om[L[pres1]][L[pres2]]*
  ups[L[pres3]]+g[lowaa,lowcc]*Nvec[lowbb]*Nvec[U[pres1]]*Nvec[U[pres2]]*Nvec[U[pres3]]*
  om[L[pres1]][L[pres2]]*ups[L[pres3]]-
  2*(-2+w)*Nvec[lowaa]*Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*
  Nvec[U[pres3]]*om[L[pres1]][L[pres2]]*ups[L[pres3]]+
  (2-w)*Nvec[lowaa][L[pres1]]*Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*
  Nvec[U[pres3]]*om[L[pres2]]*ups[L[pres3]]+
  (2-w)*Nvec[lowaa]*Nvec[lowbb][L[pres1]]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*
  Nvec[U[pres3]]*om[L[pres2]]*ups[L[pres3]]+
  (-2+w)*g[lowbb,lowcc]*Nvec[lowaa]*Nvec[U[pres1]]*Nvec[U[pres2]]*Nvec[U[pres3]]*
  om[L[pres1]]*ups[L[pres2]]*ups[L[pres3]]+
  (-2+w)*g[lowaa,lowcc]*Nvec[lowbb]*Nvec[U[pres1]]*Nvec[U[pres2]]*Nvec[U[pres3]]*
  om[L[pres1]]*ups[L[pres2]]*ups[L[pres3]]-
  (-2+w)^2*Nvec[lowaa]*Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*
  Nvec[U[pres3]]*om[L[pres1]]*ups[L[pres2]]*ups[L[pres3]]+
  g[lowbb,lowcc]*om[lowaa][L[pres1]]*ups[U[pres1]]-
  Nvec[lowbb]*Nvec[lowcc]*om[lowaa][L[pres1]]*ups[U[pres1]]+
  g[lowaa,lowcc]*om[L[pres1]][lowbb]*ups[U[pres1]]-
  Nvec[lowaa]*Nvec[lowcc]*om[L[pres1]][lowbb]*ups[U[pres1]]+
  g[lowaa,lowbb]*om[L[pres1]][lowcc]*ups[U[pres1]]-
  Nvec[lowaa]*Nvec[lowbb]*om[L[pres1]][lowcc]*ups[U[pres1]]-
  g[lowbb,lowcc]*om[L[pres1]]*ups[lowaa]*ups[U[pres1]]+
  Nvec[lowbb]*Nvec[lowcc]*om[L[pres1]]*ups[lowaa]*ups[U[pres1]]+
  (-1+w)*g[lowaa,lowcc]*om[L[pres1]]*ups[lowbb]*ups[U[pres1]]+
  (1-w)*Nvec[lowaa]*Nvec[lowcc]*om[L[pres1]]*ups[lowbb]*ups[U[pres1]]+
  (-2+w)*g[lowaa,lowbb]*om[L[pres1]]*ups[lowcc]*ups[U[pres1]]+
  (2-w)*Nvec[lowaa]*Nvec[lowbb]*om[L[pres1]]*ups[lowcc]*ups[U[pres1]]+
  (-1+w)*g[lowbb,lowcc]*om[lowaa]*ups[L[pres1]]*ups[U[pres1]]+
  (1-w)*Nvec[lowbb]*Nvec[lowcc]*om[lowaa]*ups[L[pres1]]*ups[U[pres1]]-
  g[lowaa,lowcc]*om[lowbb]*ups[L[pres1]]*ups[U[pres1]]+
  Nvec[lowaa]*Nvec[lowcc]*om[lowbb]*ups[L[pres1]]*ups[U[pres1]]-
  g[lowbb,lowcc]*Nvec[lowaa]*Nvec[U[pres1]]*om[L[pres1]][L[pres2]]*ups[U[pres2]]+
  Nvec[lowaa]*Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres1]]*om[L[pres1]][L[pres2]]*ups[U[pres2]]-
  g[lowaa,lowcc]*Nvec[lowbb]*Nvec[U[pres1]]*om[L[pres2]][L[pres1]]*ups[U[pres2]]-
  g[lowaa,lowbb]*Nvec[lowcc]*Nvec[U[pres1]]*om[L[pres2]][L[pres1]]*ups[U[pres2]]+
  2*Nvec[lowaa]*Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres1]]*om[L[pres2]][L[pres1]]*
  ups[U[pres2]]+g[lowbb,lowcc]*Nvec[lowaa]*Nvec[U[pres1]]*om[L[pres2]]*ups[L[pres1]]*
  ups[U[pres2]]+(1-w)*g[lowaa,lowcc]*Nvec[lowbb]*Nvec[U[pres1]]*om[L[pres2]]*
  ups[L[pres1]]*ups[U[pres2]]+
  (2-w)*g[lowaa,lowbb]*Nvec[lowcc]*Nvec[U[pres1]]*om[L[pres2]]*ups[L[pres1]]*
  ups[U[pres2]]+2*(-2+w)*Nvec[lowaa]*Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres1]]*
  om[L[pres2]]*ups[L[pres1]]*ups[U[pres2]]+
  (1-w)*g[lowbb,lowcc]*Nvec[lowaa]*Nvec[U[pres1]]*om[L[pres1]]*ups[L[pres2]]*
  ups[U[pres2]]+g[lowaa,lowcc]*Nvec[lowbb]*Nvec[U[pres1]]*om[L[pres1]]*ups[L[pres2]]*
  ups[U[pres2]]+(-2+w)*Nvec[lowaa]*Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres1]]*
  om[L[pres1]]*ups[L[pres2]]*ups[U[pres2]]-om[lowbb]*ups[lowaa,lowcc]+
  Nvec[lowbb]*Nvec[U[pres1]]*om[L[pres1]]*ups[lowaa,lowcc]+
  Nvec[lowcc]*Nvec[U[pres1]]*om[lowbb]*ups[lowaa,L[pres1]]-
  Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[L[pres1]]*ups[lowaa,L[pres2]]+
  (-1+w)*om[lowaa]*ups[lowbb,lowcc]+
  (1-w)*Nvec[lowaa]*Nvec[U[pres1]]*om[L[pres1]]*ups[lowbb,lowcc]+
  (1-w)*Nvec[lowcc]*Nvec[U[pres1]]*om[lowaa]*ups[lowbb,L[pres1]]+
  (-1+w)*Nvec[lowaa]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[L[pres1]]*
  ups[lowbb,L[pres2]]+(1-w)*Nvec[lowbb]*Nvec[U[pres1]]*om[lowaa]*
  ups[L[pres1],lowcc]+Nvec[lowaa]*Nvec[U[pres1]]*om[lowbb]*ups[L[pres1],lowcc]+
  (-1+w)*Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[lowaa]*
  ups[L[pres1],L[pres2]]-Nvec[lowaa]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*
  om[lowbb]*ups[L[pres1],L[pres2]]+
  (-2+w)*Nvec[lowaa]*Nvec[lowbb]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[L[pres1]]*
  ups[L[pres2],lowcc]+(2-w)*Nvec[lowaa]*Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres1]]*
  Nvec[U[pres2]]*Nvec[U[pres3]]*om[L[pres1]]*ups[L[pres2],L[pres3]]+
  g[lowaa,lowbb]*om[L[pres1]]*ups[U[pres1],lowcc]-
  Nvec[lowaa]*Nvec[lowbb]*om[L[pres1]]*ups[U[pres1],lowcc]-
  g[lowaa,lowbb]*Nvec[lowcc]*Nvec[U[pres1]]*om[L[pres2]]*ups[U[pres2],L[pres1]]+
  Nvec[lowaa]*Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres1]]*om[L[pres2]]*ups[U[pres2],L[pres1]]
);
    Temp=NewDummy[Temp];
    answer=Temp;
    answer
)];


(*****************************************************************)
(* Intrinsic covariant derivative applied to a rank-2 covariant
   tensor, computed relative to the conformal metric.

   The user must supply a covariant two-tensor.  This must be a
   two-tensor that the user has previously declared to the Ricci
   software package, not a sum of terms.  The last index that the user
   supplies is the index associated with the covariant derivative.
*)

NbSigHatEtaEta[operand_,weight_,lowbb_,lowcc_,lowaa_]:=

Module[
  {w,om,answer},
  (
   If[ToString[lowbb[[0]]]=="U",Message[SubMfd::AAAA],Null];
   If[ToString[lowcc[[0]]]=="U",Message[SubMfd::AAAA],Null];
   If[ToString[lowaa[[0]]]=="U",Message[SubMfd::AAAA],Null];
   w=weight;
   om=operand;
   answer=(
NewDummy[
om[lowbb,lowcc][lowaa]-
Nvec[lowaa]*Nvec[U[pres4]]*om[lowbb,lowcc][L[pres4]]-
Nvec[lowcc]*Nvec[U[pres4]]*om[lowbb,L[pres4]][lowaa]+
Nvec[lowaa]*Nvec[lowcc]*Nvec[U[pres4]]*Nvec[U[pres5]]*om[lowbb,L[pres4]][L[pres5]]-
Nvec[lowbb]*Nvec[U[pres4]]*om[L[pres4],lowcc][lowaa]+
Nvec[lowaa]*Nvec[lowbb]*Nvec[U[pres4]]*Nvec[U[pres5]]*om[L[pres4],lowcc][L[pres5]]+
Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres4]]*Nvec[U[pres5]]*om[L[pres4],L[pres5]][lowaa]-
Nvec[lowaa]*Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres4]]*Nvec[U[pres5]]*Nvec[U[pres6]]*
om[L[pres4],L[pres5]][L[pres6]]+(-2+w)*om[lowbb,lowcc]*ups[lowaa]+
(2-w)*Nvec[lowcc]*Nvec[U[pres4]]*om[lowbb,L[pres4]]*ups[lowaa]+
(2-w)*Nvec[lowbb]*Nvec[U[pres4]]*om[L[pres4],lowcc]*ups[lowaa]+
(-2+w)*Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres4]]*Nvec[U[pres5]]*om[L[pres4],L[pres5]]*
ups[lowaa]-om[lowaa,lowcc]*ups[lowbb]+
Nvec[lowcc]*Nvec[U[pres4]]*om[lowaa,L[pres4]]*ups[lowbb]+
Nvec[lowaa]*Nvec[U[pres4]]*om[L[pres4],lowcc]*ups[lowbb]-
Nvec[lowaa]*Nvec[lowcc]*Nvec[U[pres4]]*Nvec[U[pres5]]*om[L[pres4],L[pres5]]*ups[lowbb]-
om[lowbb,lowaa]*ups[lowcc]+
Nvec[lowaa]*Nvec[U[pres4]]*om[lowbb,L[pres4]]*ups[lowcc]+
Nvec[lowbb]*Nvec[U[pres4]]*om[L[pres4],lowaa]*ups[lowcc]-
Nvec[lowaa]*Nvec[lowbb]*Nvec[U[pres4]]*Nvec[U[pres5]]*om[L[pres4],L[pres5]]*ups[lowcc]+
Nvec[lowbb]*Nvec[U[pres4]]*om[lowaa,lowcc]*ups[L[pres4]]+
Nvec[lowcc]*Nvec[U[pres4]]*om[lowbb,lowaa]*ups[L[pres4]]+
(2-w)*Nvec[lowaa]*Nvec[U[pres4]]*om[lowbb,lowcc]*ups[L[pres4]]-
Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres4]]*Nvec[U[pres5]]*om[lowaa,L[pres4]]*ups[L[pres5]]+
(-3+w)*Nvec[lowaa]*Nvec[lowcc]*Nvec[U[pres4]]*Nvec[U[pres5]]*om[lowbb,L[pres4]]*
ups[L[pres5]]-Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres4]]*Nvec[U[pres5]]*
om[L[pres4],lowaa]*ups[L[pres5]]+
(-3+w)*Nvec[lowaa]*Nvec[lowbb]*Nvec[U[pres4]]*Nvec[U[pres5]]*om[L[pres4],lowcc]*
ups[L[pres5]]+(4-w)*Nvec[lowaa]*Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres4]]*
Nvec[U[pres5]]*Nvec[U[pres6]]*om[L[pres4],L[pres5]]*ups[L[pres6]]+
g[lowaa,lowcc]*om[lowbb,L[pres4]]*ups[U[pres4]]-
Nvec[lowaa]*Nvec[lowcc]*om[lowbb,L[pres4]]*ups[U[pres4]]+
g[lowaa,lowbb]*om[L[pres4],lowcc]*ups[U[pres4]]-
Nvec[lowaa]*Nvec[lowbb]*om[L[pres4],lowcc]*ups[U[pres4]]-
g[lowaa,lowcc]*Nvec[lowbb]*Nvec[U[pres4]]*om[L[pres4],L[pres5]]*ups[U[pres5]]+
Nvec[lowaa]*Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres4]]*om[L[pres4],L[pres5]]*ups[U[pres5]]-
g[lowaa,lowbb]*Nvec[lowcc]*Nvec[U[pres4]]*om[L[pres5],L[pres4]]*ups[U[pres5]]+
Nvec[lowaa]*Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres4]]*om[L[pres5],L[pres4]]*ups[U[pres5]]]
);
answer
  )
];


(*****************************************************************)
(* Intrinsic covariant derivative applied to a rank-3 covariant
   tensor, computed relative to the conformal metric.

   The user must supply a covariant three-tensor.  This must be a
   three-tensor that the user has previously declared to the Ricci
   software package, not a sum of terms.  The last index that the user
   supplies is the index associated with the covariant derivative.
*)

NbSigHatEtaEtaEta[operand_,weight_,lowbb_,lowcc_,lowdd_,lowaa_]:=

Module[
  {w2,om,Temp,answer},
  (
   If[ToString[lowbb[[0]]]=="U",Message[SubMfd::AAAA],Null];
   If[ToString[lowcc[[0]]]=="U",Message[SubMfd::AAAA],Null];
   If[ToString[lowdd[[0]]]=="U",Message[SubMfd::AAAA],Null];
   If[ToString[lowaa[[0]]]=="U",Message[SubMfd::AAAA],Null];
   w2=weight;
   om=operand;
   Temp=(
om[lowbb,lowcc,lowdd][lowaa]-
Nvec[lowaa]*Nvec[U[pres1]]*om[lowbb,lowcc,lowdd][L[pres1]]-
Nvec[lowdd]*Nvec[U[pres1]]*om[lowbb,lowcc,L[pres1]][lowaa]+
Nvec[lowaa]*Nvec[lowdd]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[lowbb,lowcc,L[pres1]][L[pres2]]-
Nvec[lowcc]*Nvec[U[pres1]]*om[lowbb,L[pres1],lowdd][lowaa]+
Nvec[lowaa]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[lowbb,L[pres1],lowdd][L[pres2]]+
Nvec[lowcc]*Nvec[lowdd]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[lowbb,L[pres1],L[pres2]][lowaa]-
Nvec[lowaa]*Nvec[lowcc]*Nvec[lowdd]*Nvec[U[pres1]]*Nvec[U[pres2]]*Nvec[U[pres3]]*
om[lowbb,L[pres1],L[pres2]][L[pres3]]-
Nvec[lowbb]*Nvec[U[pres1]]*om[L[pres1],lowcc,lowdd][lowaa]+
Nvec[lowaa]*Nvec[lowbb]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[L[pres1],lowcc,lowdd][L[pres2]]+
Nvec[lowbb]*Nvec[lowdd]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[L[pres1],lowcc,L[pres2]][lowaa]-
Nvec[lowaa]*Nvec[lowbb]*Nvec[lowdd]*Nvec[U[pres1]]*Nvec[U[pres2]]*Nvec[U[pres3]]*
om[L[pres1],lowcc,L[pres2]][L[pres3]]+
Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[L[pres1],L[pres2],lowdd][lowaa]-
Nvec[lowaa]*Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*Nvec[U[pres3]]*
om[L[pres1],L[pres2],lowdd][L[pres3]]-
Nvec[lowbb]*Nvec[lowcc]*Nvec[lowdd]*Nvec[U[pres1]]*Nvec[U[pres2]]*Nvec[U[pres3]]*
om[L[pres1],L[pres2],L[pres3]][lowaa]+
Nvec[lowaa]*Nvec[lowbb]*Nvec[lowcc]*Nvec[lowdd]*Nvec[U[pres1]]*Nvec[U[pres2]]*
Nvec[U[pres3]]*Nvec[U[pres4]]*om[L[pres1],L[pres2],L[pres3]][L[pres4]]+
(-3+w2)*om[lowbb,lowcc,lowdd]*ups[lowaa]+
(3-w2)*Nvec[lowdd]*Nvec[U[pres1]]*om[lowbb,lowcc,L[pres1]]*ups[lowaa]+
(3-w2)*Nvec[lowcc]*Nvec[U[pres1]]*om[lowbb,L[pres1],lowdd]*ups[lowaa]+
(-3+w2)*Nvec[lowcc]*Nvec[lowdd]*Nvec[U[pres1]]*Nvec[U[pres2]]*
om[lowbb,L[pres1],L[pres2]]*ups[lowaa]+
(3-w2)*Nvec[lowbb]*Nvec[U[pres1]]*om[L[pres1],lowcc,lowdd]*ups[lowaa]+
(-3+w2)*Nvec[lowbb]*Nvec[lowdd]*Nvec[U[pres1]]*Nvec[U[pres2]]*
om[L[pres1],lowcc,L[pres2]]*ups[lowaa]+
(-3+w2)*Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*
om[L[pres1],L[pres2],lowdd]*ups[lowaa]+
(3-w2)*Nvec[lowbb]*Nvec[lowcc]*Nvec[lowdd]*Nvec[U[pres1]]*Nvec[U[pres2]]*
Nvec[U[pres3]]*om[L[pres1],L[pres2],L[pres3]]*ups[lowaa]-
om[lowaa,lowcc,lowdd]*ups[lowbb]+
Nvec[lowdd]*Nvec[U[pres1]]*om[lowaa,lowcc,L[pres1]]*ups[lowbb]+
Nvec[lowcc]*Nvec[U[pres1]]*om[lowaa,L[pres1],lowdd]*ups[lowbb]-
Nvec[lowcc]*Nvec[lowdd]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[lowaa,L[pres1],L[pres2]]*
ups[lowbb]+Nvec[lowaa]*Nvec[U[pres1]]*om[L[pres1],lowcc,lowdd]*ups[lowbb]-
Nvec[lowaa]*Nvec[lowdd]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[L[pres1],lowcc,L[pres2]]*
ups[lowbb]-Nvec[lowaa]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*
om[L[pres1],L[pres2],lowdd]*ups[lowbb]+
Nvec[lowaa]*Nvec[lowcc]*Nvec[lowdd]*Nvec[U[pres1]]*Nvec[U[pres2]]*Nvec[U[pres3]]*
om[L[pres1],L[pres2],L[pres3]]*ups[lowbb]-om[lowbb,lowaa,lowdd]*ups[lowcc]+
Nvec[lowdd]*Nvec[U[pres1]]*om[lowbb,lowaa,L[pres1]]*ups[lowcc]+
Nvec[lowaa]*Nvec[U[pres1]]*om[lowbb,L[pres1],lowdd]*ups[lowcc]-
Nvec[lowaa]*Nvec[lowdd]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[lowbb,L[pres1],L[pres2]]*
ups[lowcc]+Nvec[lowbb]*Nvec[U[pres1]]*om[L[pres1],lowaa,lowdd]*ups[lowcc]-
Nvec[lowbb]*Nvec[lowdd]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[L[pres1],lowaa,L[pres2]]*
ups[lowcc]-Nvec[lowaa]*Nvec[lowbb]*Nvec[U[pres1]]*Nvec[U[pres2]]*
om[L[pres1],L[pres2],lowdd]*ups[lowcc]+
Nvec[lowaa]*Nvec[lowbb]*Nvec[lowdd]*Nvec[U[pres1]]*Nvec[U[pres2]]*Nvec[U[pres3]]*
om[L[pres1],L[pres2],L[pres3]]*ups[lowcc]-om[lowbb,lowcc,lowaa]*ups[lowdd]+
Nvec[lowaa]*Nvec[U[pres1]]*om[lowbb,lowcc,L[pres1]]*ups[lowdd]+
Nvec[lowcc]*Nvec[U[pres1]]*om[lowbb,L[pres1],lowaa]*ups[lowdd]-
Nvec[lowaa]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[lowbb,L[pres1],L[pres2]]*
ups[lowdd]+Nvec[lowbb]*Nvec[U[pres1]]*om[L[pres1],lowcc,lowaa]*ups[lowdd]-
Nvec[lowaa]*Nvec[lowbb]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[L[pres1],lowcc,L[pres2]]*
ups[lowdd]-Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*
om[L[pres1],L[pres2],lowaa]*ups[lowdd]+
Nvec[lowaa]*Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*Nvec[U[pres3]]*
om[L[pres1],L[pres2],L[pres3]]*ups[lowdd]+
Nvec[lowbb]*Nvec[U[pres1]]*om[lowaa,lowcc,lowdd]*ups[L[pres1]]+
Nvec[lowcc]*Nvec[U[pres1]]*om[lowbb,lowaa,lowdd]*ups[L[pres1]]+
Nvec[lowdd]*Nvec[U[pres1]]*om[lowbb,lowcc,lowaa]*ups[L[pres1]]+
(3-w2)*Nvec[lowaa]*Nvec[U[pres1]]*om[lowbb,lowcc,lowdd]*ups[L[pres1]]-
Nvec[lowbb]*Nvec[lowdd]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[lowaa,lowcc,L[pres1]]*
ups[L[pres2]]-Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*
om[lowaa,L[pres1],lowdd]*ups[L[pres2]]-
Nvec[lowcc]*Nvec[lowdd]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[lowbb,lowaa,L[pres1]]*
ups[L[pres2]]+(-4+w2)*Nvec[lowaa]*Nvec[lowdd]*Nvec[U[pres1]]*Nvec[U[pres2]]*
om[lowbb,lowcc,L[pres1]]*ups[L[pres2]]-
Nvec[lowcc]*Nvec[lowdd]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[lowbb,L[pres1],lowaa]*
ups[L[pres2]]+(-4+w2)*Nvec[lowaa]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*
om[lowbb,L[pres1],lowdd]*ups[L[pres2]]-
Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*om[L[pres1],lowaa,lowdd]*
ups[L[pres2]]-Nvec[lowbb]*Nvec[lowdd]*Nvec[U[pres1]]*Nvec[U[pres2]]*
om[L[pres1],lowcc,lowaa]*ups[L[pres2]]+
(-4+w2)*Nvec[lowaa]*Nvec[lowbb]*Nvec[U[pres1]]*Nvec[U[pres2]]*
om[L[pres1],lowcc,lowdd]*ups[L[pres2]]+
Nvec[lowbb]*Nvec[lowcc]*Nvec[lowdd]*Nvec[U[pres1]]*Nvec[U[pres2]]*Nvec[U[pres3]]*
om[lowaa,L[pres1],L[pres2]]*ups[L[pres3]]+
(5-w2)*Nvec[lowaa]*Nvec[lowcc]*Nvec[lowdd]*Nvec[U[pres1]]*Nvec[U[pres2]]*
Nvec[U[pres3]]*om[lowbb,L[pres1],L[pres2]]*ups[L[pres3]]+
Nvec[lowbb]*Nvec[lowcc]*Nvec[lowdd]*Nvec[U[pres1]]*Nvec[U[pres2]]*Nvec[U[pres3]]*
om[L[pres1],lowaa,L[pres2]]*ups[L[pres3]]+
(5-w2)*Nvec[lowaa]*Nvec[lowbb]*Nvec[lowdd]*Nvec[U[pres1]]*Nvec[U[pres2]]*
Nvec[U[pres3]]*om[L[pres1],lowcc,L[pres2]]*ups[L[pres3]]+
Nvec[lowbb]*Nvec[lowcc]*Nvec[lowdd]*Nvec[U[pres1]]*Nvec[U[pres2]]*Nvec[U[pres3]]*
om[L[pres1],L[pres2],lowaa]*ups[L[pres3]]+
(5-w2)*Nvec[lowaa]*Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*
Nvec[U[pres3]]*om[L[pres1],L[pres2],lowdd]*ups[L[pres3]]+
(-6+w2)*Nvec[lowaa]*Nvec[lowbb]*Nvec[lowcc]*Nvec[lowdd]*Nvec[U[pres1]]*
Nvec[U[pres2]]*Nvec[U[pres3]]*Nvec[U[pres4]]*om[L[pres1],L[pres2],L[pres3]]*ups[L[pres4]]+
g[lowaa,lowdd]*om[lowbb,lowcc,L[pres1]]*ups[U[pres1]]-
Nvec[lowaa]*Nvec[lowdd]*om[lowbb,lowcc,L[pres1]]*ups[U[pres1]]+
g[lowaa,lowcc]*om[lowbb,L[pres1],lowdd]*ups[U[pres1]]-
Nvec[lowaa]*Nvec[lowcc]*om[lowbb,L[pres1],lowdd]*ups[U[pres1]]+
g[lowaa,lowbb]*om[L[pres1],lowcc,lowdd]*ups[U[pres1]]-
Nvec[lowaa]*Nvec[lowbb]*om[L[pres1],lowcc,lowdd]*ups[U[pres1]]-
g[lowaa,lowdd]*Nvec[lowcc]*Nvec[U[pres1]]*om[lowbb,L[pres1],L[pres2]]*ups[U[pres2]]+
Nvec[lowaa]*Nvec[lowcc]*Nvec[lowdd]*Nvec[U[pres1]]*om[lowbb,L[pres1],L[pres2]]*
ups[U[pres2]]-g[lowaa,lowcc]*Nvec[lowdd]*Nvec[U[pres1]]*om[lowbb,L[pres2],L[pres1]]*
ups[U[pres2]]+Nvec[lowaa]*Nvec[lowcc]*Nvec[lowdd]*Nvec[U[pres1]]*
om[lowbb,L[pres2],L[pres1]]*ups[U[pres2]]-
g[lowaa,lowdd]*Nvec[lowbb]*Nvec[U[pres1]]*om[L[pres1],lowcc,L[pres2]]*ups[U[pres2]]+
Nvec[lowaa]*Nvec[lowbb]*Nvec[lowdd]*Nvec[U[pres1]]*om[L[pres1],lowcc,L[pres2]]*
ups[U[pres2]]-g[lowaa,lowcc]*Nvec[lowbb]*Nvec[U[pres1]]*om[L[pres1],L[pres2],lowdd]*
ups[U[pres2]]+Nvec[lowaa]*Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres1]]*
om[L[pres1],L[pres2],lowdd]*ups[U[pres2]]-
g[lowaa,lowbb]*Nvec[lowdd]*Nvec[U[pres1]]*om[L[pres2],lowcc,L[pres1]]*ups[U[pres2]]+
Nvec[lowaa]*Nvec[lowbb]*Nvec[lowdd]*Nvec[U[pres1]]*om[L[pres2],lowcc,L[pres1]]*
ups[U[pres2]]-g[lowaa,lowbb]*Nvec[lowcc]*Nvec[U[pres1]]*om[L[pres2],L[pres1],lowdd]*
ups[U[pres2]]+Nvec[lowaa]*Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres1]]*
om[L[pres2],L[pres1],lowdd]*ups[U[pres2]]+
g[lowaa,lowdd]*Nvec[lowbb]*Nvec[lowcc]*Nvec[U[pres1]]*Nvec[U[pres2]]*
om[L[pres1],L[pres2],L[pres3]]*ups[U[pres3]]-
Nvec[lowaa]*Nvec[lowbb]*Nvec[lowcc]*Nvec[lowdd]*Nvec[U[pres1]]*Nvec[U[pres2]]*
om[L[pres1],L[pres2],L[pres3]]*ups[U[pres3]]+
g[lowaa,lowcc]*Nvec[lowbb]*Nvec[lowdd]*Nvec[U[pres1]]*Nvec[U[pres2]]*
om[L[pres1],L[pres3],L[pres2]]*ups[U[pres3]]-
Nvec[lowaa]*Nvec[lowbb]*Nvec[lowcc]*Nvec[lowdd]*Nvec[U[pres1]]*Nvec[U[pres2]]*
om[L[pres1],L[pres3],L[pres2]]*ups[U[pres3]]+
g[lowaa,lowbb]*Nvec[lowcc]*Nvec[lowdd]*Nvec[U[pres1]]*Nvec[U[pres2]]*
om[L[pres3],L[pres1],L[pres2]]*ups[U[pres3]]-
Nvec[lowaa]*Nvec[lowbb]*Nvec[lowcc]*Nvec[lowdd]*Nvec[U[pres1]]*Nvec[U[pres2]]*
om[L[pres3],L[pres1],L[pres2]]*ups[U[pres3]]
   );
  Temp=NewDummy[Temp];
  answer=Temp;
  answer
  )
  ];

(*****************************************************************)

(* Intrinsic covariant derivative acting on a vector field.  Operator
   is computed by means of the conformal metric.

   The user supplies an intrinsic vector field, its weight, and two
   indices.  The second index is the index associated with covariant
   differentiation.
*)

NbSigHatVV[operand_,weight_,upbb_,lowaa_]:=

Module[
  {w,VV,answer},
  (
   If[ToString[upbb[[0]]]=="L",Message[SubMfd::AAAA],Null];
   If[ToString[lowaa[[0]]]=="U",Message[SubMfd::AAAA],Null];
   VV=operand;
   w=weight;
   answer=
   (
    NewDummy[
    PiPro[lowaa,U[pres1]]PiPro[L[pres2],upbb]*
      (VV[U[pres2]][L[pres1]]+
      (w+1)ups[L[pres1]]VV[U[pres2]]-
      ups[U[pres2]]VV[L[pres1]]+
      Kronecker[L[pres1],U[pres2]]ups[L[pres3]]VV[U[pres3]])
    ]
   );
   answer
  )];

(******************************************************************)
(* Big box operator on densities, computed with conformal metric.

   User supplies an ambient density and a weight.
*)

BigBoxHatDen[operand_,weight_]:=

Module[
  {w,Den,answer,Temp},
  (
   Den=operand;
   w=weight;
   Temp=
   (
    NbNbHatDen[Den,w,L[pres10],L[pres11]]g[U[pres10],U[pres11]]+
    w*NewDummy[PH[L[i],U[i]]]Den
   );
   Temp=NewDummy[Temp];
   answer=Temp;
   answer
  )];


(******************************************************************)
(* Intrinsic Laplacian acting on densities, computed relative to the
   conformal metric.

   User supplies a density and a weight.
*)

LapSigHatDen[operand_,weight_]:=

Module[
  {w,Den,answer,Temp},
  (
   Den=operand;
   w=weight;
   Temp=
   (
     Den[L[pres10],U[pres10]]-Den[L[pres10],L[pres11]]*
     Nvec[U[pres10]]*Nvec[U[pres11]]-
     Den[L[pres11]]*Nvec[U[pres10]][L[pres10]]*
     Nvec[U[pres11]]+
     (3-n-2*w)*Den[L[pres10]]*Nvec[U[pres10]]*
     Nvec[U[pres11]]*ups[L[pres11]]-
     w*Den*Nvec[U[pres10]][L[pres10]]*Nvec[U[pres11]]*ups[L[pres11]]-
     w*(-3+n+w)*Den*Nvec[U[pres10]]*Nvec[U[pres11]]*
     ups[L[pres10]]*ups[L[pres11]]+
     (-3+n+2*w)*Den[L[pres10]]*ups[U[pres10]]+
     w*(-3+n+w)*Den*ups[L[pres10]]*ups[U[pres10]]-
     w*Den*Nvec[U[pres10]]*Nvec[U[pres11]]*ups[L[pres10],L[pres11]]+
     w*Den*ups[L[pres10],U[pres10]]
   );
   Temp=NewDummy[Temp];
   answer=Temp;
   answer
  )];


(******************************************************************)
(* Ambient Laplacian acting on densities, computed relative to the
   conformal metric.

   User supplies a density and a weight.
*)

LapHatDen[operand_,weight_]:=

Module[
  {w,Den,answer,Temp},
  (
   Den=operand;
   w=weight;
   Temp=
   (
    Den[L[pres10],U[pres10]]+(-2+n+2*w)*Den[L[pres10]]*ups[U[pres10]]+
    w*(-2+n+w)*Den*ups[L[pres10]]*ups[U[pres10]]+
    w*Den*ups[L[pres10],U[pres10]]
   );
   Temp=NewDummy[Temp];
   answer=Temp;
   answer
  )];

(******************************************************************)
(* Second Fundamental Form Shuffle

   User supplies any tensor expression.

   Function exploits the symmetry of the second fundamental form.
   Function converts derivatives of Nvec into copies of the second
   fundamental form, applies SuperSimplify, and converts back to Nvec.
*)

SFFShuffle[operand_]:=

Module[
{Temp},
(
Temp=operand;
Temp=(Temp/.NbNvecToSFF);
Temp=TensorSimplify[Temp];
Temp=(Temp/.NvecRule);
Temp=TensorSimplify[Temp];
Temp=(Temp/.NvecRule);
Temp=SuperSimplify[Temp];
Temp=(Temp/.NvecRule);
Temp=TensorSimplify[Temp];
Temp=(Temp/.ExpandSFF);
Temp=TensorSimplify[Temp];
Temp=(Temp/.NvecRule);
Temp=(Temp/.ExpandPiPro);
Temp=TensorSimplify[Temp];
Temp=(Temp/.NvecRule);
Temp=TensorSimplify[Temp];
Temp=(Temp/.NvecRule);
Temp=TensorSimplify[Temp];
Temp
)
];

(******************************************************************)
(* The Robin operator (conformally invariant Neumann operator)

   User supplies a tensor-tractor expression and the weight of this
   expression.  Function applies the Robin operator to this expression
   and returns the result.  See page 45 of David Grant's thesis.
*)

Robin[operand_,weight_]:=

Module[
{Temp,www},
(
www=weight;
Temp=operand;
Temp=(Nvec[U[pres1]](Temp[L[pres1]])-www*Hmc*Temp);
Temp=(Temp/.GradXYZ);
Temp=TensorExpand[Temp];
Temp=NewDummy[Temp];
Temp
)
];

(******************************************************************)
(* The Robin operator with indices.

   This is the same as the Robin operator, but the user supplies a pair
   of repeated indices.  The idea is to avoid the NewDummy command,
   which may take some time.  This function does not call NewDummy!
*)

RobinInd[operand_,weight_,lowaa_,upaa_]:=

Module[
{Temp,www},
(
If[ToString[lowaa[[0]]]=="U",Message[SubMfd::AAAA],Null];
If[ToString[upaa[[0]]]=="L",Message[SubMfd::AAAA],Null];
If[ToString[lowaa[[1]]]!=ToString[upaa[[1]]],Message[SubMfd::BBBB],Null];
www=weight;
Temp=operand;
Temp=(Nvec[upaa](Temp[lowaa])-www*Hmc*Temp);
Temp=(Temp/.GradXYZ);
Temp=TensorExpand[Temp];
Temp
)
];

(******************************************************************)
(* The intrinsic tractor-D operator

   User supplies operand, its weight, and the new tractor index.  The
   operand is assumed to be an intrinsic tensor-tractor.  This function
   uses covariant derivatives.  These covariant derivatives are assumed to
   be intrinsic covariant derivatives.  When these intrinsic covariant
   derivatives hit the splitting tractors, this function expands them.
   It is up to the caller to expand the other covariant derivatives,
   however.  THIS LATTER POINT IS A KEY POINT!
*)

DOpSig[operand_,weight_,newindex_]:=

Module[{w,LocalOp,Temp},
  (
    w=weight;
    LocalOp=operand;
    Temp=
     (
      (*******)
      (amn-1+2*w-2)*w*YS[newindex]*LocalOp+
      (*******)
      (amn-1+2*w-2)*ZS[newindex,U[pres1]]*(LocalOp[L[pres1]])+
      (*******)
      (-1)XS[newindex](LocalOp[L[pres1],U[pres1]]+w*TrPSigma*LocalOp)
      (*******)
     );
    Temp=(Temp/.GradXYZSigma);
    Temp=(Temp/.GradXYZSigma);
    Temp=NewDummy[Temp];
    Temp
    )
  ];

(******************************************************************)
(*
   Tractor curvature

   Notes:

   Tensors OmabKL and OmABKL are defined in the file May2.m.

   It turns out that I have already defined a macro to expand the
   tractor curvature W.  See MayWABCD and WABCD in May6.m.
*)
(******************************************************************)

DefineRule[ExpandOmabKL,OmabKL[L[i],L[j],U[KK],L[LL]],
  (P[L[j],U[k]][L[i]]-P[L[i],U[k]][L[j]])Z[U[KK],L[k]]X[L[LL]]+
  Weyl[L[i],L[j],U[k],L[l]]Z[U[KK],L[k]]Z[L[LL],U[l]]-
  (P[L[j],L[l]][L[i]]-P[L[i],L[l]][L[j]])X[U[KK]]Z[L[LL],U[l]]
  ];

DefineRule[ExpandOmABKL,OmABKL[L[AA],L[BB],U[KK],L[LL]],
  Z[L[AA],U[i]]Z[L[BB],U[j]]OmabKL[L[i],L[j],U[KK],L[LL]]
  ];

(******************************************************************)
(*
  Rules to combine Y-, Z-, and X-tractors.

  The idea here is to reduce computational time complexity.
*)
(******************************************************************)

DefineTensor[FourYYYY,4,
  Bundle->tractor1];

DefineRule[FourYYYYToFake,
  Y[L[AA]]Y[L[BB]]Y[L[CC]]Y[L[DD]],
  FourYYYY[L[AA],L[BB],L[CC],L[DD]],
  NewRule->True];

DefineRule[FakeToFourYYYY,
  FourYYYY[L[AA],L[BB],L[CC],L[DD]],
  Y[L[AA]]Y[L[BB]]Y[L[CC]]Y[L[DD]],
  NewRule->True];

(******)

DefineTensor[ThreeYYYOneZ,5,
  Bundle->{tractor1,tractor1,tractor1,tractor1,tangent}];

DefineRule[ThreeYYYOneZToFake,
  Y[L[AA1]]Y[L[AA2]]Y[L[AA3]]Z[L[AA4],L[a4]],
  ThreeYYYOneZ[L[AA1],L[AA2],L[AA3],L[AA4],L[a4]],
  NewRule->True];

DefineRule[FakeToThreeYYYOneZ,
  ThreeYYYOneZ[L[AA1],L[AA2],L[AA3],L[AA4],L[a4]],
  Y[L[AA1]]Y[L[AA2]]Y[L[AA3]]Z[L[AA4],L[a4]],
  NewRule->True];

(******)

DefineTensor[OneYThreeZZZ,7,
  Bundle->{tractor1,tractor1,tangent,tractor1,tangent,tractor1,tangent}];

DefineRule[OneYThreeZZZToFake,
  Y[L[AA1]]Z[L[AA2],L[a2]]Z[L[AA3],L[a3]]Z[L[AA4],L[a4]],
  OneYThreeZZZ[L[AA1],L[AA2],L[a2],L[AA3],L[a3],L[AA4],L[a4]],
  NewRule->True];

DefineRule[FakeToOneYThreeZZZ,
  OneYThreeZZZ[L[AA1],L[AA2],L[a2],L[AA3],L[a3],L[AA4],L[a4]],
  Y[L[AA1]]Z[L[AA2],L[a2]]Z[L[AA3],L[a3]]Z[L[AA4],L[a4]],
  NewRule->True];

(******)

DefineTensor[FourZZZZ,8,
  Bundle->{tractor1,tangent,tractor1,tangent,tractor1,tangent,tractor1,tangent}]

DefineRule[FourZZZZToFake,
  Z[L[BB1],L[b1]]Z[L[BB2],L[b2]]Z[L[BB3],L[b3]]Z[L[BB4],L[b4]],
  FourZZZZ[L[BB1],L[b1],L[BB2],L[b2],L[BB3],L[b3],L[BB4],L[b4]],
  NewRule->True];

DefineRule[FakeToFourZZZZ,
  FourZZZZ[L[BB1],L[b1],L[BB2],L[b2],L[BB3],L[b3],L[BB4],L[b4]],
  Z[L[BB1],L[b1]]Z[L[BB2],L[b2]]Z[L[BB3],L[b3]]Z[L[BB4],L[b4]],
  NewRule->True];

(******)

DefineTensor[ThreeZZZ,6,
  Bundle->{tractor1,tangent,tractor1,tangent,tractor1,tangent}];

DefineRule[ThreeZZZToFake,
  Z[L[BB1],L[b1]]Z[L[BB2],L[b2]]Z[L[BB3],L[b3]],
  ThreeZZZ[L[BB1],L[b1],L[BB2],L[b2],L[BB3],L[b3]],
  NewRule->True];

DefineRule[FakeToThreeZZZ,
  ThreeZZZ[L[BB1],L[b1],L[BB2],L[b2],L[BB3],L[b3]],
  Z[L[BB1],L[b1]]Z[L[BB2],L[b2]]Z[L[BB3],L[b3]],
  NewRule->True];

(******)

DefineTensor[TwoYYTwoZZ,6,
  Bundle->{tractor1,tractor1,tractor1,tangent,tractor1,tangent}];

DefineRule[TwoYYTwoZZToFake,
  Y[L[AA1]]Y[L[AA2]]Z[L[AA3],L[a3]]Z[L[AA4],L[a4]],
  TwoYYTwoZZ[L[AA1],L[AA2],L[AA3],L[a3],L[AA4],L[a4]],
  NewRule->True];

DefineRule[FakeToTwoYYTwoZZ,
  TwoYYTwoZZ[L[AA1],L[AA2],L[AA3],L[a3],L[AA4],L[a4]],
  Y[L[AA1]]Y[L[AA2]]Z[L[AA3],L[a3]]Z[L[AA4],L[a4]],
  NewRule->True];

(******)

DefineTensor[ThreeYYY,3,Bundle->tractor1];

DefineRule[ThreeYYYToFake,
  Y[L[AA]]Y[L[BB]]Y[L[CC]],
  ThreeYYY[L[AA],L[BB],L[CC]],
  NewRule->True];

DefineRule[FakeToThreeYYY,
  ThreeYYY[L[AA],L[BB],L[CC]],
  Y[L[AA]]Y[L[BB]]Y[L[CC]],
  NewRule->True];

(******)

DefineTensor[OneYTwoZZ,5,
  Bundle->{tractor1,tractor1,tangent,tractor1,tangent}];

DefineRule[OneYTwoZZToFake,
  Y[L[AA1]]Z[L[AA2],L[a2]]Z[L[AA3],L[a3]],
  OneYTwoZZ[L[AA1],L[AA2],L[a2],L[AA3],L[a3]],
  NewRule->True];

DefineRule[FakeToOneYTwoZZ,
  OneYTwoZZ[L[AA1],L[AA2],L[a2],L[AA3],L[a3]],
  Y[L[AA1]]Z[L[AA2],L[a2]]Z[L[AA3],L[a3]],
  NewRule->True];

(******)

DefineTensor[TwoYYOneZ,4,
  Bundle->{tractor1,tractor1,tractor1,tangent}];

DefineRule[TwoYYOneZToFake,
  Y[L[AA1]]Y[L[AA2]]Z[L[AA3],L[a3]],
  TwoYYOneZ[L[AA1],L[AA2],L[AA3],L[a3]],
  NewRule->True];

DefineRule[FakeToTwoYYOneZ,
  TwoYYOneZ[L[AA1],L[AA2],L[AA3],L[a3]],
  Y[L[AA1]]Y[L[AA2]]Z[L[AA3],L[a3]],
  NewRule->True];

(***************************************************************)
(*
  The Paneitz operator.

  Function receives an operand, which is supposed to be a density of
  any weight.  Function computes the action of the Paneitz operator
  on this density and returns the result.
*)

Paneitz[operand_]:=

Module[
  {f,Temp},
  (
    f=operand;
    Temp=(
      f[L[a],U[a],L[b],U[b]]+
      ((4-n)*f*P[L[a],U[a]][L[b],U[b]])/2+
      (2-n)*f[L[a],U[a]]*P[L[b],U[b]]+
      ((-4+n)*n*f*P[L[a],U[a]]*P[L[b],U[b]])/4+
      (6-n)*f[L[a]]*P[L[b],U[b]][U[a]]+
      4*f[L[a],L[b]]*P[U[a],U[b]]+(4-n)*f*P[L[a],L[b]]*P[U[a],U[b]]
         );
    Temp=NewDummy[Temp];
    Temp
  )
];

(***************************************************************)
(* The tractor second fundamental form *)
(***************************************************************)

DefineTensor[TracSFF,2,Bundle->tractor1,Symmetries->Symmetric];

DefineRule[ExpandTracSFF,
  TracSFF[L[AA],L[BB]],
(Nvec[U[a]][L[a],L[b],U[b]]*X[L[AA]]*X[L[BB]])/(-1+n)-
(Nvec[U[a]][L[b]]*Nvec[U[b]][L[c]]*Nvec[U[c]][L[a]]*X[L[AA]]*X[L[BB]])/
(-3+n)+(n*Nvec[U[a]][L[a]]*Nvec[U[b]][L[c]]*Nvec[U[c]][L[b]]*
X[L[AA]]*X[L[BB]])/((-3+n)*(-1+n))-
(Nvec[U[a]][L[a]]*Nvec[U[b]][L[b]]*Nvec[U[c]][L[c]]*X[L[AA]]*X[L[BB]])/
((-3+n)*(-1+n))-(Nvec[U[a]]*Nvec[U[b]][L[b]]*
Nvec[U[c]][L[c],L[a]]*X[L[AA]]*X[L[BB]])/(-1+n)-
(Nvec[U[a]]*Nvec[U[b]]*Nvec[U[c]][L[c],L[a],L[b]]*X[L[AA]]*X[L[BB]])/
(-1+n)+(Nvec[L[a]][L[b]]*Nvec[U[a]][L[c]]*Nvec[U[b]][L[d]]*
Nvec[U[c]]*Nvec[U[d]]*X[L[AA]]*X[L[BB]])/(-2+n)-
(Nvec[L[a]][L[b]]*Nvec[U[a]][L[c]]*Nvec[U[b]]*Nvec[U[c]][L[d]]*
Nvec[U[d]]*X[L[AA]]*X[L[BB]])/(-2+n)-
((-2+n)*Nvec[U[a]]*Nvec[U[b]]*Nvec[U[c]][L[c]]*P[L[a],L[b]]*X[L[AA]]*
X[L[BB]])/(-1+n)-Nvec[U[a]]*Nvec[U[b]]*Nvec[U[c]]*
P[L[a],L[b]][L[c]]*X[L[AA]]*X[L[BB]]+
2*Nvec[U[a]][L[b]]*P[L[a],U[b]]*X[L[AA]]*X[L[BB]]-
2*Nvec[U[a]]*Nvec[U[b]]*Nvec[U[c]][L[a]]*P[L[b],L[c]]*X[L[AA]]*
X[L[BB]]-(Nvec[U[a]][L[a]]*P[L[b],U[b]]*X[L[AA]]*X[L[BB]])/(-1+n)+
Nvec[U[a]]*P[L[b],U[b]][L[a]]*X[L[AA]]*X[L[BB]]-
(Nvec[U[a]]*Nvec[U[b]]*Nvec[U[c]][L[d]]*Weyl[L[a],L[c],L[b],U[d]]*
X[L[AA]]*X[L[BB]])/(-3+n)+
((-3+n)*Nvec[U[a]]*Nvec[U[b]][L[a]]*Nvec[U[c]][L[c]]*X[L[BB]]*
Z[L[AA],L[b]])/(-2+n)+
((-3+n)*Nvec[U[a]]*Nvec[U[b]]*Nvec[U[c]][L[a],L[b]]*X[L[BB]]*
Z[L[AA],L[c]])/(-2+n)-
((-3+n)*Nvec[L[a]][L[b],U[b]]*X[L[BB]]*Z[L[AA],U[a]])/(-2+n)-
((-3+n)*Nvec[L[a]]*Nvec[L[b]][L[c]]*Nvec[U[b]][U[c]]*X[L[BB]]*
Z[L[AA],U[a]])/(-2+n)-
((-3+n)*Nvec[L[a]]*Nvec[U[b]]*Nvec[U[c]][L[c],L[b]]*X[L[BB]]*
Z[L[AA],U[a]])/((-2+n)*(-1+n))+
((-3+n)*Nvec[L[a]]*Nvec[L[b]][L[c]]*Nvec[U[b]][L[d]]*Nvec[U[c]]*
Nvec[U[d]]*X[L[BB]]*Z[L[AA],U[a]])/(-2+n)+
((-3+n)*Nvec[U[a]][L[a],L[b]]*X[L[BB]]*Z[L[AA],U[b]])/
((-2+n)*(-1+n))+((-3+n)*Nvec[U[a]]*Nvec[U[b]][L[a]]*
Nvec[U[c]][L[c]]*X[L[AA]]*Z[L[BB],L[b]])/(-2+n)+
((-3+n)*Nvec[U[a]]*Nvec[U[b]]*Nvec[U[c]][L[a],L[b]]*X[L[AA]]*
Z[L[BB],L[c]])/(-2+n)+
(3-n)*Nvec[L[a]]*Nvec[U[b]]*Nvec[U[c]][L[b]]*Z[L[AA],U[a]]*
Z[L[BB],L[c]]-((-3+n)*Nvec[L[a]][L[b],U[b]]*X[L[AA]]*
Z[L[BB],U[a]])/(-2+n)-
((-3+n)*Nvec[L[a]]*Nvec[L[b]][L[c]]*Nvec[U[b]][U[c]]*X[L[AA]]*
Z[L[BB],U[a]])/(-2+n)-
((-3+n)*Nvec[L[a]]*Nvec[U[b]]*Nvec[U[c]][L[c],L[b]]*X[L[AA]]*
Z[L[BB],U[a]])/((-2+n)*(-1+n))+
((-3+n)*Nvec[L[a]]*Nvec[L[b]][L[c]]*Nvec[U[b]][L[d]]*Nvec[U[c]]*
Nvec[U[d]]*X[L[AA]]*Z[L[BB],U[a]])/(-2+n)+
(-3+n)*Nvec[L[a]][L[b]]*Z[L[AA],U[b]]*Z[L[BB],U[a]]+
((-3+n)*Nvec[U[a]][L[a],L[b]]*X[L[AA]]*Z[L[BB],U[b]])/
((-2+n)*(-1+n))-((-3+n)*Nvec[U[a]][L[a]]*Z[L[AA],L[b]]*
Z[L[BB],U[b]])/(-1+n)+
((-3+n)*Nvec[L[a]]*Nvec[L[b]]*Nvec[U[c]][L[c]]*Z[L[AA],U[a]]*
Z[L[BB],U[b]])/(-1+n),
  NewRule->True];

(****************************************************************)
(*
  DTildeABOp

  If the caller is interested in \tilde{D}_{AB}, then he or she supplies
  the indices A and B in that order.  Caller supplies the weight of the
  operand.  Function computes as follows.
  1.  Compute D_A D_B f.
  2.  Throw out all terms involving X.
  3.  Divide by (n+2w-4).
*)

DTildeABOp[operand_,weight_,indAA_,indBB_] :=

Module[
{Temp,w,LocalOp,Answer},
(
  LocalOp=operand;
  w=weight;
  Temp=
    (
      (-1+w)*w*(-2+n+2*w)*LocalOp*Y[indAA]*Y[indBB]+
      (-1+w)*(-2+n+2*w)*LocalOp[L[pres1]]*Y[indBB]*Z[indAA,U[pres1]]+
      (-1+w)*(-2+n+2*w)*LocalOp[L[pres1]]*Y[indAA]*Z[indBB,U[pres1]]-
      LocalOp[L[pres2],U[pres2]]*Z[indAA,L[pres1]]*Z[indBB,U[pres1]]-
      w*LocalOp*P[L[pres2],U[pres2]]*Z[indAA,L[pres1]]*Z[indBB,U[pres1]]+
      (-2+n+2*w)*LocalOp[L[pres1],L[pres2]]*Z[indAA,U[pres1]]*Z[indBB,U[pres2]]+
      w*(-2+n+2*w)*LocalOp*P[L[pres1],L[pres2]]*Z[indAA,U[pres1]]*Z[indBB,U[pres2]]
    );
  Temp=(Temp/.GradXYZ);
  Temp=(Temp/.GradXYZ);
  Temp=NewDummy[Temp];
  Answer=Temp;
  Answer
)
];

(****************************************************************)
(*
  DABOp

  Caller supplies the weight of the operand.  If the caller is
  interested in D^{AB}, then he or she supplies the indices A and B in
  that order.  See display (7) of Conformally invariant powers article
  or display (17) of Rod's article "Invariant Theory and Calculus for
  Conformal Geometries."

  Operand is a weighted tractor.  This function does not change the
  weight.
*)

DABOp[operand_,weight_,indAA_,indBB_] :=

Module[
{Temp,w,LocalOp,Answer},
(
  LocalOp=operand;
  w=weight;
  Temp=
    (
     w*X[indBB]Y[indAA]LocalOp + X[indBB]Z[indAA,U[pres1]]operand[L[pres1]]-
     w*X[indAA]Y[indBB]LocalOp - X[indAA]Z[indBB,U[pres1]]operand[L[pres1]]
    );
  Temp=(Temp/.GradXYZ);
  Temp=NewDummy[Temp];
  Answer=Temp;
  Answer
)
];

(****************************************************************)
(****************************************************************)
(*
  Covariant derivatives with respect to the conformal metric
  Exp[2*ups]g.

  These will be covariant derivatives of weighted tensors.  We will
  assume that the weight is "wabc" and that all indices are down.

  See the notebook Test8.nb.
*)

(*
  Define tensors of weight wabc.
*)

DefineTensor[ZeroW,0];
DefineTensor[OneW,1];
DefineTensor[TwoW,2];
DefineTensor[ThreeW,3];
DefineTensor[FourW,4];

DefineTensor[NbHatZeroW,1];
DefineTensor[NbNbHatZeroW,2];
DefineTensor[NbNbNbHatZeroW,3];

DefineTensor[NbHatOneW,2];
DefineTensor[NbNbHatOneW,3];
DefineTensor[NbNbNbHatOneW,4];

DefineTensor[NbHatTwoW,3];
DefineTensor[NbHatThreeW,4];
DefineTensor[NbHatFourW,5];
DefineTensor[NbNbHatTwoW,4];
DefineTensor[NbNbNbHatTwoW,5];

(*
  The leftmost indices are always the original indices of the
  undifferentiated tensor.  The other indices are the indices
  associated with covariant differentiation, and these indices are
  listed in the order in which the covariant derivatives are applied.
*)

DefineRule[ExpandNbHatZeroW,
  NbHatZeroW[L[i]],
    ZeroW[L[i]]+wabc*ZeroW*ups[L[i]],
  NewRule->True];

DefineRule[ExpandNbNbHatZeroW,
  NbNbHatZeroW[L[a],L[b]],
    (-2+wabc)*wabc*ups[L[a]]*ups[L[b]]*ZeroW+
    wabc*g[L[a],L[b]]*ups[L[c]]*ups[U[c]]*ZeroW+
    wabc*ups[L[a],L[b]]*ZeroW+(-1+wabc)*ups[L[b]]*ZeroW[L[a]]+
    (-1+wabc)*ups[L[a]]*ZeroW[L[b]]+
    g[L[a],L[b]]*ups[L[c]]*ZeroW[U[c]]+ZeroW[L[a],L[b]],
  NewRule->True];

DefineRule[ExpandNbNbNbHatZeroW,
  NbNbNbHatZeroW[L[a1],L[a2],L[a3]],
    f[L[a1],L[a2],L[a3]]+
    (-1+wabc)*f[L[a2],L[a3]]*ups[L[a1]]-
    f[L[a3],L[a2]]*ups[L[a1]]+
    (-2+wabc)*f[L[a1],L[a3]]*ups[L[a2]]+
    (2-4*wabc+wabc^2)*f[L[a3]]*ups[L[a1]]*ups[L[a2]]+
    (-2+wabc)*f[L[a1],L[a2]]*ups[L[a3]]+
    (-3+wabc)*(-1+wabc)*f[L[a2]]*ups[L[a1]]*ups[L[a3]]+
    (-3+wabc)*(-1+wabc)*f[L[a1]]*ups[L[a2]]*ups[L[a3]]+
    (-4+wabc)*(-2+wabc)*wabc*f*ups[L[a1]]*ups[L[a2]]*ups[L[a3]]+
    f[L[a],L[a3]]*g[L[a1],L[a2]]*ups[U[a]]+
    f[L[a],L[a2]]*g[L[a1],L[a3]]*ups[U[a]]+
    f[L[a1],L[a]]*g[L[a2],L[a3]]*ups[U[a]]+
    wabc*f[L[a3]]*g[L[a1],L[a2]]*ups[L[a]]*ups[U[a]]+
    (-1+wabc)*f[L[a2]]*g[L[a1],L[a3]]*ups[L[a]]*ups[U[a]]+
    (-1+wabc)*f[L[a1]]*g[L[a2],L[a3]]*ups[L[a]]*ups[U[a]]+
    (-1+wabc)*f[L[a]]*g[L[a2],L[a3]]*ups[L[a1]]*ups[U[a]]+
    (-2+wabc)*wabc*f*g[L[a2],L[a3]]*ups[L[a]]*ups[L[a1]]*
    ups[U[a]]+(-1+wabc)*f[L[a]]*g[L[a1],L[a3]]*ups[L[a2]]*
    ups[U[a]]+(-2+wabc)*wabc*f*g[L[a1],L[a3]]*ups[L[a]]*
    ups[L[a2]]*ups[U[a]]+
    (-2+wabc)*f[L[a]]*g[L[a1],L[a2]]*ups[L[a3]]*ups[U[a]]+
    (-2+wabc)*wabc*f*g[L[a1],L[a2]]*ups[L[a]]*ups[L[a3]]*
    ups[U[a]]+wabc*f[L[a3]]*ups[L[a1],L[a2]]+
    (-2+wabc)*wabc*f*ups[L[a3]]*ups[L[a1],L[a2]]+
    (-1+wabc)*f[L[a2]]*ups[L[a1],L[a3]]+
    (-3+wabc)*wabc*f*ups[L[a2]]*ups[L[a1],L[a3]]+
    wabc*f*g[L[a2],L[a3]]*ups[L[a]]*ups[L[a1],U[a]]+
    (-1+wabc)*f[L[a1]]*ups[L[a2],L[a3]]+
    (-2+wabc)*wabc*f*ups[L[a1]]*ups[L[a2],L[a3]]-
    wabc*f*ups[L[a1]]*ups[L[a3],L[a2]]+
    wabc*f*g[L[a1],L[a3]]*ups[L[a]]*ups[U[a],L[a2]]+
    f[L[a]]*g[L[a1],L[a2]]*ups[U[a],L[a3]]+
    2*wabc*f*g[L[a1],L[a2]]*ups[L[a]]*ups[U[a],L[a3]]+
    wabc*f*ups[L[a1],L[a2],L[a3]],
NewRule->True];

DefineRule[ExpandNbHatOneW,
  NbHatOneW[L[i],L[j]],
    OneW[L[i]][L[j]]-OneW[L[j]]*ups[L[i]]+
    (-1+wabc)*OneW[L[i]]*ups[L[j]]+g[L[i],L[j]]*OneW[L[a]]*ups[U[a]],
  NewRule->True];

DefineRule[ExpandNbNbHatOneW,
  NbNbHatOneW[L[a],L[b],L[c]],
    OneW[L[a]][L[b],L[c]]-OneW[L[b]][L[c]]*ups[L[a]]-
    OneW[L[c]][L[b]]*ups[L[a]]+
    (-2+wabc)*OneW[L[a]][L[c]]*ups[L[b]]+
    (2-wabc)*OneW[L[c]]*ups[L[a]]*ups[L[b]]+
    (-2+wabc)*OneW[L[a]][L[b]]*ups[L[c]]+
    (3-wabc)*OneW[L[b]]*ups[L[a]]*ups[L[c]]+
    (-3+wabc)*(-1+wabc)*OneW[L[a]]*ups[L[b]]*ups[L[c]]+
    g[L[b],L[c]]*OneW[L[a]][L[d]]*ups[U[d]]+
    g[L[a],L[c]]*OneW[L[d]][L[b]]*ups[U[d]]+
    g[L[a],L[b]]*OneW[L[d]][L[c]]*ups[U[d]]-
    g[L[b],L[c]]*OneW[L[d]]*ups[L[a]]*ups[U[d]]+
    (-1+wabc)*g[L[a],L[c]]*OneW[L[d]]*ups[L[b]]*ups[U[d]]+
    (-2+wabc)*g[L[a],L[b]]*OneW[L[d]]*ups[L[c]]*ups[U[d]]+
    (-1+wabc)*g[L[b],L[c]]*OneW[L[a]]*ups[L[d]]*ups[U[d]]-
    g[L[a],L[c]]*OneW[L[b]]*ups[L[d]]*ups[U[d]]-
    OneW[L[b]]*ups[L[a],L[c]]+
    (-1+wabc)*OneW[L[a]]*ups[L[b],L[c]]+
    g[L[a],L[b]]*OneW[L[d]]*ups[U[d],L[c]],
  NewRule->True];

DefineRule[ExpandNbNbNbHatOneW,
  NbNbNbHatOneW[L[a],L[b],L[c],L[d]],
    OneW[L[a]][L[b],L[c],L[d]]-
    OneW[L[b]][L[c],L[d]]*ups[][L[a]]-
    OneW[L[c]][L[b],L[d]]*ups[][L[a]]-
    OneW[L[d]][L[b],L[c]]*ups[][L[a]]+
    (-2+wabc)*OneW[L[a]][L[c],L[d]]*ups[][L[b]]-
    OneW[L[a]][L[d],L[c]]*ups[][L[b]]+
    (3-wabc)*OneW[L[c]][L[d]]*ups[][L[a]]*ups[][L[b]]+
    (3-wabc)*OneW[L[d]][L[c]]*ups[][L[a]]*ups[][L[b]]+
    (-3+wabc)*OneW[L[a]][L[b],L[d]]*ups[][L[c]]+
    (4-wabc)*OneW[L[b]][L[d]]*ups[][L[a]]*ups[][L[c]]+
    (3-wabc)*OneW[L[d]][L[b]]*ups[][L[a]]*ups[][L[c]]+
    (7-6*wabc+wabc^2)*OneW[L[a]][L[d]]*ups[][L[b]]*ups[][L[c]]-
    (-4+wabc)*(-2+wabc)*OneW[L[d]]*ups[][L[a]]*ups[][L[b]]*
    ups[][L[c]]+(-3+wabc)*OneW[L[a]][L[b],L[c]]*ups[][L[d]]+
    (4-wabc)*OneW[L[b]][L[c]]*ups[][L[a]]*ups[][L[d]]+
    (4-wabc)*OneW[L[c]][L[b]]*ups[][L[a]]*ups[][L[d]]+
    (-4+wabc)*(-2+wabc)*OneW[L[a]][L[c]]*ups[][L[b]]*ups[][L[d]]-
    (-5+wabc)*(-2+wabc)*OneW[L[c]]*ups[][L[a]]*ups[][L[b]]*
    ups[][L[d]]+(-4+wabc)*(-2+wabc)*OneW[L[a]][L[b]]*ups[][L[c]]*
    ups[][L[d]]-(-5+wabc)*(-3+wabc)*OneW[L[b]]*ups[][L[a]]*
    ups[][L[c]]*ups[][L[d]]+
    (-5+wabc)*(-3+wabc)*(-1+wabc)*OneW[L[a]]*ups[][L[b]]*ups[][L[c]]*
    ups[][L[d]]+g[L[c],L[d]]*OneW[L[a]][L[b],L[e]]*ups[][U[e]]+
    g[L[b],L[d]]*OneW[L[a]][L[e],L[c]]*ups[][U[e]]+
    g[L[b],L[c]]*OneW[L[a]][L[e],L[d]]*ups[][U[e]]+
    g[L[a],L[d]]*OneW[L[e]][L[b],L[c]]*ups[][U[e]]+
    g[L[a],L[c]]*OneW[L[e]][L[b],L[d]]*ups[][U[e]]+
    g[L[a],L[b]]*OneW[L[e]][L[c],L[d]]*ups[][U[e]]-
    g[L[c],L[d]]*OneW[L[b]][L[e]]*ups[][L[a]]*ups[][U[e]]-
    g[L[b],L[d]]*OneW[L[c]][L[e]]*ups[][L[a]]*ups[][U[e]]-
    g[L[b],L[c]]*OneW[L[d]][L[e]]*ups[][L[a]]*ups[][U[e]]-
    g[L[c],L[d]]*OneW[L[e]][L[b]]*ups[][L[a]]*ups[][U[e]]-
    g[L[b],L[d]]*OneW[L[e]][L[c]]*ups[][L[a]]*ups[][U[e]]-
    g[L[b],L[c]]*OneW[L[e]][L[d]]*ups[][L[a]]*ups[][U[e]]+
    (-2+wabc)*g[L[c],L[d]]*OneW[L[a]][L[e]]*ups[][L[b]]*ups[][U[e]]+
    (-2+wabc)*g[L[a],L[d]]*OneW[L[e]][L[c]]*ups[][L[b]]*ups[][U[e]]+
    (-2+wabc)*g[L[a],L[c]]*OneW[L[e]][L[d]]*ups[][L[b]]*ups[][U[e]]+
    (2-wabc)*g[L[c],L[d]]*OneW[L[e]]*ups[][L[a]]*ups[][L[b]]*
    ups[][U[e]]+(-2+wabc)*g[L[b],L[d]]*OneW[L[a]][L[e]]*ups[][L[c]]*
    ups[][U[e]]+(-2+wabc)*g[L[a],L[d]]*OneW[L[e]][L[b]]*ups[][L[c]]*
    ups[][U[e]]+(-3+wabc)*g[L[a],L[b]]*OneW[L[e]][L[d]]*ups[][L[c]]*
    ups[][U[e]]+(3-wabc)*g[L[b],L[d]]*OneW[L[e]]*ups[][L[a]]*
    ups[][L[c]]*ups[][U[e]]+
    (-3+wabc)*(-1+wabc)*g[L[a],L[d]]*OneW[L[e]]*ups[][L[b]]*
    ups[][L[c]]*ups[][U[e]]+
    (-3+wabc)*g[L[b],L[c]]*OneW[L[a]][L[e]]*ups[][L[d]]*ups[][U[e]]+
    (-3+wabc)*g[L[a],L[c]]*OneW[L[e]][L[b]]*ups[][L[d]]*ups[][U[e]]+
    (-3+wabc)*g[L[a],L[b]]*OneW[L[e]][L[c]]*ups[][L[d]]*ups[][U[e]]+
    (4-wabc)*g[L[b],L[c]]*OneW[L[e]]*ups[][L[a]]*ups[][L[d]]*
    ups[][U[e]]+(-4+wabc)*(-1+wabc)*g[L[a],L[c]]*OneW[L[e]]*
    ups[][L[b]]*ups[][L[d]]*ups[][U[e]]+
    (-4+wabc)*(-2+wabc)*g[L[a],L[b]]*OneW[L[e]]*ups[][L[c]]*
    ups[][L[d]]*ups[][U[e]]+
    (-2+wabc)*g[L[c],L[d]]*OneW[L[a]][L[b]]*ups[][L[e]]*ups[][U[e]]+
    (-2+wabc)*g[L[b],L[d]]*OneW[L[a]][L[c]]*ups[][L[e]]*ups[][U[e]]+
    (-1+wabc)*g[L[b],L[c]]*OneW[L[a]][L[d]]*ups[][L[e]]*ups[][U[e]]-
    g[L[a],L[d]]*OneW[L[b]][L[c]]*ups[][L[e]]*ups[][U[e]]-
    g[L[a],L[c]]*OneW[L[b]][L[d]]*ups[][L[e]]*ups[][U[e]]-
    g[L[a],L[d]]*OneW[L[c]][L[b]]*ups[][L[e]]*ups[][U[e]]+
    (3-wabc)*g[L[c],L[d]]*OneW[L[b]]*ups[][L[a]]*ups[][L[e]]*
    ups[][U[e]]+(2-wabc)*g[L[b],L[d]]*OneW[L[c]]*ups[][L[a]]*
    ups[][L[e]]*ups[][U[e]]+
    (1-wabc)*g[L[b],L[c]]*OneW[L[d]]*ups[][L[a]]*ups[][L[e]]*
    ups[][U[e]]+(-3+wabc)*(-1+wabc)*g[L[c],L[d]]*OneW[L[a]]*
    ups[][L[b]]*ups[][L[e]]*ups[][U[e]]+
    (2-wabc)*g[L[a],L[d]]*OneW[L[c]]*ups[][L[b]]*ups[][L[e]]*
    ups[][U[e]]+g[L[a],L[c]]*OneW[L[d]]*ups[][L[b]]*ups[][L[e]]*
    ups[][U[e]]+(-3+wabc)*(-1+wabc)*g[L[b],L[d]]*OneW[L[a]]*
    ups[][L[c]]*ups[][L[e]]*ups[][U[e]]+
    (3-wabc)*g[L[a],L[d]]*OneW[L[b]]*ups[][L[c]]*ups[][L[e]]*
    ups[][U[e]]+(-3+wabc)*(-1+wabc)*g[L[b],L[c]]*OneW[L[a]]*
    ups[][L[d]]*ups[][L[e]]*ups[][U[e]]+
    (3-wabc)*g[L[a],L[c]]*OneW[L[b]]*ups[][L[d]]*ups[][L[e]]*
    ups[][U[e]]+g[L[a],L[d]]*g[L[b],L[c]]*OneW[L[e]][L[i]]*
    ups[][U[e]]*ups[][U[i]]+
    g[L[a],L[c]]*g[L[b],L[d]]*OneW[L[e]][L[i]]*ups[][U[e]]*ups[][U[i]]+
    g[L[a],L[b]]*g[L[c],L[d]]*OneW[L[e]][L[i]]*ups[][U[e]]*ups[][U[i]]+
    (-2+wabc)*g[L[a],L[d]]*g[L[b],L[c]]*OneW[L[e]]*ups[][L[i]]*
    ups[][U[e]]*ups[][U[i]]+
    (-2+wabc)*g[L[a],L[c]]*g[L[b],L[d]]*OneW[L[e]]*ups[][L[i]]*
    ups[][U[e]]*ups[][U[i]]+
    (-2+wabc)*g[L[a],L[b]]*g[L[c],L[d]]*OneW[L[e]]*ups[][L[i]]*
    ups[][U[e]]*ups[][U[i]]-OneW[L[b]][L[d]]*ups[][L[a],L[c]]+
    OneW[L[d]]*ups[][L[b]]*ups[][L[a],L[c]]+
    (3-wabc)*OneW[L[b]]*ups[][L[d]]*ups[][L[a],L[c]]-
    g[L[b],L[d]]*OneW[L[e]]*ups[][U[e]]*ups[][L[a],L[c]]-
    OneW[L[b]][L[c]]*ups[][L[a],L[d]]-
    OneW[L[c]][L[b]]*ups[][L[a],L[d]]+
    (2-wabc)*OneW[L[c]]*ups[][L[b]]*ups[][L[a],L[d]]+
    (4-wabc)*OneW[L[b]]*ups[][L[c]]*ups[][L[a],L[d]]-
    g[L[b],L[c]]*OneW[L[e]]*ups[][U[e]]*ups[][L[a],L[d]]-
    g[L[c],L[d]]*OneW[L[b]]*ups[][L[e]]*ups[][L[a],U[e]]+
    (-1+wabc)*OneW[L[a]][L[d]]*ups[][L[b],L[c]]+
    (1-wabc)*OneW[L[d]]*ups[][L[a]]*ups[][L[b],L[c]]+
    (-3+wabc)*(-1+wabc)*OneW[L[a]]*ups[][L[d]]*ups[][L[b],L[c]]+
    (-1+wabc)*g[L[a],L[d]]*OneW[L[e]]*ups[][U[e]]*ups[][L[b],L[c]]+
    (-2+wabc)*OneW[L[a]][L[c]]*ups[][L[b],L[d]]+
    (2-wabc)*OneW[L[c]]*ups[][L[a]]*ups[][L[b],L[d]]+
    (-4+wabc)*(-1+wabc)*OneW[L[a]]*ups[][L[c]]*ups[][L[b],L[d]]+
    (-1+wabc)*g[L[a],L[c]]*OneW[L[e]]*ups[][U[e]]*ups[][L[b],L[d]]+
    (-1+wabc)*g[L[c],L[d]]*OneW[L[a]]*ups[][L[e]]*ups[][L[b],U[e]]+
    (-2+wabc)*OneW[L[a]][L[b]]*ups[][L[c],L[d]]+
    (3-wabc)*OneW[L[b]]*ups[][L[a]]*ups[][L[c],L[d]]+
    (-3+wabc)*(-1+wabc)*OneW[L[a]]*ups[][L[b]]*ups[][L[c],L[d]]+
    (-2+wabc)*g[L[a],L[b]]*OneW[L[e]]*ups[][U[e]]*ups[][L[c],L[d]]+
    OneW[L[b]]*ups[][L[a]]*ups[][L[d],L[c]]+
    (1-wabc)*OneW[L[a]]*ups[][L[b]]*ups[][L[d],L[c]]+
    g[L[a],L[b]]*OneW[L[e]][L[d]]*ups[][U[e],L[c]]+
    (-3+wabc)*g[L[a],L[b]]*OneW[L[e]]*ups[][L[d]]*ups[][U[e],L[c]]+
    (-1+wabc)*g[L[b],L[d]]*OneW[L[a]]*ups[][L[e]]*ups[][U[e],L[c]]-
    g[L[a],L[d]]*OneW[L[b]]*ups[][L[e]]*ups[][U[e],L[c]]+
    g[L[b],L[c]]*OneW[L[a]][L[e]]*ups[][U[e],L[d]]+
    g[L[a],L[c]]*OneW[L[e]][L[b]]*ups[][U[e],L[d]]+
    g[L[a],L[b]]*OneW[L[e]][L[c]]*ups[][U[e],L[d]]-
    g[L[b],L[c]]*OneW[L[e]]*ups[][L[a]]*ups[][U[e],L[d]]+
    (-1+wabc)*g[L[a],L[c]]*OneW[L[e]]*ups[][L[b]]*ups[][U[e],L[d]]+
    (-3+wabc)*g[L[a],L[b]]*OneW[L[e]]*ups[][L[c]]*ups[][U[e],L[d]]+
    2*(-1+wabc)*g[L[b],L[c]]*OneW[L[a]]*ups[][L[e]]*ups[][U[e],L[d]]-
    2*g[L[a],L[c]]*OneW[L[b]]*ups[][L[e]]*ups[][U[e],L[d]]+
    g[L[a],L[b]]*g[L[c],L[d]]*OneW[L[e]]*ups[][L[i]]*ups[][U[e],U[i]]-
    OneW[L[b]]*ups[][L[a],L[c],L[d]]+
    (-1+wabc)*OneW[L[a]]*ups[][L[b],L[c],L[d]]+
    g[L[a],L[b]]*OneW[L[e]]*ups[][U[e],L[c],L[d]],
  NewRule->True];

DefineRule[ExpandNbHatTwoW,
                 NbHatTwoW[L[a],L[b],L[c]],
  TwoW[L[a],L[b]][L[c]]-TwoW[L[c],L[b]]*ups[L[a]]-
  TwoW[L[a],L[c]]*ups[L[b]]+
  (-2+wabc)*TwoW[L[a],L[b]]*ups[L[c]]+
  g[L[b],L[c]]*TwoW[L[a],L[i]]*ups[U[i]]+
  g[L[a],L[c]]*TwoW[L[i],L[b]]*ups[U[i]],
    NewRule->True];

DefineRule[ExpandNbHatThreeW,
                 NbHatThreeW[L[a],L[b],L[c],L[d]],
  ThreeW[L[a],L[b],L[c]][L[d]]-
  ThreeW[L[d],L[b],L[c]]*ups[L[a]]-
  ThreeW[L[a],L[d],L[c]]*ups[L[b]]-
  ThreeW[L[a],L[b],L[d]]*ups[L[c]]+
  (-3+wabc)*ThreeW[L[a],L[b],L[c]]*ups[L[d]]+
  g[L[c],L[d]]*ThreeW[L[a],L[b],L[i]]*ups[U[i]]+
  g[L[b],L[d]]*ThreeW[L[a],L[i],L[c]]*ups[U[i]]+
  g[L[a],L[d]]*ThreeW[L[i],L[b],L[c]]*ups[U[i]],
    NewRule->True];

DefineRule[ExpandNbHatFourW,
                 NbHatFourW[L[a],L[b],L[c],L[d],L[e]],
  FourW[L[a],L[b],L[c],L[d]][L[e]]-
  FourW[L[e],L[b],L[c],L[d]]*ups[L[a]]-
  FourW[L[a],L[e],L[c],L[d]]*ups[L[b]]-
  FourW[L[a],L[b],L[e],L[d]]*ups[L[c]]-
  FourW[L[a],L[b],L[c],L[e]]*ups[L[d]]+
  (-4+wabc)*FourW[L[a],L[b],L[c],L[d]]*ups[L[e]]+
  FourW[L[i],L[b],L[c],L[d]]*g[L[a],L[e]]*ups[U[i]]+
  FourW[L[a],L[i],L[c],L[d]]*g[L[b],L[e]]*ups[U[i]]+
  FourW[L[a],L[b],L[i],L[d]]*g[L[c],L[e]]*ups[U[i]]+
  FourW[L[a],L[b],L[c],L[i]]*g[L[d],L[e]]*ups[U[i]],
    NewRule->True];

(****************************************************************)

DefineRule[ExpandNbNbHatTwoW,
                 NbNbHatTwoW[L[a],L[b],L[c],L[d]],
TwoW[L[a],L[b]][L[c],L[d]]-
TwoW[L[c],L[b]][L[d]]*ups[][L[a]]-
TwoW[L[d],L[b]][L[c]]*ups[][L[a]]-
TwoW[L[a],L[c]][L[d]]*ups[][L[b]]-
TwoW[L[a],L[d]][L[c]]*ups[][L[b]]+
TwoW[L[c],L[d]]*ups[][L[a]]*ups[][L[b]]+
TwoW[L[d],L[c]]*ups[][L[a]]*ups[][L[b]]+
(-3+wabc)*TwoW[L[a],L[b]][L[d]]*ups[][L[c]]+
(3-wabc)*TwoW[L[d],L[b]]*ups[][L[a]]*ups[][L[c]]+
(3-wabc)*TwoW[L[a],L[d]]*ups[][L[b]]*ups[][L[c]]+
(-3+wabc)*TwoW[L[a],L[b]][L[c]]*ups[][L[d]]+
(4-wabc)*TwoW[L[c],L[b]]*ups[][L[a]]*ups[][L[d]]+
(4-wabc)*TwoW[L[a],L[c]]*ups[][L[b]]*ups[][L[d]]+
(-4+wabc)*(-2+wabc)*TwoW[L[a],L[b]]*ups[][L[c]]*ups[][L[d]]+
g[L[c],L[d]]*TwoW[L[a],L[b]][L[e]]*ups[][U[e]]+
g[L[b],L[d]]*TwoW[L[a],L[e]][L[c]]*ups[][U[e]]+
g[L[b],L[c]]*TwoW[L[a],L[e]][L[d]]*ups[][U[e]]+
g[L[a],L[d]]*TwoW[L[e],L[b]][L[c]]*ups[][U[e]]+
g[L[a],L[c]]*TwoW[L[e],L[b]][L[d]]*ups[][U[e]]-
g[L[b],L[d]]*TwoW[L[c],L[e]]*ups[][L[a]]*ups[][U[e]]-
g[L[b],L[c]]*TwoW[L[d],L[e]]*ups[][L[a]]*ups[][U[e]]-
g[L[c],L[d]]*TwoW[L[e],L[b]]*ups[][L[a]]*ups[][U[e]]-
g[L[c],L[d]]*TwoW[L[a],L[e]]*ups[][L[b]]*ups[][U[e]]-
g[L[a],L[d]]*TwoW[L[e],L[c]]*ups[][L[b]]*ups[][U[e]]-
g[L[a],L[c]]*TwoW[L[e],L[d]]*ups[][L[b]]*ups[][U[e]]+
(-2+wabc)*g[L[b],L[d]]*TwoW[L[a],L[e]]*ups[][L[c]]*ups[][U[e]]+
(-2+wabc)*g[L[a],L[d]]*TwoW[L[e],L[b]]*ups[][L[c]]*ups[][U[e]]+
(-3+wabc)*g[L[b],L[c]]*TwoW[L[a],L[e]]*ups[][L[d]]*ups[][U[e]]+
(-3+wabc)*g[L[a],L[c]]*TwoW[L[e],L[b]]*ups[][L[d]]*ups[][U[e]]+
(-2+wabc)*g[L[c],L[d]]*TwoW[L[a],L[b]]*ups[][L[e]]*ups[][U[e]]-
g[L[b],L[d]]*TwoW[L[a],L[c]]*ups[][L[e]]*ups[][U[e]]-
g[L[a],L[d]]*TwoW[L[c],L[b]]*ups[][L[e]]*ups[][U[e]]+
g[L[a],L[d]]*g[L[b],L[c]]*TwoW[L[e],L[i]]*ups[][U[e]]*ups[][U[i]]+
g[L[a],L[c]]*g[L[b],L[d]]*TwoW[L[e],L[i]]*ups[][U[e]]*ups[][U[i]]-
TwoW[L[c],L[b]]*ups[][L[a],L[d]]-
TwoW[L[a],L[c]]*ups[][L[b],L[d]]+
(-2+wabc)*TwoW[L[a],L[b]]*ups[][L[c],L[d]]+
g[L[b],L[c]]*TwoW[L[a],L[e]]*ups[][U[e],L[d]]+
g[L[a],L[c]]*TwoW[L[e],L[b]]*ups[][U[e],L[d]],
     NewRule->True];

(**********************************************************)

DefineRule[ExpandNbNbNbHatTwoW,
                 NbNbNbHatTwoW[L[a],L[b],L[c],L[d],L[e]],
TwoW[L[a],L[b]][L[c],L[d],L[e]]-
TwoW[L[c],L[b]][L[d],L[e]]*ups[][L[a]]-
TwoW[L[d],L[b]][L[c],L[e]]*ups[][L[a]]-
TwoW[L[e],L[b]][L[c],L[d]]*ups[][L[a]]-
TwoW[L[a],L[c]][L[d],L[e]]*ups[][L[b]]-
TwoW[L[a],L[d]][L[c],L[e]]*ups[][L[b]]-
TwoW[L[a],L[e]][L[c],L[d]]*ups[][L[b]]+
TwoW[L[c],L[d]][L[e]]*ups[][L[a]]*ups[][L[b]]+
TwoW[L[c],L[e]][L[d]]*ups[][L[a]]*ups[][L[b]]+
TwoW[L[d],L[c]][L[e]]*ups[][L[a]]*ups[][L[b]]+
TwoW[L[d],L[e]][L[c]]*ups[][L[a]]*ups[][L[b]]+
TwoW[L[e],L[c]][L[d]]*ups[][L[a]]*ups[][L[b]]+
TwoW[L[e],L[d]][L[c]]*ups[][L[a]]*ups[][L[b]]+
(-3+wabc)*TwoW[L[a],L[b]][L[d],L[e]]*ups[][L[c]]-
TwoW[L[a],L[b]][L[e],L[d]]*ups[][L[c]]+
(4-wabc)*TwoW[L[d],L[b]][L[e]]*ups[][L[a]]*ups[][L[c]]+
(4-wabc)*TwoW[L[e],L[b]][L[d]]*ups[][L[a]]*ups[][L[c]]+
(4-wabc)*TwoW[L[a],L[d]][L[e]]*ups[][L[b]]*ups[][L[c]]+
(4-wabc)*TwoW[L[a],L[e]][L[d]]*ups[][L[b]]*ups[][L[c]]+
(-4+wabc)*TwoW[L[d],L[e]]*ups[][L[a]]*ups[][L[b]]*ups[][L[c]]+
(-4+wabc)*TwoW[L[e],L[d]]*ups[][L[a]]*ups[][L[b]]*ups[][L[c]]+
(-4+wabc)*TwoW[L[a],L[b]][L[c],L[e]]*ups[][L[d]]+
(5-wabc)*TwoW[L[c],L[b]][L[e]]*ups[][L[a]]*ups[][L[d]]+
(4-wabc)*TwoW[L[e],L[b]][L[c]]*ups[][L[a]]*ups[][L[d]]+
(5-wabc)*TwoW[L[a],L[c]][L[e]]*ups[][L[b]]*ups[][L[d]]+
(4-wabc)*TwoW[L[a],L[e]][L[c]]*ups[][L[b]]*ups[][L[d]]+
(-5+wabc)*TwoW[L[c],L[e]]*ups[][L[a]]*ups[][L[b]]*ups[][L[d]]+
(-5+wabc)*TwoW[L[e],L[c]]*ups[][L[a]]*ups[][L[b]]*ups[][L[d]]+
(14-8*wabc+wabc^2)*TwoW[L[a],L[b]][L[e]]*ups[][L[c]]*ups[][L[d]]-
(-5+wabc)*(-3+wabc)*TwoW[L[e],L[b]]*ups[][L[a]]*ups[][L[c]]*
ups[][L[d]]-(-5+wabc)*(-3+wabc)*TwoW[L[a],L[e]]*ups[][L[b]]*
ups[][L[c]]*ups[][L[d]]+
(-4+wabc)*TwoW[L[a],L[b]][L[c],L[d]]*ups[][L[e]]+
(5-wabc)*TwoW[L[c],L[b]][L[d]]*ups[][L[a]]*ups[][L[e]]+
(5-wabc)*TwoW[L[d],L[b]][L[c]]*ups[][L[a]]*ups[][L[e]]+
(5-wabc)*TwoW[L[a],L[c]][L[d]]*ups[][L[b]]*ups[][L[e]]+
(5-wabc)*TwoW[L[a],L[d]][L[c]]*ups[][L[b]]*ups[][L[e]]+
(-6+wabc)*TwoW[L[c],L[d]]*ups[][L[a]]*ups[][L[b]]*ups[][L[e]]+
(-6+wabc)*TwoW[L[d],L[c]]*ups[][L[a]]*ups[][L[b]]*ups[][L[e]]+
(-5+wabc)*(-3+wabc)*TwoW[L[a],L[b]][L[d]]*ups[][L[c]]*
ups[][L[e]]-(-6+wabc)*(-3+wabc)*TwoW[L[d],L[b]]*ups[][L[a]]*
ups[][L[c]]*ups[][L[e]]-
(-6+wabc)*(-3+wabc)*TwoW[L[a],L[d]]*ups[][L[b]]*ups[][L[c]]*
ups[][L[e]]+(-5+wabc)*(-3+wabc)*TwoW[L[a],L[b]][L[c]]*
ups[][L[d]]*ups[][L[e]]-
(-6+wabc)*(-4+wabc)*TwoW[L[c],L[b]]*ups[][L[a]]*ups[][L[d]]*
ups[][L[e]]-(-6+wabc)*(-4+wabc)*TwoW[L[a],L[c]]*ups[][L[b]]*
ups[][L[d]]*ups[][L[e]]+
(-6+wabc)*(-4+wabc)*(-2+wabc)*TwoW[L[a],L[b]]*ups[][L[c]]*
ups[][L[d]]*ups[][L[e]]+
g[L[d],L[e]]*TwoW[L[a],L[b]][L[c],L[i]]*ups[][U[i]]+
g[L[c],L[e]]*TwoW[L[a],L[b]][L[i],L[d]]*ups[][U[i]]+
g[L[c],L[d]]*TwoW[L[a],L[b]][L[i],L[e]]*ups[][U[i]]+
g[L[b],L[e]]*TwoW[L[a],L[i]][L[c],L[d]]*ups[][U[i]]+
g[L[b],L[d]]*TwoW[L[a],L[i]][L[c],L[e]]*ups[][U[i]]+
g[L[b],L[c]]*TwoW[L[a],L[i]][L[d],L[e]]*ups[][U[i]]+
g[L[a],L[e]]*TwoW[L[i],L[b]][L[c],L[d]]*ups[][U[i]]+
g[L[a],L[d]]*TwoW[L[i],L[b]][L[c],L[e]]*ups[][U[i]]+
g[L[a],L[c]]*TwoW[L[i],L[b]][L[d],L[e]]*ups[][U[i]]-
g[L[d],L[e]]*TwoW[L[c],L[b]][L[i]]*ups[][L[a]]*ups[][U[i]]-
g[L[b],L[e]]*TwoW[L[c],L[i]][L[d]]*ups[][L[a]]*ups[][U[i]]-
g[L[b],L[d]]*TwoW[L[c],L[i]][L[e]]*ups[][L[a]]*ups[][U[i]]-
g[L[c],L[e]]*TwoW[L[d],L[b]][L[i]]*ups[][L[a]]*ups[][U[i]]-
g[L[b],L[e]]*TwoW[L[d],L[i]][L[c]]*ups[][L[a]]*ups[][U[i]]-
g[L[b],L[c]]*TwoW[L[d],L[i]][L[e]]*ups[][L[a]]*ups[][U[i]]-
g[L[c],L[d]]*TwoW[L[e],L[b]][L[i]]*ups[][L[a]]*ups[][U[i]]-
g[L[b],L[d]]*TwoW[L[e],L[i]][L[c]]*ups[][L[a]]*ups[][U[i]]-
g[L[b],L[c]]*TwoW[L[e],L[i]][L[d]]*ups[][L[a]]*ups[][U[i]]-
g[L[d],L[e]]*TwoW[L[i],L[b]][L[c]]*ups[][L[a]]*ups[][U[i]]-
g[L[c],L[e]]*TwoW[L[i],L[b]][L[d]]*ups[][L[a]]*ups[][U[i]]-
g[L[c],L[d]]*TwoW[L[i],L[b]][L[e]]*ups[][L[a]]*ups[][U[i]]-
g[L[d],L[e]]*TwoW[L[a],L[c]][L[i]]*ups[][L[b]]*ups[][U[i]]-
g[L[c],L[e]]*TwoW[L[a],L[d]][L[i]]*ups[][L[b]]*ups[][U[i]]-
g[L[c],L[d]]*TwoW[L[a],L[e]][L[i]]*ups[][L[b]]*ups[][U[i]]-
g[L[d],L[e]]*TwoW[L[a],L[i]][L[c]]*ups[][L[b]]*ups[][U[i]]-
g[L[c],L[e]]*TwoW[L[a],L[i]][L[d]]*ups[][L[b]]*ups[][U[i]]-
g[L[c],L[d]]*TwoW[L[a],L[i]][L[e]]*ups[][L[b]]*ups[][U[i]]-
g[L[a],L[e]]*TwoW[L[i],L[c]][L[d]]*ups[][L[b]]*ups[][U[i]]-
g[L[a],L[d]]*TwoW[L[i],L[c]][L[e]]*ups[][L[b]]*ups[][U[i]]-
g[L[a],L[e]]*TwoW[L[i],L[d]][L[c]]*ups[][L[b]]*ups[][U[i]]-
g[L[a],L[c]]*TwoW[L[i],L[d]][L[e]]*ups[][L[b]]*ups[][U[i]]-
g[L[a],L[d]]*TwoW[L[i],L[e]][L[c]]*ups[][L[b]]*ups[][U[i]]-
g[L[a],L[c]]*TwoW[L[i],L[e]][L[d]]*ups[][L[b]]*ups[][U[i]]+
g[L[d],L[e]]*TwoW[L[c],L[i]]*ups[][L[a]]*ups[][L[b]]*ups[][U[i]]+
g[L[c],L[e]]*TwoW[L[d],L[i]]*ups[][L[a]]*ups[][L[b]]*ups[][U[i]]+
g[L[c],L[d]]*TwoW[L[e],L[i]]*ups[][L[a]]*ups[][L[b]]*ups[][U[i]]+
g[L[d],L[e]]*TwoW[L[i],L[c]]*ups[][L[a]]*ups[][L[b]]*ups[][U[i]]+
g[L[c],L[e]]*TwoW[L[i],L[d]]*ups[][L[a]]*ups[][L[b]]*ups[][U[i]]+
g[L[c],L[d]]*TwoW[L[i],L[e]]*ups[][L[a]]*ups[][L[b]]*ups[][U[i]]+
(-3+wabc)*g[L[d],L[e]]*TwoW[L[a],L[b]][L[i]]*ups[][L[c]]*
ups[][U[i]]+(-3+wabc)*g[L[b],L[e]]*TwoW[L[a],L[i]][L[d]]*
ups[][L[c]]*ups[][U[i]]+
(-3+wabc)*g[L[b],L[d]]*TwoW[L[a],L[i]][L[e]]*ups[][L[c]]*
ups[][U[i]]+(-3+wabc)*g[L[a],L[e]]*TwoW[L[i],L[b]][L[d]]*
ups[][L[c]]*ups[][U[i]]+
(-3+wabc)*g[L[a],L[d]]*TwoW[L[i],L[b]][L[e]]*ups[][L[c]]*
ups[][U[i]]+(3-wabc)*g[L[b],L[e]]*TwoW[L[d],L[i]]*ups[][L[a]]*
ups[][L[c]]*ups[][U[i]]+
(3-wabc)*g[L[b],L[d]]*TwoW[L[e],L[i]]*ups[][L[a]]*ups[][L[c]]*
ups[][U[i]]+(3-wabc)*g[L[d],L[e]]*TwoW[L[i],L[b]]*ups[][L[a]]*
ups[][L[c]]*ups[][U[i]]+
(3-wabc)*g[L[d],L[e]]*TwoW[L[a],L[i]]*ups[][L[b]]*ups[][L[c]]*
ups[][U[i]]+(3-wabc)*g[L[a],L[e]]*TwoW[L[i],L[d]]*ups[][L[b]]*
ups[][L[c]]*ups[][U[i]]+
(3-wabc)*g[L[a],L[d]]*TwoW[L[i],L[e]]*ups[][L[b]]*ups[][L[c]]*
ups[][U[i]]+(-3+wabc)*g[L[c],L[e]]*TwoW[L[a],L[b]][L[i]]*
ups[][L[d]]*ups[][U[i]]+
(-3+wabc)*g[L[b],L[e]]*TwoW[L[a],L[i]][L[c]]*ups[][L[d]]*
ups[][U[i]]+(-4+wabc)*g[L[b],L[c]]*TwoW[L[a],L[i]][L[e]]*
ups[][L[d]]*ups[][U[i]]+
(-3+wabc)*g[L[a],L[e]]*TwoW[L[i],L[b]][L[c]]*ups[][L[d]]*
ups[][U[i]]+(-4+wabc)*g[L[a],L[c]]*TwoW[L[i],L[b]][L[e]]*
ups[][L[d]]*ups[][U[i]]+
(4-wabc)*g[L[b],L[e]]*TwoW[L[c],L[i]]*ups[][L[a]]*ups[][L[d]]*
ups[][U[i]]+(4-wabc)*g[L[b],L[c]]*TwoW[L[e],L[i]]*ups[][L[a]]*
ups[][L[d]]*ups[][U[i]]+
(4-wabc)*g[L[c],L[e]]*TwoW[L[i],L[b]]*ups[][L[a]]*ups[][L[d]]*
ups[][U[i]]+(4-wabc)*g[L[c],L[e]]*TwoW[L[a],L[i]]*ups[][L[b]]*
ups[][L[d]]*ups[][U[i]]+
(4-wabc)*g[L[a],L[e]]*TwoW[L[i],L[c]]*ups[][L[b]]*ups[][L[d]]*
ups[][U[i]]+(4-wabc)*g[L[a],L[c]]*TwoW[L[i],L[e]]*ups[][L[b]]*
ups[][L[d]]*ups[][U[i]]+
(-4+wabc)*(-2+wabc)*g[L[b],L[e]]*TwoW[L[a],L[i]]*ups[][L[c]]*
ups[][L[d]]*ups[][U[i]]+
(-4+wabc)*(-2+wabc)*g[L[a],L[e]]*TwoW[L[i],L[b]]*ups[][L[c]]*
ups[][L[d]]*ups[][U[i]]+
(-4+wabc)*g[L[c],L[d]]*TwoW[L[a],L[b]][L[i]]*ups[][L[e]]*
ups[][U[i]]+(-4+wabc)*g[L[b],L[d]]*TwoW[L[a],L[i]][L[c]]*
ups[][L[e]]*ups[][U[i]]+
(-4+wabc)*g[L[b],L[c]]*TwoW[L[a],L[i]][L[d]]*ups[][L[e]]*
ups[][U[i]]+(-4+wabc)*g[L[a],L[d]]*TwoW[L[i],L[b]][L[c]]*
ups[][L[e]]*ups[][U[i]]+
(-4+wabc)*g[L[a],L[c]]*TwoW[L[i],L[b]][L[d]]*ups[][L[e]]*
ups[][U[i]]+(5-wabc)*g[L[b],L[d]]*TwoW[L[c],L[i]]*ups[][L[a]]*
ups[][L[e]]*ups[][U[i]]+
(5-wabc)*g[L[b],L[c]]*TwoW[L[d],L[i]]*ups[][L[a]]*ups[][L[e]]*
ups[][U[i]]+(5-wabc)*g[L[c],L[d]]*TwoW[L[i],L[b]]*ups[][L[a]]*
ups[][L[e]]*ups[][U[i]]+
(5-wabc)*g[L[c],L[d]]*TwoW[L[a],L[i]]*ups[][L[b]]*ups[][L[e]]*
ups[][U[i]]+(5-wabc)*g[L[a],L[d]]*TwoW[L[i],L[c]]*ups[][L[b]]*
ups[][L[e]]*ups[][U[i]]+
(5-wabc)*g[L[a],L[c]]*TwoW[L[i],L[d]]*ups[][L[b]]*ups[][L[e]]*
ups[][U[i]]+(-5+wabc)*(-2+wabc)*g[L[b],L[d]]*TwoW[L[a],L[i]]*
ups[][L[c]]*ups[][L[e]]*ups[][U[i]]+
(-5+wabc)*(-2+wabc)*g[L[a],L[d]]*TwoW[L[i],L[b]]*ups[][L[c]]*
ups[][L[e]]*ups[][U[i]]+
(-5+wabc)*(-3+wabc)*g[L[b],L[c]]*TwoW[L[a],L[i]]*ups[][L[d]]*
ups[][L[e]]*ups[][U[i]]+
(-5+wabc)*(-3+wabc)*g[L[a],L[c]]*TwoW[L[i],L[b]]*ups[][L[d]]*
ups[][L[e]]*ups[][U[i]]+
(-3+wabc)*g[L[d],L[e]]*TwoW[L[a],L[b]][L[c]]*ups[][L[i]]*
ups[][U[i]]+(-3+wabc)*g[L[c],L[e]]*TwoW[L[a],L[b]][L[d]]*
ups[][L[i]]*ups[][U[i]]+
(-2+wabc)*g[L[c],L[d]]*TwoW[L[a],L[b]][L[e]]*ups[][L[i]]*
ups[][U[i]]-g[L[b],L[e]]*TwoW[L[a],L[c]][L[d]]*ups[][L[i]]*
ups[][U[i]]-g[L[b],L[d]]*TwoW[L[a],L[c]][L[e]]*ups[][L[i]]*
ups[][U[i]]-g[L[b],L[e]]*TwoW[L[a],L[d]][L[c]]*ups[][L[i]]*
ups[][U[i]]-g[L[a],L[e]]*TwoW[L[c],L[b]][L[d]]*ups[][L[i]]*
ups[][U[i]]-g[L[a],L[d]]*TwoW[L[c],L[b]][L[e]]*ups[][L[i]]*
ups[][U[i]]-g[L[a],L[e]]*TwoW[L[d],L[b]][L[c]]*ups[][L[i]]*
ups[][U[i]]+(4-wabc)*g[L[d],L[e]]*TwoW[L[c],L[b]]*ups[][L[a]]*
ups[][L[i]]*ups[][U[i]]+
g[L[b],L[e]]*TwoW[L[c],L[d]]*ups[][L[a]]*ups[][L[i]]*ups[][U[i]]+
(3-wabc)*g[L[c],L[e]]*TwoW[L[d],L[b]]*ups[][L[a]]*ups[][L[i]]*
ups[][U[i]]+g[L[b],L[e]]*TwoW[L[d],L[c]]*ups[][L[a]]*ups[][L[i]]*
ups[][U[i]]+(2-wabc)*g[L[c],L[d]]*TwoW[L[e],L[b]]*ups[][L[a]]*
ups[][L[i]]*ups[][U[i]]+
g[L[b],L[d]]*TwoW[L[e],L[c]]*ups[][L[a]]*ups[][L[i]]*ups[][U[i]]+
(4-wabc)*g[L[d],L[e]]*TwoW[L[a],L[c]]*ups[][L[b]]*ups[][L[i]]*
ups[][U[i]]+(3-wabc)*g[L[c],L[e]]*TwoW[L[a],L[d]]*ups[][L[b]]*
ups[][L[i]]*ups[][U[i]]+
(2-wabc)*g[L[c],L[d]]*TwoW[L[a],L[e]]*ups[][L[b]]*ups[][L[i]]*
ups[][U[i]]+g[L[a],L[e]]*TwoW[L[c],L[d]]*ups[][L[b]]*ups[][L[i]]*
ups[][U[i]]+g[L[a],L[d]]*TwoW[L[c],L[e]]*ups[][L[b]]*ups[][L[i]]*
ups[][U[i]]+g[L[a],L[e]]*TwoW[L[d],L[c]]*ups[][L[b]]*ups[][L[i]]*
ups[][U[i]]+(-4+wabc)*(-2+wabc)*g[L[d],L[e]]*TwoW[L[a],L[b]]*
ups[][L[c]]*ups[][L[i]]*ups[][U[i]]+
(3-wabc)*g[L[b],L[e]]*TwoW[L[a],L[d]]*ups[][L[c]]*ups[][L[i]]*
ups[][U[i]]+g[L[b],L[d]]*TwoW[L[a],L[e]]*ups[][L[c]]*ups[][L[i]]*
ups[][U[i]]+(3-wabc)*g[L[a],L[e]]*TwoW[L[d],L[b]]*ups[][L[c]]*
ups[][L[i]]*ups[][U[i]]+
g[L[a],L[d]]*TwoW[L[e],L[b]]*ups[][L[c]]*ups[][L[i]]*ups[][U[i]]+
(-4+wabc)*(-2+wabc)*g[L[c],L[e]]*TwoW[L[a],L[b]]*ups[][L[d]]*
ups[][L[i]]*ups[][U[i]]+
(4-wabc)*g[L[b],L[e]]*TwoW[L[a],L[c]]*ups[][L[d]]*ups[][L[i]]*
ups[][U[i]]+(4-wabc)*g[L[a],L[e]]*TwoW[L[c],L[b]]*ups[][L[d]]*
ups[][L[i]]*ups[][U[i]]+
(-4+wabc)*(-2+wabc)*g[L[c],L[d]]*TwoW[L[a],L[b]]*ups[][L[e]]*
ups[][L[i]]*ups[][U[i]]+
(4-wabc)*g[L[b],L[d]]*TwoW[L[a],L[c]]*ups[][L[e]]*ups[][L[i]]*
ups[][U[i]]+(4-wabc)*g[L[a],L[d]]*TwoW[L[c],L[b]]*ups[][L[e]]*
ups[][L[i]]*ups[][U[i]]+
g[L[b],L[e]]*g[L[c],L[d]]*TwoW[L[a],L[i]][L[j]]*ups[][U[i]]*
ups[][U[j]]+g[L[b],L[d]]*g[L[c],L[e]]*TwoW[L[a],L[i]][L[j]]*
ups[][U[i]]*ups[][U[j]]+
g[L[b],L[c]]*g[L[d],L[e]]*TwoW[L[a],L[i]][L[j]]*ups[][U[i]]*
ups[][U[j]]+g[L[a],L[e]]*g[L[c],L[d]]*TwoW[L[i],L[b]][L[j]]*
ups[][U[i]]*ups[][U[j]]+
g[L[a],L[d]]*g[L[c],L[e]]*TwoW[L[i],L[b]][L[j]]*ups[][U[i]]*
ups[][U[j]]+g[L[a],L[c]]*g[L[d],L[e]]*TwoW[L[i],L[b]][L[j]]*
ups[][U[i]]*ups[][U[j]]+
g[L[a],L[e]]*g[L[b],L[d]]*TwoW[L[i],L[j]][L[c]]*ups[][U[i]]*
ups[][U[j]]+g[L[a],L[d]]*g[L[b],L[e]]*TwoW[L[i],L[j]][L[c]]*
ups[][U[i]]*ups[][U[j]]+
g[L[a],L[e]]*g[L[b],L[c]]*TwoW[L[i],L[j]][L[d]]*ups[][U[i]]*
ups[][U[j]]+g[L[a],L[c]]*g[L[b],L[e]]*TwoW[L[i],L[j]][L[d]]*
ups[][U[i]]*ups[][U[j]]+
g[L[a],L[d]]*g[L[b],L[c]]*TwoW[L[i],L[j]][L[e]]*ups[][U[i]]*
ups[][U[j]]+g[L[a],L[c]]*g[L[b],L[d]]*TwoW[L[i],L[j]][L[e]]*
ups[][U[i]]*ups[][U[j]]-
g[L[b],L[e]]*g[L[c],L[d]]*TwoW[L[i],L[j]]*ups[][L[a]]*ups[][U[i]]*
ups[][U[j]]-g[L[b],L[d]]*g[L[c],L[e]]*TwoW[L[i],L[j]]*ups[][L[a]]*
ups[][U[i]]*ups[][U[j]]-
g[L[b],L[c]]*g[L[d],L[e]]*TwoW[L[i],L[j]]*ups[][L[a]]*ups[][U[i]]*
ups[][U[j]]-g[L[a],L[e]]*g[L[c],L[d]]*TwoW[L[i],L[j]]*ups[][L[b]]*
ups[][U[i]]*ups[][U[j]]-
g[L[a],L[d]]*g[L[c],L[e]]*TwoW[L[i],L[j]]*ups[][L[b]]*ups[][U[i]]*
ups[][U[j]]-g[L[a],L[c]]*g[L[d],L[e]]*TwoW[L[i],L[j]]*ups[][L[b]]*
ups[][U[i]]*ups[][U[j]]+
(-2+wabc)*g[L[a],L[e]]*g[L[b],L[d]]*TwoW[L[i],L[j]]*ups[][L[c]]*
ups[][U[i]]*ups[][U[j]]+
(-2+wabc)*g[L[a],L[d]]*g[L[b],L[e]]*TwoW[L[i],L[j]]*ups[][L[c]]*
ups[][U[i]]*ups[][U[j]]+
(-3+wabc)*g[L[a],L[e]]*g[L[b],L[c]]*TwoW[L[i],L[j]]*ups[][L[d]]*
ups[][U[i]]*ups[][U[j]]+
(-3+wabc)*g[L[a],L[c]]*g[L[b],L[e]]*TwoW[L[i],L[j]]*ups[][L[d]]*
ups[][U[i]]*ups[][U[j]]+
(-4+wabc)*g[L[a],L[d]]*g[L[b],L[c]]*TwoW[L[i],L[j]]*ups[][L[e]]*
ups[][U[i]]*ups[][U[j]]+
(-4+wabc)*g[L[a],L[c]]*g[L[b],L[d]]*TwoW[L[i],L[j]]*ups[][L[e]]*
ups[][U[i]]*ups[][U[j]]+
(-3+wabc)*g[L[b],L[e]]*g[L[c],L[d]]*TwoW[L[a],L[i]]*ups[][L[j]]*
ups[][U[i]]*ups[][U[j]]+
(-3+wabc)*g[L[b],L[d]]*g[L[c],L[e]]*TwoW[L[a],L[i]]*ups[][L[j]]*
ups[][U[i]]*ups[][U[j]]+
(-3+wabc)*g[L[b],L[c]]*g[L[d],L[e]]*TwoW[L[a],L[i]]*ups[][L[j]]*
ups[][U[i]]*ups[][U[j]]-
g[L[a],L[e]]*g[L[b],L[d]]*TwoW[L[c],L[i]]*ups[][L[j]]*ups[][U[i]]*
ups[][U[j]]-g[L[a],L[d]]*g[L[b],L[e]]*TwoW[L[c],L[i]]*ups[][L[j]]*
ups[][U[i]]*ups[][U[j]]-
g[L[a],L[e]]*g[L[b],L[c]]*TwoW[L[d],L[i]]*ups[][L[j]]*ups[][U[i]]*
ups[][U[j]]+(-3+wabc)*g[L[a],L[e]]*g[L[c],L[d]]*TwoW[L[i],L[b]]*
ups[][L[j]]*ups[][U[i]]*ups[][U[j]]+
(-3+wabc)*g[L[a],L[d]]*g[L[c],L[e]]*TwoW[L[i],L[b]]*ups[][L[j]]*
ups[][U[i]]*ups[][U[j]]+
(-3+wabc)*g[L[a],L[c]]*g[L[d],L[e]]*TwoW[L[i],L[b]]*ups[][L[j]]*
ups[][U[i]]*ups[][U[j]]-
g[L[a],L[e]]*g[L[b],L[d]]*TwoW[L[i],L[c]]*ups[][L[j]]*ups[][U[i]]*
ups[][U[j]]-g[L[a],L[d]]*g[L[b],L[e]]*TwoW[L[i],L[c]]*ups[][L[j]]*
ups[][U[i]]*ups[][U[j]]-
g[L[a],L[c]]*g[L[b],L[e]]*TwoW[L[i],L[d]]*ups[][L[j]]*ups[][U[i]]*
ups[][U[j]]-TwoW[L[c],L[b]][L[e]]*ups[][L[a],L[d]]+
TwoW[L[c],L[e]]*ups[][L[b]]*ups[][L[a],L[d]]+
TwoW[L[e],L[b]]*ups[][L[c]]*ups[][L[a],L[d]]+
(4-wabc)*TwoW[L[c],L[b]]*ups[][L[e]]*ups[][L[a],L[d]]-
g[L[b],L[e]]*TwoW[L[c],L[i]]*ups[][U[i]]*ups[][L[a],L[d]]-
g[L[c],L[e]]*TwoW[L[i],L[b]]*ups[][U[i]]*ups[][L[a],L[d]]-
TwoW[L[c],L[b]][L[d]]*ups[][L[a],L[e]]-
TwoW[L[d],L[b]][L[c]]*ups[][L[a],L[e]]+
TwoW[L[c],L[d]]*ups[][L[b]]*ups[][L[a],L[e]]+
TwoW[L[d],L[c]]*ups[][L[b]]*ups[][L[a],L[e]]+
(3-wabc)*TwoW[L[d],L[b]]*ups[][L[c]]*ups[][L[a],L[e]]+
(5-wabc)*TwoW[L[c],L[b]]*ups[][L[d]]*ups[][L[a],L[e]]-
g[L[b],L[d]]*TwoW[L[c],L[i]]*ups[][U[i]]*ups[][L[a],L[e]]-
g[L[b],L[c]]*TwoW[L[d],L[i]]*ups[][U[i]]*ups[][L[a],L[e]]-
g[L[c],L[d]]*TwoW[L[i],L[b]]*ups[][U[i]]*ups[][L[a],L[e]]-
g[L[d],L[e]]*TwoW[L[c],L[b]]*ups[][L[i]]*ups[][L[a],U[i]]-
TwoW[L[a],L[c]][L[e]]*ups[][L[b],L[d]]+
TwoW[L[e],L[c]]*ups[][L[a]]*ups[][L[b],L[d]]+
TwoW[L[a],L[e]]*ups[][L[c]]*ups[][L[b],L[d]]+
(4-wabc)*TwoW[L[a],L[c]]*ups[][L[e]]*ups[][L[b],L[d]]-
g[L[c],L[e]]*TwoW[L[a],L[i]]*ups[][U[i]]*ups[][L[b],L[d]]-
g[L[a],L[e]]*TwoW[L[i],L[c]]*ups[][U[i]]*ups[][L[b],L[d]]-
TwoW[L[a],L[c]][L[d]]*ups[][L[b],L[e]]-
TwoW[L[a],L[d]][L[c]]*ups[][L[b],L[e]]+
TwoW[L[c],L[d]]*ups[][L[a]]*ups[][L[b],L[e]]+
TwoW[L[d],L[c]]*ups[][L[a]]*ups[][L[b],L[e]]+
(3-wabc)*TwoW[L[a],L[d]]*ups[][L[c]]*ups[][L[b],L[e]]+
(5-wabc)*TwoW[L[a],L[c]]*ups[][L[d]]*ups[][L[b],L[e]]-
g[L[c],L[d]]*TwoW[L[a],L[i]]*ups[][U[i]]*ups[][L[b],L[e]]-
g[L[a],L[d]]*TwoW[L[i],L[c]]*ups[][U[i]]*ups[][L[b],L[e]]-
g[L[a],L[c]]*TwoW[L[i],L[d]]*ups[][U[i]]*ups[][L[b],L[e]]-
g[L[d],L[e]]*TwoW[L[a],L[c]]*ups[][L[i]]*ups[][L[b],U[i]]+
(-2+wabc)*TwoW[L[a],L[b]][L[e]]*ups[][L[c],L[d]]+
(2-wabc)*TwoW[L[e],L[b]]*ups[][L[a]]*ups[][L[c],L[d]]+
(2-wabc)*TwoW[L[a],L[e]]*ups[][L[b]]*ups[][L[c],L[d]]+
(-4+wabc)*(-2+wabc)*TwoW[L[a],L[b]]*ups[][L[e]]*ups[][L[c],L[d]]+
(-2+wabc)*g[L[b],L[e]]*TwoW[L[a],L[i]]*ups[][U[i]]*
ups[][L[c],L[d]]+(-2+wabc)*g[L[a],L[e]]*TwoW[L[i],L[b]]*
ups[][U[i]]*ups[][L[c],L[d]]+
(-3+wabc)*TwoW[L[a],L[b]][L[d]]*ups[][L[c],L[e]]+
(3-wabc)*TwoW[L[d],L[b]]*ups[][L[a]]*ups[][L[c],L[e]]+
(3-wabc)*TwoW[L[a],L[d]]*ups[][L[b]]*ups[][L[c],L[e]]+
(-5+wabc)*(-2+wabc)*TwoW[L[a],L[b]]*ups[][L[d]]*ups[][L[c],L[e]]+
(-2+wabc)*g[L[b],L[d]]*TwoW[L[a],L[i]]*ups[][U[i]]*
ups[][L[c],L[e]]+(-2+wabc)*g[L[a],L[d]]*TwoW[L[i],L[b]]*
ups[][U[i]]*ups[][L[c],L[e]]+
(-2+wabc)*g[L[d],L[e]]*TwoW[L[a],L[b]]*ups[][L[i]]*
ups[][L[c],U[i]]+(-3+wabc)*TwoW[L[a],L[b]][L[c]]*
ups[][L[d],L[e]]+(4-wabc)*TwoW[L[c],L[b]]*ups[][L[a]]*
ups[][L[d],L[e]]+(4-wabc)*TwoW[L[a],L[c]]*ups[][L[b]]*
ups[][L[d],L[e]]+(-4+wabc)*(-2+wabc)*TwoW[L[a],L[b]]*
ups[][L[c]]*ups[][L[d],L[e]]+
(-3+wabc)*g[L[b],L[c]]*TwoW[L[a],L[i]]*ups[][U[i]]*
ups[][L[d],L[e]]+(-3+wabc)*g[L[a],L[c]]*TwoW[L[i],L[b]]*
ups[][U[i]]*ups[][L[d],L[e]]+
TwoW[L[c],L[b]]*ups[][L[a]]*ups[][L[e],L[d]]+
TwoW[L[a],L[c]]*ups[][L[b]]*ups[][L[e],L[d]]+
(2-wabc)*TwoW[L[a],L[b]]*ups[][L[c]]*ups[][L[e],L[d]]+
g[L[b],L[c]]*TwoW[L[a],L[i]][L[e]]*ups[][U[i],L[d]]+
g[L[a],L[c]]*TwoW[L[i],L[b]][L[e]]*ups[][U[i],L[d]]-
g[L[b],L[c]]*TwoW[L[e],L[i]]*ups[][L[a]]*ups[][U[i],L[d]]-
g[L[a],L[c]]*TwoW[L[i],L[e]]*ups[][L[b]]*ups[][U[i],L[d]]+
(-4+wabc)*g[L[b],L[c]]*TwoW[L[a],L[i]]*ups[][L[e]]*
ups[][U[i],L[d]]+(-4+wabc)*g[L[a],L[c]]*TwoW[L[i],L[b]]*
ups[][L[e]]*ups[][U[i],L[d]]+
(-2+wabc)*g[L[c],L[e]]*TwoW[L[a],L[b]]*ups[][L[i]]*
ups[][U[i],L[d]]-g[L[b],L[e]]*TwoW[L[a],L[c]]*ups[][L[i]]*
ups[][U[i],L[d]]-g[L[a],L[e]]*TwoW[L[c],L[b]]*ups[][L[i]]*
ups[][U[i],L[d]]+g[L[a],L[c]]*g[L[b],L[e]]*TwoW[L[i],L[j]]*
ups[][U[j]]*ups[][U[i],L[d]]+
g[L[c],L[d]]*TwoW[L[a],L[b]][L[i]]*ups[][U[i],L[e]]+
g[L[b],L[d]]*TwoW[L[a],L[i]][L[c]]*ups[][U[i],L[e]]+
g[L[b],L[c]]*TwoW[L[a],L[i]][L[d]]*ups[][U[i],L[e]]+
g[L[a],L[d]]*TwoW[L[i],L[b]][L[c]]*ups[][U[i],L[e]]+
g[L[a],L[c]]*TwoW[L[i],L[b]][L[d]]*ups[][U[i],L[e]]-
g[L[b],L[d]]*TwoW[L[c],L[i]]*ups[][L[a]]*ups[][U[i],L[e]]-
g[L[b],L[c]]*TwoW[L[d],L[i]]*ups[][L[a]]*ups[][U[i],L[e]]-
g[L[c],L[d]]*TwoW[L[i],L[b]]*ups[][L[a]]*ups[][U[i],L[e]]-
g[L[c],L[d]]*TwoW[L[a],L[i]]*ups[][L[b]]*ups[][U[i],L[e]]-
g[L[a],L[d]]*TwoW[L[i],L[c]]*ups[][L[b]]*ups[][U[i],L[e]]-
g[L[a],L[c]]*TwoW[L[i],L[d]]*ups[][L[b]]*ups[][U[i],L[e]]+
(-2+wabc)*g[L[b],L[d]]*TwoW[L[a],L[i]]*ups[][L[c]]*
ups[][U[i],L[e]]+(-2+wabc)*g[L[a],L[d]]*TwoW[L[i],L[b]]*
ups[][L[c]]*ups[][U[i],L[e]]+
(-4+wabc)*g[L[b],L[c]]*TwoW[L[a],L[i]]*ups[][L[d]]*
ups[][U[i],L[e]]+(-4+wabc)*g[L[a],L[c]]*TwoW[L[i],L[b]]*
ups[][L[d]]*ups[][U[i],L[e]]+
2*(-2+wabc)*g[L[c],L[d]]*TwoW[L[a],L[b]]*ups[][L[i]]*
ups[][U[i],L[e]]-2*g[L[b],L[d]]*TwoW[L[a],L[c]]*ups[][L[i]]*
ups[][U[i],L[e]]-2*g[L[a],L[d]]*TwoW[L[c],L[b]]*ups[][L[i]]*
ups[][U[i],L[e]]+g[L[a],L[d]]*g[L[b],L[c]]*TwoW[L[i],L[j]]*
ups[][U[j]]*ups[][U[i],L[e]]+
g[L[a],L[c]]*g[L[b],L[d]]*TwoW[L[i],L[j]]*ups[][U[j]]*
ups[][U[i],L[e]]+g[L[b],L[c]]*g[L[d],L[e]]*TwoW[L[a],L[i]]*
ups[][L[j]]*ups[][U[i],U[j]]+
g[L[a],L[c]]*g[L[d],L[e]]*TwoW[L[i],L[b]]*ups[][L[j]]*
ups[][U[i],U[j]]+g[L[a],L[e]]*g[L[b],L[c]]*TwoW[L[i],L[j]]*
ups[][U[i]]*ups[][U[j],L[d]]+
g[L[a],L[d]]*g[L[b],L[c]]*TwoW[L[i],L[j]]*ups[][U[i]]*
ups[][U[j],L[e]]+g[L[a],L[c]]*g[L[b],L[d]]*TwoW[L[i],L[j]]*
ups[][U[i]]*ups[][U[j],L[e]]-
TwoW[L[c],L[b]]*ups[][L[a],L[d],L[e]]-
TwoW[L[a],L[c]]*ups[][L[b],L[d],L[e]]+
(-2+wabc)*TwoW[L[a],L[b]]*ups[][L[c],L[d],L[e]]+
g[L[b],L[c]]*TwoW[L[a],L[i]]*ups[][U[i],L[d],L[e]]+
g[L[a],L[c]]*TwoW[L[i],L[b]]*ups[][U[i],L[d],L[e]],
      NewRule->True];

(****************************************************************)
(****************************************************************)
(*
  The next function converts derivatives of Nvec to the trace-free
  second fundamental form.
*)

ToTfSFF[Operand_] :=

Module[
{Answer,LocalOp,Temp},
(
LocalOp=Operand;
Temp=LocalOp;
Temp=(Temp/.NbNvecToSFF);
Temp=TensorSimplify[Temp];
Temp=(Temp/.NvecRule);
Temp=(Temp/.NvecRule);
Temp=(Temp/.NvecRule);
Temp=TensorSimplify[Temp];
Temp=(Temp/.SFFToTfSFF);
Temp=TensorSimplify[Temp];
Temp=(Temp/.ExpandgSgm);
Temp=TensorSimplify[Temp];
Temp=(Temp/.NvecRule);
Temp=(Temp/.NvecRule);
Temp=(Temp/.NvecRule);
Temp=TensorSimplify[Temp];
Temp=(Temp/.KillTraceTfSFF);
Temp=(Temp/.NvecSFF);
Answer=Temp;
Answer
)
];

(****************************************************************)
(*
  The next function converts the second fundamental form and the
  trace-free second fundamental form to derivatives of the normal vector.
*)

ToNbNvec[Operand_] :=

Module[
{Answer,LocalOp,Temp},
(
LocalOp=Operand;
Temp=LocalOp;
Temp=(Temp/.ExpandTfSFF);
Temp=TensorSimplify[Temp];
Temp=(Temp/.NvecRule);
Temp=(Temp/.ExpandgSgm);
Temp=(Temp/.NvecRule);
Temp=TensorSimplify[Temp];
Temp=(Temp/.ExpandSFF);
Temp=(Temp/.ExpandHmc);
Temp=(Temp/.NvecRule);
Temp=TensorSimplify[Temp];
Temp=(Temp/.ExpandPiPro);
Temp=TensorSimplify[Temp];
Temp=(Temp/.NvecRule);
Temp=(Temp/.NvecRule);
Temp=TensorSimplify[Temp];
Answer=Temp;
Answer
)
];

(****************************************************************)

(* The next function applies rules like NvecRule, PartsNvec, etc.
 *)

NvecClean[Operand_] :=

Module[
  {Temp},
(
Temp=Operand;
Temp=(Temp/.NvecRule);
Temp=(Temp/.NvecRule);
Temp=TensorSimplify[Temp];
Temp=(Temp/.PartsNvecThree);
Temp=(Temp/.NvecRule);
Temp=(Temp/.PartsNvec);
Temp=TensorSimplify[Temp];
Temp=(Temp/.PartsNvec);
Temp=(Temp/.NvecRule);
Temp=TensorSimplify[Temp];
Temp=(Temp/.PartsNvec);
Temp=TensorSimplify[Temp];
Temp=(Temp/.NvecRule);
Temp=TensorSimplify[Temp];
Temp)
];

(****************************************************************)

(*--- End of file ---*)
