(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    107645,       3141]
NotebookOptionsPosition[     98202,       2843]
NotebookOutlinePosition[     98946,       2867]
CellTagsIndexPosition[     98903,       2864]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Alias.nb (\[OpenCurlyDoubleQuote]Test and illustrate alias tensors.\
\[CloseCurlyDoubleQuote])", "Text",
 CellChangeTimes->{{3.762890231053714*^9, 3.7628902750297194`*^9}, 
   3.764532069585166*^9, {3.765879248499001*^9, 3.765879249554697*^9}},
 FontSize->18,
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]],

Cell[TextData[{
 "Date last modified:  5 May 2019\n\nIn this notebook, we illustrate and test \
our definitions relating to alias identifiers for intrinsic derivatives of \
intrinsic tensors and densities.  In a few of our notebooks, the covariant \
derivative (as indicated by the semicolon) sometimes indicates the intrinsic \
derivative.  At other times in these same notebooks, the covariant derivative \
(as indicated by the semicolon) indicates the usual covariant derivative on \
",
 StyleBox["M",
  FontSlant->"Italic"],
 ".  So when the semicolon indicates the intrinsic derivative, we will define \
an alias tensor.  One or more of the indices of the alias tensor will be \
associated with the intrinsic covariant derivative.  We have created commands \
which will transform the intrinsically differentiated tensor (with the \
intrinsic derivative indicated by a semicolon) into an alias tensor.  We will \
later expand the alias tensors in such a way as to express the intrinsically \
differentiated tensor in terms of ambient derivatives on ",
 StyleBox["M",
  FontSlant->"Italic"],
 ".  In this notebook, we test and illustrate the definitions that we will \
use to accomplish all of this."
}], "Text",
 CellChangeTimes->{{3.7627642842629557`*^9, 3.762764290958097*^9}, {
   3.7627643231518593`*^9, 3.762764377953272*^9}, {3.762850661476184*^9, 
   3.762850661886075*^9}, {3.762890299438554*^9, 3.7628904561204557`*^9}, {
   3.7628905001295023`*^9, 3.762890708477516*^9}, {3.762890747805581*^9, 
   3.7628908094235353`*^9}, {3.762890881950575*^9, 3.762890892313396*^9}, {
   3.7628909479142447`*^9, 3.762890953967227*^9}, {3.762975390356318*^9, 
   3.762975391677025*^9}, {3.763063659518675*^9, 3.763063659913632*^9}, {
   3.764273625662142*^9, 3.764273630832775*^9}, {3.7644058718759823`*^9, 
   3.764405872703289*^9}, {3.764532072105846*^9, 3.7645320726050997`*^9}, {
   3.7653881222092667`*^9, 3.7653881246522627`*^9}, {3.7657030592673197`*^9, 
   3.76570306269311*^9}, 3.765703196501934*^9, {3.765874579735165*^9, 
   3.765874580392951*^9}, {3.765960824115892*^9, 3.765960824743228*^9}, {
   3.766088626854998*^9, 3.766088627482449*^9}}],

Cell[TextData[{
 "Special warning concerning the display of graphical output from ",
 StyleBox["Mathematica",
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.765703229354857*^9, 3.765703244647833*^9}, {
  3.765790640365418*^9, 3.765790649374778*^9}, {3.765961389677267*^9, 
  3.765961405564399*^9}, {3.765961448549405*^9, 3.765961457572194*^9}, {
  3.765961560085361*^9, 3.765961580965189*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[TextData[{
 StyleBox["   ",
  FontSize->9,
  FontWeight->"Bold"],
 StyleBox["\nPlease read this warning note, if you have not done so already!",
  
  FontWeight->"Bold"],
 "\n\nIf you run any of the notebooks in this group of notebooks, you should \
set ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote]s default output format type to \[OpenCurlyDoubleQuote]",
 StyleBox["OutputForm", "Input"],
 ".\[CloseCurlyDoubleQuote]  (To \[OpenCurlyDoubleQuote]run\
\[CloseCurlyDoubleQuote] a notebook means to have ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " actually execute the commands in the notebook.  Reading the contents of a \
notebook is not the same as running the notebook.)\n\nIf you set the default \
output format type to \[OpenCurlyDoubleQuote]",
 StyleBox["OutputForm", "Input"],
 ",\[CloseCurlyDoubleQuote] this will allow ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to format ",
 StyleBox["Ricci",
  FontSlant->"Italic"],
 " output properly.  I have provided a command which will set the default \
output format type to \[OpenCurlyDoubleQuote]",
 StyleBox["OutputForm", "Input"],
 ".\[CloseCurlyDoubleQuote]  This command appears shortly after this warning \
note.\n\nWhen you change the default output format type, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " may record the new default output format type in its configuration files \
on your computer.  In the future, when you start a new work session with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will probably use the default output format type that you were using at \
the end of your previous ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " work session.  ",
 StyleBox["If this default output format type is \[OpenCurlyDoubleQuote]",
  FontWeight->"Bold"],
 StyleBox["OutputForm", "Input",
  FontWeight->"Bold"],
 StyleBox[",\[CloseCurlyDoubleQuote] then, in the future work session, ",
  FontWeight->"Bold"],
 StyleBox["Mathematica",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[" may not display graphical output.  ",
  FontWeight->"Bold"],
 "This could be a problem for you if you use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " for purposes other than your work with ",
 StyleBox["Ricci",
  FontSlant->"Italic"],
 ".\n\nThe term \[OpenCurlyDoubleQuote]graphical output\
\[CloseCurlyDoubleQuote] includes graphs of functions.  The command \
\[OpenCurlyDoubleQuote]",
 StyleBox["Plot[x^2,{x,-2,2}]", "Input"],
 ",\[CloseCurlyDoubleQuote] for example, is supposed to produce the graph of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "=", 
    SuperscriptBox["x", "2"]}], TraditionalForm]]],
 " over the interval from ",
 StyleBox["x",
  FontSlant->"Italic"],
 " = -2 to ",
 StyleBox["x",
  FontSlant->"Italic"],
 " = 2.  If ",
 StyleBox["Mathematica\[CloseCurlyQuote]",
  FontSlant->"Italic"],
 "s default output format type is \[OpenCurlyDoubleQuote]",
 StyleBox["OutputForm", "Input"],
 ",\[CloseCurlyDoubleQuote] this ",
 StyleBox["Plot", "Input"],
 " command may produce the following output:\n\n     -Graphics-\n\nThis is \
probably not the output you would like.  In future ",
 StyleBox["Mathematica ",
  FontSlant->"Italic"],
 "work sessions, if you would like to have ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " display graphical output, you should set the default output format type to \
either \[OpenCurlyDoubleQuote]",
 StyleBox["TraditionalForm", "Input"],
 "\[CloseCurlyDoubleQuote] or \[OpenCurlyDoubleQuote]",
 StyleBox["StandardForm", "Input"],
 ".\[CloseCurlyDoubleQuote]  You can do this at the end of your current ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " work session or during some future ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " work session.  According to the documentation for ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 11.0.1 for Linux, you may also set the default output format type to \
\[OpenCurlyDoubleQuote]",
 StyleBox["InputForm", "Input"],
 ",\[CloseCurlyDoubleQuote] but this will probably produce undesirable \
results.  Every notebook in this collection of notebooks contains commands \
for changing the default output format type to \[OpenCurlyDoubleQuote]",
 StyleBox["TraditionalForm", "Input"],
 "\[CloseCurlyDoubleQuote] or \[OpenCurlyDoubleQuote]",
 StyleBox["StandardForm", "Input"],
 ".\[CloseCurlyDoubleQuote]  These commands appear at the end of each \
notebook.  After you are finished with a given session of ",
 StyleBox["Ricci",
  FontSlant->"Italic"],
 " work, you may wish to use one of these commands to set the default output \
format type to \[OpenCurlyDoubleQuote]",
 StyleBox["TraditionalForm", "Input"],
 "\[CloseCurlyDoubleQuote] or \[OpenCurlyDoubleQuote]",
 StyleBox["StandardForm", "Input"],
 ".\[CloseCurlyDoubleQuote]  It may also be possible to change the default \
output format type by using the menus at the top of your computer screen.  \
You might try\n\n     Edit -> Preferences... -> Evaluation.\n     \nThere may \
be other better ways of dealing with the default output format type problem.\n\
\nI used ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 11.0.1 to test the notebooks in this collection of notebooks.  The \
behavior of future versions of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " may differ from that of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 11.0.1."
}], "Text",
 CellChangeTimes->{{3.765790578386015*^9, 3.765790611358521*^9}, {
   3.765790663613566*^9, 3.765790801846695*^9}, {3.765875954764688*^9, 
   3.7658759639976797`*^9}, {3.7658760391316967`*^9, 
   3.7658760576780357`*^9}, {3.7658760901351624`*^9, 
   3.7658762065929937`*^9}, {3.7658762391943483`*^9, 3.765876513510744*^9}, {
   3.765876744822448*^9, 3.765876815078334*^9}, {3.7658769365869827`*^9, 
   3.765876941988489*^9}, {3.765877012050274*^9, 3.765877063837459*^9}, {
   3.7658771073930187`*^9, 3.765877107759053*^9}, {3.765877179607602*^9, 
   3.765877204719202*^9}, {3.765877252976372*^9, 3.765877279373424*^9}, {
   3.765877619837624*^9, 3.765877663902957*^9}, {3.76587776858379*^9, 
   3.765877788800474*^9}, {3.765878052788946*^9, 3.7658780996120234`*^9}, {
   3.765878627761004*^9, 3.765878640876671*^9}, {3.765878719612721*^9, 
   3.765878720204338*^9}, {3.7659609617941732`*^9, 3.765960963718663*^9}, {
   3.765966052259457*^9, 3.765966173368919*^9}, {3.765967777738826*^9, 
   3.7659678125610437`*^9}, {3.7659678623551197`*^9, 3.765967897224872*^9}, {
   3.765968083996738*^9, 3.7659680935279922`*^9}, {3.76596813668933*^9, 
   3.765968166200952*^9}, {3.765968387403921*^9, 3.765968400843381*^9}, {
   3.765968442375699*^9, 3.7659685071638002`*^9}, {3.765968557760788*^9, 
   3.765968600025187*^9}, 3.765968811324258*^9, {3.765979647396905*^9, 
   3.765979732958995*^9}, {3.7659922229476833`*^9, 3.765992229580228*^9}}],

Cell["Set the default output format type.", "Text",
 CellChangeTimes->{{3.765875996954977*^9, 3.765876011059374*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[TextData[{
 "The command in the following cell changes the default output format type to \
",
 StyleBox["OutputForm", "Input"],
 ".  If you wish to run the commands in this notebook, you should run this \
command.  But please read the above warning, if you have not done so \
already."
}], "Text",
 CellChangeTimes->{{3.765703515212728*^9, 3.7657036140941277`*^9}, {
  3.765703700534972*^9, 3.7657037430389233`*^9}, {3.7657037775116997`*^9, 
  3.765703990513781*^9}, {3.765704029370473*^9, 3.7657041791393213`*^9}, {
  3.765704213274665*^9, 3.765704314899963*^9}, {3.765704413804091*^9, 
  3.7657044788131657`*^9}, {3.7657045247421007`*^9, 3.765704761206297*^9}, {
  3.765704981345673*^9, 3.765705101689434*^9}, {3.7657051996495647`*^9, 
  3.7657052319711857`*^9}, {3.765705281036148*^9, 3.765705434701811*^9}, {
  3.765705701409999*^9, 3.765705780007972*^9}, {3.765789519789137*^9, 
  3.7657895820023527`*^9}, {3.765790550645265*^9, 3.765790563500952*^9}, {
  3.765791972361102*^9, 3.765792021203673*^9}, {3.765792060772276*^9, 
  3.7657920702574453`*^9}}],

Cell[BoxData[
 RowBox[{"<<", "~/bop/gen/dtm/defout.m"}]], "Input",
 CellChangeTimes->{{3.76579048166709*^9, 3.7657905106044493`*^9}}],

Cell["Read files and set parameters.  Read the Ricci package.", "Text",
 CellChangeTimes->{{3.765874941167532*^9, 3.765874976975177*^9}, {
  3.765961087459785*^9, 3.7659611389638968`*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[TextData[{
 "The following command tells ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " where to make the line breaks in the command output."
}], "Text",
 CellChangeTimes->{{3.7627642842629557`*^9, 3.762764290958097*^9}, {
   3.7627643231518593`*^9, 3.762764377953272*^9}, {3.762850661476184*^9, 
   3.762850661886075*^9}, {3.762890299438554*^9, 3.7628904561204557`*^9}, {
   3.7628905001295023`*^9, 3.762890708477516*^9}, {3.762890747805581*^9, 
   3.7628908094235353`*^9}, {3.762890881950575*^9, 3.762890892313396*^9}, {
   3.7628909479142447`*^9, 3.762890953967227*^9}, {3.762975390356318*^9, 
   3.762975391677025*^9}, {3.763063659518675*^9, 3.763063659913632*^9}, {
   3.764273625662142*^9, 3.764273630832775*^9}, {3.7644058718759823`*^9, 
   3.764405872703289*^9}, {3.764532072105846*^9, 3.7645320726050997`*^9}, {
   3.7653881222092667`*^9, 3.7653881246522627`*^9}, {3.7657030592673197`*^9, 
   3.76570306269311*^9}, 3.765792428014216*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetOptions", "[", 
  RowBox[{"$Output", ",", 
   RowBox[{"PageWidth", "\[Rule]", "110"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.762764391138027*^9, 3.762764392393855*^9}, {
  3.762765009326685*^9, 3.762765010806072*^9}, {3.764273635150352*^9, 
  3.764273636413838*^9}}],

Cell[OutputFormData["\<\
{{BinaryFormat -> False, FormatType -> OutputForm, PageWidth -> 110, \
PageHeight -> 22, 
  TotalWidth -> Infinity, TotalHeight -> Infinity, CharacterEncoding :> \
\"Unicode\", 
  NumberMarks :> $NumberMarks, Method -> {\"File\", BinaryFormat -> False}}}\
\>", "\<\
{{BinaryFormat -> False, FormatType -> OutputForm, PageWidth -> 110, \
PageHeight -> 22, 
 
   TotalWidth -> Infinity, TotalHeight -> Infinity, CharacterEncoding :> \
Unicode, 
 
   NumberMarks :> $NumberMarks, Method -> {File, BinaryFormat -> False}}}\
\>"], "Output",
 CellChangeTimes->{
  3.762764393463768*^9, 3.762765011716523*^9, 3.7628506717814503`*^9, 
   3.762889423744157*^9, 3.762890956586349*^9, 3.762891268106801*^9, 
   3.7629754663534117`*^9, 3.763063668919883*^9, 3.7630654666053743`*^9, 
   3.764273637635248*^9, 3.764273719280908*^9, 3.764405887247324*^9, 
   3.765388137298691*^9, 3.7657924338083076`*^9, 3.7659610692347507`*^9, 
   3.7659611489566813`*^9, 3.7659612555759583`*^9, 3.765992281654422*^9, {
   3.765996117117345*^9, 3.765996129412203*^9}, 3.766088944002736*^9}]
}, Open  ]],

Cell[TextData[{
 "Print the version number for ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.7659923013162203`*^9, 3.765992323112632*^9}}],

Cell[CellGroupData[{

Cell[BoxData["$Version"], "Input",
 CellChangeTimes->{{3.765992332098835*^9, 3.76599233506927*^9}}],

Cell[OutputFormData["\<\
\"11.0.1 for Linux x86 (64-bit) (September 21, 2016)\"\
\>", "\<\
11.0.1 for Linux x86 (64-bit) (September 21, 2016)\
\>"], "Output",
 CellChangeTimes->{
  3.765992336090156*^9, {3.7659961059247513`*^9, 3.765996131567045*^9}, 
   3.766088945856195*^9}]
}, Open  ]],

Cell[TextData[{
 "We now read in the ",
 StyleBox["Ricci",
  FontSlant->"Italic"],
 " package."
}], "Text",
 CellChangeTimes->{{3.765874910802298*^9, 3.7658749237986803`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"<<", "~/bop/gen/dtm3/Ricci1.61.m"}]], "Input",
 CellChangeTimes->{{3.7627644065066843`*^9, 3.762764426618567*^9}, {
  3.765874894693124*^9, 3.765874896588677*^9}, {3.7659923417497807`*^9, 
  3.765992342605335*^9}}],

Cell["\<\
 -- Ricci Version 1.61 (March 10, 2016) --
    Copyright 1992 - 2016 John M. Lee
    Problem reports or suggestions to:
      lee@math.washington.edu
 -- For properly formatted output in a notebook,
    set the default output format type to OutputForm\
\>", "Print",
 CellChangeTimes->{3.764273720315215*^9, 3.764405889490387*^9, 
  3.765388138685137*^9, 3.765961150679544*^9, 3.76596126055513*^9, 
  3.76599234426644*^9, 3.76599614089025*^9, 3.766088946996126*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"$Quiet", "=", "True"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"<<", "~/bop/gen/dtm3/June8tan.m"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"<<", "~/bop/gen/dtm2/Maybund.m"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"<<", "~/bop/gen/dtm2/Maybase.m"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"<<", "~/bop/gen/dtm2/May2.m"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"<<", "~/bop/gen/dtm2/May3.m"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"<<", "~/bop/gen/dtm2/May6.m"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"<<", "~/bop/gen/dtm2/May7.m"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"<<", "~/bop/gen/dtm2/MayCottBach.m"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"<<", "~/bop/gen/dtm/PrintTime.m"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"<<", "~/bop/gen/dtm3/June8.m"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"<<", "~/bop/gen/dtm3/June9a.m"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"<<", "~/bop/gen/dtm3/Warning1.m"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$Quiet", "=", "False"}], ";"}], "\n", 
 RowBox[{"PrintTime", ";"}]}], "Input",
 CellChangeTimes->{{3.762764407666642*^9, 3.762764410771296*^9}, {
  3.762891236228237*^9, 3.762891249196126*^9}, {3.7630647308335333`*^9, 
  3.763064732034946*^9}, {3.764273698218135*^9, 3.7642736986869164`*^9}, {
  3.764275272016528*^9, 3.764275272424035*^9}}],

Cell["\<\
Time:  18 hours, 49 minutes, 9 seconds
Date:  5 May 2019\
\>", "Print",
 CellChangeTimes->{3.7628506741749153`*^9, 3.762889427202777*^9, 
  3.762890960277123*^9, 3.76289127141181*^9, 3.762975470158064*^9, 
  3.763063672137787*^9, 3.763065470359929*^9, 3.764273690839683*^9, 
  3.76427373262004*^9, 3.7644058939338017`*^9, 3.765388145521776*^9, 
  3.7659611539035673`*^9, 3.765961262821643*^9, 3.7659923577955713`*^9, 
  3.7659961490847*^9, 3.766088949411038*^9}]
}, Open  ]],

Cell["We do some preparations.", "Text",
 CellChangeTimes->{{3.7628914262875023`*^9, 3.762891440146576*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[TextData[{
 "When we originally coded many of our commands for intrinsic derivatives, we \
gave them the capability of computing the derivative relative to the \
conformal metric.  The conformal factor is ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", 
    RowBox[{"2", "*", "Upsilon"}]], TraditionalForm]]],
 ".  In our present article, we want to compute the derivatives relative to \
the background metric.  So we will always set upsilon equal to zero.  We \
define a command to do this here."
}], "Text",
 CellChangeTimes->{{3.7628914492147617`*^9, 3.762891595040762*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DefineRule", "[", 
  RowBox[{"Killups", ",", "ups", ",", "0", ",", 
   RowBox[{"NewRule", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.762891384947166*^9, 3.76289139631842*^9}}],

Cell["Rule defined.", "Print",
 CellChangeTimes->{3.762891397726721*^9, 3.762975500717772*^9, 
  3.763063676911543*^9, 3.763065475653597*^9, 3.764405899568969*^9, 
  3.765388154841321*^9, 3.7659611668426867`*^9, 3.76596126664258*^9, 
  3.7659923626721067`*^9, 3.765996171180396*^9, 3.7660889526583776`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Holder", "=", 
   RowBox[{"{", 
    RowBox[{"ups", ",", 
     RowBox[{"ups", "[", 
      RowBox[{"L", "[", "i", "]"}], "]"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", "Holder"}], "Input",
 CellChangeTimes->{{3.762891399351549*^9, 3.76289140743604*^9}}],

Cell[OutputFormData["\<\
{ups, ups[] [L[i]]}\
\>", "\<\
{ups, ups   }
         ;i\
\>"], "Output",
 CellChangeTimes->{{3.765992420694401*^9, 3.7659924541916533`*^9}, 
   3.765996172246902*^9, 3.766088954643568*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Holder", "/.", "Killups"}]], "Input",
 CellChangeTimes->{{3.7628914089037647`*^9, 3.7628914113261414`*^9}}],

Cell[OutputFormData["\<\
{0, 0}\
\>", "\<\
{0, 0}\
\>"], "Output",
 CellChangeTimes->{3.762891412819098*^9, 3.762975502183085*^9, 
  3.763063678826364*^9, 3.76306547798871*^9, 3.7644059016119432`*^9, 
  3.76538817145467*^9, 3.7659611684532967`*^9, 3.76596126822631*^9, 
  3.765992364911149*^9, 3.7659924629946823`*^9, 3.7659961729305897`*^9, 
  3.766088955276866*^9}]
}, Open  ]],

Cell[TextData[{
 "We test the alias ",
 StyleBox["LapLapf", "Input"],
 "."
}], "Text",
 CellChangeTimes->{{3.7627644828952847`*^9, 3.762764503779745*^9}, 
   3.762852127250988*^9, {3.762891032240436*^9, 3.762891040288322*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[TextData[{
 "Here we consider ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    OverscriptBox["\[CapitalDelta]", "_"], "2"], TraditionalForm]]],
 StyleBox["f",
  FontSlant->"Italic"],
 ", where ",
 StyleBox["f  ",
  FontSlant->"Italic"],
 "is a density."
}], "Text",
 CellChangeTimes->{{3.7627645296385927`*^9, 3.762764576508325*^9}, {
  3.762891053544849*^9, 3.762891135371291*^9}, {3.7628927284402857`*^9, 
  3.762892736376254*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"LapSquaredHolder", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"L", "[", "i", "]"}], ",", 
     RowBox[{"U", "[", "i", "]"}], ",", 
     RowBox[{"L", "[", "j", "]"}], ",", 
     RowBox[{"U", "[", "j", "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", "LapSquaredHolder"}], "Input",
 CellChangeTimes->{{3.762891152866128*^9, 3.762891186970661*^9}}],

Cell[OutputFormData["\<\
f[] [L[i], U[i], L[j], U[j]]\
\>", "\<\
    i   j 
f
 ;i   j\
\>"], "Output",
 CellChangeTimes->{{3.762891169473559*^9, 3.762891188336553*^9}, 
   3.762891273963842*^9, 3.762975507689158*^9, 3.76306368243139*^9, 
   3.7630654823098307`*^9, 3.764405905452379*^9, 3.7653881751243477`*^9, 
   3.7659961774583673`*^9, 3.766088959032978*^9}]
}, Open  ]],

Cell["\<\
In the above output, we assume that the derivatives are derivatives \
associated with intrinsic connection on \[Sum].  We now convert the above \
output into alias form.\
\>", "Text",
 CellChangeTimes->{{3.762892587516725*^9, 3.762892598719824*^9}, {
  3.7629755115091753`*^9, 3.762975577933968*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", "LapSquaredHolder"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "LapLapfToFake"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StepAAOne", "=", "Temp"}], 
  ";"}], "\[IndentingNewLine]", "StepAAOne"}], "Input",
 CellChangeTimes->{{3.7628911995501328`*^9, 3.762891223523608*^9}, {
  3.7628912794853163`*^9, 3.762891290004459*^9}}],

Cell[OutputFormData["\<\
LapLapf\
\>", "\<\
LapLapf\
\>"], "Output",
 CellChangeTimes->{{3.762891275005537*^9, 3.762891290800667*^9}, 
   3.7629755876504307`*^9, 3.7630636839811087`*^9, 3.76306548421014*^9, 
   3.764405908590179*^9, 3.7653881770566587`*^9, 3.7659961823352423`*^9, 
   3.766088961648403*^9}]
}, Open  ]],

Cell["Now expand the alias.", "Text",
 CellChangeTimes->{{3.7628926073549023`*^9, 3.76289261601615*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", "StepAAOne"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "ExpandLapLapf"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StepAATwo", "=", "Temp"}], 
  ";"}], "\[IndentingNewLine]", "StepAATwo"}], "Input",
 CellChangeTimes->{{3.7628913072882223`*^9, 3.7628913359011297`*^9}}],

Cell[OutputFormData["\<\
f[] [L[a], U[a], L[b], U[b]] - f[] [L[a], L[b], L[c], \
U[c]]*Nvec[U[a]]*Nvec[U[b]] - 

   f[] [L[b], L[c], U[c]]*Nvec[U[a]] [L[a]]*Nvec[U[b]] - 2*f[] [L[a], L[b], \
L[c]]*Nvec[U[a]] [U[c]]*

    Nvec[U[b]] - f[] [L[a], L[b]]*Nvec[U[a]] [L[c], U[c]]*Nvec[U[b]] - 

   2*f[] [L[a], L[b], L[c]]*Nvec[U[a]]*Nvec[U[b]] [U[c]] - 2*f[] [L[a], \
L[b]]*Nvec[U[a]] [L[c]]*

    Nvec[U[b]] [U[c]] - f[] [L[a], L[b]]*Nvec[U[a]]*Nvec[U[b]] [L[c], U[c]] - 

   f[] [L[b]]*Nvec[U[a]] [L[a]]*Nvec[U[b]] [L[c], U[c]] - f[] [L[a], U[a], \
L[b], L[c]]*Nvec[U[b]]*Nvec[U[c]] \\
- 
 f[] [L[a], U[a], L[c]]*Nvec[U[b]] [L[b]]*Nvec[U[c]] - 2*f[] [L[a], \
L[b]]*Nvec[U[a]] [U[b]]*

    Nvec[U[c]] [L[c]] - 2*f[] [L[a], L[b]]*Nvec[U[a]]*Nvec[U[c]] [L[c], U[b]] \
- 

   2*f[] [L[a]]*Nvec[U[a]] [L[b]]*Nvec[U[c]] [L[c], U[b]] - 

   f[] [L[b]]*Nvec[U[b]]*Nvec[U[c]] [L[c], L[a], U[a]] + f[] [L[a], L[b], \
L[c], L[d]]*Nvec[U[a]]*Nvec[U[b]]*

    Nvec[U[c]]*Nvec[U[d]] + f[] [L[b], L[c], L[d]]*Nvec[U[a]] \
[L[a]]*Nvec[U[b]]*Nvec[U[c]]*Nvec[U[d]] + 

   2*f[] [L[a], L[b], L[c]]*Nvec[U[a]] \
[L[d]]*Nvec[U[b]]*Nvec[U[c]]*Nvec[U[d]] + 

   f[] [L[a], L[b]]*Nvec[U[a]] [L[c], L[d]]*Nvec[U[b]]*Nvec[U[c]]*Nvec[U[d]] + 

   2*f[] [L[a], L[b], L[c]]*Nvec[U[a]]*Nvec[U[b]] \
[L[d]]*Nvec[U[c]]*Nvec[U[d]] + 

   2*f[] [L[a], L[b]]*Nvec[U[a]] [L[c]]*Nvec[U[b]] \
[L[d]]*Nvec[U[c]]*Nvec[U[d]] + 

   f[] [L[a], L[b]]*Nvec[U[a]]*Nvec[U[b]] [L[c], L[d]]*Nvec[U[c]]*Nvec[U[d]] + 

   f[] [L[b]]*Nvec[U[a]] [L[a]]*Nvec[U[b]] [L[c], L[d]]*Nvec[U[c]]*Nvec[U[d]] \
+ 

   f[] [L[a], L[b], L[d]]*Nvec[U[a]]*Nvec[U[b]]*Nvec[U[c]] [L[c]]*Nvec[U[d]] + 

   f[] [L[b], L[d]]*Nvec[U[a]] [L[a]]*Nvec[U[b]]*Nvec[U[c]] [L[c]]*Nvec[U[d]] \
+ 

   3*f[] [L[a], L[b]]*Nvec[U[a]] [L[c]]*Nvec[U[b]]*Nvec[U[c]]*Nvec[U[d]] \
[L[d]] + 

   f[] [L[a], L[b]]*Nvec[U[a]]*Nvec[U[b]] [L[c]]*Nvec[U[c]]*Nvec[U[d]] [L[d]] \
+ 

   f[] [L[a]]*Nvec[U[a]] [L[b]]*Nvec[U[b]]*Nvec[U[c]] [L[c]]*Nvec[U[d]] \
[L[d]] + 

   f[] [L[a]]*Nvec[U[a]]*Nvec[U[b]]*Nvec[U[c]] [L[c]]*Nvec[U[d]] [L[d], L[b]] \
+ 

   2*f[] [L[a], L[b]]*Nvec[U[a]]*Nvec[U[b]]*Nvec[U[c]]*Nvec[U[d]] [L[d], \
L[c]] + 

   2*f[] [L[a]]*Nvec[U[a]] [L[b]]*Nvec[U[b]]*Nvec[U[c]]*Nvec[U[d]] [L[d], \
L[c]] + 

   f[] [L[a]]*Nvec[U[a]]*Nvec[U[b]]*Nvec[U[c]]*Nvec[U[d]] [L[d], L[b], L[c]]\
\>", "\<\
    a   b            c      a      b          c      a         b              \
     a  c      b 
f          - f          Nvec   Nvec   - f        Nvec      Nvec   - 2 f       \
 Nvec      Nvec   - 
 ;a   b       ;a b c                     ;b c          ;a              ;a b c \
       ;
 
             a    c      b                   a      b  c                 a    \
     b  c 
  f      Nvec        Nvec   - 2 f        Nvec   Nvec      - 2 f      Nvec     \
 Nvec      - 
   ;a b        ;c                ;a b c               ;        ;a b        ;c \
       ;
 
             a      b    c             a         b    c        a          b   \
   c 
  f      Nvec   Nvec        - f    Nvec      Nvec        - f          Nvec   \
Nvec   - 
   ;a b               ;c       ;b        ;a        ;c       ;a   b c 
 
      a        b         c                 a  b      c                    a   \
   c    b 
  f        Nvec      Nvec   - 2 f      Nvec      Nvec      - 2 f      Nvec   \
Nvec        - 
   ;a   c        ;b              ;a b        ;         ;c       ;a b          \
     ;c 
 
             a         c    b             b      c      a                   a \
     b      c      d 
  2 f    Nvec      Nvec        - f    Nvec   Nvec          + f          Nvec  \
 Nvec   Nvec   Nvec   + 
     ;a        ;b        ;c       ;b               ;c a       ;a b c d 
 
               a         b      c      d                   a         b      c \
     d 
  f        Nvec      Nvec   Nvec   Nvec   + 2 f        Nvec      Nvec   Nvec  \
 Nvec   + 
   ;b c d        ;a                            ;a b c        ;d 
 
             a           b      c      d                   a      b         c \
     d 
  f      Nvec        Nvec   Nvec   Nvec   + 2 f        Nvec   Nvec      Nvec  \
 Nvec   + 
   ;a b        ;c d                            ;a b c               ;d 
 
               a         b         c      d               a      b           \
c      d 
  2 f      Nvec      Nvec      Nvec   Nvec   + f      Nvec   Nvec        Nvec \
  Nvec   + 
     ;a b        ;c        ;d                   ;a b               ;c d 
 
           a         b           c      d                 a      b      c     \
    d 
  f    Nvec      Nvec        Nvec   Nvec   + f        Nvec   Nvec   Nvec      \
Nvec   + 
   ;b        ;a        ;c d                   ;a b d                      ;c 
 
             a         b      c         d                 a         b      c  \
    d 
  f      Nvec      Nvec   Nvec      Nvec   + 3 f      Nvec      Nvec   Nvec   \
Nvec      + 
   ;b d        ;a               ;c              ;a b        ;c                \
      ;d 
 
             a      b         c      d                a         b      c      \
   d 
  f      Nvec   Nvec      Nvec   Nvec      + f    Nvec      Nvec   Nvec      \
Nvec      + 
   ;a b               ;c               ;d     ;a        ;b               ;c   \
     ;d 
 
           a      b      c         d                      a      b      c     \
 d 
  f    Nvec   Nvec   Nvec      Nvec        + 2 f      Nvec   Nvec   Nvec   \
Nvec        + 
   ;a                      ;c        ;d b       ;a b                          \
   ;d c 
 
             a         b      c      d                  a      b      c      d 
  2 f    Nvec      Nvec   Nvec   Nvec        + f    Nvec   Nvec   Nvec   Nvec
     ;a        ;b                      ;d c     ;a                            \
 ;d b c\
\>"], "Output",
 CellChangeTimes->{3.762891336940257*^9, 3.762975591150313*^9, 
  3.7630636857349443`*^9, 3.7630654862599792`*^9, 3.764405910744567*^9, 
  3.765388179957716*^9, 3.765996186449411*^9, 3.766088966491549*^9}]
}, Open  ]],

Cell["Now test the above expansion.", "Text",
 CellChangeTimes->{{3.762892623793185*^9, 3.762892631760112*^9}, {
  3.762975609710601*^9, 3.762975610806452*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"LapSigHatDen", "[", 
    RowBox[{"f", ",", "w"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "Killups"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"LapSigHatDen", "[", 
    RowBox[{"Temp", ",", 
     RowBox[{"w", "-", "2"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "Killups"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StepAAThree", "=", "Temp"}], 
  ";"}], "\[IndentingNewLine]", "StepAAThree"}], "Input",
 CellChangeTimes->{{3.762891368968485*^9, 3.762891372302754*^9}, {
  3.762891652465686*^9, 3.7628917369071712`*^9}}],

Cell[OutputFormData["\<\
f[] [L[a], U[a], L[b], U[b]] - f[] [L[a], L[b], L[c], \
U[c]]*Nvec[U[a]]*Nvec[U[b]] - 

   f[] [L[b], L[c], U[c]]*Nvec[U[a]] [L[a]]*Nvec[U[b]] - 2*f[] [L[a], L[b], \
L[c]]*Nvec[U[a]] [U[c]]*

    Nvec[U[b]] - f[] [L[a], L[b]]*Nvec[U[a]] [L[c], U[c]]*Nvec[U[b]] - 

   2*f[] [L[a], L[b], L[c]]*Nvec[U[a]]*Nvec[U[b]] [U[c]] - 2*f[] [L[a], \
L[b]]*Nvec[U[a]] [L[c]]*

    Nvec[U[b]] [U[c]] - f[] [L[a], L[b]]*Nvec[U[a]]*Nvec[U[b]] [L[c], U[c]] - 

   f[] [L[b]]*Nvec[U[a]] [L[a]]*Nvec[U[b]] [L[c], U[c]] - f[] [L[a], U[a], \
L[b], L[c]]*Nvec[U[b]]*Nvec[U[c]] \\
- 
 f[] [L[a], U[a], L[c]]*Nvec[U[b]] [L[b]]*Nvec[U[c]] - 2*f[] [L[a], \
L[b]]*Nvec[U[a]] [U[b]]*

    Nvec[U[c]] [L[c]] - 2*f[] [L[a], L[b]]*Nvec[U[a]]*Nvec[U[c]] [L[c], U[b]] \
- 

   2*f[] [L[a]]*Nvec[U[a]] [L[b]]*Nvec[U[c]] [L[c], U[b]] - 

   f[] [L[b]]*Nvec[U[b]]*Nvec[U[c]] [L[c], L[a], U[a]] + f[] [L[a], L[b], \
L[c], L[d]]*Nvec[U[a]]*Nvec[U[b]]*

    Nvec[U[c]]*Nvec[U[d]] + f[] [L[b], L[c], L[d]]*Nvec[U[a]] \
[L[a]]*Nvec[U[b]]*Nvec[U[c]]*Nvec[U[d]] + 

   2*f[] [L[a], L[b], L[c]]*Nvec[U[a]] \
[L[d]]*Nvec[U[b]]*Nvec[U[c]]*Nvec[U[d]] + 

   f[] [L[a], L[b]]*Nvec[U[a]] [L[c], L[d]]*Nvec[U[b]]*Nvec[U[c]]*Nvec[U[d]] + 

   2*f[] [L[a], L[b], L[c]]*Nvec[U[a]]*Nvec[U[b]] \
[L[d]]*Nvec[U[c]]*Nvec[U[d]] + 

   2*f[] [L[a], L[b]]*Nvec[U[a]] [L[c]]*Nvec[U[b]] \
[L[d]]*Nvec[U[c]]*Nvec[U[d]] + 

   f[] [L[a], L[b]]*Nvec[U[a]]*Nvec[U[b]] [L[c], L[d]]*Nvec[U[c]]*Nvec[U[d]] + 

   f[] [L[b]]*Nvec[U[a]] [L[a]]*Nvec[U[b]] [L[c], L[d]]*Nvec[U[c]]*Nvec[U[d]] \
+ 

   f[] [L[a], L[b], L[d]]*Nvec[U[a]]*Nvec[U[b]]*Nvec[U[c]] [L[c]]*Nvec[U[d]] + 

   f[] [L[b], L[d]]*Nvec[U[a]] [L[a]]*Nvec[U[b]]*Nvec[U[c]] [L[c]]*Nvec[U[d]] \
+ 

   3*f[] [L[a], L[b]]*Nvec[U[a]] [L[c]]*Nvec[U[b]]*Nvec[U[c]]*Nvec[U[d]] \
[L[d]] + 

   f[] [L[a], L[b]]*Nvec[U[a]]*Nvec[U[b]] [L[c]]*Nvec[U[c]]*Nvec[U[d]] [L[d]] \
+ 

   f[] [L[a]]*Nvec[U[a]] [L[b]]*Nvec[U[b]]*Nvec[U[c]] [L[c]]*Nvec[U[d]] \
[L[d]] + 

   f[] [L[a]]*Nvec[U[a]]*Nvec[U[b]]*Nvec[U[c]] [L[c]]*Nvec[U[d]] [L[d], L[b]] \
+ 

   2*f[] [L[a], L[b]]*Nvec[U[a]]*Nvec[U[b]]*Nvec[U[c]]*Nvec[U[d]] [L[d], \
L[c]] + 

   2*f[] [L[b]]*Nvec[U[a]]*Nvec[U[b]] [L[a]]*Nvec[U[c]]*Nvec[U[d]] [L[d], \
L[c]] + 

   f[] [L[a]]*Nvec[U[a]]*Nvec[U[b]]*Nvec[U[c]]*Nvec[U[d]] [L[d], L[b], L[c]]\
\>", "\<\
    a   b            c      a      b          c      a         b              \
     a  c      b 
f          - f          Nvec   Nvec   - f        Nvec      Nvec   - 2 f       \
 Nvec      Nvec   - 
 ;a   b       ;a b c                     ;b c          ;a              ;a b c \
       ;
 
             a    c      b                   a      b  c                 a    \
     b  c 
  f      Nvec        Nvec   - 2 f        Nvec   Nvec      - 2 f      Nvec     \
 Nvec      - 
   ;a b        ;c                ;a b c               ;        ;a b        ;c \
       ;
 
             a      b    c             a         b    c        a          b   \
   c 
  f      Nvec   Nvec        - f    Nvec      Nvec        - f          Nvec   \
Nvec   - 
   ;a b               ;c       ;b        ;a        ;c       ;a   b c 
 
      a        b         c                 a  b      c                    a   \
   c    b 
  f        Nvec      Nvec   - 2 f      Nvec      Nvec      - 2 f      Nvec   \
Nvec        - 
   ;a   c        ;b              ;a b        ;         ;c       ;a b          \
     ;c 
 
             a         c    b             b      c      a                   a \
     b      c      d 
  2 f    Nvec      Nvec        - f    Nvec   Nvec          + f          Nvec  \
 Nvec   Nvec   Nvec   + 
     ;a        ;b        ;c       ;b               ;c a       ;a b c d 
 
               a         b      c      d                   a         b      c \
     d 
  f        Nvec      Nvec   Nvec   Nvec   + 2 f        Nvec      Nvec   Nvec  \
 Nvec   + 
   ;b c d        ;a                            ;a b c        ;d 
 
             a           b      c      d                   a      b         c \
     d 
  f      Nvec        Nvec   Nvec   Nvec   + 2 f        Nvec   Nvec      Nvec  \
 Nvec   + 
   ;a b        ;c d                            ;a b c               ;d 
 
               a         b         c      d               a      b           \
c      d 
  2 f      Nvec      Nvec      Nvec   Nvec   + f      Nvec   Nvec        Nvec \
  Nvec   + 
     ;a b        ;c        ;d                   ;a b               ;c d 
 
           a         b           c      d                 a      b      c     \
    d 
  f    Nvec      Nvec        Nvec   Nvec   + f        Nvec   Nvec   Nvec      \
Nvec   + 
   ;b        ;a        ;c d                   ;a b d                      ;c 
 
             a         b      c         d                 a         b      c  \
    d 
  f      Nvec      Nvec   Nvec      Nvec   + 3 f      Nvec      Nvec   Nvec   \
Nvec      + 
   ;b d        ;a               ;c              ;a b        ;c                \
      ;d 
 
             a      b         c      d                a         b      c      \
   d 
  f      Nvec   Nvec      Nvec   Nvec      + f    Nvec      Nvec   Nvec      \
Nvec      + 
   ;a b               ;c               ;d     ;a        ;b               ;c   \
     ;d 
 
           a      b      c         d                      a      b      c     \
 d 
  f    Nvec   Nvec   Nvec      Nvec        + 2 f      Nvec   Nvec   Nvec   \
Nvec        + 
   ;a                      ;c        ;d b       ;a b                          \
   ;d c 
 
             a      b         c      d                  a      b      c      d 
  2 f    Nvec   Nvec      Nvec   Nvec        + f    Nvec   Nvec   Nvec   Nvec
     ;b               ;a               ;d c     ;a                            \
 ;d b c\
\>"], "Output",
 CellChangeTimes->{{3.762891668735474*^9, 3.762891680805183*^9}, {
   3.762891718845901*^9, 3.76289173794816*^9}, 3.762975615507082*^9, 
   3.763063689638784*^9, 3.763065498030395*^9, 3.76440591563361*^9, 
   3.765388183620981*^9, 3.7659961918977633`*^9, 3.766088975057745*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"StepAATwo", "-", "StepAAThree"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", "Temp"}], "Input",
 CellChangeTimes->{{3.762891739796708*^9, 3.762891770595155*^9}}],

Cell[OutputFormData["\<\
0\
\>", "\<\
0\
\>"], "Output",
 CellChangeTimes->{{3.762891745573084*^9, 3.76289177170061*^9}, 
   3.7629756187664423`*^9, 3.763063691864168*^9, 3.763065500128388*^9, 
   3.764405918952104*^9, 3.765388186061142*^9, 3.7659961945310383`*^9, 
   3.766088981297628*^9}]
}, Open  ]],

Cell["The output from the above command should be zero.", "Text",
 CellChangeTimes->{{3.762891772819058*^9, 3.7628917866712217`*^9}}],

Cell[TextData[{
 "We test the alias ",
 StyleBox["Lapf", "Input"],
 "."
}], "Text",
 CellChangeTimes->{{3.7627644828952847`*^9, 3.762764503779745*^9}, 
   3.762852127250988*^9, {3.762891032240436*^9, 3.762891040288322*^9}, {
   3.762892319555184*^9, 3.7628923202428627`*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[TextData[{
 "Here we consider ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[CapitalDelta]", "_"], TraditionalForm]]],
 StyleBox["f",
  FontSlant->"Italic"],
 ", where ",
 StyleBox["f",
  FontSlant->"Italic"],
 "  is a density."
}], "Text",
 CellChangeTimes->{{3.7627645296385927`*^9, 3.762764576508325*^9}, {
   3.762891053544849*^9, 3.762891135371291*^9}, {3.762892364420093*^9, 
   3.762892365180257*^9}, 3.7628927183125143`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"LapHolder", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"L", "[", "i", "]"}], ",", 
     RowBox[{"U", "[", "i", "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", "LapHolder"}], "Input",
 CellChangeTimes->{{3.762892370501306*^9, 3.7628923780992603`*^9}}],

Cell[OutputFormData["\<\
f[] [L[i], U[i]]\
\>", "\<\
    i 
f
 ;i\
\>"], "Output",
 CellChangeTimes->{3.76289237904932*^9, 3.7629757413850737`*^9, 
  3.763063695259322*^9, 3.7630655045293407`*^9, 3.764405922574192*^9, 
  3.765388191790214*^9, 3.765996198235778*^9, 3.766088989125966*^9}]
}, Open  ]],

Cell["\<\
In the above output, derivatives are associated with \[Sum].  Convert the \
above output into alias form.\
\>", "Text",
 CellChangeTimes->{{3.762892643155846*^9, 3.762892650912427*^9}, {
  3.7629757471600037`*^9, 3.7629757820565243`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", "LapHolder"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "LapfToFake"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StepBBOne", "=", "Temp"}], 
  ";"}], "\[IndentingNewLine]", "StepBBOne"}], "Input",
 CellChangeTimes->{{3.762892381612577*^9, 3.762892417468101*^9}}],

Cell[OutputFormData["\<\
Lapf\
\>", "\<\
Lapf\
\>"], "Output",
 CellChangeTimes->{{3.762892406250011*^9, 3.762892418881915*^9}, 
   3.762975791378237*^9, 3.763063696787745*^9, 3.763065505881691*^9, 
   3.7644059238803673`*^9, 3.765388193476069*^9, 3.765996200004601*^9, 
   3.766088990901927*^9}]
}, Open  ]],

Cell["Now expand the alias.", "Text",
 CellChangeTimes->{{3.7628926625482492`*^9, 3.762892670161001*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", "StepBBOne"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "ExpandLapf"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StepBBTwo", "=", "Temp"}], 
  ";"}], "\[IndentingNewLine]", "StepBBTwo"}], "Input",
 CellChangeTimes->{{3.762892423095796*^9, 3.7628924562846127`*^9}}],

Cell[OutputFormData["\<\
f[] [L[a], U[a]] - f[] [L[a], L[b]]*Nvec[U[a]]*Nvec[U[b]] - f[] \
[L[b]]*Nvec[U[a]] [L[a]]*Nvec[U[b]]\
\>", "\<\
    a               a      b             a         b 
f      - f      Nvec   Nvec   - f    Nvec      Nvec
 ;a       ;a b                   ;b        ;a\
\>"], "Output",
 CellChangeTimes->{{3.762892441209125*^9, 3.762892457273131*^9}, 
   3.762975809365322*^9, 3.763063699968014*^9, 3.763065508496265*^9, 
   3.764405926349271*^9, 3.765388195913612*^9, 3.7659962047917128`*^9, 
   3.7660889948760138`*^9}]
}, Open  ]],

Cell["Now test the expansion.", "Text",
 CellChangeTimes->{{3.762892678813142*^9, 3.762892689152998*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"LapSigHatDen", "[", 
    RowBox[{"f", ",", "w"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "Killups"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StepBBThree", "=", "Temp"}], 
  ";"}], "\[IndentingNewLine]", "StepBBThree"}], "Input",
 CellChangeTimes->{{3.762892470121628*^9, 3.76289251706958*^9}}],

Cell[OutputFormData["\<\
f[] [L[a], U[a]] - f[] [L[a], L[b]]*Nvec[U[a]]*Nvec[U[b]] - f[] \
[L[b]]*Nvec[U[a]] [L[a]]*Nvec[U[b]]\
\>", "\<\
    a               a      b             a         b 
f      - f      Nvec   Nvec   - f    Nvec      Nvec
 ;a       ;a b                   ;b        ;a\
\>"], "Output",
 CellChangeTimes->{{3.7628925025018787`*^9, 3.762892518174677*^9}, 
   3.762975820685446*^9, 3.763063701615137*^9, 3.763065509790245*^9, 
   3.764405927862026*^9, 3.765388198335737*^9, 3.7659962067550592`*^9, 
   3.76608899739865*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StepBBTwo", "-", "StepBBThree"}]], "Input",
 CellChangeTimes->{{3.762892521554365*^9, 3.7628925302462997`*^9}}],

Cell[OutputFormData["\<\
0\
\>", "\<\
0\
\>"], "Output",
 CellChangeTimes->{{3.7628925270764503`*^9, 3.762892530954921*^9}, 
   3.762975823703809*^9, 3.763063703749215*^9, 3.763065511766824*^9, 
   3.764405929811252*^9, 3.765388204048456*^9, 3.765996208776353*^9, 
   3.766088999485346*^9}]
}, Open  ]],

Cell["The output from the above command should be zero.", "Text",
 CellChangeTimes->{{3.762892533456091*^9, 3.762892549159033*^9}}],

Cell[TextData[{
 "We now test the alias ",
 StyleBox["fDTwo.", "Input"]
}], "Text",
 CellChangeTimes->{{3.762975845421989*^9, 3.7629760599801292`*^9}, {
  3.7629761497492228`*^9, 3.762976173982633*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[TextData[{
 "Here we consider ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["\[Del]", "_"], "a"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["\[Del]", "_"], "b"], TraditionalForm]]],
 ", where ",
 StyleBox["f",
  FontSlant->"Italic"],
 "  is a density of weight w."
}], "Text",
 CellChangeTimes->{{3.762975845421989*^9, 3.7629760599801292`*^9}, {
  3.7629761497492228`*^9, 3.762976195181673*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"fDTwoHolder", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"L", "[", "b", "]"}], ",", 
     RowBox[{"L", "[", "a", "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", "fDTwoHolder"}], "Input",
 CellChangeTimes->{{3.762976072292553*^9, 3.7629761211026497`*^9}}],

Cell[OutputFormData["\<\
f[] [L[b], L[a]]\
\>", "\<\
f
 ;b a\
\>"], "Output",
 CellChangeTimes->{{3.762976093615312*^9, 3.762976121616529*^9}, {
   3.7629761996691732`*^9, 3.762976228884699*^9}, 3.762976661914948*^9, 
   3.762976820467218*^9, 3.763063706018928*^9, 3.763065513903968*^9, 
   3.764405932093747*^9, 3.7653882103334417`*^9, 3.765996211031969*^9, 
   3.766089006173727*^9}]
}, Open  ]],

Cell["\<\
The derivatives above are associated with \[Sum].  Now convert the expression \
into alias form.\
\>", "Text",
 CellChangeTimes->{{3.762976288065839*^9, 3.762976331150921*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", "fDTwoHolder"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "fDTwoToFake"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StepCCOne", "=", "Temp"}], 
  ";"}], "\[IndentingNewLine]", "StepCCOne"}], "Input",
 CellChangeTimes->{{3.7629760990552597`*^9, 3.762976126909128*^9}, {
  3.7629762070944967`*^9, 3.762976264582273*^9}}],

Cell[OutputFormData["\<\
fDTwo[L[b], L[a]]\
\>", "\<\
fDTwo
     b a\
\>"], "Output",
 CellChangeTimes->{
  3.762976127939847*^9, {3.762976200556204*^9, 3.762976265363759*^9}, 
   3.7629763118469954`*^9, 3.76297682410069*^9, 3.763063707545206*^9, 
   3.763065515539864*^9, 3.7644059333431187`*^9, 3.7653882140823517`*^9, 
   3.765996212370698*^9, 3.7660890107101183`*^9}]
}, Open  ]],

Cell["Now expand the alias.", "Text",
 CellChangeTimes->{{3.762976275210292*^9, 3.762976276110475*^9}, {
  3.762976337559622*^9, 3.76297634592039*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", "StepCCOne"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "ExpandfDTwo"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StepCCTwo", "=", "Temp"}], 
  ";"}], "\[IndentingNewLine]", "StepCCTwo"}], "Input",
 CellChangeTimes->{{3.762976350521677*^9, 3.762976398200225*^9}}],

Cell[OutputFormData["\<\
f[] [L[b], L[a]] - f[] [L[b], L[c]]*Nvec[L[a]]*Nvec[U[c]] - f[] [L[c], \
L[a]]*Nvec[L[b]]*Nvec[U[c]] - 

   f[] [L[c]]*Nvec[L[b]] [L[a]]*Nvec[U[c]] + f[] [L[c], \
L[d]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[U[c]]*Nvec[U[d]] + 

   f[] [L[c]]*Nvec[L[a]]*Nvec[L[b]] [L[d]]*Nvec[U[c]]*Nvec[U[d]]\
\>", "\<\
                           c                      c                       c 
f      - f      Nvec   Nvec   - f      Nvec   Nvec   - f    Nvec      Nvec   + 
 ;b a     ;b c      a            ;c a      b            ;c      b ;a 
 
                           c      d                              c      d 
  f      Nvec   Nvec   Nvec   Nvec   + f    Nvec   Nvec      Nvec   Nvec
   ;c d      a      b                   ;c      a      b ;d\
\>"], "Output",
 CellChangeTimes->{{3.76297638115906*^9, 3.762976399320806*^9}, 
   3.762976828462976*^9, 3.763063709394898*^9, 3.763065517799302*^9, 
   3.764405936703516*^9, 3.765388217338669*^9, 3.765996215309619*^9, 
   3.7660890143140078`*^9}]
}, Open  ]],

Cell["Now test the expansion.", "Text",
 CellChangeTimes->{{3.762976405526289*^9, 3.762976415281114*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"NbNbSigHatDen", "[", 
    RowBox[{"f", ",", "w", ",", 
     RowBox[{"L", "[", "b", "]"}], ",", 
     RowBox[{"L", "[", "a", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "Killups"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StepCCThree", "=", "Temp"}], 
  ";"}], "\[IndentingNewLine]", "StepCCThree"}], "Input",
 CellChangeTimes->{{3.762976438462976*^9, 3.762976485032888*^9}}],

Cell[OutputFormData["\<\
f[] [L[b], L[a]] - f[] [L[b], L[c]]*Nvec[L[a]]*Nvec[U[c]] - f[] [L[c], \
L[a]]*Nvec[L[b]]*Nvec[U[c]] - 

   f[] [L[c]]*Nvec[L[b]] [L[a]]*Nvec[U[c]] + f[] [L[c], \
L[d]]*Nvec[L[a]]*Nvec[L[b]]*Nvec[U[c]]*Nvec[U[d]] + 

   f[] [L[c]]*Nvec[L[a]]*Nvec[L[b]] [L[d]]*Nvec[U[c]]*Nvec[U[d]]\
\>", "\<\
                           c                      c                       c 
f      - f      Nvec   Nvec   - f      Nvec   Nvec   - f    Nvec      Nvec   + 
 ;b a     ;b c      a            ;c a      b            ;c      b ;a 
 
                           c      d                              c      d 
  f      Nvec   Nvec   Nvec   Nvec   + f    Nvec   Nvec      Nvec   Nvec
   ;c d      a      b                   ;c      a      b ;d\
\>"], "Output",
 CellChangeTimes->{{3.7629764689811172`*^9, 3.762976486066927*^9}, 
   3.762976838361112*^9, 3.763063712061481*^9, 3.7630655194411507`*^9, 
   3.764405938315242*^9, 3.7653882191762543`*^9, 3.7659962169237547`*^9, 
   3.76608901637646*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"StepCCTwo", "-", "StepCCThree"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", "Temp"}], "Input",
 CellChangeTimes->{{3.76297650724244*^9, 3.7629765185302258`*^9}}],

Cell[OutputFormData["\<\
0\
\>", "\<\
0\
\>"], "Output",
 CellChangeTimes->{3.7629765191353283`*^9, 3.762976839702722*^9, 
  3.763063713856904*^9, 3.763065521541121*^9, 3.764405940390811*^9, 
  3.765388221692328*^9, 3.765996218837784*^9, 3.766089026651848*^9}]
}, Open  ]],

Cell["The output from the above command should be zero.", "Text",
 CellChangeTimes->{{3.76297652745242*^9, 3.762976543258668*^9}}],

Cell[TextData[{
 "We now test the alias ",
 StyleBox["fDOne.", "Input"]
}], "Text",
 CellChangeTimes->{{3.762975845421989*^9, 3.7629760599801292`*^9}, {
  3.7629761497492228`*^9, 3.762976173982633*^9}, {3.7629766024502897`*^9, 
  3.762976604041731*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[TextData[{
 "Here we consider ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["\[Del]", "_"], "a"], TraditionalForm]]],
 ", where ",
 StyleBox["f",
  FontSlant->"Italic"],
 "  is a density of weight w."
}], "Text",
 CellChangeTimes->{{3.762975845421989*^9, 3.7629760599801292`*^9}, {
  3.7629761497492228`*^9, 3.762976195181673*^9}, {3.7629766071626596`*^9, 
  3.762976609115827*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"fDOneHolder", "=", 
   RowBox[{"f", "[", 
    RowBox[{"L", "[", "a", "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", "fDOneHolder"}], "Input",
 CellChangeTimes->{{3.762976072292553*^9, 3.7629761211026497`*^9}, {
  3.762976612250992*^9, 3.7629766131625433`*^9}, {3.762976646691873*^9, 
  3.7629766541389313`*^9}}],

Cell[OutputFormData["\<\
f[] [L[a]]\
\>", "\<\
f
 ;a\
\>"], "Output",
 CellChangeTimes->{{3.762976093615312*^9, 3.762976121616529*^9}, {
   3.7629761996691732`*^9, 3.762976228884699*^9}, 3.762976614292214*^9, 
   3.762976654733876*^9, 3.762976843872015*^9, 3.763063716939867*^9, 
   3.763065523711134*^9, 3.764405942538555*^9, 3.765388224486318*^9, 
   3.765996221154573*^9, 3.766089029642158*^9}]
}, Open  ]],

Cell["\<\
The derivatives above are associated with \[Sum].  Now convert the expression \
into alias form.\
\>", "Text",
 CellChangeTimes->{{3.762976288065839*^9, 3.762976331150921*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", "fDOneHolder"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "fDOneToFake"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StepDDOne", "=", "Temp"}], 
  ";"}], "\[IndentingNewLine]", "StepDDOne"}], "Input",
 CellChangeTimes->{{3.7629760990552597`*^9, 3.762976126909128*^9}, {
  3.7629762070944967`*^9, 3.762976264582273*^9}, {3.762976621803183*^9, 
  3.762976634906561*^9}}],

Cell[OutputFormData["\<\
fDOne[L[a]]\
\>", "\<\
fDOne
     a\
\>"], "Output",
 CellChangeTimes->{
  3.762976127939847*^9, {3.762976200556204*^9, 3.762976265363759*^9}, 
   3.7629763118469954`*^9, {3.762976636613654*^9, 3.762976656960822*^9}, 
   3.76297684727378*^9, 3.763063718343975*^9, 3.763065525240273*^9, 
   3.7644059443078527`*^9, 3.765388225727675*^9, 3.7659962225285673`*^9, 
   3.7660890308494997`*^9}]
}, Open  ]],

Cell["Now expand the alias.", "Text",
 CellChangeTimes->{{3.762976275210292*^9, 3.762976276110475*^9}, {
  3.762976337559622*^9, 3.76297634592039*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", "StepDDOne"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "ExpandfDOne"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StepDDTwo", "=", "Temp"}], 
  ";"}], "\[IndentingNewLine]", "StepDDTwo"}], "Input",
 CellChangeTimes->{{3.762976350521677*^9, 3.762976398200225*^9}, {
  3.762976670291566*^9, 3.762976687875185*^9}}],

Cell[OutputFormData["\<\
f[] [L[b]]*PiPro[L[a], U[b]]\
\>", "\<\
            b 
f    PiPro
 ;b       a\
\>"], "Output",
 CellChangeTimes->{{3.76297638115906*^9, 3.762976399320806*^9}, 
   3.76297668950527*^9, 3.7629768550507*^9, 3.763063721351615*^9, 
   3.76306552751492*^9, 3.764405946683058*^9, 3.765388228539579*^9, 
   3.765996225279439*^9, 3.766089035216967*^9}]
}, Open  ]],

Cell["Now test the expansion.", "Text",
 CellChangeTimes->{{3.762976405526289*^9, 3.762976415281114*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"NbSigHatDen", "[", 
    RowBox[{"f", ",", "w", ",", 
     RowBox[{"L", "[", "a", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "Killups"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StepDDThree", "=", "Temp"}], 
  ";"}], "\[IndentingNewLine]", "StepDDThree"}], "Input",
 CellChangeTimes->{{3.762976438462976*^9, 3.762976485032888*^9}, {
  3.762976695683691*^9, 3.762976700931628*^9}, {3.7629767652690763`*^9, 
  3.7629767687324*^9}}],

Cell[OutputFormData["\<\
f[] [L[b]]*PiPro[L[a], U[b]]\
\>", "\<\
            b 
f    PiPro
 ;b       a\
\>"], "Output",
 CellChangeTimes->{{3.7629764689811172`*^9, 3.762976486066927*^9}, 
   3.762976701926231*^9, 3.762976769524984*^9, 3.762976805872225*^9, 
   3.762976866302395*^9, 3.7630637237522163`*^9, 3.763065528897599*^9, 
   3.76440594811899*^9, 3.765388229870364*^9, 3.7659962266960163`*^9, 
   3.766089037323811*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"StepDDTwo", "-", "StepDDThree"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", "Temp"}], "Input",
 CellChangeTimes->{{3.76297650724244*^9, 3.7629765185302258`*^9}, {
   3.762976704755554*^9, 3.762976747228093*^9}, 3.762976787612947*^9, {
   3.762976870509635*^9, 3.762976873068741*^9}}],

Cell[OutputFormData["\<\
0\
\>", "\<\
0\
\>"], "Output",
 CellChangeTimes->{3.762976873588509*^9, 3.76306372484418*^9, 
  3.763065530988402*^9, 3.7644059501793747`*^9, 3.765388232161914*^9, 
  3.765996228730966*^9, 3.766089039553898*^9}]
}, Open  ]],

Cell["The output from the above command should be zero.", "Text",
 CellChangeTimes->{{3.76297652745242*^9, 3.762976543258668*^9}}],

Cell[TextData[{
 "We now test the alias ",
 StyleBox["LapTrPSigma", "Input"],
 "."
}], "Text",
 CellChangeTimes->{{3.7629769363283463`*^9, 3.762976950079176*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[TextData[{
 "We test the alias for ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[CapitalDelta]", "_"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    OverscriptBox["J", "_"]}], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{{3.76297697781641*^9, 3.762977044343535*^9}, {
  3.762977082176692*^9, 3.76297709636051*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"LapTrPSigmaHolder", "=", 
   RowBox[{"TrPSigma", "[", 
    RowBox[{
     RowBox[{"L", "[", "a", "]"}], ",", 
     RowBox[{"U", "[", "a", "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", "LapTrPSigmaHolder"}], "Input",
 CellChangeTimes->{{3.7629770585911617`*^9, 3.762977067287609*^9}, {
  3.762977101176512*^9, 3.76297711664812*^9}}],

Cell[OutputFormData["\<\
TrPSigma[] [L[a], U[a]]\
\>", "\<\
           a 
TrPSigma
        ;a\
\>"], "Output",
 CellChangeTimes->{3.762977117430813*^9, 3.7630637280354443`*^9, 
  3.7630655329670553`*^9, 3.764405952440637*^9, 3.765388235058771*^9, 
  3.765996230901293*^9, 3.766089042757303*^9}]
}, Open  ]],

Cell["\<\
The above derivatives are associated with \[Sum].  Now convert to alias form.\
\
\>", "Text",
 CellChangeTimes->{{3.762977129909425*^9, 3.762977158880474*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", "LapTrPSigmaHolder"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "LapTrPSigmaToFake"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StepEEOne", "=", "Temp"}], 
  ";"}], "\[IndentingNewLine]", "StepEEOne"}], "Input",
 CellChangeTimes->{{3.762977178238455*^9, 3.762977212521365*^9}}],

Cell[OutputFormData["\<\
LapTrPSigma\
\>", "\<\
LapTrPSigma\
\>"], "Output",
 CellChangeTimes->{{3.762977193309247*^9, 3.762977213018209*^9}, 
   3.763063729348531*^9, 3.76306553462776*^9, 3.7644059542515707`*^9, 
   3.7653882366510353`*^9, 3.765996232226513*^9, 3.7660890450078697`*^9}]
}, Open  ]],

Cell["Now expand alias.", "Text",
 CellChangeTimes->{{3.762977217515992*^9, 3.762977229330655*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", "StepEEOne"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "ExpandLapTrPSigma"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StepEETwo", "=", "Temp"}], 
  ";"}], "\[IndentingNewLine]", "StepEETwo"}], "Input",
 CellChangeTimes->{{3.762977232556882*^9, 3.76297726472985*^9}}],

Cell[OutputFormData["\<\
-(Nvec[U[a]] [L[a]]*Nvec[U[b]]*TrPSigma[] [L[b]]) - \
Nvec[U[a]]*Nvec[U[b]]*TrPSigma[] [L[a], L[b]] + 

   TrPSigma[] [L[a], U[a]]\
\>", "\<\
     a         b                    a      b                             a 
-Nvec      Nvec   TrPSigma    - Nvec   Nvec   TrPSigma      + TrPSigma
       ;a                 ;b                          ;a b            ;a\
\>"], "Output",
 CellChangeTimes->{3.762977265506214*^9, 3.7630637320927753`*^9, 
  3.76306553677563*^9, 3.76440595719328*^9, 3.765388239399693*^9, 
  3.76599623540029*^9, 3.766089051465876*^9}]
}, Open  ]],

Cell["Now test expansion.", "Text",
 CellChangeTimes->{{3.762977276292232*^9, 3.762977286955233*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"LapSigHatDen", "[", 
    RowBox[{"TrPSigma", ",", "w"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "Killups"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StepEEThree", "=", "Temp"}], 
  ";"}], "\[IndentingNewLine]", "StepEEThree"}], "Input",
 CellChangeTimes->{{3.762977295210868*^9, 3.762977328226625*^9}}],

Cell[OutputFormData["\<\
-(Nvec[U[a]] [L[a]]*Nvec[U[b]]*TrPSigma[] [L[b]]) - \
Nvec[U[a]]*Nvec[U[b]]*TrPSigma[] [L[a], L[b]] + 

   TrPSigma[] [L[a], U[a]]\
\>", "\<\
     a         b                    a      b                             a 
-Nvec      Nvec   TrPSigma    - Nvec   Nvec   TrPSigma      + TrPSigma
       ;a                 ;b                          ;a b            ;a\
\>"], "Output",
 CellChangeTimes->{3.76297732885397*^9, 3.763063733434557*^9, 
  3.76306553802083*^9, 3.764405958470455*^9, 3.765388240914665*^9, 
  3.765996236836768*^9, 3.766089056115488*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"StepEETwo", "-", "StepEEThree"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", "Temp"}], "Input",
 CellChangeTimes->{{3.762977333565567*^9, 3.762977341962839*^9}}],

Cell[OutputFormData["\<\
0\
\>", "\<\
0\
\>"], "Output",
 CellChangeTimes->{3.762977342447171*^9, 3.763063735447425*^9, 
  3.7630655402905188`*^9, 3.7644059602909937`*^9, 3.765388243119676*^9, 
  3.765996239086719*^9, 3.766089057851328*^9}]
}, Open  ]],

Cell["The output from the above command should be zero.", "Text",
 CellChangeTimes->{{3.7629773436941233`*^9, 3.76297735498811*^9}}],

Cell[TextData[{
 "Now test the alias ",
 StyleBox["RhoSigmaDOne", "Input"],
 "."
}], "Text",
 CellChangeTimes->{{3.762977545141156*^9, 3.762977559686577*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[TextData[{
 "We consider ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["\[Del]", "_"], "a"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["P", "_"], 
    StyleBox["bc",
     FontSlant->"Italic"]], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{{3.7629775735758047`*^9, 3.7629776485986*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"RhoSigmaDOneHolder", "=", 
   RowBox[{
    RowBox[{"RhoSigma", "[", 
     RowBox[{
      RowBox[{"L", "[", "b", "]"}], ",", 
      RowBox[{"L", "[", "c", "]"}]}], "]"}], "[", 
    RowBox[{"L", "[", "a", "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", "RhoSigmaDOneHolder"}], "Input",
 CellChangeTimes->{{3.762977665574478*^9, 3.762977687670809*^9}}],

Cell[OutputFormData["\<\
RhoSigma[L[b], L[c]] [L[a]]\
\>", "\<\
RhoSigma
        b c ;a\
\>"], "Output",
 CellChangeTimes->{
  3.762977688118781*^9, {3.762978197350032*^9, 3.762978231276001*^9}, 
   3.763063737529101*^9, 3.76306554362899*^9, 3.7644059623643017`*^9, 
   3.7653882459895563`*^9, 3.765996241313451*^9, 3.766089064772422*^9}]
}, Open  ]],

Cell["\<\
The derivative above is associated with \[Sum].  Convert the above to alias \
form.\
\>", "Text",
 CellChangeTimes->{{3.762977703452804*^9, 3.762977717424552*^9}, {
  3.762978202612932*^9, 3.76297821471702*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", "RhoSigmaDOneHolder"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "RhoSigmaDOneToFake"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StepFFOne", "=", "Temp"}], 
  ";"}], "\[IndentingNewLine]", "StepFFOne"}], "Input",
 CellChangeTimes->{{3.762977826895146*^9, 3.762977844357122*^9}, {
  3.762977935810545*^9, 3.762977943522196*^9}}],

Cell[OutputFormData["\<\
RhoSigmaDOne[L[b], L[c], L[a]]\
\>", "\<\
RhoSigmaDOne
            b c a\
\>"], "Output",
 CellChangeTimes->{3.762977845509551*^9, 3.7629779442182703`*^9, 
  3.762978234144911*^9, 3.763063739073347*^9, 3.7630655450803556`*^9, 
  3.764405963653677*^9, 3.7653882474449167`*^9, 3.765996242811961*^9, 
  3.766089067117015*^9}]
}, Open  ]],

Cell["Now expand alias.", "Text",
 CellChangeTimes->{{3.762977958996944*^9, 3.7629779686514397`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", "StepFFOne"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "ExpandRhoSigmaDOne"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StepFFTwo", "=", "Temp"}], 
  ";"}], "\[IndentingNewLine]", "StepFFTwo"}], "Input",
 CellChangeTimes->{{3.762977737248351*^9, 3.7629777712159777`*^9}, {
  3.762977973803562*^9, 3.7629779927545967`*^9}}],

Cell[OutputFormData["\<\
RhoSigma[L[b], L[c]] [L[a]] - Nvec[L[a]]*Nvec[U[d]]*RhoSigma[L[b], L[c]] \
[L[d]] - 

   Nvec[L[c]]*Nvec[U[d]]*RhoSigma[L[b], L[d]] [L[a]] + \
Nvec[L[a]]*Nvec[L[c]]*Nvec[U[d]]*Nvec[U[e]]*

    RhoSigma[L[b], L[d]] [L[e]] - Nvec[L[b]]*Nvec[U[d]]*RhoSigma[L[d], L[c]] \
[L[a]] + 

   Nvec[L[a]]*Nvec[L[b]]*Nvec[U[d]]*Nvec[U[e]]*RhoSigma[L[d], L[c]] [L[e]] + 

   Nvec[L[b]]*Nvec[L[c]]*Nvec[U[d]]*Nvec[U[e]]*RhoSigma[L[d], L[e]] [L[a]] - 

   Nvec[L[a]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[U[d]]*Nvec[U[e]]*Nvec[U[i]]*RhoSigma[\
L[d], L[e]] [L[i]]\
\>", "\<\
                             d                               d 
RhoSigma        - Nvec   Nvec   RhoSigma        - Nvec   Nvec   RhoSigma      \
  + 
        b c ;a        a                 b c ;d        c                 b d ;a 
 
                    d      e                               d 
  Nvec   Nvec   Nvec   Nvec   RhoSigma        - Nvec   Nvec   RhoSigma        \
+ 
      a      c                        b d ;e        b                 d c ;a 
 
                    d      e                                      d      e 
  Nvec   Nvec   Nvec   Nvec   RhoSigma        + Nvec   Nvec   Nvec   Nvec   \
RhoSigma        - 
      a      b                        d c ;e        b      c                  \
      d e ;a 
 
                           d      e      i 
  Nvec   Nvec   Nvec   Nvec   Nvec   Nvec   RhoSigma
      a      b      c                               d e ;i\
\>"], "Output",
 CellChangeTimes->{
  3.762977772054904*^9, {3.762977986918358*^9, 3.762977996105341*^9}, 
   3.7629782396636333`*^9, 3.763063741067137*^9, 3.763065547346712*^9, 
   3.7644059665741367`*^9, 3.765388250737611*^9, 3.765996246061727*^9, 
   3.766089072294427*^9}]
}, Open  ]],

Cell["Now test expansion.", "Text",
 CellChangeTimes->{{3.762978005232554*^9, 3.762978013291654*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"NbSigHatEtaEta", "[", 
    RowBox[{"RhoSigma", ",", "w", ",", 
     RowBox[{"L", "[", "b", "]"}], ",", 
     RowBox[{"L", "[", "c", "]"}], ",", 
     RowBox[{"L", "[", "a", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "Killups"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StepFFThree", "=", "Temp"}], 
  ";"}], "\[IndentingNewLine]", "StepFFThree"}], "Input",
 CellChangeTimes->{{3.762978024201569*^9, 3.76297810902002*^9}}],

Cell[OutputFormData["\<\
RhoSigma[L[b], L[c]] [L[a]] - Nvec[L[a]]*Nvec[U[d]]*RhoSigma[L[b], L[c]] \
[L[d]] - 

   Nvec[L[c]]*Nvec[U[d]]*RhoSigma[L[b], L[d]] [L[a]] + \
Nvec[L[a]]*Nvec[L[c]]*Nvec[U[d]]*Nvec[U[e]]*

    RhoSigma[L[b], L[d]] [L[e]] - Nvec[L[b]]*Nvec[U[d]]*RhoSigma[L[d], L[c]] \
[L[a]] + 

   Nvec[L[a]]*Nvec[L[b]]*Nvec[U[d]]*Nvec[U[e]]*RhoSigma[L[d], L[c]] [L[e]] + 

   Nvec[L[b]]*Nvec[L[c]]*Nvec[U[d]]*Nvec[U[e]]*RhoSigma[L[d], L[e]] [L[a]] - 

   Nvec[L[a]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[U[d]]*Nvec[U[e]]*Nvec[U[i]]*RhoSigma[\
L[d], L[e]] [L[i]]\
\>", "\<\
                             d                               d 
RhoSigma        - Nvec   Nvec   RhoSigma        - Nvec   Nvec   RhoSigma      \
  + 
        b c ;a        a                 b c ;d        c                 b d ;a 
 
                    d      e                               d 
  Nvec   Nvec   Nvec   Nvec   RhoSigma        - Nvec   Nvec   RhoSigma        \
+ 
      a      c                        b d ;e        b                 d c ;a 
 
                    d      e                                      d      e 
  Nvec   Nvec   Nvec   Nvec   RhoSigma        + Nvec   Nvec   Nvec   Nvec   \
RhoSigma        - 
      a      b                        d c ;e        b      c                  \
      d e ;a 
 
                           d      e      i 
  Nvec   Nvec   Nvec   Nvec   Nvec   Nvec   RhoSigma
      a      b      c                               d e ;i\
\>"], "Output",
 CellChangeTimes->{{3.7629780933428593`*^9, 3.762978109670586*^9}, 
   3.7629782523624353`*^9, 3.763063742729018*^9, 3.763065550122529*^9, 
   3.7644059686550426`*^9, 3.76538825223706*^9, 3.765996247496554*^9, 
   3.766089074650144*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StepFFTwo", "-", "StepFFThree"}]], "Input",
 CellChangeTimes->{{3.762978112191772*^9, 3.762978116276175*^9}}],

Cell[OutputFormData["\<\
0\
\>", "\<\
0\
\>"], "Output",
 CellChangeTimes->{3.762978116789823*^9, 3.762978263333515*^9, 
  3.763063744651287*^9, 3.763065552542457*^9, 3.764405971747781*^9, 
  3.765388254945793*^9, 3.765996249398322*^9, 3.766089076884707*^9}]
}, Open  ]],

Cell["The output from the above command should be zero.", "Text",
 CellChangeTimes->{{3.762978118177374*^9, 3.7629781393574133`*^9}}],

Cell[TextData[{
 "Now test the alias ",
 StyleBox["TrPSigmaDOne", "Input"],
 "."
}], "Text",
 CellChangeTimes->{{3.762978277604555*^9, 3.762978300424238*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[TextData[{
 "We consider ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["\[Del]", "_"], "a"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   OverscriptBox["J", "_"], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{{3.7629775735758047`*^9, 3.7629776485986*^9}, {
  3.762978346487659*^9, 3.762978351495504*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"TrPSigmaDOneHolder", "=", 
   RowBox[{"TrPSigma", "[", 
    RowBox[{"L", "[", "a", "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", "TrPSigmaDOneHolder"}], "Input",
 CellChangeTimes->{{3.76297837908174*^9, 3.762978397239358*^9}}],

Cell[OutputFormData["\<\
TrPSigma[] [L[a]]\
\>", "\<\
TrPSigma
        ;a\
\>"], "Output",
 CellChangeTimes->{
  3.7629783976338997`*^9, {3.7629786163644943`*^9, 3.7629786368428183`*^9}, 
   3.762978714860886*^9, 3.763063746844903*^9, 3.763065555372878*^9, 
   3.764405975061564*^9, 3.7653882574980087`*^9, 3.765996251565444*^9, 
   3.7660890797544003`*^9}]
}, Open  ]],

Cell["\<\
In the above output, the derivative is associated with \[Sum].  Convert to \
alias form.\
\>", "Text",
 CellChangeTimes->{{3.762978400508922*^9, 3.762978406608399*^9}, {
  3.762978651354941*^9, 3.762978668707594*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", "TrPSigmaDOneHolder"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "TrPSigmaDOneToFake"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StepGGOne", "=", "Temp"}], 
  ";"}], "\[IndentingNewLine]", "StepGGOne"}], "Input",
 CellChangeTimes->{{3.762978412639296*^9, 3.762978441200448*^9}}],

Cell[OutputFormData["\<\
TrPSigmaDOne[L[a]]\
\>", "\<\
TrPSigmaDOne
            a\
\>"], "Output",
 CellChangeTimes->{{3.7629784288708687`*^9, 3.762978441959999*^9}, {
   3.7629786269728193`*^9, 3.762978643846732*^9}, 3.762978716732511*^9, 
   3.7630637496999407`*^9, 3.7630655567064533`*^9, 3.764405977355824*^9, 
   3.7653882588500547`*^9, 3.7659962528313227`*^9, 3.7660890814484053`*^9}]
}, Open  ]],

Cell["Now expand the alias.", "Text",
 CellChangeTimes->{{3.762978458564292*^9, 3.76297846903393*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", "StepGGOne"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "ExpandTrPSigmaDOne"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StepGGTwo", "=", "Temp"}], 
  ";"}], "\[IndentingNewLine]", "StepGGTwo"}], "Input",
 CellChangeTimes->{{3.762978472353283*^9, 3.7629784995927477`*^9}}],

Cell[OutputFormData["\<\
PiPro[L[a], U[b]]*TrPSigma[] [L[b]]\
\>", "\<\
       b 
PiPro     TrPSigma
     a            ;b\
\>"], "Output",
 CellChangeTimes->{3.7629785011318493`*^9, 3.762978722651127*^9, 
  3.763063751910084*^9, 3.763065559244132*^9, 3.764405979879775*^9, 
  3.765388261934739*^9, 3.765996257371484*^9, 3.7660890842767353`*^9}]
}, Open  ]],

Cell["Now test the expansion.", "Text",
 CellChangeTimes->{{3.7629785076177187`*^9, 3.76297851750664*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"NbSigHatDen", "[", 
    RowBox[{"TrPSigma", ",", "w", ",", 
     RowBox[{"L", "[", "a", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "Killups"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StepGGThree", "=", "Temp"}], 
  ";"}], "\[IndentingNewLine]", "StepGGThree"}], "Input",
 CellChangeTimes->{{3.762978521873611*^9, 3.762978558346089*^9}}],

Cell[OutputFormData["\<\
PiPro[L[a], U[b]]*TrPSigma[] [L[b]]\
\>", "\<\
       b 
PiPro     TrPSigma
     a            ;b\
\>"], "Output",
 CellChangeTimes->{3.762978558572798*^9, 3.762978732521613*^9, 
  3.763063753203041*^9, 3.763065563177598*^9, 3.764405981037212*^9, 
  3.765388263779396*^9, 3.76599625896266*^9, 3.766089087310711*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StepGGTwo", "-", "StepGGThree"}]], "Input",
 CellChangeTimes->{{3.762978561708445*^9, 3.762978567786126*^9}}],

Cell[OutputFormData["\<\
0\
\>", "\<\
0\
\>"], "Output",
 CellChangeTimes->{3.7629785684193077`*^9, 3.762978734235916*^9, 
  3.763063756292774*^9, 3.7630655653808727`*^9, 3.764405982944257*^9, 
  3.76538826589255*^9, 3.765996260215282*^9, 3.766089089708091*^9}]
}, Open  ]],

Cell["The output from the above command should be zero.", "Text",
 CellChangeTimes->{{3.7629785701251783`*^9, 3.762978586571406*^9}}],

Cell[TextData[{
 "Now test the alias ",
 StyleBox["TfSFFDTwo", "Input"],
 "."
}], "Text",
 CellChangeTimes->{{3.7630638177842484`*^9, 3.7630638382904377`*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[TextData[{
 "We consider ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["\[Del]", "_"], "d"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["\[Del]", "_"], "c"], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["L", "\[SmallCircle]"], 
    StyleBox["ab",
     FontSlant->"Italic"]], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{{3.763063857913254*^9, 3.76306409320998*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"TfSFFDTwoHolder", "=", 
   RowBox[{
    RowBox[{"TfSFF", "[", 
     RowBox[{
      RowBox[{"L", "[", "a", "]"}], ",", 
      RowBox[{"L", "[", "b", "]"}]}], "]"}], "[", 
    RowBox[{
     RowBox[{"L", "[", "c", "]"}], ",", 
     RowBox[{"L", "[", "d", "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", "TfSFFDTwoHolder"}], "Input",
 CellChangeTimes->{{3.763064121020403*^9, 3.76306414170647*^9}}],

Cell[OutputFormData["\<\
TfSFF[L[a], L[b]] [L[c], L[d]]\
\>", "\<\
TfSFF
     a b ;c d\
\>"], "Output",
 CellChangeTimes->{3.763064142593755*^9, 3.7630648987314262`*^9, 
  3.763064953871196*^9, 3.763065567449471*^9, 3.764405985083982*^9, 
  3.765388268224762*^9, 3.765996263344296*^9, 3.76608909842769*^9}]
}, Open  ]],

Cell["\<\
The derivatives in the above expression are intrinsic derivatives associated \
with \[Sum].  We now convert the above expression to alias form.\
\>", "Text",
 CellChangeTimes->{{3.763064149136146*^9, 3.763064198154888*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", "TfSFFDTwoHolder"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "TfSFFDTwoToFake"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StepHHOne", "=", "Temp"}], 
  ";"}], "\[IndentingNewLine]", "StepHHOne"}], "Input",
 CellChangeTimes->{{3.76306420255717*^9, 3.7630642457393293`*^9}}],

Cell[OutputFormData["\<\
TfSFFDTwo[L[a], L[b], L[c], L[d]]\
\>", "\<\
TfSFFDTwo
         a b c d\
\>"], "Output",
 CellChangeTimes->{3.763064246441945*^9, 3.7630649054174833`*^9, 
  3.763064963108534*^9, 3.763065568988204*^9, 3.764405986610015*^9, 
  3.7653882698208857`*^9, 3.765996265404611*^9, 3.766089103355151*^9}]
}, Open  ]],

Cell["Now expand the alias.", "Text",
 CellChangeTimes->{{3.76306425494217*^9, 3.763064261924733*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", "StepHHOne"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "ExpandTfSFFDTwo"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "Killups"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StepHHTwo", "=", "Temp"}], 
  ";"}], "\[IndentingNewLine]", "StepHHTwo"}], "Input",
 CellChangeTimes->{{3.76306426450181*^9, 3.7630643093724003`*^9}, 
   3.763064891619442*^9, 3.7630652729354477`*^9}],

Cell[OutputFormData["\<\
-(Nvec[L[c]] [L[d]]*Nvec[U[e]]*TfSFF[L[a], L[b]] [L[e]]) + Nvec[L[c]] \\
[L[e]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*
  TfSFF[L[a], L[b]] [L[i]] + TfSFF[L[a], L[b]] [L[c], L[d]] - 

   Nvec[L[d]]*Nvec[U[e]]*TfSFF[L[a], L[b]] [L[c], L[e]] - 

   Nvec[L[c]]*Nvec[U[e]]*TfSFF[L[a], L[b]] [L[e], L[d]] + \
Nvec[L[c]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*

    TfSFF[L[a], L[b]] [L[e], L[i]] - Nvec[L[b]] [L[d]]*Nvec[U[e]]*TfSFF[L[a], \
L[e]] [L[c]] + 

   Nvec[L[b]] [L[d]]*Nvec[L[c]]*Nvec[U[e]]*Nvec[U[i]]*TfSFF[L[a], L[e]] \
[L[i]] + 

   Nvec[L[b]]*Nvec[L[c]] [L[d]]*Nvec[U[e]]*Nvec[U[i]]*TfSFF[L[a], L[e]] \
[L[i]] - 

   Nvec[L[b]]*Nvec[U[e]]*TfSFF[L[a], L[e]] [L[c], L[d]] + \
Nvec[L[b]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*

    TfSFF[L[a], L[e]] [L[c], L[i]] + \
Nvec[L[b]]*Nvec[L[c]]*Nvec[U[e]]*Nvec[U[i]]*

    TfSFF[L[a], L[e]] [L[i], L[d]] - \
Nvec[L[b]]*Nvec[L[c]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*

    TfSFF[L[a], L[e]] [L[i], L[j]] + Nvec[L[b]] \
[L[e]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*

    TfSFF[L[a], L[i]] [L[c]] - Nvec[L[b]] \
[L[e]]*Nvec[L[c]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*

    TfSFF[L[a], L[i]] [L[j]] - Nvec[L[b]]*Nvec[L[c]] \
[L[e]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*

    TfSFF[L[a], L[i]] [L[j]] - Nvec[L[a]] [L[d]]*Nvec[U[e]]*TfSFF[L[b], L[e]] \
[L[c]] + 

   Nvec[L[a]] [L[d]]*Nvec[L[c]]*Nvec[U[e]]*Nvec[U[i]]*TfSFF[L[b], L[e]] \
[L[i]] + 

   Nvec[L[a]]*Nvec[L[c]] [L[d]]*Nvec[U[e]]*Nvec[U[i]]*TfSFF[L[b], L[e]] \
[L[i]] - 

   Nvec[L[a]]*Nvec[U[e]]*TfSFF[L[b], L[e]] [L[c], L[d]] + \
Nvec[L[a]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*

    TfSFF[L[b], L[e]] [L[c], L[i]] + \
Nvec[L[a]]*Nvec[L[c]]*Nvec[U[e]]*Nvec[U[i]]*

    TfSFF[L[b], L[e]] [L[i], L[d]] - \
Nvec[L[a]]*Nvec[L[c]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*

    TfSFF[L[b], L[e]] [L[i], L[j]] + Nvec[L[a]] \
[L[e]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*

    TfSFF[L[b], L[i]] [L[c]] - Nvec[L[a]] \
[L[e]]*Nvec[L[c]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*

    TfSFF[L[b], L[i]] [L[j]] - Nvec[L[a]]*Nvec[L[c]] \
[L[e]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*

    TfSFF[L[b], L[i]] [L[j]] + Nvec[L[a]] \
[L[d]]*Nvec[L[b]]*Nvec[U[e]]*Nvec[U[i]]*TfSFF[L[e], L[i]] [L[c]] + 

   Nvec[L[a]]*Nvec[L[b]] [L[d]]*Nvec[U[e]]*Nvec[U[i]]*TfSFF[L[e], L[i]] \
[L[c]] - 

   Nvec[L[a]] \
[L[d]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*TfSFF[L[e], \
L[i]] [L[j]] - 

   Nvec[L[a]]*Nvec[L[b]] \
[L[d]]*Nvec[L[c]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*TfSFF[L[e], L[i]] [L[j]] - 

   Nvec[L[a]]*Nvec[L[b]]*Nvec[L[c]] \
[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*TfSFF[L[e], L[i]] [L[j]] + 

   Nvec[L[a]]*Nvec[L[b]]*Nvec[U[e]]*Nvec[U[i]]*TfSFF[L[e], L[i]] [L[c], L[d]] \
- 

   Nvec[L[a]]*Nvec[L[b]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*TfSFF[L[\
e], L[i]] [L[c], L[j]] - 

   Nvec[L[a]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*TfSFF[L[\
e], L[i]] [L[j], L[d]] + 

   Nvec[L[a]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]\
]*Nvec[U[k]]*

    TfSFF[L[e], L[i]] [L[j], L[k]] - Nvec[L[a]] \\
[L[e]]*Nvec[L[b]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*
  TfSFF[L[i], L[j]] [L[c]] - \\
Nvec[L[a]]*Nvec[L[b]] [L[e]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*
  TfSFF[L[i], L[j]] [L[c]] + \\
Nvec[L[a]] [L[e]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*
  Nvec[U[j]]*Nvec[U[k]]*TfSFF[L[i], \\
L[j]] [L[k]] + Nvec[L[a]]*Nvec[L[b]] [L[e]]*Nvec[L[c]]*Nvec[L[d]]*
  \\
Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*Nvec[U[k]]*TfSFF[L[i], L[j]] [L[k]] + 
 Nvec[L[a]]*Nvec[L[b]]*Nvec[L[c]] \\
[L[e]]*Nvec[L[d]]*Nvec[U[e]]*Nvec[U[i]]*Nvec[U[j]]*Nvec[U[k]]*
  TfSFF[L[i], L[j]] [L[k]]\
\>", "\<\
               e                                      e      i 
-Nvec      Nvec   TfSFF        + Nvec      Nvec   Nvec   Nvec   TfSFF        \
+ TfSFF          - 
     c ;d              a b ;e        c ;e      d                     a b ;i   \
      a b ;c d 
 
             e                              e                                 \
    e      i 
  Nvec   Nvec   TfSFF          - Nvec   Nvec   TfSFF          + Nvec   Nvec   \
Nvec   Nvec   TfSFF          - 
      d              a b ;c e        c              a b ;e d        c      d  \
                   a b ;e i 
 
                e                                      e      i 
  Nvec      Nvec   TfSFF        + Nvec      Nvec   Nvec   Nvec   TfSFF        \
+ 
      b ;d              a e ;c        b ;d      c                     a e ;i 
 
                       e      i                            e 
  Nvec   Nvec      Nvec   Nvec   TfSFF        - Nvec   Nvec   TfSFF          + 
      b      c ;d                     a e ;i        b              a e ;c d 
 
                    e      i                                     e      i 
  Nvec   Nvec   Nvec   Nvec   TfSFF          + Nvec   Nvec   Nvec   Nvec   \
TfSFF          - 
      b      d                     a e ;c i        b      c                   \
  a e ;i d 
 
                           e      i      j                                    \
    e      i 
  Nvec   Nvec   Nvec   Nvec   Nvec   Nvec   TfSFF          + Nvec      Nvec   \
Nvec   Nvec   TfSFF        - 
      b      c      d                            a e ;i j        b ;e      d  \
                   a i ;c 
 
                              e      i      j 
  Nvec      Nvec   Nvec   Nvec   Nvec   Nvec   TfSFF        - 
      b ;e      c      d                            a i ;j 
 
                              e      i      j                               e \

  Nvec   Nvec      Nvec   Nvec   Nvec   Nvec   TfSFF        - Nvec      Nvec  \
 TfSFF        + 
      b      c ;e      d                            a i ;j        a ;d        \
      b e ;c 
 
                       e      i                                      e      i \

  Nvec      Nvec   Nvec   Nvec   TfSFF        + Nvec   Nvec      Nvec   Nvec  \
 TfSFF        - 
      a ;d      c                     b e ;i        a      c ;d               \
      b e ;i 
 
             e                                     e      i 
  Nvec   Nvec   TfSFF          + Nvec   Nvec   Nvec   Nvec   TfSFF          + \

      a              b e ;c d        a      d                     b e ;c i 
 
                    e      i                                            e     \
 i      j 
  Nvec   Nvec   Nvec   Nvec   TfSFF          - Nvec   Nvec   Nvec   Nvec   \
Nvec   Nvec   TfSFF          + 
      a      c                     b e ;i d        a      c      d            \
                b e ;i j 
 
                       e      i                                             e \
     i      j 
  Nvec      Nvec   Nvec   Nvec   TfSFF        - Nvec      Nvec   Nvec   Nvec  \
 Nvec   Nvec   TfSFF        - 
      a ;e      d                     b i ;c        a ;e      c      d        \
                    b i ;j 
 
                              e      i      j                                 \
     e      i 
  Nvec   Nvec      Nvec   Nvec   Nvec   Nvec   TfSFF        + Nvec      Nvec  \
 Nvec   Nvec   TfSFF        + 
      a      c ;e      d                            b i ;j        a ;d      b \
                    e i ;c 
 
                       e      i                                             e \
     i      j 
  Nvec   Nvec      Nvec   Nvec   TfSFF        - Nvec      Nvec   Nvec   Nvec  \
 Nvec   Nvec   TfSFF        - 
      a      b ;d                     e i ;c        a ;d      b      c        \
                    e i ;j 
 
                              e      i      j 
  Nvec   Nvec      Nvec   Nvec   Nvec   Nvec   TfSFF        - 
      a      b ;d      c                            e i ;j 
 
                              e      i      j                                 \
  e      i 
  Nvec   Nvec   Nvec      Nvec   Nvec   Nvec   TfSFF        + Nvec   Nvec   \
Nvec   Nvec   TfSFF          - 
      a      b      c ;d                            e i ;j        a      b    \
                 e i ;c d 
 
                           e      i      j 
  Nvec   Nvec   Nvec   Nvec   Nvec   Nvec   TfSFF          - 
      a      b      d                            e i ;c j 
 
                           e      i      j 
  Nvec   Nvec   Nvec   Nvec   Nvec   Nvec   TfSFF          + 
      a      b      c                            e i ;j d 
 
                                  e      i      j      k 
  Nvec   Nvec   Nvec   Nvec   Nvec   Nvec   Nvec   Nvec   TfSFF          - 
      a      b      c      d                                   e i ;j k 
 
                              e      i      j 
  Nvec      Nvec   Nvec   Nvec   Nvec   Nvec   TfSFF        - 
      a ;e      b      d                            i j ;c 
 
                              e      i      j 
  Nvec   Nvec      Nvec   Nvec   Nvec   Nvec   TfSFF        + 
      a      b ;e      d                            i j ;c 
 
                                     e      i      j      k 
  Nvec      Nvec   Nvec   Nvec   Nvec   Nvec   Nvec   Nvec   TfSFF        + 
      a ;e      b      c      d                                   i j ;k 
 
                                     e      i      j      k 
  Nvec   Nvec      Nvec   Nvec   Nvec   Nvec   Nvec   Nvec   TfSFF        + 
      a      b ;e      c      d                                   i j ;k 
 
                                     e      i      j      k 
  Nvec   Nvec   Nvec      Nvec   Nvec   Nvec   Nvec   Nvec   TfSFF
      a      b      c ;e      d                                   i j ;k\
\>"], "Output",
 CellChangeTimes->{3.763065274244648*^9, 3.7630655712466*^9, 
  3.76440598908832*^9, 3.765388272635408*^9, 3.76599627160793*^9, 
  3.766089112781947*^9}]
}, Open  ]],

Cell["Now test the expansion.", "Text",
 CellChangeTimes->{{3.7630643437675943`*^9, 3.7630643542937517`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"NbNbSigHatEtaEta", "[", 
    RowBox[{"TfSFF", ",", "w", ",", 
     RowBox[{"L", "[", "a", "]"}], ",", 
     RowBox[{"L", "[", "b", "]"}], ",", 
     RowBox[{"L", "[", "c", "]"}], ",", 
     RowBox[{"L", "[", "d", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "Killups"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StepHHThree", "=", "Temp"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"StepHHThree", ";"}]}], "Input",
 CellChangeTimes->{{3.7630643644880877`*^9, 3.7630644419578133`*^9}, {
  3.763064789649784*^9, 3.763064834386668*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StepHHTwo", "-", "StepHHThree"}]], "Input",
 CellChangeTimes->{{3.76306483877701*^9, 3.763064843313951*^9}}],

Cell[OutputFormData["\<\
0\
\>", "\<\
0\
\>"], "Output",
 CellChangeTimes->{3.763064844023707*^9, 3.763064989219638*^9, 
  3.763065576622485*^9, 3.764405996553488*^9, 3.76538828742258*^9, 
  3.765996282026744*^9, 3.76608914893585*^9}]
}, Open  ]],

Cell["The output from the above command should be zero.", "Text",
 CellChangeTimes->{{3.7630648482505713`*^9, 3.763064860035397*^9}}],

Cell[TextData[{
 "Now test the alias ",
 StyleBox["TfSFFDOne", "Input"],
 "."
}], "Text",
 CellChangeTimes->{{3.7630638177842484`*^9, 3.7630638382904377`*^9}, {
  3.763065037532517*^9, 3.763065039732107*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[TextData[{
 "We consider ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["\[Del]", "_"], "c"], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["L", "\[SmallCircle]"], 
    StyleBox["ab",
     FontSlant->"Italic"]], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{{3.763063857913254*^9, 3.76306409320998*^9}, {
  3.763065044364635*^9, 3.763065047206951*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"TfSFFDOneHolder", "=", 
   RowBox[{
    RowBox[{"TfSFF", "[", 
     RowBox[{
      RowBox[{"L", "[", "a", "]"}], ",", 
      RowBox[{"L", "[", "b", "]"}]}], "]"}], "[", 
    RowBox[{"L", "[", "c", "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", "TfSFFDOneHolder"}], "Input",
 CellChangeTimes->{{3.763064121020403*^9, 3.76306414170647*^9}, {
  3.763065050893208*^9, 3.7630650629571047`*^9}}],

Cell[OutputFormData["\<\
TfSFF[L[a], L[b]] [L[c]]\
\>", "\<\
TfSFF
     a b ;c\
\>"], "Output",
 CellChangeTimes->{3.763064142593755*^9, 3.7630648987314262`*^9, 
  3.763064953871196*^9, 3.763065063886854*^9, 3.763065223648877*^9, 
  3.763065280781618*^9, 3.763065579391831*^9, 3.764405998956962*^9, 
  3.765388289759877*^9, 3.765996284880301*^9, 3.766089152515642*^9}]
}, Open  ]],

Cell["\<\
The derivative in the above expression is associated with \[Sum].  We now \
convert the above expression to alias form.\
\>", "Text",
 CellChangeTimes->{{3.763064149136146*^9, 3.763064198154888*^9}, {
  3.763065807254477*^9, 3.763065820406295*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", "TfSFFDOneHolder"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "TfSFFDOneToFake"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StepIIOne", "=", "Temp"}], 
  ";"}], "\[IndentingNewLine]", "StepIIOne"}], "Input",
 CellChangeTimes->{{3.76306420255717*^9, 3.7630642457393293`*^9}, {
  3.763065073765293*^9, 3.763065088892798*^9}}],

Cell[OutputFormData["\<\
TfSFFDOne[L[a], L[b], L[c]]\
\>", "\<\
TfSFFDOne
         a b c\
\>"], "Output",
 CellChangeTimes->{3.763064246441945*^9, 3.7630649054174833`*^9, 
  3.763064963108534*^9, 3.763065091140093*^9, 3.763065230501066*^9, 
  3.7630652850100183`*^9, 3.7630655821826963`*^9, 3.764406000309182*^9, 
  3.765388291164014*^9, 3.765996286524742*^9, 3.7660891554148083`*^9}]
}, Open  ]],

Cell["Now expand the alias.", "Text",
 CellChangeTimes->{{3.76306425494217*^9, 3.763064261924733*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", "StepIIOne"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "ExpandTfSFFDOne"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "Killups"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StepIITwo", "=", "Temp"}], 
  ";"}], "\[IndentingNewLine]", "StepIITwo"}], "Input",
 CellChangeTimes->{{3.76306426450181*^9, 3.7630643093724003`*^9}, 
   3.763064891619442*^9, {3.763065095301279*^9, 3.763065119221798*^9}}],

Cell[OutputFormData["\<\
TfSFF[L[a], L[b]] [L[c]] - Nvec[L[c]]*Nvec[U[d]]*TfSFF[L[a], L[b]] [L[d]] - 

   Nvec[L[b]]*Nvec[U[d]]*TfSFF[L[a], L[d]] [L[c]] + \
Nvec[L[b]]*Nvec[L[c]]*Nvec[U[d]]*Nvec[U[e]]*

    TfSFF[L[a], L[d]] [L[e]] - Nvec[L[a]]*Nvec[U[d]]*TfSFF[L[b], L[d]] [L[c]] \
+ 

   Nvec[L[a]]*Nvec[L[c]]*Nvec[U[d]]*Nvec[U[e]]*TfSFF[L[b], L[d]] [L[e]] + 

   Nvec[L[a]]*Nvec[L[b]]*Nvec[U[d]]*Nvec[U[e]]*TfSFF[L[d], L[e]] [L[c]] - 

   Nvec[L[a]]*Nvec[L[b]]*Nvec[L[c]]*Nvec[U[d]]*Nvec[U[e]]*Nvec[U[i]]*TfSFF[L[\
d], L[e]] [L[i]]\
\>", "\<\
                          d                            d 
TfSFF        - Nvec   Nvec   TfSFF        - Nvec   Nvec   TfSFF        + 
     a b ;c        c              a b ;d        b              a d ;c 
 
                    d      e                            d 
  Nvec   Nvec   Nvec   Nvec   TfSFF        - Nvec   Nvec   TfSFF        + 
      b      c                     a d ;e        a              b d ;c 
 
                    d      e                                   d      e 
  Nvec   Nvec   Nvec   Nvec   TfSFF        + Nvec   Nvec   Nvec   Nvec   \
TfSFF        - 
      a      c                     b d ;e        a      b                     \
d e ;c 
 
                           d      e      i 
  Nvec   Nvec   Nvec   Nvec   Nvec   Nvec   TfSFF
      a      b      c                            d e ;i\
\>"], "Output",
 CellChangeTimes->{3.763065120110908*^9, 3.7630652345390873`*^9, 
  3.763065294796523*^9, 3.763065583889103*^9, 3.764406002701232*^9, 
  3.7653882935282507`*^9, 3.765996289263335*^9, 3.766089160721393*^9}]
}, Open  ]],

Cell["Now test the expansion.", "Text",
 CellChangeTimes->{{3.7630643437675943`*^9, 3.7630643542937517`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"NbSigHatEtaEta", "[", 
    RowBox[{"TfSFF", ",", "w", ",", 
     RowBox[{"L", "[", "a", "]"}], ",", 
     RowBox[{"L", "[", "b", "]"}], ",", 
     RowBox[{"L", "[", "c", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "Killups"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StepIIThree", "=", "Temp"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"StepIIThree", ";"}]}], "Input",
 CellChangeTimes->{{3.7630643644880877`*^9, 3.7630644419578133`*^9}, {
  3.763064789649784*^9, 3.763064834386668*^9}, {3.763065128718145*^9, 
  3.76306515172575*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StepIITwo", "-", "StepIIThree"}]], "Input",
 CellChangeTimes->{{3.76306483877701*^9, 3.763064843313951*^9}, {
  3.763065164438081*^9, 3.7630651806301603`*^9}}],

Cell[OutputFormData["\<\
0\
\>", "\<\
0\
\>"], "Output",
 CellChangeTimes->{3.763064844023707*^9, 3.763064989219638*^9, 
  3.7630651824375477`*^9, 3.763065311318795*^9, 3.763065587031721*^9, 
  3.764406009303875*^9, 3.765388297897554*^9, 3.7659962949766417`*^9, 
  3.766089171093265*^9}]
}, Open  ]],

Cell["The output from the above command should be zero.", "Text",
 CellChangeTimes->{{3.7630648482505713`*^9, 3.763064860035397*^9}}],

Cell["Set the default output format type.", "Text",
 CellChangeTimes->{{3.765879093989146*^9, 3.765879105330894*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[TextData[{
 "To obtain graphical output in future ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " work sessions, you will probably need to set the default output format \
type to either \[OpenCurlyDoubleQuote]",
 StyleBox["TraditionalForm", "Input"],
 "\[CloseCurlyDoubleQuote] or \[OpenCurlyDoubleQuote]",
 StyleBox["StandardForm", "Input"],
 ".\[CloseCurlyDoubleQuote]  Commands for doing this appear below.  I have \
also included a command which sets the default output format type to \
\[OpenCurlyDoubleQuote]",
 StyleBox["InputForm", "Input"],
 ",\[CloseCurlyDoubleQuote] but this default output format type will probably \
produce undesirable results.  If you are about to end the current ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " work session, I would suggest that you run the second or third of the \
three commands that follow below."
}], "Text",
 CellChangeTimes->{{3.765875392064986*^9, 3.765875400456007*^9}, {
   3.76587834324405*^9, 3.765878394132082*^9}, {3.765878426413321*^9, 
   3.765878445061092*^9}, {3.765961193069166*^9, 3.765961194076791*^9}, {
   3.7659663532701883`*^9, 3.765966465475971*^9}, {3.765966856155119*^9, 
   3.765966861099286*^9}, {3.765967018581056*^9, 3.765967086149837*^9}, {
   3.765967317464937*^9, 3.765967361792934*^9}, {3.765967508707835*^9, 
   3.765967542084031*^9}, {3.7659676087017612`*^9, 3.765967609572803*^9}, 
   3.765969161406293*^9, {3.7659703321643476`*^9, 3.7659703333552847`*^9}}],

Cell[TextData[{
 "The following command sets the default output format type to \
\[OpenCurlyDoubleQuote]",
 StyleBox["InputForm", "Input"],
 ".\[CloseCurlyDoubleQuote]  This may produce undesirable results."
}], "Text",
 CellChangeTimes->{{3.765966621690692*^9, 3.765966665064301*^9}}],

Cell[BoxData[
 RowBox[{"<<", "~/bop/gen/dtm/definp.m"}]], "Input",
 CellChangeTimes->{{3.765966474501273*^9, 3.765966489902224*^9}}],

Cell[TextData[{
 "The following command sets the default output format type to \
\[OpenCurlyDoubleQuote]",
 StyleBox["TraditionalForm", "Input"],
 ".\[CloseCurlyDoubleQuote]"
}], "Text",
 CellChangeTimes->{{3.7659666838835278`*^9, 3.765966720265163*^9}}],

Cell[BoxData[
 RowBox[{"<<", "~/bop/gen/dtm/deftra.m"}]], "Input",
 CellChangeTimes->{{3.765878480491482*^9, 3.765878494045458*^9}}],

Cell[TextData[{
 "The following command sets the default output format type to \
\[OpenCurlyDoubleQuote]Standard",
 StyleBox["Form", "Input"],
 ".\[CloseCurlyDoubleQuote]"
}], "Text",
 CellChangeTimes->{{3.7659666838835278`*^9, 3.7659667382811604`*^9}}],

Cell[BoxData[
 RowBox[{"<<", "~/bop/gen/dtm/defstd.m"}]], "Input",
 CellChangeTimes->{{3.765878480491482*^9, 3.765878510741659*^9}}]
},
WindowSize->{1837, 1060},
WindowMargins->{{0, Automatic}, {83, 30}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"Magnification"->1,
"PaperOrientation"->"Portrait",
"PaperSize"->{597.562, 842.375},
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "home", 
   "lawrence_peterson", "rsc", "Rod", "pfa"}, "OutPfaff.ps", 
  CharacterEncoding -> "iso8859-1"]},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
Magnification->2.,
FrontEndVersion->"11.0 for Linux x86 (64-bit) (September 21, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 317, 6, 76, "Text"],
Cell[878, 28, 2154, 34, 486, "Text"],
Cell[3035, 64, 435, 9, 97, "Text"],
Cell[3473, 75, 6896, 159, 1666, "Text"],
Cell[10372, 236, 149, 2, 96, "Text"],
Cell[10524, 240, 1062, 18, 106, "Text"],
Cell[11589, 260, 133, 2, 63, "Input"],
Cell[11725, 264, 220, 3, 96, "Text"],
Cell[11948, 269, 959, 16, 65, "Text"],
Cell[CellGroupData[{
Cell[12932, 289, 296, 6, 65, "Input"],
Cell[13231, 297, 1085, 22, 162, "Output"]
}, Open  ]],
Cell[14331, 322, 183, 6, 65, "Text"],
Cell[CellGroupData[{
Cell[14539, 332, 99, 1, 63, "Input"],
Cell[14641, 335, 277, 7, 75, "Output"]
}, Open  ]],
Cell[14933, 345, 175, 6, 65, "Text"],
Cell[CellGroupData[{
Cell[15133, 355, 238, 4, 63, "Input"],
Cell[15374, 361, 475, 10, 212, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15886, 376, 1353, 33, 667, "Input"],
Cell[17242, 411, 472, 9, 80, "Print"]
}, Open  ]],
Cell[17729, 423, 140, 2, 96, "Text"],
Cell[17872, 427, 586, 12, 192, "Text"],
Cell[CellGroupData[{
Cell[18483, 443, 218, 4, 65, "Input"],
Cell[18704, 449, 306, 4, 47, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19047, 458, 291, 8, 107, "Input"],
Cell[19341, 468, 214, 7, 124, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19592, 480, 131, 2, 63, "Input"],
Cell[19726, 484, 367, 9, 103, "Output"]
}, Open  ]],
Cell[20108, 496, 258, 7, 96, "Text"],
Cell[20369, 505, 441, 15, 70, "Text"],
Cell[CellGroupData[{
Cell[20835, 524, 394, 10, 107, "Input"],
Cell[21232, 536, 361, 10, 146, "Output"]
}, Open  ]],
Cell[21608, 549, 310, 6, 106, "Text"],
Cell[CellGroupData[{
Cell[21943, 559, 463, 12, 193, "Input"],
Cell[22409, 573, 307, 8, 103, "Output"]
}, Open  ]],
Cell[22731, 584, 104, 1, 64, "Text"],
Cell[CellGroupData[{
Cell[22860, 589, 526, 15, 236, "Input"],
Cell[23389, 606, 5972, 157, 1193, "Output"]
}, Open  ]],
Cell[29376, 766, 160, 2, 64, "Text"],
Cell[CellGroupData[{
Cell[29561, 772, 1164, 36, 408, "Input"],
Cell[30728, 810, 6044, 158, 1193, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[36809, 973, 358, 10, 150, "Input"],
Cell[37170, 985, 291, 8, 103, "Output"]
}, Open  ]],
Cell[37476, 996, 133, 1, 64, "Text"],
Cell[37612, 999, 307, 8, 96, "Text"],
Cell[37922, 1009, 439, 14, 66, "Text"],
Cell[CellGroupData[{
Cell[38386, 1027, 300, 8, 107, "Input"],
Cell[38689, 1037, 287, 9, 146, "Output"]
}, Open  ]],
Cell[38991, 1049, 248, 5, 64, "Text"],
Cell[CellGroupData[{
Cell[39264, 1058, 519, 15, 236, "Input"],
Cell[39786, 1075, 296, 8, 103, "Output"]
}, Open  ]],
Cell[40097, 1086, 105, 1, 64, "Text"],
Cell[CellGroupData[{
Cell[40227, 1091, 521, 15, 236, "Input"],
Cell[40751, 1108, 542, 11, 146, "Output"]
}, Open  ]],
Cell[41308, 1122, 105, 1, 64, "Text"],
Cell[CellGroupData[{
Cell[41438, 1127, 576, 17, 236, "Input"],
Cell[42017, 1146, 541, 11, 146, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42595, 1162, 135, 2, 63, "Input"],
Cell[42733, 1166, 290, 8, 103, "Output"]
}, Open  ]],
Cell[43038, 1177, 131, 1, 64, "Text"],
Cell[43172, 1180, 234, 6, 96, "Text"],
Cell[43409, 1188, 457, 16, 66, "Text"],
Cell[CellGroupData[{
Cell[43891, 1208, 304, 8, 107, "Input"],
Cell[44198, 1218, 385, 10, 124, "Output"]
}, Open  ]],
Cell[44598, 1231, 186, 4, 64, "Text"],
Cell[CellGroupData[{
Cell[44809, 1239, 456, 12, 193, "Input"],
Cell[45268, 1253, 371, 10, 124, "Output"]
}, Open  ]],
Cell[45654, 1266, 151, 2, 64, "Text"],
Cell[CellGroupData[{
Cell[45830, 1272, 520, 15, 236, "Input"],
Cell[46353, 1289, 1004, 20, 233, "Output"]
}, Open  ]],
Cell[47372, 1312, 105, 1, 64, "Text"],
Cell[CellGroupData[{
Cell[47502, 1317, 779, 23, 279, "Input"],
Cell[48284, 1342, 1010, 20, 233, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[49331, 1367, 240, 6, 107, "Input"],
Cell[49574, 1375, 260, 7, 103, "Output"]
}, Open  ]],
Cell[49849, 1385, 130, 1, 64, "Text"],
Cell[49982, 1388, 285, 7, 96, "Text"],
Cell[50270, 1397, 405, 13, 66, "Text"],
Cell[CellGroupData[{
Cell[50700, 1414, 349, 8, 107, "Input"],
Cell[51052, 1424, 397, 10, 124, "Output"]
}, Open  ]],
Cell[51464, 1437, 186, 4, 64, "Text"],
Cell[CellGroupData[{
Cell[51675, 1445, 505, 13, 193, "Input"],
Cell[52183, 1460, 413, 11, 124, "Output"]
}, Open  ]],
Cell[52611, 1474, 151, 2, 64, "Text"],
Cell[CellGroupData[{
Cell[52787, 1480, 569, 16, 236, "Input"],
Cell[53359, 1498, 368, 10, 146, "Output"]
}, Open  ]],
Cell[53742, 1511, 105, 1, 64, "Text"],
Cell[CellGroupData[{
Cell[53872, 1516, 834, 24, 279, "Input"],
Cell[54709, 1542, 426, 11, 146, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[55172, 1558, 362, 8, 135, "Input"],
Cell[55537, 1568, 237, 7, 103, "Output"]
}, Open  ]],
Cell[55789, 1578, 130, 1, 64, "Text"],
Cell[55922, 1581, 194, 6, 96, "Text"],
Cell[56119, 1589, 354, 12, 68, "Text"],
Cell[CellGroupData[{
Cell[56498, 1605, 371, 9, 135, "Input"],
Cell[56872, 1616, 294, 9, 146, "Output"]
}, Open  ]],
Cell[57181, 1628, 169, 4, 64, "Text"],
Cell[CellGroupData[{
Cell[57375, 1636, 415, 11, 221, "Input"],
Cell[57793, 1649, 287, 7, 103, "Output"]
}, Open  ]],
Cell[58095, 1659, 99, 1, 64, "Text"],
Cell[CellGroupData[{
Cell[58219, 1664, 525, 15, 264, "Input"],
Cell[58747, 1681, 582, 12, 146, "Output"]
}, Open  ]],
Cell[59344, 1696, 101, 1, 64, "Text"],
Cell[CellGroupData[{
Cell[59470, 1701, 584, 17, 264, "Input"],
Cell[60057, 1720, 581, 12, 146, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[60675, 1737, 239, 6, 135, "Input"],
Cell[60917, 1745, 240, 7, 103, "Output"]
}, Open  ]],
Cell[61172, 1755, 132, 1, 64, "Text"],
Cell[61307, 1758, 190, 6, 96, "Text"],
Cell[61500, 1766, 358, 14, 68, "Text"],
Cell[CellGroupData[{
Cell[61883, 1784, 386, 10, 135, "Input"],
Cell[62272, 1796, 338, 9, 124, "Output"]
}, Open  ]],
Cell[62625, 1808, 221, 5, 64, "Text"],
Cell[CellGroupData[{
Cell[62871, 1817, 466, 12, 221, "Input"],
Cell[63340, 1831, 347, 9, 124, "Output"]
}, Open  ]],
Cell[63702, 1843, 101, 1, 64, "Text"],
Cell[CellGroupData[{
Cell[63828, 1848, 580, 16, 264, "Input"],
Cell[64411, 1866, 1730, 41, 408, "Output"]
}, Open  ]],
Cell[66156, 1910, 101, 1, 64, "Text"],
Cell[CellGroupData[{
Cell[66282, 1915, 708, 20, 264, "Input"],
Cell[66993, 1937, 1706, 40, 408, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[68736, 1982, 133, 2, 91, "Input"],
Cell[68872, 1986, 258, 7, 103, "Output"]
}, Open  ]],
Cell[69145, 1996, 133, 1, 64, "Text"],
Cell[69281, 1999, 190, 6, 96, "Text"],
Cell[69474, 2007, 341, 12, 68, "Text"],
Cell[CellGroupData[{
Cell[69840, 2023, 265, 6, 135, "Input"],
Cell[70108, 2031, 357, 10, 124, "Output"]
}, Open  ]],
Cell[70480, 2044, 227, 5, 64, "Text"],
Cell[CellGroupData[{
Cell[70732, 2053, 417, 11, 221, "Input"],
Cell[71152, 2066, 390, 9, 124, "Output"]
}, Open  ]],
Cell[71557, 2078, 102, 1, 64, "Text"],
Cell[CellGroupData[{
Cell[71684, 2083, 529, 15, 264, "Input"],
Cell[72216, 2100, 344, 9, 146, "Output"]
}, Open  ]],
Cell[72575, 2112, 106, 1, 64, "Text"],
Cell[CellGroupData[{
Cell[72706, 2117, 624, 18, 264, "Input"],
Cell[73333, 2137, 339, 9, 146, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[73709, 2151, 133, 2, 91, "Input"],
Cell[73845, 2155, 261, 7, 103, "Output"]
}, Open  ]],
Cell[74121, 2165, 133, 1, 64, "Text"],
Cell[74257, 2168, 191, 6, 96, "Text"],
Cell[74451, 2176, 479, 19, 79, "Text"],
Cell[CellGroupData[{
Cell[74955, 2199, 433, 12, 135, "Input"],
Cell[75391, 2213, 306, 8, 124, "Output"]
}, Open  ]],
Cell[75712, 2224, 233, 4, 106, "Text"],
Cell[CellGroupData[{
Cell[75970, 2232, 412, 11, 221, "Input"],
Cell[76385, 2245, 319, 8, 124, "Output"]
}, Open  ]],
Cell[76719, 2256, 102, 1, 64, "Text"],
Cell[CellGroupData[{
Cell[76846, 2261, 708, 21, 307, "Input"],
Cell[77557, 2284, 9637, 237, 2152, "Output"]
}, Open  ]],
Cell[87209, 2524, 109, 1, 64, "Text"],
Cell[87321, 2527, 816, 22, 265, "Input"],
Cell[CellGroupData[{
Cell[88162, 2553, 132, 2, 91, "Input"],
Cell[88297, 2557, 234, 7, 103, "Output"]
}, Open  ]],
Cell[88546, 2567, 133, 1, 64, "Text"],
Cell[88682, 2570, 240, 7, 96, "Text"],
Cell[88925, 2579, 425, 16, 79, "Text"],
Cell[CellGroupData[{
Cell[89375, 2599, 427, 11, 135, "Input"],
Cell[89805, 2612, 368, 9, 124, "Output"]
}, Open  ]],
Cell[90188, 2624, 258, 5, 64, "Text"],
Cell[CellGroupData[{
Cell[90471, 2633, 461, 12, 221, "Input"],
Cell[90935, 2647, 384, 9, 124, "Output"]
}, Open  ]],
Cell[91334, 2659, 102, 1, 64, "Text"],
Cell[CellGroupData[{
Cell[91461, 2664, 730, 21, 307, "Input"],
Cell[92194, 2687, 1585, 36, 408, "Output"]
}, Open  ]],
Cell[93794, 2726, 109, 1, 64, "Text"],
Cell[93906, 2729, 821, 22, 265, "Input"],
Cell[CellGroupData[{
Cell[94752, 2755, 183, 3, 91, "Input"],
Cell[94938, 2760, 287, 8, 103, "Output"]
}, Open  ]],
Cell[95240, 2771, 133, 1, 64, "Text"],
Cell[95376, 2774, 149, 2, 96, "Text"],
Cell[95528, 2778, 1464, 27, 234, "Text"],
Cell[96995, 2807, 285, 6, 64, "Text"],
Cell[97283, 2815, 132, 2, 91, "Input"],
Cell[97418, 2819, 254, 6, 64, "Text"],
Cell[97675, 2827, 132, 2, 91, "Input"],
Cell[97810, 2831, 253, 6, 64, "Text"],
Cell[98066, 2839, 132, 2, 124, "Input"]
}
]
*)

