(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     82585,       2427]
NotebookOptionsPosition[     77474,       2268]
NotebookOutlinePosition[     78139,       2291]
CellTagsIndexPosition[     78096,       2288]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "OThreeF.nb (\[OpenCurlyDoubleQuote]Order Three Operator.  Compute ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", 
    RowBox[{"(", 
     RowBox[{"n", "+", 
      RowBox[{"2", "w"}], "-", "4"}], ")"}]], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["N", "A"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["N", "B"], TraditionalForm]]],
 "\[Delta]",
 Cell[BoxData[
  FormBox[
   SubscriptBox["D", "A"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["D", "B"], TraditionalForm]]],
 " ",
 StyleBox["f  .\[CloseCurlyDoubleQuote] ",
  FontSlant->"Italic"],
 ")"
}], "Text",
 CellChangeTimes->{{3.4531592758884363`*^9, 3.453159283270054*^9}, {
  3.453663714480641*^9, 3.453663742897434*^9}, {3.454264875723364*^9, 
  3.4542649856890078`*^9}, {3.454265169595438*^9, 3.454265183276231*^9}, {
  3.4545563392729397`*^9, 3.454556400683288*^9}, {3.4546061463487597`*^9, 
  3.454606146789274*^9}, {3.454691529083417*^9, 3.454691529532563*^9}, {
  3.454692871706007*^9, 3.4546928917816563`*^9}, {3.520886224715642*^9, 
  3.520886225974526*^9}, {3.76457958685962*^9, 3.76457960481168*^9}},
 FontSize->18,
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]],

Cell[TextData[{
 "Date last modified:  9 May 2019\n\nWe computed an expression for the above \
operator in another notebook.  This is the operator ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Delta]", 
    RowBox[{"1", ",", "2"}]], TraditionalForm]]],
 " as applied to a density of weight ",
 StyleBox["w",
  FontSlant->"Italic"],
 ".  In this notebook, we develop a linear combination describing this \
operator.  Specifically, we construct the linear combination given in Figure \
2 of our article.  We will use the previously computed formula to verify that \
we have the correct linear combination here."
}], "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBWIQbXLV4GHNnpeOSbuOPgLRKmmn3oDoZbHh70G0g0vM
cZa9Lx2N70WfAdFhDPOlfIH0ChMtWRD9z2LhURDtoJRwAkQbrfh6uM/6laNX
gMRxEL2++szz/UDabIPASxA9pcVg7SEgXb2edSOIZjxXEcZu88qx7HdYOIh2
mfrlEqvvK0dt/W9XQHSZmLSCnt8rx1c5+mA6Rqrm75KZrxyz3Xz/gWiFw7Ps
Fs965ahifhRMb5uflK84+5Xj/XeVYPqC5Sr7rcxvHL8YfPIH0c05B6tBNEP6
gjoQfWVuTD+IDvOcORlEW8m7zZ7L/cZx0sSfYPpwKGtWLM8bx10mImDaaf6L
C4z8bxy/Hcq5CqLjFk5++xBIs7gtAdMAxoun7Q==
  "]],

Cell[TextData[{
 "Special warning concerning the display of graphical output from ",
 StyleBox["Mathematica",
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.76596179493373*^9, 3.7659618335103083`*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[TextData[{
 "A special warning note appears near the beginning of the notebook ",
 StyleBox["Alias.nb", "Input"],
 ".  Please read this warning note.  This note relates to the display of \
graphical output from ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " in future work sessions with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.765961849278812*^9, 3.765961936518609*^9}, {
  3.765962026966837*^9, 3.7659620312867537`*^9}}],

Cell["Set the default output format type.", "Text",
 CellChangeTimes->{{3.765961979956499*^9, 3.765961994358906*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[TextData[{
 "We set the default output format type to \[OpenCurlyDoubleQuote]",
 StyleBox["OutputForm", "Input"],
 ".\[CloseCurlyDoubleQuote]"
}], "Text",
 CellChangeTimes->{{3.765962087165213*^9, 3.765962126566902*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"<<", "~/bop/gen/dtm/defout.m"}], ";"}]], "Input"],

Cell["Read in files.  Set parameters.  Read in Ricci.", "Text",
 CellChangeTimes->{{3.765962144718841*^9, 3.765962173240456*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[TextData[{
 "The following command tells ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " where to make the line breaks in the command output."
}], "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBWIQbXLV4GHNnpeOSbuOPgLRKmmn3oDoZbHh70G0g0vM
cZa9Lx2N70WfAdFhDPOlfIH0ChMtWRD9z2LhURDtoJRwAkQbrfh6uM/6laNX
gMRxEL2++szz/UDabIPASxA9pcVg7SEgXb2edSOIZjxXEcZu88qx7HdYOIh2
mfrlEqvvK0dt/W9XQHSZmLSCnt8rx1c5+mA6Rqrm75KZrxyz3Xz/gWiFw7Ps
Fs965ahifhRMb5uflK84+5Xj/XeVYPqC5Sr7rcxvHL8YfPIH0c05B6tBNEP6
gjoQfWVuTD+IDvOcORlEW8m7zZ7L/cZx0sSfYPpwKGtWLM8bx10mImDaaf6L
C4z8bxwXNTZdAtEs4dUTRIB0056DYBoAo7GlbA==
  "]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetOptions", "[", 
  RowBox[{"$Output", ",", 
   RowBox[{"PageWidth", "\[Rule]", "110"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.454265776374419*^9, 3.454265776894391*^9}, {
  3.570214904697701*^9, 3.5702149062974367`*^9}}],

Cell[OutputFormData["\<\
{{BinaryFormat -> False, FormatType -> OutputForm, PageWidth -> 110, \
PageHeight -> 22, 
  TotalWidth -> Infinity, TotalHeight -> Infinity, CharacterEncoding :> \
\"Unicode\", 
  NumberMarks :> $NumberMarks, Method -> {\"File\", BinaryFormat -> False}}}\
\>", "\<\
{{BinaryFormat -> False, FormatType -> OutputForm, PageWidth -> 110, \
PageHeight -> 22, 
 
   TotalWidth -> Infinity, TotalHeight -> Infinity, CharacterEncoding :> \
Unicode, 
 
   NumberMarks :> $NumberMarks, Method -> {File, BinaryFormat -> False}}}\
\>"], "Output",
 CellChangeTimes->{
  3.453159420682274*^9, 3.453664101780805*^9, 3.4537650309457912`*^9, 
   3.453768442958385*^9, 3.453844118631322*^9, 3.453858395155579*^9, 
   3.453915222079307*^9, 3.4539454046763563`*^9, 3.454006244931095*^9, 
   3.454084674302463*^9, 3.454097568777343*^9, 3.4541780304975758`*^9, 
   3.4541782316793613`*^9, 3.45417838963104*^9, 3.454181379603775*^9, 
   3.454194555282077*^9, 3.454256533202301*^9, 3.454265048850965*^9, 
   3.454265777769042*^9, 3.4542672055076313`*^9, 3.454267411278857*^9, 
   3.454273928094194*^9, 3.454278286744721*^9, 3.454280942277555*^9, 
   3.454344077173685*^9, 3.45454284668058*^9, 3.4545564076723423`*^9, 
   3.45460129755408*^9, 3.4546025763157187`*^9, 3.454605879937646*^9, 
   3.454606157330171*^9, 3.454606911337605*^9, 3.4546082183513403`*^9, 
   3.4546086431596203`*^9, 3.454689206558214*^9, 3.454691574532737*^9, 
   3.454692971940674*^9, 3.454695551454913*^9, 3.454698842133028*^9, 
   3.5208862764022923`*^9, 3.520986977297681*^9, 3.5211332503093767`*^9, 
   3.53004322462851*^9, 3.53064986454343*^9, 3.570214919223506*^9, 
   3.5707356151330853`*^9, 3.57073873853294*^9, 3.570994048546365*^9, 
   3.7600405974977703`*^9, 3.760040885706414*^9, {3.764186363616781*^9, 
   3.764186392644834*^9}, 3.764579156123086*^9, 3.7660028255388403`*^9, 
   3.766423471763527*^9, 3.7664255914379787`*^9}]
}, Open  ]],

Cell[TextData[{
 "Display the version number of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.766002827804914*^9, 3.766002843874164*^9}}],

Cell[CellGroupData[{

Cell[BoxData["$Version"], "Input",
 CellChangeTimes->{{3.76600285266084*^9, 3.7660028550065737`*^9}}],

Cell[OutputFormData["\<\
\"11.0.1 for Linux x86 (64-bit) (September 21, 2016)\"\
\>", "\<\
11.0.1 for Linux x86 (64-bit) (September 21, 2016)\
\>"], "Output",
 CellChangeTimes->{3.766002856007399*^9, 3.766423474401289*^9, 
  3.766425593362314*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"<<", "~/bop/gen/dtm3/Ricci1.61.m"}]], "Input",
 CellChangeTimes->{{3.57021490912467*^9, 3.570214915568501*^9}, {
  3.760040771485817*^9, 3.760040777994081*^9}, {3.760040852868568*^9, 
  3.760040862275971*^9}, {3.765964512082631*^9, 3.765964513138235*^9}, {
  3.766002860127015*^9, 3.766002861670889*^9}}],

Cell["\<\
 -- Ricci Version 1.61 (March 10, 2016) --
    Copyright 1992 - 2016 John M. Lee
    Problem reports or suggestions to:
      lee@math.washington.edu
 -- For properly formatted output in a notebook,
    set the default output format type to OutputForm\
\>", "Print",
 CellChangeTimes->{
  3.760040808365458*^9, {3.760040863612833*^9, 3.760040887450886*^9}, {
   3.7641863653282948`*^9, 3.764186393617381*^9}, 3.764579159286274*^9, 
   3.7660028647865267`*^9, 3.76642347559624*^9, 3.766425594576023*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"$Quiet", "=", "True"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"<<", "~/bop/gen/dtm3/June8tan.m"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"<<", "~/bop/gen/dtm2/Maybund.m"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"<<", "~/bop/gen/dtm2/Maybase.m"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"<<", "~/bop/gen/dtm2/May2.m"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"<<", "~/bop/gen/dtm2/May6.m"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"<<", "~/bop/gen/dtm/PrintTime.m"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"<<", "~/bop/gen/dtm2/May3.m"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"<<", "~/bop/gen/dtm2/May7.m"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"<<", "~/bop/gen/dtm3/June8.m"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"<<", "~/bop/gen/dtm3/June9a.m"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"<<", "~/bop/gen/dtm3/June9b.m"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$Quiet", "=", "False"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"PrintTime", ";"}]}], "Input",
 CellChangeTimes->{{3.453764984157428*^9, 3.453764991396926*^9}, {
  3.453858435780781*^9, 3.4538584407412443`*^9}, {3.760040783474845*^9, 
  3.760040796107176*^9}, {3.764186372626055*^9, 3.764186373167653*^9}}],

Cell["\<\
Time:  16 hours, 19 minutes, 57 seconds
Date:  9 May 2019\
\>", "Print",
 CellChangeTimes->{
  3.453159433558712*^9, 3.4536641087403793`*^9, 3.4537650383314323`*^9, 
   3.4537684492497253`*^9, 3.453844124077334*^9, 3.453858444306649*^9, 
   3.4539152276470537`*^9, 3.453945410818446*^9, 3.454006250497306*^9, 
   3.454084682375368*^9, 3.454097574794847*^9, 3.4541780358523197`*^9, 
   3.45417823845408*^9, 3.454178394737667*^9, 3.454181385912878*^9, 
   3.454194562617395*^9, 3.454256539341807*^9, 3.454265054697605*^9, 
   3.454267211721065*^9, 3.4542674179392233`*^9, 3.454273933495*^9, 
   3.4542782922163343`*^9, 3.4542809477190228`*^9, 3.454344082303244*^9, 
   3.4545428566647863`*^9, 3.454556416040819*^9, 3.4546013033452177`*^9, 
   3.4546025818164186`*^9, 3.454605885713771*^9, 3.454606162448224*^9, 
   3.4546069170646143`*^9, 3.454608224160009*^9, 3.4546086504328337`*^9, 
   3.454689262789496*^9, 3.4546915795579042`*^9, 3.45469297798037*^9, 
   3.4546955567912083`*^9, 3.454698846799219*^9, 3.52088628579806*^9, 
   3.5209869811788683`*^9, 3.521133254890815*^9, 3.530043229479738*^9, 
   3.530649868826081*^9, 3.5702149245396967`*^9, 3.5707356338874273`*^9, 
   3.570738741268731*^9, 3.5709940515814943`*^9, 3.76004089233077*^9, {
   3.764186367684987*^9, 3.764186395805862*^9}, 3.76457916220756*^9, 
   3.766002881365122*^9, 3.766423477603117*^9, 3.766425596540498*^9}]
}, Open  ]],

Cell[TextData[{
 "Construct the following:  ",
 StyleBox["\[Delta]\[Square]",
  FontSize->24],
 StyleBox["f",
  FontSize->24,
  FontSlant->"Italic"],
 StyleBox[".",
  FontSize->24]
}], "Text",
 CellChangeTimes->{{3.760040990948926*^9, 3.760040992579934*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[TextData[{
 "Here we assume that ",
 StyleBox["f",
  FontSlant->"Italic"],
 "  is a density of weight ",
 StyleBox["w",
  FontSlant->"Italic"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"BigBoxOp", "[", 
    RowBox[{"f", ",", "w"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"Robin", "[", 
    RowBox[{"Temp", ",", 
     RowBox[{"w", "-", "2"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DeltaBox", "=", "Temp"}], 
  ";"}], "\[IndentingNewLine]", "DeltaBox"}], "Input"],

Cell[OutputFormData["\<\
(2 - w)*f[] [L[a], U[a]]*Hmc + f[] [L[a], U[a], L[b]]*Nvec[U[b]] - (-2 + \
w)*w*f*Hmc*P[L[a], U[a]] + 

   w*f[] [L[a]]*Nvec[U[a]]*P[L[b], U[b]] + w*f*Nvec[U[a]]*P[L[b], U[b]] [L[a]]\
\>", "\<\
            a            a        b                          a               \
a     b            a     b 
(2 - w) f      Hmc + f        Nvec   - ((-2 + w) w) f Hmc P     + w f    Nvec \
  P     + w f Nvec   P
         ;a           ;a   b                               a         ;a       \
   b                  b   ;a\
\>"], "Output",
 CellChangeTimes->{3.52088639187671*^9, 3.5209871769814777`*^9, 
  3.521133476483367*^9, 3.530043268990321*^9, 3.530649896636587*^9, 
  3.570214966814939*^9, 3.570735877458639*^9, 3.570738744766633*^9, 
  3.570994067251552*^9, 3.7600410048475943`*^9, 3.764579166637233*^9, 
  3.7660028928439693`*^9, 3.766423617653432*^9, 3.766425598376473*^9}]
}, Open  ]],

Cell["\<\
Work on the second of the three parts of the linear combination.\
\>", "Text",
 CellChangeTimes->{{3.760041041605482*^9, 3.76004106017349*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[TextData[{
 "When I originally constructed rules for dealing with intrinsic derivatives \
and intrinsic operators, I gave the rules the capability of working with a \
conformal metric.  The conformal factor is ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", 
    RowBox[{"2", "\[CenterDot]", "Upsion"}]], TraditionalForm]]],
 ".  In this notebook, we always work with the background metric.  We \
therefore need to set Upsilon equal to zero.  We now define and test a rule \
which we can use to do this."
}], "Text",
 CellChangeTimes->{{3.76457918605381*^9, 3.764579386793396*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DefineRule", "[", 
  RowBox[{"Killups", ",", "ups", ",", "0", ",", 
   RowBox[{"NewRule", "\[Rule]", "True"}]}], "]"}]], "Input"],

Cell["Rule defined.", "Print",
 CellChangeTimes->{3.52088641549807*^9, 3.5209872431078167`*^9, 
  3.521133482962427*^9, 3.530043284675444*^9, 3.530649919576946*^9, 
  3.570214970813052*^9, 3.5707359130561447`*^9, 3.5707387465202637`*^9, 
  3.570994117777965*^9, 3.760041150783781*^9, 3.764579365303627*^9, 
  3.76600291855217*^9, 3.7664236373233747`*^9, 3.766425603983362*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Holder", "=", 
   RowBox[{"{", 
    RowBox[{"ups", ",", 
     RowBox[{"ups", "[", 
      RowBox[{"L", "[", "i", "]"}], "]"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", "Holder"}], "Input"],

Cell[OutputFormData["\<\
{ups, ups[] [L[i]]}\
\>", "\<\
{ups, ups   }
         ;i\
\>"], "Output",
 CellChangeTimes->{3.520886417400321*^9, 3.5209872451092997`*^9, 
  3.5211334838120728`*^9, 3.530043286350757*^9, 3.53064992034834*^9, 
  3.57021497165797*^9, 3.570735914277605*^9, 3.570738747378252*^9, 
  3.570994119177072*^9, 3.7600411524708357`*^9, 3.7645793925803432`*^9, 
  3.766002919930278*^9, 3.766423638909532*^9, 3.766425604834587*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Holder", "/.", "Killups"}]], "Input"],

Cell[OutputFormData["\<\
{0, 0}\
\>", "\<\
{0, 0}\
\>"], "Output",
 CellChangeTimes->{3.520886418283719*^9, 3.5209872467931957`*^9, 
  3.521133484595066*^9, 3.530043287604934*^9, 3.530649921189147*^9, 
  3.570214972312777*^9, 3.570735914997505*^9, 3.570738748162457*^9, 
  3.570994120613969*^9, 3.7600411548347816`*^9, 3.7645793983267193`*^9, 
  3.7660029208146276`*^9, 3.766423639625849*^9, 3.76642560561934*^9}]
}, Open  ]],

Cell["Construct first term of the second part.", "Text",
 CellChangeTimes->{{3.76004121325537*^9, 3.76004121819099*^9}},
 Background->RGBColor[1, 0.9, 1]],

Cell[TextData[{
 "Construct",
 StyleBox[" ",
  FontSize->24],
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[Square]", "_"], TraditionalForm]],
  FontSize->24],
 " ",
 StyleBox["\[Delta] ",
  FontSize->24],
 StyleBox["f",
  FontSize->24,
  FontSlant->"Italic"],
 StyleBox[".",
  FontSize->24]
}], "Text"],

Cell[TextData[{
 "Here we assume that ",
 StyleBox["f",
  FontSlant->"Italic"],
 "  is a density of weight ",
 StyleBox["w",
  FontSlant->"Italic"],
 "."
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"Robin", "[", 
    RowBox[{"f", ",", "w"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"LapSigHatDen", "[", 
      RowBox[{"Temp", ",", 
       RowBox[{"w", "-", "1"}]}], "]"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"w", "-", "1"}], ")"}], "TrPSigma", "*", "Temp"}]}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "Killups"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "ExpandTrPSigma"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"ToNbNvec", "[", "Temp", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"BoxBarDeltaOne", "=", "Temp"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"BoxBarDeltaOne", ";"}]}], "Input"],

Cell["Construct second term of the second part.", "Text",
 CellChangeTimes->{{3.7600412684479113`*^9, 3.760041275047669*^9}},
 Background->RGBColor[1, 0.9, 1]],

Cell[TextData[{
 "Construct   ",
 StyleBox["  - ",
  FontSize->24],
 Cell[BoxData[
  FormBox[
   FractionBox["2", 
    RowBox[{"3", 
     RowBox[{"(", 
      RowBox[{"n", "-", "3"}], ")"}]}]], TraditionalForm]],
  FontSize->24],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["L", 
    StyleBox["AB",
     FontSlant->"Italic"]], TraditionalForm]],
  FontSize->24],
 Cell[BoxData[
  FormBox[
   SubscriptBox["D", "A"], TraditionalForm]],
  FontSize->24],
 Cell[BoxData[
  FormBox[
   SubscriptBox["D", "B"], TraditionalForm]],
  FontSize->24],
 StyleBox[" ",
  FontSize->24],
 StyleBox["f",
  FontSize->24,
  FontSlant->"Italic"],
 StyleBox[".",
  FontSlant->"Italic"]
}], "Text"],

Cell[TextData[{
 "Here we assume that ",
 StyleBox["f",
  FontSlant->"Italic"],
 "  is a density of weight ",
 StyleBox["w",
  FontSlant->"Italic"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"PrintTime", ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"DOp", "[", 
    RowBox[{"f", ",", "w", ",", 
     RowBox[{"L", "[", "BB", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"DOp", "[", 
    RowBox[{"Temp", ",", 
     RowBox[{"w", "-", "1"}], ",", 
     RowBox[{"L", "[", "AA", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"TracSFF", "[", 
      RowBox[{
       RowBox[{"U", "[", "AA", "]"}], ",", 
       RowBox[{"U", "[", "BB", "]"}]}], "]"}], "Temp"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "/", "3"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"n", "-", "3"}], ")"}]}], ")"}], "Temp"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "ExpandTracSFF"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "IProd"}], ")"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "IProd"}], ")"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"BoxBarDeltaTwo", "=", "Temp"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"PrintTime", ";"}]}], "Input"],

Cell["\<\
Time:  16 hours, 20 minutes, 12 seconds
Date:  9 May 2019
Time:  16 hours, 20 minutes, 18 seconds
Date:  9 May 2019\
\>", "Print",
 CellChangeTimes->{3.520886500585017*^9, 3.520987470850389*^9, 
  3.521133663333662*^9, 3.530043749065452*^9, 3.530649990252705*^9, 
  3.570215099707674*^9, 3.570736230774596*^9, 3.570738754614771*^9, 
  3.570994314645542*^9, 3.7600413232139387`*^9, 3.764579408451231*^9, 
  3.766002948998506*^9, 3.766423752683762*^9, 3.766425612371688*^9}]
}, Open  ]],

Cell["Construct third term of the second part.", "Text",
 CellChangeTimes->{{3.76004138456929*^9, 3.760041389880846*^9}},
 Background->RGBColor[1, 0.9, 1]],

Cell[TextData[{
 "Construct the following:  ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     RowBox[{"3", "n"}], " ", "-", " ", "5"}], 
    RowBox[{"4", 
     RowBox[{"(", 
      RowBox[{"n", "-", "2"}], ")"}]}]], TraditionalForm]],
  FontSize->24],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["L", "\[SmallCircle]"], 
    StyleBox["ab",
     FontSlant->"Italic"]], TraditionalForm]],
  FontSize->24],
 Cell[BoxData[
  FormBox[
   OverscriptBox[
    SuperscriptBox["L", 
     StyleBox["ab",
      FontSlant->"Italic"]], 
    RowBox[{"\[SmallCircle]", "      "}]], TraditionalForm]],
  FontSize->24],
 StyleBox["\[Delta] ",
  FontSize->24],
 StyleBox["f",
  FontSize->24,
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.520886553632922*^9, 3.52088657517831*^9}, {
  3.520886624547922*^9, 3.520886676245348*^9}, {3.520886710542027*^9, 
  3.520886713951634*^9}, {3.521133811829801*^9, 3.521133813484344*^9}, {
  3.570736655996361*^9, 3.570736663670638*^9}, {3.570736716164136*^9, 
  3.570736729931302*^9}, {3.760041410201832*^9, 3.760041413609747*^9}, {
  3.766422460250943*^9, 3.766422629890347*^9}, {3.766422666917223*^9, 
  3.7664226810535393`*^9}, {3.7664227310030212`*^9, 3.7664227491418543`*^9}}],

Cell[TextData[{
 "Here we assume that ",
 StyleBox["f",
  FontSlant->"Italic"],
 "  is a density of weight ",
 StyleBox["w",
  FontSlant->"Italic"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"July11Coefficient", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", "n"}], "-", "5"}], ")"}], 
    RowBox[{"(", 
     RowBox[{"1", "/", "4"}], ")"}], 
    RowBox[{"(", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"n", "-", "2"}], ")"}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", "July11Coefficient"}], "Input",
 CellChangeTimes->{{3.520886880380745*^9, 3.520886914948934*^9}, {
  3.5707366701489067`*^9, 3.570736671660207*^9}}],

Cell[OutputFormData["\<\
(-5 + 3*n)/(4*(-2 + n))\
\>", "\<\
 -5 + 3 n
----------
4 (-2 + n)\
\>"], "Output",
 CellChangeTimes->{3.520886916601474*^9, 3.520987746487986*^9, 
  3.521133780575673*^9, 3.530044209665217*^9, 3.530650208676773*^9, 
  3.570215169368299*^9, 3.5707364701616096`*^9, 3.5707366793694468`*^9, 
  3.570736733627405*^9, 3.570736820531373*^9, 3.570738761842649*^9, 
  3.570994334599207*^9, 3.760041434998619*^9, 3.764579418918201*^9, 
  3.766002975762466*^9, 3.766423762044594*^9, 3.766425621413715*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"July11Coefficient", "*", 
     RowBox[{"TfSFF", "[", 
      RowBox[{
       RowBox[{"L", "[", "a1", "]"}], ",", 
       RowBox[{"L", "[", "b1", "]"}]}], "]"}], 
     RowBox[{"TfSFF", "[", 
      RowBox[{
       RowBox[{"U", "[", "a1", "]"}], ",", 
       RowBox[{"U", "[", "b1", "]"}]}], "]"}], 
     RowBox[{"Robin", "[", 
      RowBox[{"f", ",", "w"}], "]"}]}], ")"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"BoxBarDeltaThree", "=", "Temp"}], 
  ";"}], "\[IndentingNewLine]", "BoxBarDeltaThree"}], "Input",
 CellChangeTimes->{{3.520886842531497*^9, 3.5208868533187637`*^9}, {
  3.520886925612576*^9, 3.5208869594111147`*^9}, {3.5208870550992413`*^9, 
  3.520887069660637*^9}, {3.570736675433222*^9, 3.570736675608708*^9}}],

Cell[OutputFormData["\<\
-((-5 + 3*n)*w*f*Hmc*TfSFF[L[a], L[b]]*TfSFF[U[a], U[b]])/(4*(-2 + n)) + 

   ((-5 + 3*n)*f[] [L[c]]*Nvec[U[c]]*TfSFF[L[a], L[b]]*TfSFF[U[a], \
U[b]])/(4*(-2 + n))\
\>", "\<\
-((-5 + 3 n) w)                      a b     -5 + 3 n           c             \
    a b 
--------------- f Hmc TfSFF     TfSFF     + ---------- f    Nvec   TfSFF     \
TfSFF
  4 (-2 + n)               a b              4 (-2 + n)  ;c              a b\
\>"], "Output",
 CellChangeTimes->{3.520887074268976*^9, 3.5209877547843857`*^9, 
  3.521133783101128*^9, 3.53004421116224*^9, 3.53065021649213*^9, 
  3.5702152343903723`*^9, 3.57073647140026*^9, 3.570736642764727*^9, 
  3.5707366803133793`*^9, 3.57073673449196*^9, 3.570736817277986*^9, 
  3.570736863706053*^9, 3.57073876334443*^9, 3.5709943354889936`*^9, 
  3.760041457008396*^9, 3.764579419759285*^9, 3.7660029830819063`*^9, 
  3.7664237635822678`*^9, 3.766425622064618*^9}]
}, Open  ]],

Cell["Construct fourth group of terms for the second part.", "Text",
 CellChangeTimes->{{3.7600415171707783`*^9, 3.760041527026127*^9}},
 Background->RGBColor[1, 0.9, 1]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"BoxBarDeltaFour", "=", 
   RowBox[{"(", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "5"}], "+", "n"}], ")"}], "*", "f", "*", 
          RowBox[{"TfSFF", "[", 
           RowBox[{
            RowBox[{"L", "[", "a", "]"}], ",", 
            RowBox[{"L", "[", "b", "]"}]}], "]"}], "*", 
          RowBox[{"TfSFF", "[", 
           RowBox[{
            RowBox[{"U", "[", "a", "]"}], ",", 
            RowBox[{"L", "[", "c", "]"}]}], "]"}], "*", 
          RowBox[{"TfSFF", "[", 
           RowBox[{
            RowBox[{"U", "[", "b", "]"}], ",", 
            RowBox[{"U", "[", "c", "]"}]}], "]"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "3"}], "+", "n"}], ")"}]}], ")"}]}], ")"}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", "n"}], ")"}], "*", "f", "*", 
        RowBox[{"Nvec", "[", 
         RowBox[{"U", "[", "a", "]"}], "]"}], "*", 
        RowBox[{"Nvec", "[", 
         RowBox[{"U", "[", "b", "]"}], "]"}], "*", 
        RowBox[{"TfSFF", "[", 
         RowBox[{
          RowBox[{"L", "[", "c", "]"}], ",", 
          RowBox[{"L", "[", "d", "]"}]}], "]"}], "*", 
        RowBox[{"Weyl", "[", 
         RowBox[{
          RowBox[{"L", "[", "a", "]"}], ",", 
          RowBox[{"U", "[", "c", "]"}], ",", 
          RowBox[{"L", "[", "b", "]"}], ",", 
          RowBox[{"U", "[", "d", "]"}]}], "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"2", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", "n"}], ")"}]}], ")"}]}]}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", "BoxBarDeltaFour"}], "Input"],

Cell[OutputFormData["\<\
-((-5 + n)*f*TfSFF[L[a], L[b]]*TfSFF[U[a], L[c]]*TfSFF[U[b], U[c]])/(2*(-3 + \
n)) - 

   ((-5 + n)*f*Nvec[U[a]]*Nvec[U[b]]*TfSFF[L[c], L[d]]*Weyl[L[a], U[c], L[b], \
U[d]])/(2*(-3 + n))\
\>", "\<\
-(-5 + n)                   a         b c      -5 + n         a      b        \
          c   d 
---------- f TfSFF     TfSFF     TfSFF     - ---------- f Nvec   Nvec   TfSFF \
    Weyl
2 (-3 + n)        a b         c              2 (-3 + n)                      \
c d      a   b\
\>"], "Output",
 CellChangeTimes->{3.520887185548956*^9, 3.520987888229432*^9, 
  3.521133942929008*^9, 3.530044440682534*^9, 3.530650225021989*^9, 
  3.5702152427429934`*^9, 3.570736933774664*^9, 3.570738765210286*^9, 
  3.570994360581675*^9, 3.760041530772043*^9, 3.764579421777549*^9, 
  3.766003002530747*^9, 3.7664238421987753`*^9, 3.766425623694416*^9}]
}, Open  ]],

Cell["Now work on the third part of the linear combination.", "Text",
 CellChangeTimes->{{3.760041604595705*^9, 3.760041617995483*^9}},
 Background->RGBColor[1, 1, 0]],

Cell["Construct first two terms of last part.", "Text",
 CellChangeTimes->{{3.760041667572502*^9, 3.7600416898364077`*^9}},
 Background->RGBColor[1, 0.9, 1]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"RemainingOne", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"f", "[", "]"}], "[", 
         RowBox[{
          RowBox[{"L", "[", "a", "]"}], ",", 
          RowBox[{"L", "[", "b", "]"}]}], "]"}], "*", "Hmc", "*", 
        RowBox[{"Nvec", "[", 
         RowBox[{"U", "[", "a", "]"}], "]"}], "*", 
        RowBox[{"Nvec", "[", 
         RowBox[{"U", "[", "b", "]"}], "]"}]}], ")"}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "n", "+", 
          RowBox[{"2", "*", "w"}]}], ")"}], "*", 
        RowBox[{
         RowBox[{"f", "[", "]"}], "[", 
         RowBox[{
          RowBox[{"L", "[", "a", "]"}], ",", 
          RowBox[{"L", "[", "b", "]"}]}], "]"}], "*", 
        RowBox[{"TfSFF", "[", 
         RowBox[{
          RowBox[{"U", "[", "a", "]"}], ",", 
          RowBox[{"U", "[", "b", "]"}]}], "]"}]}], ")"}], "/", "3"}]}], 
    ")"}]}], ";"}], "\[IndentingNewLine]", "RemainingOne"}], "Input"],

Cell[OutputFormData["\<\
-(f[] [L[a], L[b]]*Hmc*Nvec[U[a]]*Nvec[U[b]]) - (2*(-1 + n + 2*w)*f[] [L[a], \
L[b]]*TfSFF[U[a], U[b]])/3\
\>", "\<\
                a      b    2 (-1 + n + 2 w)             a b 
-f      Hmc Nvec   Nvec   - ---------------- f      TfSFF
  ;a b                             3          ;a b\
\>"], "Output",
 CellChangeTimes->{3.5208873493594217`*^9, 3.520988131946681*^9, 
  3.5211341437889643`*^9, 3.53004478606067*^9, 3.530650371669174*^9, 
  3.57021533097001*^9, 3.5707371708775473`*^9, 3.5707387687458467`*^9, 
  3.570994447277713*^9, 3.760041714722324*^9, 3.764579424177824*^9, 
  3.7660030290790453`*^9, 3.766423966675783*^9, 3.766425626865637*^9}]
}, Open  ]],

Cell["Construct third term of third part.", "Text",
 CellChangeTimes->{{3.7600417520614233`*^9, 3.760041761932782*^9}},
 Background->RGBColor[1, 0.9, 1]],

Cell[TextData[{
 "We construct the following:\n\n",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"7", "-", 
     RowBox[{"4", "n"}], "-", 
     RowBox[{"12", "w"}], "+", 
     RowBox[{"4", "n", " ", "w"}], "+", 
     RowBox[{"8", 
      SuperscriptBox["w", "2"]}]}], "3"], TraditionalForm]],
  FontSize->24],
 StyleBox["(",
  FontSize->24],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["\[Del]", "_"], "a"], TraditionalForm]],
  FontSize->24],
 StyleBox["H",
  FontSize->24,
  FontSlant->"Italic"],
 StyleBox[")",
  FontSize->24],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Del]", "a"], TraditionalForm]],
  FontSize->24],
 StyleBox["f",
  FontSize->24,
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.766424185367125*^9, 3.766424190774661*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ThisCoefficient", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"(", 
       RowBox[{"7", "-", 
        RowBox[{"4", "*", "n"}], "-", 
        RowBox[{"12", "*", "w"}], "+", 
        RowBox[{"4", "*", "n", "*", "w"}], "+", 
        RowBox[{"8", "*", 
         RowBox[{"w", "^", "2"}]}]}], ")"}], ")"}], "/", "3"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ThisCoefficient", "//", "FactorConstants"}]}], "Input"],

Cell[OutputFormData["\<\
(7 - 4*n - 12*w + 4*n*w + 8*w^2)/3\
\>", "\<\
                            2
7 - 4 n - 12 w + 4 n w + 8 w
-----------------------------
              3\
\>"], "Output",
 CellChangeTimes->{3.5208873847613583`*^9, 3.520988249898649*^9, 
  3.5211343216910763`*^9, 3.530045324697136*^9, 3.530650416225848*^9, 
  3.570215379316882*^9, 3.570737371217174*^9, 3.570738772097844*^9, 
  3.570994505861849*^9, 3.760041795756686*^9, 3.764579427912362*^9, 
  3.7660030389869127`*^9, 3.766424244816598*^9, 3.766425629195942*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"NbSigHatDen", "[", 
      RowBox[{"Hmc", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"L", "[", "a", "]"}]}], "]"}], 
     RowBox[{"f", "[", 
      RowBox[{"U", "[", "a", "]"}], "]"}]}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"ThisCoefficient", "*", "Temp"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "Killups"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "ExpandPiPro"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RemainingTwo", "=", "Temp"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"RemainingTwo", "//", "FactorConstants"}]}], "Input"],

Cell[OutputFormData["\<\
((7 - 4*n - 12*w + 4*n*w + 8*w^2)*f[] [L[a]]*Hmc[] [U[a]])/3 + 

   ((-7 + 4*n + 12*w - 4*n*w - 8*w^2)*f[] [L[a]]*Hmc[] \
[L[b]]*Nvec[U[a]]*Nvec[U[b]])/3\
\>", "\<\
                            2                                            2
7 - 4 n - 12 w + 4 n w + 8 w           a    -7 + 4 n + 12 w - 4 n w - 8 w     \
             a      b 
----------------------------- f    Hmc    + ------------------------------ f  \
  Hmc    Nvec   Nvec
              3                ;a     ;                   3                 \
;a     ;b\
\>"], "Output",
 CellChangeTimes->{3.52088741002634*^9, 3.520988251108363*^9, 
  3.5211343225479937`*^9, 3.5300453264986*^9, 3.530650418243914*^9, 
  3.57021541944715*^9, 3.570737536264495*^9, 3.57073877362047*^9, 
  3.5709945066580477`*^9, 3.7600418383119287`*^9, 3.76457942900914*^9, 
  3.766003042750676*^9, 3.766424246478508*^9, 3.766425630504178*^9}]
}, Open  ]],

Cell["Construct several terms from the third part.", "Text",
 CellChangeTimes->{{3.760042306083552*^9, 3.7600423180117283`*^9}},
 Background->RGBColor[1, 0.9, 1]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"RemainingThree", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "w"}], ")"}], "*", 
        RowBox[{
         RowBox[{"f", "[", "]"}], "[", 
         RowBox[{"L", "[", "a", "]"}], "]"}], "*", 
        RowBox[{"Hmc", "^", "2"}], "*", 
        RowBox[{"Nvec", "[", 
         RowBox[{"U", "[", "a", "]"}], "]"}]}], ")"}], "/", "2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "7"}], "+", 
          RowBox[{"4", "*", "n"}], "+", 
          RowBox[{"12", "*", "w"}], "-", 
          RowBox[{"4", "*", "n", "*", "w"}], "-", 
          RowBox[{"8", "*", 
           RowBox[{"w", "^", "2"}]}]}], ")"}], "*", 
        RowBox[{
         RowBox[{"f", "[", "]"}], "[", 
         RowBox[{"L", "[", "a", "]"}], "]"}], "*", 
        RowBox[{"Nvec", "[", 
         RowBox[{"U", "[", "a", "]"}], "]"}], "*", 
        RowBox[{"Nvec", "[", 
         RowBox[{"U", "[", "b", "]"}], "]"}], "*", 
        RowBox[{"Nvec", "[", 
         RowBox[{"U", "[", "c", "]"}], "]"}], "*", 
        RowBox[{"P", "[", 
         RowBox[{
          RowBox[{"L", "[", "b", "]"}], ",", 
          RowBox[{"L", "[", "c", "]"}]}], "]"}]}], ")"}], "/", "3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", "*", 
        RowBox[{"(", 
         RowBox[{"5", "-", 
          RowBox[{"2", "*", "n"}], "-", 
          RowBox[{"6", "*", "w"}], "+", 
          RowBox[{"2", "*", "n", "*", "w"}], "+", 
          RowBox[{"4", "*", 
           RowBox[{"w", "^", "2"}]}]}], ")"}], "*", 
        RowBox[{
         RowBox[{"f", "[", "]"}], "[", 
         RowBox[{"L", "[", "a", "]"}], "]"}], "*", 
        RowBox[{"Nvec", "[", 
         RowBox[{"U", "[", "b", "]"}], "]"}], "*", 
        RowBox[{"P", "[", 
         RowBox[{
          RowBox[{"U", "[", "a", "]"}], ",", 
          RowBox[{"L", "[", "b", "]"}]}], "]"}]}], ")"}], "/", "3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "/", 
        RowBox[{"(", 
         RowBox[{"4", 
          RowBox[{"(", 
           RowBox[{"n", "-", "2"}], ")"}]}], ")"}]}], ")"}], "*", 
      RowBox[{
       RowBox[{"f", "[", "]"}], "[", 
       RowBox[{"L", "[", "a", "]"}], "]"}], "*", 
      RowBox[{"Nvec", "[", 
       RowBox[{"U", "[", "a", "]"}], "]"}], "*", 
      RowBox[{"TfSFF", "[", 
       RowBox[{
        RowBox[{"L", "[", "b", "]"}], ",", 
        RowBox[{"L", "[", "c", "]"}]}], "]"}], "*", 
      RowBox[{"TfSFF", "[", 
       RowBox[{
        RowBox[{"U", "[", "b", "]"}], ",", 
        RowBox[{"U", "[", "c", "]"}]}], "]"}]}]}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"RemainingThree", "//", "FactorConstants"}]}], "Input",
 CellChangeTimes->{{3.520887736390155*^9, 3.520887754310463*^9}, {
  3.5208877987726707`*^9, 3.5208878156773357`*^9}, {3.520989215450878*^9, 
  3.520989245271327*^9}}],

Cell[OutputFormData["\<\
(3*(-1 + w)*f[] [L[a]]*Hmc^2*Nvec[U[a]])/2 + ((-7 + 4*n + 12*w - 4*n*w - \
8*w^2)*f[] [L[a]]*Nvec[U[a]]*

     Nvec[U[b]]*Nvec[U[c]]*P[L[b], L[c]])/3 + (2*(5 - 2*n - 6*w + 2*n*w + \
4*w^2)*f[] [L[a]]*Nvec[U[b]]*

     P[U[a], L[b]])/3 - (f[] [L[a]]*Nvec[U[a]]*TfSFF[L[b], L[c]]*TfSFF[U[b], \
U[c]])/(4*(-2 + n))\
\>", "\<\
                                                           2
3 (-1 + w)         2     a    -7 + 4 n + 12 w - 4 n w - 8 w           a      \
b      c 
---------- f    Hmc  Nvec   + ------------------------------ f    Nvec   Nvec \
  Nvec   P     + 
    2       ;a                              3                 ;a              \
          b c 
 
                                2
  2 (5 - 2 n - 6 w + 2 n w + 4 w )          b   a          1               a  \
               b c 
  -------------------------------- f    Nvec   P     - ---------- f    Nvec   \
TfSFF     TfSFF
                 3                  ;a            b    4 (-2 + n)  ;a         \
     b c\
\>"], "Output",
 CellChangeTimes->{3.5209892466042547`*^9, 3.521134448932325*^9, 
  3.530045568904234*^9, 3.530650546526154*^9, 3.5702154731894493`*^9, 
  3.570737555514048*^9, 3.5707387781915283`*^9, 3.570994586252585*^9, 
  3.760041979265698*^9, 3.7645794310716*^9, 3.766003045469224*^9, 
  3.766424305809338*^9, 3.766425632510908*^9}]
}, Open  ]],

Cell["Construct the term involving the intrinsic Laplacian.", "Text",
 CellChangeTimes->{{3.760042328652117*^9, 3.7600423454115677`*^9}},
 Background->RGBColor[1, 0.9, 1]],

Cell[TextData[{
 "We construct the following:\n\n",
 StyleBox["- ",
  FontSize->24],
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"w", "(", 
     RowBox[{"5", "-", 
      RowBox[{"2", "n"}], "-", 
      RowBox[{"6", "w"}], "+", 
      RowBox[{"2", "n", " ", "w"}], "+", 
      RowBox[{"4", 
       SuperscriptBox["w", "2"]}]}], ")"}], 
    RowBox[{"3", 
     RowBox[{"(", 
      RowBox[{"n", "-", "3"}], ")"}]}]], TraditionalForm]],
  FontSize->24],
 StyleBox["(",
  FontSize->24],
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[CapitalDelta]", "_"], TraditionalForm]],
  FontSize->24],
 StyleBox["H",
  FontSize->24,
  FontSlant->"Italic"],
 StyleBox[") ",
  FontSize->24],
 StyleBox["f",
  FontSize->24,
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.760042157882194*^9, 3.760042163642169*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"HHCoefficient", "=", 
   RowBox[{"(", 
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"w", "*", 
         RowBox[{"(", 
          RowBox[{"5", "-", 
           RowBox[{"2", "*", "n"}], "-", 
           RowBox[{"6", "*", "w"}], "+", 
           RowBox[{"2", "*", "n", "*", "w"}], "+", 
           RowBox[{"4", "*", 
            RowBox[{"w", "^", "2"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"3", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "3"}], "+", "n"}], ")"}]}], ")"}]}], ")"}]}], ")"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{"HHCoefficient", "//", "FactorConstants"}]}], "Input"],

Cell[OutputFormData["\<\
-(w*(5 - 2*n - 6*w + 2*n*w + 4*w^2))/(3*(-3 + n))\
\>", "\<\
                                2
-(w (5 - 2 n - 6 w + 2 n w + 4 w ))
-----------------------------------
            3 (-3 + n)\
\>"], "Output",
 CellChangeTimes->{3.52088806955567*^9, 3.5209895123747463`*^9, 
  3.52113556525174*^9, 3.530046092489823*^9, 3.530650636431306*^9, 
  3.570215705452354*^9, 3.570738077182184*^9, 3.570738781130025*^9, 
  3.570994773219775*^9, 3.7600421851903553`*^9, 3.7645794344441*^9, 
  3.7660030490189466`*^9, 3.766424514766642*^9, 3.76642563704674*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"HHCoefficient", "*", 
     RowBox[{"LapSigHatDen", "[", 
      RowBox[{"Hmc", ",", 
       RowBox[{"-", "1"}]}], "]"}], "*", "f"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "Killups"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RemainingFour", "=", "Temp"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"RemainingFour", "//", "FactorConstants"}]}], "Input",
 CellChangeTimes->{{3.7664245158749332`*^9, 3.766424519370947*^9}}],

Cell[OutputFormData["\<\
-(w*(5 - 2*n - 6*w + 2*n*w + 4*w^2)*f*Hmc[] [L[a], U[a]])/(3*(-3 + n)) + 

   (w*(5 - 2*n - 6*w + 2*n*w + 4*w^2)*f*Hmc[] [L[a], \
L[b]]*Nvec[U[a]]*Nvec[U[b]])/(3*(-3 + n)) + 

   (w*(5 - 2*n - 6*w + 2*n*w + 4*w^2)*f*Hmc[] [L[b]]*Nvec[U[a]] \
[L[a]]*Nvec[U[b]])/(3*(-3 + n))\
\>", "\<\
                                2                                             \
 2
-(w (5 - 2 n - 6 w + 2 n w + 4 w ))         a    w (5 - 2 n - 6 w + 2 n w + 4 \
w )                a      b 
----------------------------------- f Hmc      + \
-------------------------------- f Hmc      Nvec   Nvec   + 
            3 (-3 + n)                   ;a                 3 (-3 + n)        \
         ;a b 
 
                                2
  w (5 - 2 n - 6 w + 2 n w + 4 w )              a         b 
  -------------------------------- f Hmc    Nvec      Nvec
             3 (-3 + n)                 ;b        ;a\
\>"], "Output",
 CellChangeTimes->{3.520888130333918*^9, 3.5209895135917177`*^9, 
  3.521135567730255*^9, 3.530046094185258*^9, 3.530650638927654*^9, 
  3.570215740196363*^9, 3.5707380788470373`*^9, 3.5707387825401154`*^9, 
  3.570994774168239*^9, 3.760042196213915*^9, 3.7645794368263597`*^9, 
  3.7660030499991302`*^9, 3.766424521124037*^9, 3.766425637878172*^9}]
}, Open  ]],

Cell["Construct the remaining terms from the third part.", "Text",
 CellChangeTimes->{{3.760042240018968*^9, 3.76004225325898*^9}},
 Background->RGBColor[1, 0.9, 1]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"RemainingFive", "=", 
   RowBox[{"(", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], " ", "+", " ", "w"}], ")"}], "*", "w", "*", 
          "f", "*", 
          RowBox[{"Hmc", "^", "3"}]}], ")"}], "/", "2"}], ")"}]}], " ", "+", 
     " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"w", "*", 
        RowBox[{"(", 
         RowBox[{"9", " ", "+", " ", 
          RowBox[{"2", "*", "n"}], " ", "-", " ", 
          RowBox[{"2", "*", 
           RowBox[{"n", "^", "2"}]}], " ", "-", " ", 
          RowBox[{"6", "*", "n", "*", "w"}], " ", "+", " ", 
          RowBox[{"2", "*", 
           RowBox[{"n", "^", "2"}], "*", "w"}], " ", "+", " ", 
          RowBox[{"4", "*", "n", "*", 
           RowBox[{"w", "^", "2"}]}]}], ")"}], "*", "f", "*", "Hmc", "*", 
        RowBox[{"Nvec", "[", 
         RowBox[{"U", "[", "a", "]"}], "]"}], "*", 
        RowBox[{"Nvec", "[", 
         RowBox[{"U", "[", "b", "]"}], "]"}], "*", 
        RowBox[{"P", "[", 
         RowBox[{
          RowBox[{"L", "[", "a", "]"}], ",", " ", 
          RowBox[{"L", "[", "b", "]"}]}], "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"3", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], " ", "+", " ", "n"}], ")"}]}], ")"}]}], " ", 
     "+", " ", "\n", "  ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"w", "*", 
        RowBox[{"(", 
         RowBox[{"5", " ", "-", " ", 
          RowBox[{"2", "*", "n"}], " ", "-", " ", 
          RowBox[{"6", "*", "w"}], " ", "+", " ", 
          RowBox[{"2", "*", "n", "*", "w"}], " ", "+", " ", 
          RowBox[{"4", "*", 
           RowBox[{"w", "^", "2"}]}]}], ")"}], "*", "f", "*", 
        RowBox[{"Nvec", "[", 
         RowBox[{"U", "[", "a", "]"}], "]"}], "*", 
        RowBox[{"Nvec", "[", 
         RowBox[{"U", "[", "b", "]"}], "]"}], "*", 
        RowBox[{"Nvec", "[", 
         RowBox[{"U", "[", "c", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"P", "[", 
          RowBox[{
           RowBox[{"L", "[", "a", "]"}], ",", " ", 
           RowBox[{"L", "[", "b", "]"}]}], "]"}], "[", 
         RowBox[{"L", "[", "c", "]"}], "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"3", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], " ", "+", " ", "n"}], ")"}]}], ")"}]}], " ", 
     "-", " ", "\n", "  ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"w", "*", 
        RowBox[{"(", 
         RowBox[{"5", " ", "-", " ", 
          RowBox[{"2", "*", "n"}], " ", "-", " ", 
          RowBox[{"6", "*", "w"}], " ", "+", " ", 
          RowBox[{"2", "*", "n", "*", "w"}], " ", "+", " ", 
          RowBox[{"4", "*", 
           RowBox[{"w", "^", "2"}]}]}], ")"}], "*", "f", "*", "Hmc", "*", 
        RowBox[{"P", "[", 
         RowBox[{
          RowBox[{"L", "[", "a", "]"}], ",", " ", 
          RowBox[{"U", "[", "a", "]"}]}], "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"3", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], " ", "+", " ", "n"}], ")"}]}], ")"}]}], " ", 
     "-", " ", "\n", "  ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"w", "*", 
        RowBox[{"(", 
         RowBox[{"5", " ", "-", " ", 
          RowBox[{"2", "*", "n"}], " ", "-", " ", 
          RowBox[{"6", "*", "w"}], " ", "+", " ", 
          RowBox[{"2", "*", "n", "*", "w"}], " ", "+", " ", 
          RowBox[{"4", "*", 
           RowBox[{"w", "^", "2"}]}]}], ")"}], "*", "f", "*", 
        RowBox[{"Nvec", "[", 
         RowBox[{"U", "[", "a", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"P", "[", 
          RowBox[{
           RowBox[{"L", "[", "b", "]"}], ",", " ", 
           RowBox[{"U", "[", "b", "]"}]}], "]"}], "[", 
         RowBox[{"L", "[", "a", "]"}], "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"3", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], " ", "+", " ", "n"}], ")"}]}], ")"}]}], " ", 
     "-", " ", "\n", "  ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", "*", "w", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "4"}], " ", "+", " ", "n", " ", "+", " ", 
          RowBox[{"2", "*", "w"}]}], ")"}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], " ", "+", " ", "n", " ", "+", " ", 
          RowBox[{"2", "*", "w"}]}], ")"}], "*", "f", "*", 
        RowBox[{"P", "[", 
         RowBox[{
          RowBox[{"L", "[", "a", "]"}], ",", " ", 
          RowBox[{"L", "[", "b", "]"}]}], "]"}], "*", 
        RowBox[{"TfSFF", "[", 
         RowBox[{
          RowBox[{"U", "[", "a", "]"}], ",", " ", 
          RowBox[{"U", "[", "b", "]"}]}], "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"3", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], " ", "+", " ", "n"}], ")"}]}], ")"}]}], " ", 
     "-", " ", "\n", "  ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"w", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "31"}], " ", "+", " ", 
          RowBox[{"33", "*", "n"}], " ", "-", " ", 
          RowBox[{"8", "*", 
           RowBox[{"n", "^", "2"}]}], " ", "+", " ", 
          RowBox[{"48", "*", "w"}], " ", "-", " ", 
          RowBox[{"40", "*", "n", "*", "w"}], " ", "+", " ", 
          RowBox[{"8", "*", 
           RowBox[{"n", "^", "2"}], "*", "w"}], " ", "-", " ", 
          RowBox[{"32", "*", 
           RowBox[{"w", "^", "2"}]}], " ", "+", " ", 
          RowBox[{"16", "*", "n", "*", 
           RowBox[{"w", "^", "2"}]}]}], ")"}], "*", "f", "*", "Hmc", "*", 
        RowBox[{"TfSFF", "[", 
         RowBox[{
          RowBox[{"L", "[", "a", "]"}], ",", " ", 
          RowBox[{"L", "[", "b", "]"}]}], "]"}], "*", 
        RowBox[{"TfSFF", "[", 
         RowBox[{
          RowBox[{"U", "[", "a", "]"}], ",", " ", 
          RowBox[{"U", "[", "b", "]"}]}], "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"12", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], " ", "+", " ", "n"}], ")"}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], " ", "+", " ", "n"}], ")"}]}], ")"}]}], " ", 
     "+", " ", "\n", "  ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", " ", "+", " ", 
          RowBox[{"2", "*", "w"}]}], ")"}], "*", 
        RowBox[{"(", 
         RowBox[{"9", " ", "-", " ", 
          RowBox[{"3", "*", "n"}], " ", "-", " ", 
          RowBox[{"8", "*", "w"}], " ", "+", " ", 
          RowBox[{"2", "*", "n", "*", "w"}], " ", "+", " ", 
          RowBox[{"4", "*", 
           RowBox[{"w", "^", "2"}]}]}], ")"}], "*", "f", "*", 
        RowBox[{"TfSFF", "[", 
         RowBox[{
          RowBox[{"L", "[", "a", "]"}], ",", " ", 
          RowBox[{"L", "[", "b", "]"}]}], "]"}], "*", 
        RowBox[{"TfSFF", "[", 
         RowBox[{
          RowBox[{"U", "[", "a", "]"}], ",", " ", 
          RowBox[{"L", "[", "c", "]"}]}], "]"}], "*", 
        RowBox[{"TfSFF", "[", 
         RowBox[{
          RowBox[{"U", "[", "b", "]"}], ",", " ", 
          RowBox[{"U", "[", "c", "]"}]}], "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"6", "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "3"}], " ", "+", " ", "n"}], ")"}], "^", "2"}]}], 
       ")"}]}], " ", "+", " ", "\n", "  ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", " ", "+", " ", 
          RowBox[{"2", "*", "w"}]}], ")"}], "*", 
        RowBox[{"(", 
         RowBox[{"9", " ", "-", " ", 
          RowBox[{"3", "*", "n"}], " ", "-", " ", 
          RowBox[{"8", "*", "w"}], " ", "+", " ", 
          RowBox[{"2", "*", "n", "*", "w"}], " ", "+", " ", 
          RowBox[{"4", "*", 
           RowBox[{"w", "^", "2"}]}]}], ")"}], "*", "f", "*", 
        RowBox[{"Nvec", "[", 
         RowBox[{"U", "[", "a", "]"}], "]"}], "*", 
        RowBox[{"Nvec", "[", 
         RowBox[{"U", "[", "b", "]"}], "]"}], "*", 
        RowBox[{"TfSFF", "[", 
         RowBox[{
          RowBox[{"L", "[", "c", "]"}], ",", " ", 
          RowBox[{"L", "[", "d", "]"}]}], "]"}], "*", 
        RowBox[{"Weyl", "[", 
         RowBox[{
          RowBox[{"L", "[", "a", "]"}], ",", " ", 
          RowBox[{"U", "[", "c", "]"}], ",", " ", 
          RowBox[{"L", "[", "b", "]"}], ",", " ", 
          RowBox[{"U", "[", "d", "]"}]}], "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"6", "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "3"}], " ", "+", " ", "n"}], ")"}], "^", "2"}]}], 
       ")"}]}]}], ")"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"RemainingFive", "//", "FactorConstants"}]}], "Input",
 CellChangeTimes->{
  3.520888778219823*^9, 3.520888812937994*^9, {3.520889060000094*^9, 
   3.520889075335737*^9}, {3.5209900026233473`*^9, 3.520990007447711*^9}}],

Cell[OutputFormData["\<\
-((-1 + w)*w*f*Hmc^3)/2 + (w*(9 + 2*n - 2*n^2 - 6*n*w + 2*n^2*w + \
4*n*w^2)*f*Hmc*Nvec[U[a]]*Nvec[U[b]]*

     P[L[a], L[b]])/(3*(-3 + n)) + (w*(5 - 2*n - 6*w + 2*n*w + \
4*w^2)*f*Nvec[U[a]]*Nvec[U[b]]*Nvec[U[c]]*

     P[L[a], L[b]] [L[c]])/(3*(-3 + n)) - (w*(5 - 2*n - 6*w + 2*n*w + \
4*w^2)*f*Hmc*P[L[a], U[a]])/

    (3*(-3 + n)) - (w*(5 - 2*n - 6*w + 2*n*w + 4*w^2)*f*Nvec[U[a]]*P[L[b], \
U[b]] [L[a]])/(3*(-3 + n)) - 

   (2*w*(-4 + n + 2*w)*(-2 + n + 2*w)*f*P[L[a], L[b]]*TfSFF[U[a], \
U[b]])/(3*(-3 + n)) - 

   (w*(-31 + 33*n - 8*n^2 + 48*w - 40*n*w + 8*n^2*w - 32*w^2 + \
16*n*w^2)*f*Hmc*TfSFF[L[a], L[b]]*

     TfSFF[U[a], U[b]])/(12*(-3 + n)*(-2 + n)) + ((1 + 2*w)*(9 - 3*n - 8*w + \
2*n*w + 4*w^2)*f*TfSFF[L[a], \\
L[b]]*
   TfSFF[U[a], L[c]]*TfSFF[U[b], U[c]])/(6*(-3 + n)^2) + 

   ((1 + 2*w)*(9 - 3*n - 8*w + 2*n*w + \
4*w^2)*f*Nvec[U[a]]*Nvec[U[b]]*TfSFF[L[c], L[d]]*

     Weyl[L[a], U[c], L[b], U[d]])/(6*(-3 + n)^2)\
\>", "\<\
                                       2              2          2
-((-1 + w) w)      3   w (9 + 2 n - 2 n  - 6 n w + 2 n  w + 4 n w )           \
a      b 
------------- f Hmc  + -------------------------------------------- f Hmc \
Nvec   Nvec   P     + 
      2                                 3 (-3 + n)                            \
           a b 
 
                                2
  w (5 - 2 n - 6 w + 2 n w + 4 w )       a      b      c 
  -------------------------------- f Nvec   Nvec   Nvec   P        - 
             3 (-3 + n)                                    a b ;c 
 
                                2                                             \
 2
  w (5 - 2 n - 6 w + 2 n w + 4 w )          a    w (5 - 2 n - 6 w + 2 n w + 4 \
w )       a     b 
  -------------------------------- f Hmc P     - \
-------------------------------- f Nvec   P        - 
             3 (-3 + n)                   a                 3 (-3 + n)        \
              b   ;a 
 
  2 w (-4 + n + 2 w) (-2 + n + 2 w)              a b 
  --------------------------------- f P     TfSFF     - 
             3 (-3 + n)                a b 
 
                     2                      2         2         2
  w (-31 + 33 n - 8 n  + 48 w - 40 n w + 8 n  w - 32 w  + 16 n w )            \
          a b 
  ---------------------------------------------------------------- f Hmc \
TfSFF     TfSFF     + 
                        12 (-3 + n) (-2 + n)                                  \
a b 
 
                                        2
  (1 + 2 w) (9 - 3 n - 8 w + 2 n w + 4 w )                  a         b c 
  ---------------------------------------- f TfSFF     TfSFF     TfSFF     + 
                          2                       a b         c 
                6 (-3 + n)
 
                                        2
  (1 + 2 w) (9 - 3 n - 8 w + 2 n w + 4 w )       a      b                  c  \
 d 
  ---------------------------------------- f Nvec   Nvec   TfSFF     Weyl
                          2                                     c d      a   b 
                6 (-3 + n)\
\>"], "Output",
 CellChangeTimes->{
  3.520889076520504*^9, {3.520989870755259*^9, 3.520989891497218*^9}, 
   3.520989929596809*^9, 3.5209900086653337`*^9, 3.521135783600951*^9, 
   3.530046249670725*^9, 3.530650668157002*^9, 3.570215765748877*^9, 
   3.5707382328926287`*^9, 3.570738786989174*^9, 3.570994853763165*^9, 
   3.760042383106408*^9, 3.764579439578683*^9, 3.766003052589929*^9, 
   3.7664245583767776`*^9, 3.766425642469638*^9}]
}, Open  ]],

Cell["Construct linear combination.", "Text",
 CellChangeTimes->{{3.76004276624114*^9, 3.7600427695526037`*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[BoxData[
 RowBox[{
  RowBox[{"BigLinearCombination", "=", 
   RowBox[{"(", " ", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"n", "+", 
        RowBox[{"2", "w"}], "-", "5"}], ")"}], "DeltaBox"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"n", "+", 
        RowBox[{"2", "w"}], "-", "2"}], ")"}], 
      RowBox[{"(", 
       RowBox[{
       "BoxBarDeltaOne", "+", "BoxBarDeltaTwo", "+", "BoxBarDeltaThree", "+", 
        "BoxBarDeltaFour"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"n", "+", 
        RowBox[{"2", "w"}], "-", "2"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"n", "+", 
        RowBox[{"2", "w"}], "-", "5"}], ")"}], "*", 
      RowBox[{"(", 
       RowBox[{
       "RemainingOne", "+", "RemainingTwo", "+", "RemainingThree", "+", 
        "RemainingFour", "+", "RemainingFive"}], ")"}]}]}], 
    "\[IndentingNewLine]", ")"}]}], ";"}]], "Input"],

Cell[TextData[{
 "Read in previously computed formula for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Delta]", 
    RowBox[{"1", ",", "2"}]], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{{3.530048122936763*^9, 3.530048124726558*^9}, {
  3.7600429303548203`*^9, 3.7600429536190157`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"DeltaOneTwo", "=", 
   RowBox[{"<<", "~/bop/bnb/OThree.m"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.760040797467004*^9, {3.76004284889857*^9, 3.760042849681736*^9}}],

Cell["Do a check.", "Text",
 CellChangeTimes->{{3.760042891376368*^9, 3.760042897314685*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"OldDeltaOneTwo", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "w"}], ")"}], "*", 
      RowBox[{
       RowBox[{"f", "[", "]"}], "[", 
       RowBox[{
        RowBox[{"L", "[", "a", "]"}], ",", 
        RowBox[{"U", "[", "a", "]"}]}], "]"}], "*", "Hmc"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "w"}], ")"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "w"}], ")"}], "*", "w", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "n", "+", 
        RowBox[{"2", "*", "w"}]}], ")"}], "*", "f", "*", 
      RowBox[{"Hmc", "^", "3"}]}], "+", 
     RowBox[{"3", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "w"}], ")"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "w"}], ")"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "n", "+", 
        RowBox[{"2", "*", "w"}]}], ")"}], "*", 
      RowBox[{
       RowBox[{"f", "[", "]"}], "[", 
       RowBox[{"L", "[", "a", "]"}], "]"}], "*", 
      RowBox[{"Hmc", "^", "2"}], "*", 
      RowBox[{"Nvec", "[", 
       RowBox[{"U", "[", "a", "]"}], "]"}]}], "-", 
     RowBox[{"3", "*", 
      RowBox[{
       RowBox[{"f", "[", "]"}], "[", 
       RowBox[{
        RowBox[{"L", "[", "a", "]"}], ",", 
        RowBox[{"U", "[", "a", "]"}], ",", 
        RowBox[{"L", "[", "b", "]"}]}], "]"}], "*", 
      RowBox[{"Nvec", "[", 
       RowBox[{"U", "[", "b", "]"}], "]"}]}], "-", 
     RowBox[{"3", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "w"}], ")"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "n", "+", 
        RowBox[{"2", "*", "w"}]}], ")"}], "*", 
      RowBox[{
       RowBox[{"f", "[", "]"}], "[", 
       RowBox[{
        RowBox[{"L", "[", "a", "]"}], ",", 
        RowBox[{"L", "[", "b", "]"}]}], "]"}], "*", "Hmc", "*", 
      RowBox[{"Nvec", "[", 
       RowBox[{"U", "[", "a", "]"}], "]"}], "*", 
      RowBox[{"Nvec", "[", 
       RowBox[{"U", "[", "b", "]"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "n", "+", 
        RowBox[{"2", "*", "w"}]}], ")"}], "*", 
      RowBox[{
       RowBox[{"f", "[", "]"}], "[", 
       RowBox[{
        RowBox[{"L", "[", "a", "]"}], ",", 
        RowBox[{"L", "[", "b", "]"}], ",", 
        RowBox[{"L", "[", "c", "]"}]}], "]"}], "*", 
      RowBox[{"Nvec", "[", 
       RowBox[{"U", "[", "a", "]"}], "]"}], "*", 
      RowBox[{"Nvec", "[", 
       RowBox[{"U", "[", "b", "]"}], "]"}], "*", 
      RowBox[{"Nvec", "[", 
       RowBox[{"U", "[", "c", "]"}], "]"}]}], "-", 
     RowBox[{"3", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "w"}], ")"}], "*", "w", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "n", "+", 
        RowBox[{"2", "*", "w"}]}], ")"}], "*", "f", "*", "Hmc", "*", 
      RowBox[{"Nvec", "[", 
       RowBox[{"U", "[", "a", "]"}], "]"}], "*", 
      RowBox[{"Nvec", "[", 
       RowBox[{"U", "[", "b", "]"}], "]"}], "*", 
      RowBox[{"P", "[", 
       RowBox[{
        RowBox[{"L", "[", "a", "]"}], ",", 
        RowBox[{"L", "[", "b", "]"}]}], "]"}]}], "+", 
     RowBox[{"w", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "n", "+", 
        RowBox[{"2", "*", "w"}]}], ")"}], "*", "f", "*", 
      RowBox[{"Nvec", "[", 
       RowBox[{"U", "[", "a", "]"}], "]"}], "*", 
      RowBox[{"Nvec", "[", 
       RowBox[{"U", "[", "b", "]"}], "]"}], "*", 
      RowBox[{"Nvec", "[", 
       RowBox[{"U", "[", "c", "]"}], "]"}], "*", 
      RowBox[{
       RowBox[{"P", "[", 
        RowBox[{
         RowBox[{"L", "[", "a", "]"}], ",", 
         RowBox[{"L", "[", "b", "]"}]}], "]"}], "[", 
       RowBox[{"L", "[", "c", "]"}], "]"}]}], "+", 
     RowBox[{"3", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "w"}], ")"}], "*", "w", "*", "f", "*", "Hmc",
       "*", 
      RowBox[{"P", "[", 
       RowBox[{
        RowBox[{"L", "[", "a", "]"}], ",", 
        RowBox[{"U", "[", "a", "]"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "n", "+", 
        RowBox[{"2", "*", "w"}]}], ")"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        RowBox[{"3", "*", "w"}]}], ")"}], "*", 
      RowBox[{
       RowBox[{"f", "[", "]"}], "[", 
       RowBox[{"L", "[", "a", "]"}], "]"}], "*", 
      RowBox[{"Nvec", "[", 
       RowBox[{"U", "[", "a", "]"}], "]"}], "*", 
      RowBox[{"Nvec", "[", 
       RowBox[{"U", "[", "b", "]"}], "]"}], "*", 
      RowBox[{"Nvec", "[", 
       RowBox[{"U", "[", "c", "]"}], "]"}], "*", 
      RowBox[{"P", "[", 
       RowBox[{
        RowBox[{"L", "[", "b", "]"}], ",", 
        RowBox[{"L", "[", "c", "]"}]}], "]"}]}], "-", 
     RowBox[{"3", "*", "w", "*", 
      RowBox[{
       RowBox[{"f", "[", "]"}], "[", 
       RowBox[{"L", "[", "a", "]"}], "]"}], "*", 
      RowBox[{"Nvec", "[", 
       RowBox[{"U", "[", "a", "]"}], "]"}], "*", 
      RowBox[{"P", "[", 
       RowBox[{
        RowBox[{"L", "[", "b", "]"}], ",", 
        RowBox[{"U", "[", "b", "]"}]}], "]"}]}], "-", 
     RowBox[{"3", "*", "w", "*", "f", "*", 
      RowBox[{"Nvec", "[", 
       RowBox[{"U", "[", "a", "]"}], "]"}], "*", 
      RowBox[{
       RowBox[{"P", "[", 
        RowBox[{
         RowBox[{"L", "[", "b", "]"}], ",", 
         RowBox[{"U", "[", "b", "]"}]}], "]"}], "[", 
       RowBox[{"L", "[", "a", "]"}], "]"}]}], "-", 
     RowBox[{"2", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "n", "+", 
        RowBox[{"2", "*", "w"}]}], ")"}], "*", 
      RowBox[{
       RowBox[{"f", "[", "]"}], "[", 
       RowBox[{"L", "[", "a", "]"}], "]"}], "*", 
      RowBox[{"Nvec", "[", 
       RowBox[{"U", "[", "b", "]"}], "]"}], "*", 
      RowBox[{"P", "[", 
       RowBox[{
        RowBox[{"U", "[", "a", "]"}], ",", 
        RowBox[{"L", "[", "b", "]"}]}], "]"}]}]}], ")"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.45434449635793*^9, 3.4545430367274437`*^9, 3.454556515547328*^9, 
   3.454601450591053*^9, 3.454602743244317*^9, 3.454605908224308*^9, 
   3.454606299788273*^9, 3.454606980584207*^9, 3.4546082446802607`*^9, 
   3.454608671700367*^9, 3.4546895069716253`*^9, 3.4546916387860203`*^9, 
   3.454693288002071*^9, 3.4546956295462523`*^9, 3.4546989584881163`*^9, {
   3.760042870884219*^9, 3.76004287168379*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"OldDeltaOneTwo", "-", "DeltaOneTwo"}], "//", 
  "SuperSimplify"}]], "Input",
 CellChangeTimes->{{3.760042878362619*^9, 3.760042884242482*^9}}],

Cell[OutputFormData["\<\
0\
\>", "\<\
0\
\>"], "Output",
 CellChangeTimes->{3.520992350784531*^9, 3.52114078848906*^9, 
  3.530048140511944*^9, 3.5306514188903*^9, 3.570996389016005*^9, 
  3.764579448228828*^9, 3.7660030712342997`*^9, 3.766424932563416*^9, 
  3.766425650640826*^9}]
}, Open  ]],

Cell[TextData[{
 "The output from the above command should be zero.\n\nNow verify that our \
proposed linear combination is actually equivalent to the previously computed \
formula for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Delta]", 
    RowBox[{"1", ",", "2"}]], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{{3.760042909119412*^9, 3.760042920307851*^9}, {
  3.760043002883594*^9, 3.7600430593324823`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"DeltaOneTwo", "-", "BigLinearCombination"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"KoalaAA", "=", "Temp"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"KoalaAA", ";"}]}], "Input",
 CellChangeTimes->{{3.760043065340873*^9, 3.760043066220627*^9}}],

Cell[TextData[{
 "The expression ",
 StyleBox["KoalaAA", "Input"],
 " is supposed to be zero.  We will now perform some computations to show \
that this is in fact the case."
}], "Text",
 CellChangeTimes->{{3.760043089367321*^9, 3.7600431535391817`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", "KoalaAA"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"CommuteCovD", "[", 
    RowBox[{"Temp", ",", 
     RowBox[{"L", "[", "a", "]"}], ",", 
     RowBox[{"L", "[", "b", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"CommuteCovD", "[", 
    RowBox[{"Temp", ",", 
     RowBox[{"L", "[", "a", "]"}], ",", 
     RowBox[{"U", "[", "b", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"ToWeylRho", "[", "Temp", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"ToNbNvec", "[", "Temp", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"SuperSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"KoalaBB", "=", "Temp"}], ";"}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"OldTensor", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "4"}], "+", "n", "+", 
          RowBox[{"2", "*", "w"}]}], ")"}], "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", "n", "+", 
           RowBox[{"2", "*", "w"}]}], ")"}], "^", "2"}], "*", 
        RowBox[{
         RowBox[{"f", "[", "]"}], "[", 
         RowBox[{
          RowBox[{"L", "[", "a", "]"}], ",", 
          RowBox[{"L", "[", "b", "]"}]}], "]"}], "*", 
        RowBox[{
         RowBox[{"Nvec", "[", 
          RowBox[{"U", "[", "b", "]"}], "]"}], "[", 
         RowBox[{"U", "[", "a", "]"}], "]"}]}], ")"}], "/", "3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "4"}], "+", "n", "+", 
          RowBox[{"2", "*", "w"}]}], ")"}], "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", "n", "+", 
           RowBox[{"2", "*", "w"}]}], ")"}], "^", "2"}], "*", 
        RowBox[{
         RowBox[{"f", "[", "]"}], "[", 
         RowBox[{
          RowBox[{"L", "[", "a", "]"}], ",", 
          RowBox[{"L", "[", "b", "]"}]}], "]"}], "*", 
        RowBox[{"Nvec", "[", 
         RowBox[{"U", "[", "a", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Nvec", "[", 
          RowBox[{"U", "[", "b", "]"}], "]"}], "[", 
         RowBox[{"L", "[", "c", "]"}], "]"}], "*", 
        RowBox[{"Nvec", "[", 
         RowBox[{"U", "[", "c", "]"}], "]"}]}], ")"}], "/", "3"}]}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", "OldTensor"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"CommuteCovD", "[", 
    RowBox[{"Temp", ",", 
     RowBox[{"L", "[", "a", "]"}], ",", 
     RowBox[{"L", "[", "b", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NewTensor", "=", "Temp"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"KoalaCC", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"KoalaBB", "+", "NewTensor", "-", "OldTensor"}], "//", 
     "TensorSimplify"}], ")"}]}], ";"}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", "KoalaCC"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"CommuteCovD", "[", 
    RowBox[{"Temp", ",", 
     RowBox[{"L", "[", "b", "]"}], ",", 
     RowBox[{"U", "[", "a", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"ToWeylRho", "[", "Temp", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"SFFShuffle", "[", "Temp", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "PartsNvec"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"CommuteCovD", "[", 
    RowBox[{"Temp", ",", 
     RowBox[{"L", "[", "c", "]"}], ",", 
     RowBox[{"L", "[", "b", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"ToWeylRho", "[", "Temp", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "NvecRule"}], ")"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"(", 
    RowBox[{"Temp", "/.", "KWeylTr"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"KoalaDD", "=", "Temp"}], ";"}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", "KoalaDD"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"CommuteCovD", "[", 
    RowBox[{"Temp", ",", 
     RowBox[{"U", "[", "b", "]"}], ",", 
     RowBox[{"L", "[", "a", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"CommuteCovD", "[", 
    RowBox[{"Temp", ",", 
     RowBox[{"L", "[", "b", "]"}], ",", 
     RowBox[{"L", "[", "a", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"ToWeylRho", "[", "Temp", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"SuperSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"FactorConstants", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"KoalaEE", "=", "Temp"}], ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Temp", "=", "KoalaEE"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"SFFShuffle", "[", "Temp", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Temp", "=", 
   RowBox[{"TensorSimplify", "[", "Temp", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"KoalaFF", "=", "Temp"}], 
  ";"}], "\[IndentingNewLine]", "KoalaFF"}], "Input"],

Cell[OutputFormData["\<\
0\
\>", "\<\
0\
\>"], "Output",
 CellChangeTimes->{3.520992424538419*^9, 3.521140861758882*^9, 
  3.530048200431999*^9, 3.530651657930399*^9, 3.570996522115589*^9, 
  3.7600432693728323`*^9, 3.764579501992247*^9, 3.766003158003487*^9, 
  3.766424983075656*^9, 3.7664256695284452`*^9}]
}, Open  ]],

Cell["The output from the above command should be zero.", "Text",
 CellChangeTimes->{{3.7600432764169083`*^9, 3.760043305935232*^9}, {
  3.7600434285684147`*^9, 3.760043428808271*^9}}],

Cell["Set the default output format type.", "Text",
 CellChangeTimes->{{3.765879093989146*^9, 3.765879105330894*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[TextData[{
 "To obtain graphical output in future ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " work sessions, you will probably need to set the default output format \
type to either \[OpenCurlyDoubleQuote]",
 StyleBox["TraditionalForm", "Input"],
 "\[CloseCurlyDoubleQuote] or \[OpenCurlyDoubleQuote]",
 StyleBox["StandardForm", "Input"],
 ".\[CloseCurlyDoubleQuote]  Commands for doing this appear below.  I have \
also included a command which sets the default output format type to \
\[OpenCurlyDoubleQuote]",
 StyleBox["InputForm", "Input"],
 ",\[CloseCurlyDoubleQuote] but this default output format type will probably \
produce undesirable results.  If you are about to end the current ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " work session, I would suggest that you run the second or third of the \
three commands that follow below."
}], "Text",
 CellChangeTimes->{{3.765875392064986*^9, 3.765875400456007*^9}, {
   3.76587834324405*^9, 3.765878394132082*^9}, {3.765878426413321*^9, 
   3.765878445061092*^9}, {3.765961193069166*^9, 3.765961194076791*^9}, {
   3.7659663532701883`*^9, 3.765966465475971*^9}, {3.765966856155119*^9, 
   3.765966861099286*^9}, {3.765967018581056*^9, 3.765967086149837*^9}, {
   3.765967317464937*^9, 3.765967361792934*^9}, {3.765967508707835*^9, 
   3.765967542084031*^9}, {3.7659676087017612`*^9, 3.765967609572803*^9}, 
   3.765969161406293*^9, {3.7659703321643476`*^9, 3.7659703333552847`*^9}, {
   3.766425538959968*^9, 3.7664255390926123`*^9}}],

Cell[TextData[{
 "The following command sets the default output format type to \
\[OpenCurlyDoubleQuote]",
 StyleBox["InputForm", "Input"],
 ".\[CloseCurlyDoubleQuote]  This may produce undesirable results."
}], "Text",
 CellChangeTimes->{{3.765966621690692*^9, 3.765966665064301*^9}}],

Cell[BoxData[
 RowBox[{"<<", "~/bop/gen/dtm/definp.m"}]], "Input",
 CellChangeTimes->{{3.765966474501273*^9, 3.765966489902224*^9}}],

Cell[TextData[{
 "The following command sets the default output format type to \
\[OpenCurlyDoubleQuote]",
 StyleBox["TraditionalForm", "Input"],
 ".\[CloseCurlyDoubleQuote]"
}], "Text",
 CellChangeTimes->{{3.7659666838835278`*^9, 3.765966720265163*^9}, {
  3.766425674234264*^9, 3.766425675600432*^9}}],

Cell[BoxData[
 RowBox[{"<<", "~/bop/gen/dtm/deftra.m"}]], "Input",
 CellChangeTimes->{{3.765878480491482*^9, 3.765878494045458*^9}}],

Cell[TextData[{
 "The following command sets the default output format type to \
\[OpenCurlyDoubleQuote]Standard",
 StyleBox["Form", "Input"],
 ".\[CloseCurlyDoubleQuote]"
}], "Text",
 CellChangeTimes->{{3.7659666838835278`*^9, 3.7659667382811604`*^9}, {
  3.7664256780587*^9, 3.766425679368534*^9}}],

Cell[BoxData[
 RowBox[{"<<", "~/bop/gen/dtm/defstd.m"}]], "Input",
 CellChangeTimes->{{3.765878480491482*^9, 3.765878510741659*^9}}]
},
WindowSize->{1848, 1125},
WindowMargins->{{0, Automatic}, {18, Automatic}},
PrintingCopies->1,
PrintingPageRange->{1, 9999},
PrintingOptions->{"Magnification"->1.,
"PaperOrientation"->"Portrait",
"PaperSize"->{611.28, 789.57},
"PostScriptOutputFile"->"/home/lawrence_peterson/rsc/Rod/pfa/OutPfaff.ps"},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
Magnification->1.5,
FrontEndVersion->"11.0 for Linux x86 (64-bit) (September 21, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 1213, 35, 75, "Text"],
Cell[1761, 57, 1073, 23, 182, "Text"],
Cell[2837, 82, 243, 6, 73, "Text"],
Cell[3083, 90, 485, 13, 82, "Text"],
Cell[3571, 105, 149, 2, 73, "Text"],
Cell[3723, 109, 225, 5, 49, "Text"],
Cell[3951, 116, 84, 2, 48, "Input"],
Cell[4038, 120, 161, 2, 73, "Text"],
Cell[4202, 124, 616, 14, 49, "Text"],
Cell[CellGroupData[{
Cell[4843, 142, 249, 5, 48, "Input"],
Cell[5095, 149, 1913, 34, 126, "Output"]
}, Open  ]],
Cell[7023, 186, 182, 6, 49, "Text"],
Cell[CellGroupData[{
Cell[7230, 196, 101, 1, 48, "Input"],
Cell[7334, 199, 247, 6, 57, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7618, 210, 328, 5, 48, "Input"],
Cell[7949, 217, 512, 11, 160, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8498, 233, 1362, 30, 478, "Input"],
Cell[9863, 265, 1393, 22, 61, "Print"]
}, Open  ]],
Cell[11271, 290, 290, 11, 92, "Text"],
Cell[11564, 303, 165, 8, 49, "Text"],
Cell[CellGroupData[{
Cell[11754, 315, 526, 16, 181, "Input"],
Cell[12283, 333, 899, 17, 92, "Output"]
}, Open  ]],
Cell[13197, 353, 185, 4, 73, "Text"],
Cell[13385, 359, 590, 12, 114, "Text"],
Cell[CellGroupData[{
Cell[14000, 375, 153, 3, 48, "Input"],
Cell[14156, 380, 376, 5, 35, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14569, 390, 226, 7, 82, "Input"],
Cell[14798, 399, 444, 10, 74, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15279, 414, 61, 1, 48, "Input"],
Cell[15343, 417, 413, 9, 57, "Output"]
}, Open  ]],
Cell[15771, 429, 154, 2, 73, "Text"],
Cell[15928, 433, 303, 16, 68, "Text"],
Cell[16234, 451, 165, 8, 49, "Text"],
Cell[16402, 461, 1331, 43, 346, "Input"],
Cell[17736, 506, 159, 2, 73, "Text"],
Cell[17898, 510, 676, 32, 86, "Text"],
Cell[18577, 544, 165, 8, 49, "Text"],
Cell[CellGroupData[{
Cell[18767, 556, 2232, 73, 544, "Input"],
Cell[21002, 631, 482, 10, 111, "Print"]
}, Open  ]],
Cell[21499, 644, 155, 2, 73, "Text"],
Cell[21657, 648, 1239, 38, 110, "Text"],
Cell[22899, 688, 165, 8, 49, "Text"],
Cell[CellGroupData[{
Cell[23089, 700, 503, 15, 82, "Input"],
Cell[23595, 717, 521, 12, 92, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24153, 734, 919, 24, 148, "Input"],
Cell[25075, 760, 929, 18, 92, "Output"]
}, Open  ]],
Cell[26019, 781, 170, 2, 73, "Text"],
Cell[CellGroupData[{
Cell[26214, 787, 1911, 55, 148, "Input"],
Cell[28128, 844, 863, 18, 92, "Output"]
}, Open  ]],
Cell[29006, 865, 167, 2, 73, "Text"],
Cell[29176, 869, 157, 2, 73, "Text"],
Cell[CellGroupData[{
Cell[29358, 875, 1114, 33, 82, "Input"],
Cell[30475, 910, 677, 12, 92, "Output"]
}, Open  ]],
Cell[31167, 925, 153, 2, 73, "Text"],
Cell[31323, 929, 783, 32, 153, "Text"],
Cell[CellGroupData[{
Cell[32131, 965, 482, 14, 82, "Input"],
Cell[32616, 981, 538, 12, 109, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33191, 998, 1124, 37, 280, "Input"],
Cell[34318, 1037, 913, 18, 109, "Output"]
}, Open  ]],
Cell[35246, 1058, 162, 2, 73, "Text"],
Cell[CellGroupData[{
Cell[35433, 1064, 3002, 85, 214, "Input"],
Cell[38438, 1151, 1350, 30, 194, "Output"]
}, Open  ]],
Cell[39803, 1184, 171, 2, 73, "Text"],
Cell[39977, 1188, 814, 33, 166, "Text"],
Cell[CellGroupData[{
Cell[40816, 1225, 722, 22, 82, "Input"],
Cell[41541, 1249, 572, 12, 109, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42150, 1266, 839, 25, 214, "Input"],
Cell[42992, 1293, 1284, 27, 194, "Output"]
}, Open  ]],
Cell[44291, 1323, 165, 2, 73, "Text"],
Cell[CellGroupData[{
Cell[44481, 1329, 9032, 243, 445, "Input"],
Cell[53516, 1574, 3490, 82, 639, "Output"]
}, Open  ]],
Cell[57021, 1659, 144, 2, 73, "Text"],
Cell[57168, 1663, 1000, 30, 148, "Input"],
Cell[58171, 1695, 301, 9, 52, "Text"],
Cell[58475, 1706, 204, 5, 48, "Input"],
Cell[58682, 1713, 93, 1, 49, "Text"],
Cell[58778, 1716, 6605, 189, 313, "Input"],
Cell[CellGroupData[{
Cell[65408, 1909, 177, 4, 48, "Input"],
Cell[65588, 1915, 282, 8, 57, "Output"]
}, Open  ]],
Cell[65885, 1926, 426, 11, 117, "Text"],
Cell[66314, 1939, 466, 13, 148, "Input"],
Cell[66783, 1954, 254, 6, 49, "Text"],
Cell[67040, 1962, 1152, 34, 313, "Input"],
Cell[68195, 1998, 2391, 71, 247, "Input"],
Cell[70589, 2071, 1903, 59, 511, "Input"],
Cell[72495, 2132, 1043, 31, 280, "Input"],
Cell[CellGroupData[{
Cell[73563, 2167, 423, 12, 181, "Input"],
Cell[73989, 2181, 309, 8, 79, "Output"]
}, Open  ]],
Cell[74313, 2192, 184, 2, 49, "Text"],
Cell[74500, 2196, 149, 2, 73, "Text"],
Cell[74652, 2200, 1516, 28, 147, "Text"],
Cell[76171, 2230, 285, 6, 49, "Text"],
Cell[76459, 2238, 132, 2, 48, "Input"],
Cell[76594, 2242, 303, 7, 49, "Text"],
Cell[76900, 2251, 132, 2, 48, "Input"],
Cell[77035, 2255, 300, 7, 49, "Text"],
Cell[77338, 2264, 132, 2, 81, "Input"]
}
]
*)

